/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M7 20v-16", "key": "svg-0" }], ["path", { "d": "M17 4v16", "key": "svg-1" }], ["path", { "d": "M20 4h-16", "key": "svg-2" }]];
const IconMathPi = createReactComponent("outline", "math-pi", "MathPi", __iconNode);

export { __iconNode, IconMathPi as default };
//# sourceMappingURL=IconMathPi.mjs.map
