/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M4 9h8v-3.586a1 1 0 0 1 1.707 -.707l6.586 6.586a1 1 0 0 1 0 1.414l-6.586 6.586a1 1 0 0 1 -1.707 -.707v-3.586h-8a1 1 0 0 1 -1 -1v-4a1 1 0 0 1 1 -1", "key": "svg-0" }]];
const IconArrowBigRight = createReactComponent("outline", "arrow-big-right", "ArrowBigRight", __iconNode);

export { __iconNode, IconArrowBigRight as default };
//# sourceMappingURL=IconArrowBigRight.mjs.map
