/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M4 14l6 6h-6l0 -6", "key": "svg-0" }], ["path", { "d": "M20 10l-6 -6h6l0 6", "key": "svg-1" }], ["path", { "d": "M4 4v4l12 12h4v-4l-12 -12l-4 0", "key": "svg-2" }]];
const IconBrandAppleNews = createReactComponent("outline", "brand-apple-news", "BrandAppleNews", __iconNode);

export { __iconNode, IconBrandAppleNews as default };
//# sourceMappingURL=IconBrandAppleNews.mjs.map
