/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M20 12v-6a2 2 0 0 0 -2 -2h-12a2 2 0 0 0 -2 2v8", "key": "svg-0" }], ["path", { "d": "M4 18h17", "key": "svg-1" }], ["path", { "d": "M18 15l3 3l-3 3", "key": "svg-2" }]];
const IconArrowAutofitRight = createReactComponent("outline", "arrow-autofit-right", "ArrowAutofitRight", __iconNode);

export { __iconNode, IconArrowAutofitRight as default };
//# sourceMappingURL=IconArrowAutofitRight.mjs.map
