/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M6 20v-10l10 6v-12", "key": "svg-0" }], ["path", { "d": "M13 7l3 -3l3 3", "key": "svg-1" }]];
const IconArrowZigZag = createReactComponent("outline", "arrow-zig-zag", "ArrowZigZag", __iconNode);

export { __iconNode, IconArrowZigZag as default };
//# sourceMappingURL=IconArrowZigZag.mjs.map
