/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M13 20l-3 -8l3 -8", "key": "svg-0" }]];
const IconChevronCompactLeft = createReactComponent("outline", "chevron-compact-left", "ChevronCompactLeft", __iconNode);

export { __iconNode, IconChevronCompactLeft as default };
//# sourceMappingURL=IconChevronCompactLeft.mjs.map
