/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M12 3l3 6l6 3l-6 3l-3 6l-3 -6l-6 -3l6 -3l3 -6", "key": "svg-0" }]];
const IconFlare = createReactComponent("outline", "flare", "Flare", __iconNode);

export { __iconNode, IconFlare as default };
//# sourceMappingURL=IconFlare.mjs.map
