/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M11.5 12a.5 .5 0 1 0 1 0a.5 .5 0 1 0 -1 0", "fill": "currentColor", "key": "svg-0" }], ["path", { "d": "M3 12a9 9 0 1 0 18 0a9 9 0 1 0 -18 0", "key": "svg-1" }]];
const IconFocus = createReactComponent("outline", "focus", "Focus", __iconNode);

export { __iconNode, IconFocus as default };
//# sourceMappingURL=IconFocus.mjs.map
