/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 7q 4.5 -3 9 0t 9 0", "key": "svg-0" }], ["path", { "d": "M3 17q 4.5 -3 9 0q .213 .142 .427 .27", "key": "svg-1" }], ["path", { "d": "M3 12q 4.5 -3 9 0q 2.006 1.338 4.012 1.482", "key": "svg-2" }], ["path", { "d": "M19 16v6", "key": "svg-3" }], ["path", { "d": "M22 19l-3 3l-3 -3", "key": "svg-4" }]];
const IconRippleDown = createReactComponent("outline", "ripple-down", "RippleDown", __iconNode);

export { __iconNode, IconRippleDown as default };
//# sourceMappingURL=IconRippleDown.mjs.map
