/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M1.5 19l18 -18", "key": "svg-0" }], ["path", { "d": "M4.5 22l18 -18", "key": "svg-1" }], ["path", { "d": "M18 15l3 4", "key": "svg-2" }], ["path", { "d": "M23 15l-4.5 8", "key": "svg-3" }], ["path", { "d": "M1 1l6 6", "key": "svg-4" }], ["path", { "d": "M1 7l6 -6", "key": "svg-5" }]];
const IconMathXFloorDivideY = createReactComponent("outline", "math-x-floor-divide-y", "MathXFloorDivideY", __iconNode);

export { __iconNode, IconMathXFloorDivideY as default };
//# sourceMappingURL=IconMathXFloorDivideY.mjs.map
