/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M7 3h10v4h-10l0 -4", "key": "svg-0" }], ["path", { "d": "M12 7v4", "key": "svg-1" }], ["path", { "d": "M12 11a2 2 0 0 1 2 2v6a2 2 0 1 1 -4 0v-6a2 2 0 0 1 2 -2", "key": "svg-2" }]];
const IconRazor = createReactComponent("outline", "razor", "Razor", __iconNode);

export { __iconNode, IconRazor as default };
//# sourceMappingURL=IconRazor.mjs.map
