/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M4 11h5v4h6v-4h5v9h-16v-9", "key": "svg-0" }], ["path", { "d": "M9 4h6v4h-6l0 -4", "key": "svg-1" }]];
const IconBrandUnsplash = createReactComponent("outline", "brand-unsplash", "BrandUnsplash", __iconNode);

export { __iconNode, IconBrandUnsplash as default };
//# sourceMappingURL=IconBrandUnsplash.mjs.map
