/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M18 3a3 3 0 0 1 2.995 2.824l.005 .176v12a3 3 0 0 1 -2.824 2.995l-.176 .005h-12a3 3 0 0 1 -2.995 -2.824l-.005 -.176v-12a3 3 0 0 1 2.824 -2.995l.176 -.005h12zm1 6h-14v9a1 1 0 0 0 .883 .993l.117 .007h12a1 1 0 0 0 .993 -.883l.007 -.117v-9z", "key": "svg-0" }]];
const IconLayoutNavbarFilled = createReactComponent("filled", "layout-navbar-filled", "LayoutNavbarFilled", __iconNode);

export { __iconNode, IconLayoutNavbarFilled as default };
//# sourceMappingURL=IconLayoutNavbarFilled.mjs.map
