/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M10 8v8h2a2 2 0 0 0 2 -2v-4a2 2 0 0 0 -2 -2h-2", "key": "svg-0" }]];
const IconLetterDSmall = createReactComponent("outline", "letter-d-small", "LetterDSmall", __iconNode);

export { __iconNode, IconLetterDSmall as default };
//# sourceMappingURL=IconLetterDSmall.mjs.map
