/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M2 12a2.5 2.5 0 1 0 5 0a2.5 2.5 0 1 0 -5 0", "key": "svg-0" }], ["path", { "d": "M19 12a1.5 1.5 0 1 0 3 0a1.5 1.5 0 1 0 -3 0", "key": "svg-1" }], ["path", { "d": "M11 12a2 2 0 1 0 4 0a2 2 0 1 0 -4 0", "key": "svg-2" }]];
const IconBrandMixpanel = createReactComponent("outline", "brand-mixpanel", "BrandMixpanel", __iconNode);

export { __iconNode, IconBrandMixpanel as default };
//# sourceMappingURL=IconBrandMixpanel.mjs.map
