/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M8 8h1v8", "key": "svg-0" }], ["path", { "d": "M14 10v4a2 2 0 1 0 4 0v-4a2 2 0 1 0 -4 0", "key": "svg-1" }]];
const IconNumber10Small = createReactComponent("outline", "number-10-small", "Number10Small", __iconNode);

export { __iconNode, IconNumber10Small as default };
//# sourceMappingURL=IconNumber10Small.mjs.map
