/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M5 14a5 5 0 1 0 10 0a5 5 0 1 0 -10 0", "key": "svg-0" }], ["path", { "d": "M19 5l-5.4 5.4", "key": "svg-1" }], ["path", { "d": "M19 5h-5", "key": "svg-2" }], ["path", { "d": "M19 5v5", "key": "svg-3" }]];
const IconGenderMale = createReactComponent("outline", "gender-male", "GenderMale", __iconNode);

export { __iconNode, IconGenderMale as default };
//# sourceMappingURL=IconGenderMale.mjs.map
