/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M15.876 11.403l-3.876 -8.403l-7.97 17.275c-.07 .2 -.017 .424 .135 .572c.15 .148 .374 .193 .57 .116l6.29 -2.132", "key": "svg-0" }], ["path", { "d": "M15 18a3 3 0 1 0 6 0a3 3 0 1 0 -6 0", "key": "svg-1" }], ["path", { "d": "M20.2 20.2l1.8 1.8", "key": "svg-2" }]];
const IconNavigationSearch = createReactComponent("outline", "navigation-search", "NavigationSearch", __iconNode);

export { __iconNode, IconNavigationSearch as default };
//# sourceMappingURL=IconNavigationSearch.mjs.map
