/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M9.928 3.629l2 5a1 1 0 0 1 -.414 1.228l-1.67 1.003a9.9 9.9 0 0 0 3.296 3.297l1.003 -1.671a1 1 0 0 1 1.228 -.414l5 2a1 1 0 0 1 .629 .928v4c0 1.657 -1.343 3 -3.06 2.998c-8.579 -.521 -15.418 -7.36 -15.94 -15.998a3 3 0 0 1 3 -3h4a1 1 0 0 1 .928 .629", "key": "svg-0" }], ["path", { "d": "M21.707 3.293a1 1 0 0 1 0 1.414l-4 4a1 1 0 0 1 -1.414 0l-2 -2a1 1 0 1 1 1.414 -1.414l1.293 1.293l3.293 -3.293a1 1 0 0 1 1.414 0", "key": "svg-1" }]];
const IconPhoneCheckFilled = createReactComponent("filled", "phone-check-filled", "PhoneCheckFilled", __iconNode);

export { __iconNode, IconPhoneCheckFilled as default };
//# sourceMappingURL=IconPhoneCheckFilled.mjs.map
