/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M6 7.5l-4 9.5h4l6 -15l-6 5.5", "key": "svg-0" }], ["path", { "d": "M22 20l-7 -15l-3 7l4 5l-8 3l14 0", "key": "svg-1" }]];
const IconBrandAzure = createReactComponent("outline", "brand-azure", "BrandAzure", __iconNode);

export { __iconNode, IconBrandAzure as default };
//# sourceMappingURL=IconBrandAzure.mjs.map
