/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M18 2a2 2 0 0 1 2 2v16a2 2 0 0 1 -2 2h-12a2 2 0 0 1 -2 -2v-16a2 2 0 0 1 2 -2z", "key": "svg-0" }]];
const IconColumns1Filled = createReactComponent("filled", "columns-1-filled", "Columns1Filled", __iconNode);

export { __iconNode, IconColumns1Filled as default };
//# sourceMappingURL=IconColumns1Filled.mjs.map
