/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M5.144 4.72c3.92 -3.695 10.093 -3.625 13.927 .209c3.905 3.905 3.905 10.237 0 14.142c-3.905 3.905 -10.237 3.905 -14.142 0c-3.905 -3.905 -3.905 -10.237 0 -14.142zm3.32 10.816a1 1 0 1 0 -1.414 1.414a7 7 0 0 0 9.9 0a1 1 0 0 0 -1.414 -1.414a5 5 0 0 1 -7.072 0z", "key": "svg-0" }]];
const IconInnerShadowBottomFilled = createReactComponent("filled", "inner-shadow-bottom-filled", "InnerShadowBottomFilled", __iconNode);

export { __iconNode, IconInnerShadowBottomFilled as default };
//# sourceMappingURL=IconInnerShadowBottomFilled.mjs.map
