/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M19.95 11a8 8 0 1 0 -.5 4m.5 5v-5h-5", "key": "svg-0" }]];
const IconRotate = createReactComponent("outline", "rotate", "Rotate", __iconNode);

export { __iconNode, IconRotate as default };
//# sourceMappingURL=IconRotate.mjs.map
