/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M8 16h.013", "key": "svg-0" }], ["path", { "d": "M12.01 16h.005", "key": "svg-1" }], ["path", { "d": "M16.015 16h.005", "key": "svg-2" }], ["path", { "d": "M16.015 12h.005", "key": "svg-3" }], ["path", { "d": "M8.01 12h.005", "key": "svg-4" }], ["path", { "d": "M12.01 12h.005", "key": "svg-5" }], ["path", { "d": "M16.02 8h.005", "key": "svg-6" }], ["path", { "d": "M8.015 8h.005", "key": "svg-7" }], ["path", { "d": "M12.015 8h.005", "key": "svg-8" }], ["path", { "d": "M7 4h-1a2 2 0 0 0 -2 2v12a2 2 0 0 0 2 2h1", "key": "svg-9" }], ["path", { "d": "M17 4h1a2 2 0 0 1 2 2v12a2 2 0 0 1 -2 2h-1", "key": "svg-10" }]];
const IconMatrix = createReactComponent("outline", "matrix", "Matrix", __iconNode);

export { __iconNode, IconMatrix as default };
//# sourceMappingURL=IconMatrix.mjs.map
