/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M6 7a4 4 0 0 1 4 -4h4a4 4 0 0 1 4 4v10a4 4 0 0 1 -4 4h-4a4 4 0 0 1 -4 -4l0 -10", "key": "svg-0" }], ["path", { "d": "M12 7l0 4", "key": "svg-1" }]];
const IconMouse = createReactComponent("outline", "mouse", "Mouse", __iconNode);

export { __iconNode, IconMouse as default };
//# sourceMappingURL=IconMouse.mjs.map
