/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M5 19v-6a8 8 0 0 1 8 -8h6", "key": "svg-0" }]];
const IconRadiusTopLeft = createReactComponent("outline", "radius-top-left", "RadiusTopLeft", __iconNode);

export { __iconNode, IconRadiusTopLeft as default };
//# sourceMappingURL=IconRadiusTopLeft.mjs.map
