/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M17 3.34a10 10 0 1 1 -15 8.66l.005 -.324a10 10 0 0 1 14.995 -8.336m-4.883 9.653a1 1 0 0 0 .883 -.993v-5a1 1 0 0 0 -2 0v4h-2.5a1 1 0 0 0 -.993 .883l-.007 .117a1 1 0 0 0 1 1h3.5z", "key": "svg-0" }]];
const IconClockHour9Filled = createReactComponent("filled", "clock-hour-9-filled", "ClockHour9Filled", __iconNode);

export { __iconNode, IconClockHour9Filled as default };
//# sourceMappingURL=IconClockHour9Filled.mjs.map
