/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M4 6l16 0", "key": "svg-0" }], ["path", { "d": "M10 12l10 0", "key": "svg-1" }], ["path", { "d": "M6 18l14 0", "key": "svg-2" }]];
const IconAlignRight = createReactComponent("outline", "align-right", "AlignRight", __iconNode);

export { __iconNode, IconAlignRight as default };
//# sourceMappingURL=IconAlignRight.mjs.map
