/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M4 5v14l12 -7l-12 -7", "key": "svg-0" }], ["path", { "d": "M20 5l0 14", "key": "svg-1" }]];
const IconPlayerSkipForward = createReactComponent("outline", "player-skip-forward", "PlayerSkipForward", __iconNode);

export { __iconNode, IconPlayerSkipForward as default };
//# sourceMappingURL=IconPlayerSkipForward.mjs.map
