/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M18.364 4.636a9 9 0 0 1 .203 12.519l-.203 .21l-4.243 4.242a3 3 0 0 1 -4.097 .135l-.144 -.135l-4.244 -4.243a9 9 0 0 1 12.728 -12.728zm-6.364 3.364a3 3 0 1 0 0 6a3 3 0 0 0 0 -6", "key": "svg-0" }]];
const IconMapPinFilled = createReactComponent("filled", "map-pin-filled", "MapPinFilled", __iconNode);

export { __iconNode, IconMapPinFilled as default };
//# sourceMappingURL=IconMapPinFilled.mjs.map
