/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M4 5l16 -2", "key": "svg-0" }], ["path", { "d": "M12 4v10", "key": "svg-1" }], ["path", { "d": "M6.894 8h10.306c2.45 3 2.45 9 -.2 12h-10.106c-2.544 -3 -2.544 -9 0 -12", "key": "svg-2" }], ["path", { "d": "M5 14h14", "key": "svg-3" }]];
const IconAerialLift = createReactComponent("outline", "aerial-lift", "AerialLift", __iconNode);

export { __iconNode, IconAerialLift as default };
//# sourceMappingURL=IconAerialLift.mjs.map
