/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 12h4.5l1.5 -6l4 12l2 -9l1.5 3h4.5", "key": "svg-0" }]];
const IconActivityHeartbeat = createReactComponent("outline", "activity-heartbeat", "ActivityHeartbeat", __iconNode);

export { __iconNode, IconActivityHeartbeat as default };
//# sourceMappingURL=IconActivityHeartbeat.mjs.map
