/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M10 8l2 5l2 -5", "key": "svg-0" }], ["path", { "d": "M12 16v-3", "key": "svg-1" }]];
const IconLetterYSmall = createReactComponent("outline", "letter-y-small", "LetterYSmall", __iconNode);

export { __iconNode, IconLetterYSmall as default };
//# sourceMappingURL=IconLetterYSmall.mjs.map
