/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M14 5.5a2.5 2.5 0 1 0 5 0a2.5 2.5 0 1 0 -5 0", "key": "svg-0" }], ["path", { "d": "M6 3h5v5h-5l0 -5", "key": "svg-1" }], ["path", { "d": "M11 11v10a5 5 0 0 1 -.217 -9.995l.217 -.005", "key": "svg-2" }]];
const IconBrandRadixUi = createReactComponent("outline", "brand-radix-ui", "BrandRadixUi", __iconNode);

export { __iconNode, IconBrandRadixUi as default };
//# sourceMappingURL=IconBrandRadixUi.mjs.map
