/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M10 13a3 3 0 1 0 6 0a3 3 0 1 0 -6 0", "key": "svg-0" }], ["path", { "d": "M13 16v5", "key": "svg-1" }], ["path", { "d": "M13 3v7", "key": "svg-2" }], ["path", { "d": "M9 7l4 -4l4 4", "key": "svg-3" }]];
const IconArrowRotaryStraight = createReactComponent("outline", "arrow-rotary-straight", "ArrowRotaryStraight", __iconNode);

export { __iconNode, IconArrowRotaryStraight as default };
//# sourceMappingURL=IconArrowRotaryStraight.mjs.map
