/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M5 21h3.5l2.5 -6l2.5 -1l2.5 7h4l1 -4.5l-2 -1l-7 -12l-6 -.5l1.5 4l2.5 .5l1 2.5l-7 8l1 3", "key": "svg-0" }]];
const IconBrandLinqpad = createReactComponent("outline", "brand-linqpad", "BrandLinqpad", __iconNode);

export { __iconNode, IconBrandLinqpad as default };
//# sourceMappingURL=IconBrandLinqpad.mjs.map
