/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M9 21h6v-10a1 1 0 0 0 -1 -1h-4a1 1 0 0 0 -1 1l0 10", "key": "svg-0" }], ["path", { "d": "M12 2l1.465 1.638a2 2 0 1 1 -3.015 .099l1.55 -1.737", "key": "svg-1" }]];
const IconCandle = createReactComponent("outline", "candle", "Candle", __iconNode);

export { __iconNode, IconCandle as default };
//# sourceMappingURL=IconCandle.mjs.map
