/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M18 3v8.707", "key": "svg-0" }], ["path", { "d": "M8 14l-4 -4l4 -4", "key": "svg-1" }], ["path", { "d": "M18 21c0 -6.075 -4.925 -11 -11 -11h-3", "key": "svg-2" }]];
const IconArrowRampLeft2 = createReactComponent("outline", "arrow-ramp-left-2", "ArrowRampLeft2", __iconNode);

export { __iconNode, IconArrowRampLeft2 as default };
//# sourceMappingURL=IconArrowRampLeft2.mjs.map
