/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M17 13v-6l-5 4l-5 -4v6l5 4l5 -4", "key": "svg-0" }]];
const IconArrowBadgeDown = createReactComponent("outline", "arrow-badge-down", "ArrowBadgeDown", __iconNode);

export { __iconNode, IconArrowBadgeDown as default };
//# sourceMappingURL=IconArrowBadgeDown.mjs.map
