/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M5 20l14 -8l-14 -8l0 16", "key": "svg-0" }], ["path", { "d": "M19 20l-14 -8l14 -8l0 16", "key": "svg-1" }]];
const IconBrandBackbone = createReactComponent("outline", "brand-backbone", "BrandBackbone", __iconNode);

export { __iconNode, IconBrandBackbone as default };
//# sourceMappingURL=IconBrandBackbone.mjs.map
