/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M21 14l-9 7l-9 -7l3 -11l3 7h6l3 -7l3 11", "key": "svg-0" }]];
const IconBrandGitlab = createReactComponent("outline", "brand-gitlab", "BrandGitlab", __iconNode);

export { __iconNode, IconBrandGitlab as default };
//# sourceMappingURL=IconBrandGitlab.mjs.map
