/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M4 13l8 -3l8 3", "key": "svg-0" }]];
const IconChevronCompactUp = createReactComponent("outline", "chevron-compact-up", "ChevronCompactUp", __iconNode);

export { __iconNode, IconChevronCompactUp as default };
//# sourceMappingURL=IconChevronCompactUp.mjs.map
