/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 11a2 2 0 1 0 4 0a2 2 0 1 0 -4 0", "key": "svg-0" }], ["path", { "d": "M10 13h11v-2a3 3 0 0 0 -3 -3h-8v5", "key": "svg-1" }], ["path", { "d": "M3 16h18", "key": "svg-2" }]];
const IconBedFlat = createReactComponent("outline", "bed-flat", "BedFlat", __iconNode);

export { __iconNode, IconBedFlat as default };
//# sourceMappingURL=IconBedFlat.mjs.map
