/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 14v-6h6", "key": "svg-0" }], ["path", { "d": "M3 8l9 9l9 -9", "key": "svg-1" }]];
const IconArrowElbowLeft = createReactComponent("outline", "arrow-elbow-left", "ArrowElbowLeft", __iconNode);

export { __iconNode, IconArrowElbowLeft as default };
//# sourceMappingURL=IconArrowElbowLeft.mjs.map
