/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M6 12a6 6 0 1 0 12 0a6 6 0 1 0 -12 0", "key": "svg-0" }], ["path", { "d": "M13 13l5 5", "key": "svg-1" }]];
const IconCurrencyQuetzal = createReactComponent("outline", "currency-quetzal", "CurrencyQuetzal", __iconNode);

export { __iconNode, IconCurrencyQuetzal as default };
//# sourceMappingURL=IconCurrencyQuetzal.mjs.map
