/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M16 10h4a2 2 0 0 1 0 4h-4l-4 7h-3l2 -7h-4l-2 2h-3l2 -4l-2 -4h3l2 2h4l-2 -7h3l4 7", "key": "svg-0" }]];
const IconPlane = createReactComponent("outline", "plane", "Plane", __iconNode);

export { __iconNode, IconPlane as default };
//# sourceMappingURL=IconPlane.mjs.map
