/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M10 10.105a1.105 1.105 0 0 1 1.105 -1.105h1.79a1.105 1.105 0 0 1 1.105 1.105v9.79a1.105 1.105 0 0 1 -1.105 1.105h-1.79a1.105 1.105 0 0 1 -1.105 -1.105l0 -9.79", "key": "svg-0" }], ["path", { "d": "M17 4.105a1.105 1.105 0 0 1 1.105 -1.105h1.79a1.105 1.105 0 0 1 1.105 1.105v15.79a1.105 1.105 0 0 1 -1.105 1.105h-1.79a1.105 1.105 0 0 1 -1.105 -1.105l0 -15.79", "key": "svg-1" }], ["path", { "d": "M3 19a2 2 0 1 0 4 0a2 2 0 1 0 -4 0", "key": "svg-2" }]];
const IconBrandGoogleAnalytics = createReactComponent("outline", "brand-google-analytics", "BrandGoogleAnalytics", __iconNode);

export { __iconNode, IconBrandGoogleAnalytics as default };
//# sourceMappingURL=IconBrandGoogleAnalytics.mjs.map
