/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M19.5 4a3.5 3.5 0 0 1 0 7h-1.086l-8.12 8.121a3 3 0 0 1 -1.924 .872l-.198 .007h-3.672a3.5 3.5 0 0 1 0 -7h2.084l8.123 -8.121a3 3 0 0 1 1.923 -.872l.198 -.007z", "key": "svg-0" }]];
const IconEscalatorFilled = createReactComponent("filled", "escalator-filled", "EscalatorFilled", __iconNode);

export { __iconNode, IconEscalatorFilled as default };
//# sourceMappingURL=IconEscalatorFilled.mjs.map
