/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M6 6h6a3 3 0 0 1 3 3v10l-4 -4m8 0l-4 4", "key": "svg-0" }]];
const IconCornerRightDown = createReactComponent("outline", "corner-right-down", "CornerRightDown", __iconNode);

export { __iconNode, IconCornerRightDown as default };
//# sourceMappingURL=IconCornerRightDown.mjs.map
