/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M6 8l2 2l4 -4l4 4l2 -2l-6 -6l-6 6", "key": "svg-0" }], ["path", { "d": "M6 16l2 -2l4 4l3.5 -3.5l2 2l-5.5 5.5l-6 -6", "key": "svg-1" }], ["path", { "d": "M20 10l2 2l-2 2l-2 -2l2 -2", "key": "svg-2" }], ["path", { "d": "M4 10l2 2l-2 2l-2 -2l2 -2", "key": "svg-3" }], ["path", { "d": "M12 10l2 2l-2 2l-2 -2l2 -2", "key": "svg-4" }]];
const IconBrandBinance = createReactComponent("outline", "brand-binance", "BrandBinance", __iconNode);

export { __iconNode, IconBrandBinance as default };
//# sourceMappingURL=IconBrandBinance.mjs.map
