/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M16 21l-4 -8l-4 8l4 -2l4 2", "key": "svg-0" }], ["path", { "d": "M10 9v-6l4 6v-6", "key": "svg-1" }]];
const IconNavigationNorth = createReactComponent("outline", "navigation-north", "NavigationNorth", __iconNode);

export { __iconNode, IconNavigationNorth as default };
//# sourceMappingURL=IconNavigationNorth.mjs.map
