/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3.262 10.878l8 8.789c.4 .44 1.091 .44 1.491 0l8 -8.79c.313 -.344 .349 -.859 .087 -1.243l-3.537 -5.194a1 1 0 0 0 -.823 -.436h-8.926a1 1 0 0 0 -.823 .436l-3.54 5.192c-.263 .385 -.227 .901 .087 1.246l-.016 0", "key": "svg-0" }]];
const IconBrandSketch = createReactComponent("outline", "brand-sketch", "BrandSketch", __iconNode);

export { __iconNode, IconBrandSketch as default };
//# sourceMappingURL=IconBrandSketch.mjs.map
