/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M16 16v2a2 2 0 0 1 -2 2h-8a2 2 0 0 1 -2 -2v-8a2 2 0 0 1 2 -2h2v-2a2 2 0 0 1 2 -2h8a2 2 0 0 1 2 2v8a2 2 0 0 1 -2 2h-2", "key": "svg-0" }]];
const IconLayersUnion = createReactComponent("outline", "layers-union", "LayersUnion", __iconNode);

export { __iconNode, IconLayersUnion as default };
//# sourceMappingURL=IconLayersUnion.mjs.map
