/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M5 3l4 1.5v12l6 -2.5l-2 -1l-1 -4l7 2.5v4.5l-10 5l-4 -2l0 -16", "key": "svg-0" }]];
const IconBrandBing = createReactComponent("outline", "brand-bing", "BrandBing", __iconNode);

export { __iconNode, IconBrandBing as default };
//# sourceMappingURL=IconBrandBing.mjs.map
