/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 21l18 -18", "key": "svg-0" }], ["path", { "d": "M4 12a8 8 0 1 0 16 0a8 8 0 1 0 -16 0", "key": "svg-1" }]];
const IconMathAvg = createReactComponent("outline", "math-avg", "MathAvg", __iconNode);

export { __iconNode, IconMathAvg as default };
//# sourceMappingURL=IconMathAvg.mjs.map
