/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M17 3.34a10 10 0 1 1 -15 8.66l.005 -.324a10 10 0 0 1 14.995 -8.336m-5 2.66a1 1 0 0 0 -1 1v5a1 1 0 0 0 1 1h3.5a1 1 0 0 0 0 -2h-2.5v-4a1 1 0 0 0 -.883 -.993z", "key": "svg-0" }]];
const IconClockHour3Filled = createReactComponent("filled", "clock-hour-3-filled", "ClockHour3Filled", __iconNode);

export { __iconNode, IconClockHour3Filled as default };
//# sourceMappingURL=IconClockHour3Filled.mjs.map
