/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M7 7l10 10", "key": "svg-0" }], ["path", { "d": "M16 7l-9 0l0 9", "key": "svg-1" }]];
const IconArrowUpLeft = createReactComponent("outline", "arrow-up-left", "ArrowUpLeft", __iconNode);

export { __iconNode, IconArrowUpLeft as default };
//# sourceMappingURL=IconArrowUpLeft.mjs.map
