/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M12 21a9 9 0 0 0 9 -9a9 9 0 0 0 -9 -9a9 9 0 0 0 -9 9a9 9 0 0 0 9 9", "key": "svg-0" }], ["path", { "d": "M8 9a1 1 0 0 1 1 -1h6a1 1 0 0 1 1 1v6a1 1 0 0 1 -1 1h-6a1 1 0 0 1 -1 -1l0 -6", "key": "svg-1" }]];
const IconPlaystationSquare = createReactComponent("outline", "playstation-square", "PlaystationSquare", __iconNode);

export { __iconNode, IconPlaystationSquare as default };
//# sourceMappingURL=IconPlaystationSquare.mjs.map
