/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M10 16h2a2 2 0 1 0 0 -4h-2h2a2 2 0 1 0 0 -4h-2v8", "key": "svg-0" }]];
const IconLetterBSmall = createReactComponent("outline", "letter-b-small", "LetterBSmall", __iconNode);

export { __iconNode, IconLetterBSmall as default };
//# sourceMappingURL=IconLetterBSmall.mjs.map
