/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M7 21a1 1 0 0 1 0 -2h1v-2h-4a2 2 0 0 1 -2 -2v-10a2 2 0 0 1 2 -2h16a2 2 0 0 1 2 2v10a2 2 0 0 1 -2 2h-4v2h1a1 1 0 0 1 0 2zm7 -4h-4v2h4z", "key": "svg-0" }]];
const IconDeviceDesktopFilled = createReactComponent("filled", "device-desktop-filled", "DeviceDesktopFilled", __iconNode);

export { __iconNode, IconDeviceDesktopFilled as default };
//# sourceMappingURL=IconDeviceDesktopFilled.mjs.map
