/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M15 4v8h3.586a1 1 0 0 1 .707 1.707l-6.586 6.586a1 1 0 0 1 -1.414 0l-6.586 -6.586a1 1 0 0 1 .707 -1.707h3.586v-8a1 1 0 0 1 1 -1h4a1 1 0 0 1 1 1", "key": "svg-0" }]];
const IconArrowBigDown = createReactComponent("outline", "arrow-big-down", "ArrowBigDown", __iconNode);

export { __iconNode, IconArrowBigDown as default };
//# sourceMappingURL=IconArrowBigDown.mjs.map
