/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M4 20v-5c0 -6.075 4.925 -11 11 -11h5", "key": "svg-0" }]];
const IconBorderCornerPill = createReactComponent("outline", "border-corner-pill", "BorderCornerPill", __iconNode);

export { __iconNode, IconBorderCornerPill as default };
//# sourceMappingURL=IconBorderCornerPill.mjs.map
