/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M4 20h16l-8 -16l-8 16", "key": "svg-0" }]];
const IconDelta = createReactComponent("outline", "delta", "Delta", __iconNode);

export { __iconNode, IconDelta as default };
//# sourceMappingURL=IconDelta.mjs.map
