/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M9 3h6l3 7l-6 2l-6 -2l3 -7", "key": "svg-0" }], ["path", { "d": "M12 12l-3 -9", "key": "svg-1" }], ["path", { "d": "M15 11l-3 -8", "key": "svg-2" }], ["path", { "d": "M12 19.5l-3 1.5l.5 -3.5l-2 -2l3 -.5l1.5 -3l1.5 3l3 .5l-2 2l.5 3.5l-3 -1.5", "key": "svg-3" }]];
const IconMedal2 = createReactComponent("outline", "medal-2", "Medal2", __iconNode);

export { __iconNode, IconMedal2 as default };
//# sourceMappingURL=IconMedal2.mjs.map
