/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M12 21a9 9 0 0 0 9 -9a9 9 0 0 0 -9 -9a9 9 0 0 0 -9 9a9 9 0 0 0 9 9", "key": "svg-0" }], ["path", { "d": "M8.5 8.5l7 7", "key": "svg-1" }], ["path", { "d": "M8.5 15.5l7 -7", "key": "svg-2" }]];
const IconPlaystationX = createReactComponent("outline", "playstation-x", "PlaystationX", __iconNode);

export { __iconNode, IconPlaystationX as default };
//# sourceMappingURL=IconPlaystationX.mjs.map
