/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M12 20h-7a2 2 0 0 1 -2 -2v-12a2 2 0 0 1 2 -2h14a2 2 0 0 1 2 2v9", "key": "svg-0" }], ["path", { "d": "M9 17h3.5", "key": "svg-1" }], ["path", { "d": "M16 19h6", "key": "svg-2" }]];
const IconDeviceIpadHorizontalMinus = createReactComponent("outline", "device-ipad-horizontal-minus", "DeviceIpadHorizontalMinus", __iconNode);

export { __iconNode, IconDeviceIpadHorizontalMinus as default };
//# sourceMappingURL=IconDeviceIpadHorizontalMinus.mjs.map
