/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M4 20v-10a6 6 0 0 1 6 -6h10", "key": "svg-0" }]];
const IconBorderCornerRounded = createReactComponent("outline", "border-corner-rounded", "BorderCornerRounded", __iconNode);

export { __iconNode, IconBorderCornerRounded as default };
//# sourceMappingURL=IconBorderCornerRounded.mjs.map
