/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M9.586 4l-6.586 6.586a2 2 0 0 0 0 2.828l6.586 6.586a2 2 0 0 0 2.18 .434l.145 -.068a2 2 0 0 0 1.089 -1.78v-2.586h7a2 2 0 0 0 2 -2v-4l-.005 -.15a2 2 0 0 0 -1.995 -1.85l-7 -.001v-2.585a2 2 0 0 0 -3.414 -1.414z", "key": "svg-0" }]];
const IconArrowBigLeftFilled = createReactComponent("filled", "arrow-big-left-filled", "ArrowBigLeftFilled", __iconNode);

export { __iconNode, IconArrowBigLeftFilled as default };
//# sourceMappingURL=IconArrowBigLeftFilled.mjs.map
