/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M13 3l0 7l6 0l-8 11l0 -7l-6 0l8 -11", "key": "svg-0" }]];
const IconBolt = createReactComponent("outline", "bolt", "Bolt", __iconNode);

export { __iconNode, IconBolt as default };
//# sourceMappingURL=IconBolt.mjs.map
