/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M17 4l0 16", "key": "svg-0" }], ["path", { "d": "M7 12l10 0", "key": "svg-1" }], ["path", { "d": "M7 4l0 16", "key": "svg-2" }]];
const IconLetterH = createReactComponent("outline", "letter-h", "LetterH", __iconNode);

export { __iconNode, IconLetterH as default };
//# sourceMappingURL=IconLetterH.mjs.map
