/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M5 13h14", "key": "svg-0" }], ["path", { "d": "M5 17h14", "key": "svg-1" }], ["path", { "d": "M5 7.686c2.333 -2.624 4.667 -1.856 7 .064s4.667 2.688 7 .064", "key": "svg-2" }]];
const IconCongruentTo = createReactComponent("outline", "congruent-to", "CongruentTo", __iconNode);

export { __iconNode, IconCongruentTo as default };
//# sourceMappingURL=IconCongruentTo.mjs.map
