/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M10 4v16l-6 -5.5", "key": "svg-0" }], ["path", { "d": "M14 20v-16l6 5.5", "key": "svg-1" }]];
const IconTransferVertical = createReactComponent("outline", "transfer-vertical", "TransferVertical", __iconNode);

export { __iconNode, IconTransferVertical as default };
//# sourceMappingURL=IconTransferVertical.mjs.map
