/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M19 19h-6a8 8 0 0 1 -8 -8v-6", "key": "svg-0" }]];
const IconRadiusBottomLeft = createReactComponent("outline", "radius-bottom-left", "RadiusBottomLeft", __iconNode);

export { __iconNode, IconRadiusBottomLeft as default };
//# sourceMappingURL=IconRadiusBottomLeft.mjs.map
