/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M5 12h14l-7 -8l-7 8", "key": "svg-0" }], ["path", { "d": "M5 17a1 1 0 0 1 1 -1h12a1 1 0 0 1 1 1v2a1 1 0 0 1 -1 1h-12a1 1 0 0 1 -1 -1l0 -2", "key": "svg-1" }]];
const IconPlayerEject = createReactComponent("outline", "player-eject", "PlayerEject", __iconNode);

export { __iconNode, IconPlayerEject as default };
//# sourceMappingURL=IconPlayerEject.mjs.map
