/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M7 7l10 10", "key": "svg-0" }], ["path", { "d": "M17 8l0 9l-9 0", "key": "svg-1" }]];
const IconArrowDownRight = createReactComponent("outline", "arrow-down-right", "ArrowDownRight", __iconNode);

export { __iconNode, IconArrowDownRight as default };
//# sourceMappingURL=IconArrowDownRight.mjs.map
