/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M19 18l-14 -6l14 -6", "key": "svg-0" }]];
const IconMathLower = createReactComponent("outline", "math-lower", "MathLower", __iconNode);

export { __iconNode, IconMathLower as default };
//# sourceMappingURL=IconMathLower.mjs.map
