/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M10 12h3", "key": "svg-0" }], ["path", { "d": "M14 8h-4v8", "key": "svg-1" }]];
const IconLetterFSmall = createReactComponent("outline", "letter-f-small", "LetterFSmall", __iconNode);

export { __iconNode, IconLetterFSmall as default };
//# sourceMappingURL=IconLetterFSmall.mjs.map
