/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 10v8l7 -3v-2.6l-7 -2.4", "key": "svg-0" }], ["path", { "d": "M3 6l9 3l9 -3l-9 -3l-9 3", "key": "svg-1" }], ["path", { "d": "M14 12.3v8.7l7 -3v-8l-7 2.3", "key": "svg-2" }]];
const IconBrandAirtable = createReactComponent("outline", "brand-airtable", "BrandAirtable", __iconNode);

export { __iconNode, IconBrandAirtable as default };
//# sourceMappingURL=IconBrandAirtable.mjs.map
