/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M17 18h-7a3 3 0 0 1 -3 -3v-10", "key": "svg-0" }]];
const IconCurrencyLeu = createReactComponent("outline", "currency-leu", "CurrencyLeu", __iconNode);

export { __iconNode, IconCurrencyLeu as default };
//# sourceMappingURL=IconCurrencyLeu.mjs.map
