/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M5.64 5.632a9 9 0 1 0 6.36 -2.632v7.714", "key": "svg-0" }]];
const IconBrandGravatar = createReactComponent("outline", "brand-gravatar", "BrandGravatar", __iconNode);

export { __iconNode, IconBrandGravatar as default };
//# sourceMappingURL=IconBrandGravatar.mjs.map
