/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M17 18v-12", "key": "svg-0" }], ["path", { "d": "M13 6l4 4l4 -4", "key": "svg-1" }], ["path", { "d": "M11 18l-7 -8l4 -4l4 4l-7 8", "key": "svg-2" }]];
const IconAlphabetRunes = createReactComponent("outline", "alphabet-runes", "AlphabetRunes", __iconNode);

export { __iconNode, IconAlphabetRunes as default };
//# sourceMappingURL=IconAlphabetRunes.mjs.map
