/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M19 22.5a4.75 4.75 0 0 1 3.5 -3.5a4.75 4.75 0 0 1 -3.5 -3.5a4.75 4.75 0 0 1 -3.5 3.5a4.75 4.75 0 0 1 3.5 3.5", "key": "svg-0" }], ["path", { "d": "M3 7a3 3 0 0 1 3 -3h12a3 3 0 0 1 3 3v2a3 3 0 0 1 -3 3h-12a3 3 0 0 1 -3 -3l0 -2", "key": "svg-1" }], ["path", { "d": "M12 20h-6a3 3 0 0 1 -3 -3v-2a3 3 0 0 1 3 -3h10.5", "key": "svg-2" }], ["path", { "d": "M7 8v.01", "key": "svg-3" }], ["path", { "d": "M7 16v.01", "key": "svg-4" }]];
const IconServerSpark = createReactComponent("outline", "server-spark", "ServerSpark", __iconNode);

export { __iconNode, IconServerSpark as default };
//# sourceMappingURL=IconServerSpark.mjs.map
