/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M17 17v-4l-5 3l-5 -3v4l5 3l5 -3", "key": "svg-0" }], ["path", { "d": "M17 8v-4l-5 3l-5 -3v4l5 3l5 -3", "key": "svg-1" }]];
const IconBadges = createReactComponent("outline", "badges", "Badges", __iconNode);

export { __iconNode, IconBadges as default };
//# sourceMappingURL=IconBadges.mjs.map
