/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M15 15l-3 -3l3 -3", "key": "svg-0" }], ["path", { "d": "M11 15l-3 -3l3 -3", "key": "svg-1" }], ["path", { "d": "M12 3c7.2 0 9 1.8 9 9c0 7.2 -1.8 9 -9 9c-7.2 0 -9 -1.8 -9 -9c0 -7.2 1.8 -9 9 -9", "key": "svg-2" }]];
const IconSquareRoundedChevronsLeft = createReactComponent("outline", "square-rounded-chevrons-left", "SquareRoundedChevronsLeft", __iconNode);

export { __iconNode, IconSquareRoundedChevronsLeft as default };
//# sourceMappingURL=IconSquareRoundedChevronsLeft.mjs.map
