/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M14 7v3h3l3 -3h-3v-3l-3 3", "key": "svg-0" }], ["path", { "d": "M14 10l-9 9", "key": "svg-1" }], ["path", { "d": "M5 15v4h4", "key": "svg-2" }]];
const IconArcheryArrow = createReactComponent("outline", "archery-arrow", "ArcheryArrow", __iconNode);

export { __iconNode, IconArcheryArrow as default };
//# sourceMappingURL=IconArcheryArrow.mjs.map
