/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M22 17c0 -5.523 -4.477 -10 -10 -10c-5.523 0 -10 4.477 -10 10", "key": "svg-0" }], ["path", { "d": "M18 17a6 6 0 1 0 -12 0", "key": "svg-1" }], ["path", { "d": "M14 17a2 2 0 1 0 -4 0", "key": "svg-2" }]];
const IconRainbow = createReactComponent("outline", "rainbow", "Rainbow", __iconNode);

export { __iconNode, IconRainbow as default };
//# sourceMappingURL=IconRainbow.mjs.map
