/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M10 10a2 2 0 1 0 4 0a2 2 0 1 0 -4 0", "key": "svg-0" }], ["path", { "d": "M7 5a2 2 0 0 1 2 -2h6a2 2 0 0 1 2 2v14a2 2 0 0 1 -2 2h-6a2 2 0 0 1 -2 -2l0 -14", "key": "svg-1" }], ["path", { "d": "M12 3v2", "key": "svg-2" }], ["path", { "d": "M10 15v.01", "key": "svg-3" }], ["path", { "d": "M10 18v.01", "key": "svg-4" }], ["path", { "d": "M14 18v.01", "key": "svg-5" }], ["path", { "d": "M14 15v.01", "key": "svg-6" }]];
const IconDeviceRemote = createReactComponent("outline", "device-remote", "DeviceRemote", __iconNode);

export { __iconNode, IconDeviceRemote as default };
//# sourceMappingURL=IconDeviceRemote.mjs.map
