/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M16 5v4a1 1 0 0 0 1 1h4", "key": "svg-0" }], ["path", { "d": "M3 7v10a2 2 0 0 0 2 2h14a2 2 0 0 0 2 -2v-7l-5 -5h-11a2 2 0 0 0 -2 2", "key": "svg-1" }]];
const IconFileHorizontal = createReactComponent("outline", "file-horizontal", "FileHorizontal", __iconNode);

export { __iconNode, IconFileHorizontal as default };
//# sourceMappingURL=IconFileHorizontal.mjs.map
