/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M7 9a5 5 0 1 0 10 0a5 5 0 1 0 -10 0", "key": "svg-0" }], ["path", { "d": "M12 14v7", "key": "svg-1" }], ["path", { "d": "M9 18h6", "key": "svg-2" }]];
const IconGenderFemale = createReactComponent("outline", "gender-female", "GenderFemale", __iconNode);

export { __iconNode, IconGenderFemale as default };
//# sourceMappingURL=IconGenderFemale.mjs.map
