/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M12.46 20.871c-.153 .046 -.306 .089 -.46 .129a12 12 0 0 1 -8.5 -15a12 12 0 0 0 8.5 -3a12 12 0 0 0 8.5 3a12 12 0 0 1 -.916 9.015", "key": "svg-0" }], ["path", { "d": "M16 19h6", "key": "svg-1" }]];
const IconShieldMinus = createReactComponent("outline", "shield-minus", "ShieldMinus", __iconNode);

export { __iconNode, IconShieldMinus as default };
//# sourceMappingURL=IconShieldMinus.mjs.map
