/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M12 13v-10", "key": "svg-0" }], ["path", { "d": "M12 21l-6 -8h12l-6 8", "key": "svg-1" }]];
const IconCircuitGroundDigital = createReactComponent("outline", "circuit-ground-digital", "CircuitGroundDigital", __iconNode);

export { __iconNode, IconCircuitGroundDigital as default };
//# sourceMappingURL=IconCircuitGroundDigital.mjs.map
