/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M14.5 14h4.5l2 -2v-6l-6.5 8", "key": "svg-0" }], ["path", { "d": "M9 19h5l-11 -13v6l6 7", "key": "svg-1" }]];
const IconBrandValorant = createReactComponent("outline", "brand-valorant", "BrandValorant", __iconNode);

export { __iconNode, IconBrandValorant as default };
//# sourceMappingURL=IconBrandValorant.mjs.map
