/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M9 18h6a6 6 0 0 0 6 -6v-5a1 1 0 0 0 -1 -1h-16a1 1 0 0 0 -1 1v5a6 6 0 0 0 6 6", "key": "svg-0" }]];
const IconRectangleRoundedBottom = createReactComponent("outline", "rectangle-rounded-bottom", "RectangleRoundedBottom", __iconNode);

export { __iconNode, IconRectangleRoundedBottom as default };
//# sourceMappingURL=IconRectangleRoundedBottom.mjs.map
