/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M6 5h12", "key": "svg-0" }], ["path", { "d": "M6 9h12", "key": "svg-1" }], ["path", { "d": "M12 9v10", "key": "svg-2" }]];
const IconCurrencyTenge = createReactComponent("outline", "currency-tenge", "CurrencyTenge", __iconNode);

export { __iconNode, IconCurrencyTenge as default };
//# sourceMappingURL=IconCurrencyTenge.mjs.map
