/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M16 4l4 0l0 4", "key": "svg-0" }], ["path", { "d": "M14 10l6 -6", "key": "svg-1" }], ["path", { "d": "M8 20l-4 0l0 -4", "key": "svg-2" }], ["path", { "d": "M4 20l6 -6", "key": "svg-3" }]];
const IconArrowsDiagonal = createReactComponent("outline", "arrows-diagonal", "ArrowsDiagonal", __iconNode);

export { __iconNode, IconArrowsDiagonal as default };
//# sourceMappingURL=IconArrowsDiagonal.mjs.map
