/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M8 22a1 1 0 0 1 0 -2h.616l.25 -2h-4.866a2 2 0 0 1 -2 -2v-12a2 2 0 0 1 2 -2h16a2 2 0 0 1 2 2v12a2 2 0 0 1 -2 2h-4.867l.25 2h.617a1 1 0 0 1 0 2zm5.116 -4h-2.233l-.25 2h2.733z", "key": "svg-0" }]];
const IconDeviceImacFilled = createReactComponent("filled", "device-imac-filled", "DeviceImacFilled", __iconNode);

export { __iconNode, IconDeviceImacFilled as default };
//# sourceMappingURL=IconDeviceImacFilled.mjs.map
