/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["g", { "key": "svg-0", "strokeWidth": "1.838" }]];
const IconBrandKbin = createReactComponent("outline", "brand-kbin", "BrandKbin", __iconNode);

export { __iconNode, IconBrandKbin as default };
//# sourceMappingURL=IconBrandKbin.mjs.map
