/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M17 11v6l-5 -4l-5 4v-6l5 -4l5 4", "key": "svg-0" }]];
const IconArrowBadgeUp = createReactComponent("outline", "arrow-badge-up", "ArrowBadgeUp", __iconNode);

export { __iconNode, IconArrowBadgeUp as default };
//# sourceMappingURL=IconArrowBadgeUp.mjs.map
