/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M15 9v8a2 2 0 1 0 4 0", "key": "svg-0" }], ["path", { "d": "M19 9h-14", "key": "svg-1" }], ["path", { "d": "M19 5h-14", "key": "svg-2" }], ["path", { "d": "M9 9v4c0 2.5 -.667 4 -2 6", "key": "svg-3" }]];
const IconCurrencyRenminbi = createReactComponent("outline", "currency-renminbi", "CurrencyRenminbi", __iconNode);

export { __iconNode, IconCurrencyRenminbi as default };
//# sourceMappingURL=IconCurrencyRenminbi.mjs.map
