/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M4 18h12l4 -4h-12l-4 4", "key": "svg-0" }], ["path", { "d": "M8 14l-4 -4h12l4 4", "key": "svg-1" }], ["path", { "d": "M16 10l4 -4h-12l-4 4", "key": "svg-2" }]];
const IconCurrencySolana = createReactComponent("outline", "currency-solana", "CurrencySolana", __iconNode);

export { __iconNode, IconCurrencySolana as default };
//# sourceMappingURL=IconCurrencySolana.mjs.map
