/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M18 6a3 3 0 0 1 3 3v9a2 2 0 0 1 -2 2h-2a2 2 0 0 1 -2 -2v-2a3 3 0 0 0 -6 0v2a2 2 0 0 1 -2 2h-2a2 2 0 0 1 -2 -2v-9a3 3 0 0 1 3 -3z", "key": "svg-0" }]];
const IconBuildingBridge2Filled = createReactComponent("filled", "building-bridge-2-filled", "BuildingBridge2Filled", __iconNode);

export { __iconNode, IconBuildingBridge2Filled as default };
//# sourceMappingURL=IconBuildingBridge2Filled.mjs.map
