/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 8v3a1 1 0 0 0 1 1h3", "key": "svg-0" }], ["path", { "d": "M7 8v8", "key": "svg-1" }], ["path", { "d": "M17 8v3a1 1 0 0 0 1 1h3", "key": "svg-2" }], ["path", { "d": "M21 8v8", "key": "svg-3" }], ["path", { "d": "M10 10v4a2 2 0 1 0 4 0v-4a2 2 0 1 0 -4 0", "key": "svg-4" }]];
const IconError404 = createReactComponent("outline", "error-404", "Error404", __iconNode);

export { __iconNode, IconError404 as default };
//# sourceMappingURL=IconError404.mjs.map
