/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 12c0 -3.314 4.03 -6 9 -6s9 2.686 9 6s-4.03 6 -9 6s-9 -2.686 -9 -6", "key": "svg-0" }]];
const IconOvalVertical = createReactComponent("outline", "oval-vertical", "OvalVertical", __iconNode);

export { __iconNode, IconOvalVertical as default };
//# sourceMappingURL=IconOvalVertical.mjs.map
