/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M11 6a1 1 0 1 0 2 0a1 1 0 1 0 -2 0", "fill": "currentColor", "key": "svg-0" }], ["path", { "d": "M11 18a1 1 0 1 0 2 0a1 1 0 1 0 -2 0", "fill": "currentColor", "key": "svg-1" }], ["path", { "d": "M5 12l14 0", "key": "svg-2" }]];
const IconDivide = createReactComponent("outline", "divide", "Divide", __iconNode);

export { __iconNode, IconDivide as default };
//# sourceMappingURL=IconDivide.mjs.map
