/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M10 6h-3a2 2 0 0 0 -2 2v9a2 2 0 0 0 2 2h9a2 2 0 0 0 2 -2v-3", "key": "svg-0" }], ["path", { "d": "M14 7a3 3 0 1 0 6 0a3 3 0 1 0 -6 0", "key": "svg-1" }]];
const IconNotification = createReactComponent("outline", "notification", "Notification", __iconNode);

export { __iconNode, IconNotification as default };
//# sourceMappingURL=IconNotification.mjs.map
