/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M7 11l5 -5l5 5", "key": "svg-0" }], ["path", { "d": "M7 17l5 -5l5 5", "key": "svg-1" }]];
const IconChevronsUp = createReactComponent("outline", "chevrons-up", "ChevronsUp", __iconNode);

export { __iconNode, IconChevronsUp as default };
//# sourceMappingURL=IconChevronsUp.mjs.map
