/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M7 14l-3 -3l8 -8h6l-11 11", "key": "svg-0" }], ["path", { "d": "M14 21l-5 -5l5 -5h5l-5 5l5 5l-5 0", "key": "svg-1" }]];
const IconBrandFlutter = createReactComponent("outline", "brand-flutter", "BrandFlutter", __iconNode);

export { __iconNode, IconBrandFlutter as default };
//# sourceMappingURL=IconBrandFlutter.mjs.map
