/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 7v10l7 4v-18l-7 4", "key": "svg-0" }], ["path", { "d": "M21 7v10l-7 4v-18l7 4", "key": "svg-1" }]];
const IconBrandMetabrainz = createReactComponent("outline", "brand-metabrainz", "BrandMetabrainz", __iconNode);

export { __iconNode, IconBrandMetabrainz as default };
//# sourceMappingURL=IconBrandMetabrainz.mjs.map
