/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M5 3h5a1 1 0 0 1 1 1v6a1 1 0 0 1 -1 1h-6a1 1 0 0 1 -1 -1v-5a2 2 0 0 1 2 -2", "key": "svg-0" }], ["path", { "d": "M14 3h5a2 2 0 0 1 2 2v2a1 1 0 0 1 -1 1h-6a1 1 0 0 1 -1 -1v-3a1 1 0 0 1 1 -1", "key": "svg-1" }], ["path", { "d": "M13 11a1 1 0 0 1 1 -1h6a1 1 0 0 1 1 1v2a1 1 0 0 1 -1 1h-6a1 1 0 0 1 -1 -1z", "key": "svg-2" }], ["path", { "d": "M14 16h6a1 1 0 0 1 1 1v2a2 2 0 0 1 -2 2h-5a1 1 0 0 1 -1 -1v-3a1 1 0 0 1 1 -1", "key": "svg-3" }], ["path", { "d": "M4 13h6a1 1 0 0 1 1 1v6a1 1 0 0 1 -1 1h-5a2 2 0 0 1 -2 -2v-5a1 1 0 0 1 1 -1", "key": "svg-4" }]];
const IconLayoutBoardSplitFilled = createReactComponent("filled", "layout-board-split-filled", "LayoutBoardSplitFilled", __iconNode);

export { __iconNode, IconLayoutBoardSplitFilled as default };
//# sourceMappingURL=IconLayoutBoardSplitFilled.mjs.map
