/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 18l18 -12h-18l9 14l9 -14v10l-18 -10l0 12", "key": "svg-0" }]];
const IconBrandDcos = createReactComponent("outline", "brand-dcos", "BrandDcos", __iconNode);

export { __iconNode, IconBrandDcos as default };
//# sourceMappingURL=IconBrandDcos.mjs.map
