/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 11a1 1 0 0 1 1 -1h2a1 1 0 0 1 1 1v2a1 1 0 0 1 -1 1h-2a1 1 0 0 1 -1 -1l0 -2", "key": "svg-0" }], ["path", { "d": "M17 11a1 1 0 0 1 1 -1h2a1 1 0 0 1 1 1v2a1 1 0 0 1 -1 1h-2a1 1 0 0 1 -1 -1l0 -2", "key": "svg-1" }], ["path", { "d": "M10 4a1 1 0 0 1 1 -1h2a1 1 0 0 1 1 1v2a1 1 0 0 1 -1 1h-2a1 1 0 0 1 -1 -1l0 -2", "key": "svg-2" }], ["path", { "d": "M10 18a1 1 0 0 1 1 -1h2a1 1 0 0 1 1 1v2a1 1 0 0 1 -1 1h-2a1 1 0 0 1 -1 -1l0 -2", "key": "svg-3" }], ["path", { "d": "M19 10a5 5 0 0 0 -5 -5", "key": "svg-4" }], ["path", { "d": "M5 14a5 5 0 0 0 5 5", "key": "svg-5" }], ["path", { "d": "M5 10a5 5 0 0 1 5 -5", "key": "svg-6" }]];
const IconVectorBezierArc = createReactComponent("outline", "vector-bezier-arc", "VectorBezierArc", __iconNode);

export { __iconNode, IconVectorBezierArc as default };
//# sourceMappingURL=IconVectorBezierArc.mjs.map
