/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M12.5 8l4 4l-4 4h4.5l4 -4l-4 -4l-4.5 0", "key": "svg-0" }], ["path", { "d": "M3.5 8l4 4l-4 4h4.5l4 -4l-4 -4l-4.5 0", "key": "svg-1" }]];
const IconBrandInertia = createReactComponent("outline", "brand-inertia", "BrandInertia", __iconNode);

export { __iconNode, IconBrandInertia as default };
//# sourceMappingURL=IconBrandInertia.mjs.map
