/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M10 2l-.15 .005a2 2 0 0 0 -1.85 1.995v6.999l-2.586 .001a2 2 0 0 0 -1.414 3.414l6.586 6.586a2 2 0 0 0 2.828 0l6.586 -6.586a2 2 0 0 0 .434 -2.18l-.068 -.145a2 2 0 0 0 -1.78 -1.089l-2.586 -.001v-6.999a2 2 0 0 0 -2 -2h-4z", "key": "svg-0" }]];
const IconArrowBigDownFilled = createReactComponent("filled", "arrow-big-down-filled", "ArrowBigDownFilled", __iconNode);

export { __iconNode, IconArrowBigDownFilled as default };
//# sourceMappingURL=IconArrowBigDownFilled.mjs.map
