/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M12 3l2 3l2 15h-8l2 -15l2 -3", "key": "svg-0" }], ["path", { "d": "M8 9l8 0", "key": "svg-1" }], ["path", { "d": "M3 11l2 -2l-2 -2", "key": "svg-2" }], ["path", { "d": "M21 11l-2 -2l2 -2", "key": "svg-3" }]];
const IconBuildingLighthouse = createReactComponent("outline", "building-lighthouse", "BuildingLighthouse", __iconNode);

export { __iconNode, IconBuildingLighthouse as default };
//# sourceMappingURL=IconBuildingLighthouse.mjs.map
