/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M10 6h10", "key": "svg-0" }], ["path", { "d": "M4 12h16", "key": "svg-1" }], ["path", { "d": "M7 12h13", "key": "svg-2" }], ["path", { "d": "M4 18h10", "key": "svg-3" }]];
const IconMenu3 = createReactComponent("outline", "menu-3", "Menu3", __iconNode);

export { __iconNode, IconMenu3 as default };
//# sourceMappingURL=IconMenu3.mjs.map
