/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M8 5.072a8 8 0 1 1 -3.995 7.213l-.005 -.285l.005 -.285a8 8 0 0 1 3.995 -6.643z", "key": "svg-0" }]];
const IconPlayerRecordFilled = createReactComponent("filled", "player-record-filled", "PlayerRecordFilled", __iconNode);

export { __iconNode, IconPlayerRecordFilled as default };
//# sourceMappingURL=IconPlayerRecordFilled.mjs.map
