/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 12l0 .01", "key": "svg-0" }], ["path", { "d": "M7 12l10 0", "key": "svg-1" }], ["path", { "d": "M21 12l0 .01", "key": "svg-2" }]];
const IconSeparator = createReactComponent("outline", "separator", "Separator", __iconNode);

export { __iconNode, IconSeparator as default };
//# sourceMappingURL=IconSeparator.mjs.map
