/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M18 9a5 5 0 0 0 -5 -5h-2a5 5 0 0 0 -5 5v6a5 5 0 0 0 5 5h2a5 5 0 0 0 5 -5v-2h-4", "key": "svg-0" }]];
const IconLetterG = createReactComponent("outline", "letter-g", "LetterG", __iconNode);

export { __iconNode, IconLetterG as default };
//# sourceMappingURL=IconLetterG.mjs.map
