/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M13 4v4c-6.575 1.028 -9.02 6.788 -10 12c-.037 .206 5.384 -5.962 10 -6v4l8 -7l-8 -7", "key": "svg-0" }]];
const IconShare3 = createReactComponent("outline", "share-3", "Share3", __iconNode);

export { __iconNode, IconShare3 as default };
//# sourceMappingURL=IconShare3.mjs.map
