/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M17.657 11a6 6 0 1 0 -11.315 0", "key": "svg-0" }], ["path", { "d": "M6.342 11l5.658 11l5.657 -11l-11.315 0", "key": "svg-1" }]];
const IconIceCream2 = createReactComponent("outline", "ice-cream-2", "IceCream2", __iconNode);

export { __iconNode, IconIceCream2 as default };
//# sourceMappingURL=IconIceCream2.mjs.map
