/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M9 11a3 3 0 1 0 6 0a3 3 0 0 0 -6 0", "key": "svg-0" }], ["path", { "d": "M12.758 21.337a2 2 0 0 1 -2.171 -.437l-4.244 -4.243a8 8 0 1 1 12.585 -1.652", "key": "svg-1" }], ["path", { "d": "M16 19h6", "key": "svg-2" }]];
const IconMapPinMinus = createReactComponent("outline", "map-pin-minus", "MapPinMinus", __iconNode);

export { __iconNode, IconMapPinMinus as default };
//# sourceMappingURL=IconMapPinMinus.mjs.map
