/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M16 7l2 9m-10 -9l-2 9m-1 -9h14m2 5h-18", "key": "svg-0" }]];
const IconPicnicTable = createReactComponent("outline", "picnic-table", "PicnicTable", __iconNode);

export { __iconNode, IconPicnicTable as default };
//# sourceMappingURL=IconPicnicTable.mjs.map
