/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M5 21v-16a2 2 0 0 1 2 -2h10a2 2 0 0 1 2 2v16l-3 -2l-2 2l-2 -2l-2 2l-2 -2l-3 2m4 -14h6m-6 4h6m-2 4h2", "key": "svg-0" }]];
const IconReceipt = createReactComponent("outline", "receipt", "Receipt", __iconNode);

export { __iconNode, IconReceipt as default };
//# sourceMappingURL=IconReceipt.mjs.map
