/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M4 4h16", "key": "svg-0" }], ["path", { "d": "M4 20h16", "key": "svg-1" }]];
const IconBaselineDensityLarge = createReactComponent("outline", "baseline-density-large", "BaselineDensityLarge", __iconNode);

export { __iconNode, IconBaselineDensityLarge as default };
//# sourceMappingURL=IconBaselineDensityLarge.mjs.map
