/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M13 20v-16l-5 5", "key": "svg-0" }]];
const IconNumber1 = createReactComponent("outline", "number-1", "Number1", __iconNode);

export { __iconNode, IconNumber1 as default };
//# sourceMappingURL=IconNumber1.mjs.map
