/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M6 3a7 7 0 0 1 6.95 6.155a6.97 6.97 0 0 1 5.05 -2.155h3a1 1 0 0 1 1 1v1a7 7 0 0 1 -7 7h-2v4a1 1 0 0 1 -2 0v-7h-2a7 7 0 0 1 -7 -7v-2a1 1 0 0 1 1 -1z", "key": "svg-0" }]];
const IconSeedlingFilled = createReactComponent("filled", "seedling-filled", "SeedlingFilled", __iconNode);

export { __iconNode, IconSeedlingFilled as default };
//# sourceMappingURL=IconSeedlingFilled.mjs.map
