/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M7 8h10v8a5 5 0 0 1 -10 0l0 -8", "key": "svg-0" }], ["path", { "d": "M9 8v-5h6v5", "key": "svg-1" }]];
const IconDeviceUsb = createReactComponent("outline", "device-usb", "DeviceUsb", __iconNode);

export { __iconNode, IconDeviceUsb as default };
//# sourceMappingURL=IconDeviceUsb.mjs.map
