/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 9h18v-6h-18v18h6v-18", "key": "svg-0" }], ["path", { "d": "M3 15h12v-12", "key": "svg-1" }]];
const IconChartCohort = createReactComponent("outline", "chart-cohort", "ChartCohort", __iconNode);

export { __iconNode, IconChartCohort as default };
//# sourceMappingURL=IconChartCohort.mjs.map
