/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M20 11.1c0 -4.474 -3.582 -8.1 -8 -8.1s-8 3.626 -8 8.1a.9 .9 0 0 0 .9 .9h14.2a.9 .9 0 0 0 .9 -.9", "key": "svg-0" }], ["path", { "d": "M10 12v7a2 2 0 1 0 4 0v-7", "key": "svg-1" }]];
const IconMushroom = createReactComponent("outline", "mushroom", "Mushroom", __iconNode);

export { __iconNode, IconMushroom as default };
//# sourceMappingURL=IconMushroom.mjs.map
