/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M6 15h12l-12 -12h12v6h-12v6l6 6v-6", "key": "svg-0" }]];
const IconBrandFramer = createReactComponent("outline", "brand-framer", "BrandFramer", __iconNode);

export { __iconNode, IconBrandFramer as default };
//# sourceMappingURL=IconBrandFramer.mjs.map
