/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 12a9 9 0 0 0 9 9a9 9 0 0 0 9 -9a9 9 0 0 0 -9 -9", "key": "svg-0" }], ["path", { "d": "M17 12a5 5 0 1 0 -5 5", "key": "svg-1" }]];
const IconLoader3 = createReactComponent("outline", "loader-3", "Loader3", __iconNode);

export { __iconNode, IconLoader3 as default };
//# sourceMappingURL=IconLoader3.mjs.map
