/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M16 8a4 4 0 1 0 -8 0v1a4 4 0 1 0 8 0", "key": "svg-0" }], ["path", { "d": "M8 16a4 4 0 1 0 8 0v-8", "key": "svg-1" }]];
const IconNumber9 = createReactComponent("outline", "number-9", "Number9", __iconNode);

export { __iconNode, IconNumber9 as default };
//# sourceMappingURL=IconNumber9.mjs.map
