/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 21h9", "key": "svg-0" }], ["path", { "d": "M9 8h1", "key": "svg-1" }], ["path", { "d": "M9 12h1", "key": "svg-2" }], ["path", { "d": "M9 16h1", "key": "svg-3" }], ["path", { "d": "M14 8h1", "key": "svg-4" }], ["path", { "d": "M14 12h1", "key": "svg-5" }], ["path", { "d": "M5 21v-16c0 -.53 .211 -1.039 .586 -1.414c.375 -.375 .884 -.586 1.414 -.586h10c.53 0 1.039 .211 1.414 .586c.375 .375 .586 .884 .586 1.414v7", "key": "svg-6" }], ["path", { "d": "M16 19h6", "key": "svg-7" }]];
const IconBuildingMinus = createReactComponent("outline", "building-minus", "BuildingMinus", __iconNode);

export { __iconNode, IconBuildingMinus as default };
//# sourceMappingURL=IconBuildingMinus.mjs.map
