/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M12 12l-8 -8v16l16 -16v16l-4 -4", "key": "svg-0" }], ["path", { "d": "M20 12l-8 8l-4 -4", "key": "svg-1" }]];
const IconBrandFramerMotion = createReactComponent("outline", "brand-framer-motion", "BrandFramerMotion", __iconNode);

export { __iconNode, IconBrandFramerMotion as default };
//# sourceMappingURL=IconBrandFramerMotion.mjs.map
