/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M4 18v-6a3 3 0 0 1 3 -3h7", "key": "svg-0" }], ["path", { "d": "M10 13l4 -4l-4 -4m5 8l4 -4l-4 -4", "key": "svg-1" }]];
const IconCornerUpRightDouble = createReactComponent("outline", "corner-up-right-double", "CornerUpRightDouble", __iconNode);

export { __iconNode, IconCornerUpRightDouble as default };
//# sourceMappingURL=IconCornerUpRightDouble.mjs.map
