/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M12 3a12 12 0 0 0 8.5 3a12 12 0 0 1 -8.5 15a12 12 0 0 1 -8.5 -15a12 12 0 0 0 8.5 -3", "key": "svg-0" }], ["path", { "d": "M12 3v18", "key": "svg-1" }], ["path", { "d": "M3.5 12h17", "key": "svg-2" }]];
const IconShieldCheckered = createReactComponent("outline", "shield-checkered", "ShieldCheckered", __iconNode);

export { __iconNode, IconShieldCheckered as default };
//# sourceMappingURL=IconShieldCheckered.mjs.map
