/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M5 3h5a1 1 0 0 1 1 1v3a1 1 0 0 1 -1 1h-6a1 1 0 0 1 -1 -1v-2a2 2 0 0 1 2 -2", "key": "svg-0" }], ["path", { "d": "M14 3h5a2 2 0 0 1 2 2v8a1 1 0 0 1 -1 1h-6a1 1 0 0 1 -1 -1v-9a1 1 0 0 1 1 -1", "key": "svg-1" }], ["path", { "d": "M14 16h6a1 1 0 0 1 1 1v2a2 2 0 0 1 -2 2h-5a1 1 0 0 1 -1 -1v-3a1 1 0 0 1 1 -1", "key": "svg-2" }], ["path", { "d": "M4 10h6a1 1 0 0 1 1 1v9a1 1 0 0 1 -1 1h-5a2 2 0 0 1 -2 -2v-8a1 1 0 0 1 1 -1", "key": "svg-3" }]];
const IconLayoutBoardFilled = createReactComponent("filled", "layout-board-filled", "LayoutBoardFilled", __iconNode);

export { __iconNode, IconLayoutBoardFilled as default };
//# sourceMappingURL=IconLayoutBoardFilled.mjs.map
