/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 17h4v4h-4l0 -4", "key": "svg-0" }], ["path", { "d": "M17 3h4v4h-4l0 -4", "key": "svg-1" }], ["path", { "d": "M11 19h5.5a3.5 3.5 0 0 0 0 -7h-8a3.5 3.5 0 0 1 0 -7h4.5", "key": "svg-2" }]];
const IconRouteSquare = createReactComponent("outline", "route-square", "RouteSquare", __iconNode);

export { __iconNode, IconRouteSquare as default };
//# sourceMappingURL=IconRouteSquare.mjs.map
