/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M7 21s9.286 -9.841 9.286 -13.841a3.864 3.864 0 0 0 -1.182 -3.008a4.13 4.13 0 0 0 -3.104 -1.144a4.13 4.13 0 0 0 -3.104 1.143a3.864 3.864 0 0 0 -1.182 3.01c0 4 9.286 13.84 9.286 13.84", "key": "svg-0" }]];
const IconRibbonHealth = createReactComponent("outline", "ribbon-health", "RibbonHealth", __iconNode);

export { __iconNode, IconRibbonHealth as default };
//# sourceMappingURL=IconRibbonHealth.mjs.map
