/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M12 2c5.523 0 10 4.477 10 10s-4.477 10 -10 10a10 10 0 1 1 0 -20m-2.293 8.293a1 1 0 0 0 -1.414 1.414l3 3a1 1 0 0 0 1.414 0l3 -3a1 1 0 0 0 0 -1.414l-.094 -.083a1 1 0 0 0 -1.32 .083l-2.294 2.292z", "key": "svg-0" }]];
const IconCircleChevronDownFilled = createReactComponent("filled", "circle-chevron-down-filled", "CircleChevronDownFilled", __iconNode);

export { __iconNode, IconCircleChevronDownFilled as default };
//# sourceMappingURL=IconCircleChevronDownFilled.mjs.map
