/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 12a9 9 0 1 0 18 0a9 9 0 0 0 -18 0", "key": "svg-0" }], ["path", { "d": "M12 8v8", "key": "svg-1" }], ["path", { "d": "M15.5 10l-7 4", "key": "svg-2" }], ["path", { "d": "M15.5 14l-7 -4", "key": "svg-3" }]];
const IconMedicalCrossCircle = createReactComponent("outline", "medical-cross-circle", "MedicalCrossCircle", __iconNode);

export { __iconNode, IconMedicalCrossCircle as default };
//# sourceMappingURL=IconMedicalCrossCircle.mjs.map
