/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M9 16v-8l3 5l3 -5v8", "key": "svg-0" }], ["path", { "d": "M12 3c7.2 0 9 1.8 9 9c0 7.2 -1.8 9 -9 9c-7.2 0 -9 -1.8 -9 -9c0 -7.2 1.8 -9 9 -9", "key": "svg-1" }]];
const IconSquareRoundedLetterM = createReactComponent("outline", "square-rounded-letter-m", "SquareRoundedLetterM", __iconNode);

export { __iconNode, IconSquareRoundedLetterM as default };
//# sourceMappingURL=IconSquareRoundedLetterM.mjs.map
