/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 12a9 9 0 1 0 18 0a9 9 0 1 0 -18 0", "key": "svg-0" }], ["path", { "d": "M10 8h4v6a2 2 0 1 1 -4 0", "key": "svg-1" }]];
const IconCircleLetterJ = createReactComponent("outline", "circle-letter-j", "CircleLetterJ", __iconNode);

export { __iconNode, IconCircleLetterJ as default };
//# sourceMappingURL=IconCircleLetterJ.mjs.map
