/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M10 18v-12h-5v10a2 2 0 0 1 -2 2", "key": "svg-0" }], ["path", { "d": "M14 6v12h4a3 3 0 0 0 0 -6h-4h4a3 3 0 0 0 0 -6h-4", "key": "svg-1" }]];
const IconCurrencySom = createReactComponent("outline", "currency-som", "CurrencySom", __iconNode);

export { __iconNode, IconCurrencySom as default };
//# sourceMappingURL=IconCurrencySom.mjs.map
