/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M8 4h-3v16h3", "key": "svg-0" }], ["path", { "d": "M16 4h3v16h-3", "key": "svg-1" }]];
const IconBrackets = createReactComponent("outline", "brackets", "Brackets", __iconNode);

export { __iconNode, IconBrackets as default };
//# sourceMappingURL=IconBrackets.mjs.map
