/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 12l18 0", "key": "svg-0" }], ["path", { "d": "M7 16l10 0l-10 5l0 -5", "key": "svg-1" }], ["path", { "d": "M7 8l10 0l-10 -5l0 5", "key": "svg-2" }]];
const IconFlipHorizontal = createReactComponent("outline", "flip-horizontal", "FlipHorizontal", __iconNode);

export { __iconNode, IconFlipHorizontal as default };
//# sourceMappingURL=IconFlipHorizontal.mjs.map
