/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M2 8a3 3 0 0 1 3 -3h14a3 3 0 0 1 3 3v8a3 3 0 0 1 -3 3h-14a3 3 0 0 1 -3 -3l0 -8", "key": "svg-0" }], ["path", { "d": "M6 10v4", "key": "svg-1" }], ["path", { "d": "M11 10a2 2 0 1 0 0 4", "key": "svg-2" }], ["path", { "d": "M14 12a2 2 0 1 0 4 0a2 2 0 1 0 -4 0", "key": "svg-3" }]];
const IconFavicon = createReactComponent("outline", "favicon", "Favicon", __iconNode);

export { __iconNode, IconFavicon as default };
//# sourceMappingURL=IconFavicon.mjs.map
