/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M7 6v12", "key": "svg-0" }], ["path", { "d": "M18 6l-6 6l6 6", "key": "svg-1" }]];
const IconChevronLeftPipe = createReactComponent("outline", "chevron-left-pipe", "ChevronLeftPipe", __iconNode);

export { __iconNode, IconChevronLeftPipe as default };
//# sourceMappingURL=IconChevronLeftPipe.mjs.map
