/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 12a9 9 0 1 0 18 0a9 9 0 1 0 -18 0", "key": "svg-0" }], ["path", { "d": "M10 16v-8h2.5a2.5 2.5 0 1 1 0 5h-2.5", "key": "svg-1" }]];
const IconWashDryP = createReactComponent("outline", "wash-dry-p", "WashDryP", __iconNode);

export { __iconNode, IconWashDryP as default };
//# sourceMappingURL=IconWashDryP.mjs.map
