/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M4 6h16", "key": "svg-0" }], ["path", { "d": "M6 12h10", "key": "svg-1" }], ["path", { "d": "M9 18h4", "key": "svg-2" }], ["path", { "d": "M21 15h-2m-2 6h2m0 0v1m0 -1h.5c.398 0 .779 -.158 1.061 -.439c.281 -.281 .439 -.663 .439 -1.061c0 -.398 -.158 -.779 -.439 -1.061c-.281 -.281 -.663 -.439 -1.061 -.439h-1c-.398 0 -.779 -.158 -1.061 -.439c-.281 -.281 -.439 -.663 -.439 -1.061c0 -.398 .158 -.779 .439 -1.061c.281 -.281 .663 -.439 1.061 -.439h.5m0 -1v1", "key": "svg-3" }]];
const IconFilter2Dollar = createReactComponent("outline", "filter-2-dollar", "Filter2Dollar", __iconNode);

export { __iconNode, IconFilter2Dollar as default };
//# sourceMappingURL=IconFilter2Dollar.mjs.map
