/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M19 5v14a2 2 0 0 1 -2 2h-10a2 2 0 0 1 -2 -2v-14a2 2 0 0 1 2 -2h10a2 2 0 0 1 2 2", "key": "svg-0" }], ["path", { "d": "M8 6h.01", "key": "svg-1" }], ["path", { "d": "M16 18h.01", "key": "svg-2" }], ["path", { "d": "M10 15h3a1 1 0 0 0 1 -1v-4a1 1 0 0 0 -1 -1h-2a1 1 0 0 0 -1 1v1a1 1 0 0 0 1 1h3", "key": "svg-3" }]];
const IconPlayCard9 = createReactComponent("outline", "play-card-9", "PlayCard9", __iconNode);

export { __iconNode, IconPlayCard9 as default };
//# sourceMappingURL=IconPlayCard9.mjs.map
