/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M11 17h6l-4 -5l4 -5h-6l-4 5l4 5", "key": "svg-0" }]];
const IconArrowBadgeLeft = createReactComponent("outline", "arrow-badge-left", "ArrowBadgeLeft", __iconNode);

export { __iconNode, IconArrowBadgeLeft as default };
//# sourceMappingURL=IconArrowBadgeLeft.mjs.map
