/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M19 18l-14 -4", "key": "svg-0" }], ["path", { "d": "M19 14l-14 -4l14 -4", "key": "svg-1" }]];
const IconMathEqualLower = createReactComponent("outline", "math-equal-lower", "MathEqualLower", __iconNode);

export { __iconNode, IconMathEqualLower as default };
//# sourceMappingURL=IconMathEqualLower.mjs.map
