/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M14 8h2.5a1.5 1.5 0 0 1 1.5 1.5v1a1.5 1.5 0 0 1 -1.5 1.5h-1.5h1.5a1.5 1.5 0 0 1 1.5 1.5v1a1.5 1.5 0 0 1 -1.5 1.5h-2.5", "key": "svg-0" }], ["path", { "d": "M6 8h4l-2 8", "key": "svg-1" }]];
const IconNumber73Small = createReactComponent("outline", "number-73-small", "Number73Small", __iconNode);

export { __iconNode, IconNumber73Small as default };
//# sourceMappingURL=IconNumber73Small.mjs.map
