/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M10 8l4 8", "key": "svg-0" }], ["path", { "d": "M10 16l4 -8", "key": "svg-1" }]];
const IconLetterXSmall = createReactComponent("outline", "letter-x-small", "LetterXSmall", __iconNode);

export { __iconNode, IconLetterXSmall as default };
//# sourceMappingURL=IconLetterXSmall.mjs.map
