/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M12 21a9 9 0 0 0 9 -9a9 9 0 0 0 -9 -9a9 9 0 0 0 -9 9a9 9 0 0 0 9 9", "key": "svg-0" }], ["path", { "d": "M7.5 15h9l-4.5 -8l-4.5 8", "key": "svg-1" }]];
const IconPlaystationTriangle = createReactComponent("outline", "playstation-triangle", "PlaystationTriangle", __iconNode);

export { __iconNode, IconPlaystationTriangle as default };
//# sourceMappingURL=IconPlaystationTriangle.mjs.map
