/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M10 9l-3 3l3 3", "key": "svg-0" }], ["path", { "d": "M14 9l3 3l-3 3", "key": "svg-1" }]];
const IconDirectionHorizontal = createReactComponent("outline", "direction-horizontal", "DirectionHorizontal", __iconNode);

export { __iconNode, IconDirectionHorizontal as default };
//# sourceMappingURL=IconDirectionHorizontal.mjs.map
