/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M14 4h6v6h-6l0 -6", "key": "svg-0" }], ["path", { "d": "M4 14h6v6h-6l0 -6", "key": "svg-1" }], ["path", { "d": "M14 17a3 3 0 1 0 6 0a3 3 0 1 0 -6 0", "key": "svg-2" }], ["path", { "d": "M4 7a3 3 0 1 0 6 0a3 3 0 1 0 -6 0", "key": "svg-3" }]];
const IconCategory2 = createReactComponent("outline", "category-2", "Category2", __iconNode);

export { __iconNode, IconCategory2 as default };
//# sourceMappingURL=IconCategory2.mjs.map
