/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M17 10h-14l4 -4", "key": "svg-0" }], ["path", { "d": "M7 14h14l-4 4", "key": "svg-1" }]];
const IconArrowsExchange2 = createReactComponent("outline", "arrows-exchange-2", "ArrowsExchange2", __iconNode);

export { __iconNode, IconArrowsExchange2 as default };
//# sourceMappingURL=IconArrowsExchange2.mjs.map
