/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M6 12a2 2 0 1 0 4 0a2 2 0 1 0 -4 0", "key": "svg-0" }], ["path", { "d": "M2 12a6 6 0 0 1 6 -6h8a6 6 0 0 1 6 6a6 6 0 0 1 -6 6h-8a6 6 0 0 1 -6 -6", "key": "svg-1" }]];
const IconToggleLeft = createReactComponent("outline", "toggle-left", "ToggleLeft", __iconNode);

export { __iconNode, IconToggleLeft as default };
//# sourceMappingURL=IconToggleLeft.mjs.map
