/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M18 15l3 -3l-3 -3", "key": "svg-0" }], ["path", { "d": "M3 12a2 2 0 1 0 4 0a2 2 0 1 0 -4 0", "key": "svg-1" }], ["path", { "d": "M7 12h14", "key": "svg-2" }]];
const IconArrowRightCircle = createReactComponent("outline", "arrow-right-circle", "ArrowRightCircle", __iconNode);

export { __iconNode, IconArrowRightCircle as default };
//# sourceMappingURL=IconArrowRightCircle.mjs.map
