/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M5 4h6a3 3 0 0 1 3 3v7", "key": "svg-0" }], ["path", { "d": "M10 10l4 4l4 -4m-8 5l4 4l4 -4", "key": "svg-1" }]];
const IconCornerRightDownDouble = createReactComponent("outline", "corner-right-down-double", "CornerRightDownDouble", __iconNode);

export { __iconNode, IconCornerRightDownDouble as default };
//# sourceMappingURL=IconCornerRightDownDouble.mjs.map
