/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M5 16l1 -9l5 -5l6.5 6l-3.5 4l5 5l-8 5l-6 -6", "key": "svg-0" }]];
const IconBrandBulma = createReactComponent("outline", "brand-bulma", "BrandBulma", __iconNode);

export { __iconNode, IconBrandBulma as default };
//# sourceMappingURL=IconBrandBulma.mjs.map
