/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M6.141 4.163l12 1.714a1 1 0 0 1 .859 .99v10.266a1 1 0 0 1 -.859 .99l-12 1.714a1 1 0 0 1 -1.141 -.99v-13.694a1 1 0 0 1 1.141 -.99", "key": "svg-0" }]];
const IconPerspective = createReactComponent("outline", "perspective", "Perspective", __iconNode);

export { __iconNode, IconPerspective as default };
//# sourceMappingURL=IconPerspective.mjs.map
