/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M5.636 19.364a9 9 0 1 1 12.728 0", "key": "svg-0" }], ["path", { "d": "M16 9l-4 4", "key": "svg-1" }]];
const IconBrandSpeedtest = createReactComponent("outline", "brand-speedtest", "BrandSpeedtest", __iconNode);

export { __iconNode, IconBrandSpeedtest as default };
//# sourceMappingURL=IconBrandSpeedtest.mjs.map
