/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M14.401 8.398l1.599 -2.398h5l-4 6l4 6h-5l-8 -12h-5l4 6l-4 6h5l1.596 -2.393", "key": "svg-0" }]];
const IconBrandXdeep = createReactComponent("outline", "brand-xdeep", "BrandXdeep", __iconNode);

export { __iconNode, IconBrandXdeep as default };
//# sourceMappingURL=IconBrandXdeep.mjs.map
