/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M6 12l6 -9l6 9l-6 9l-6 -9", "key": "svg-0" }], ["path", { "d": "M6 12l6 -3l6 3l-6 2l-6 -2", "key": "svg-1" }]];
const IconCurrencyEthereum = createReactComponent("outline", "currency-ethereum", "CurrencyEthereum", __iconNode);

export { __iconNode, IconCurrencyEthereum as default };
//# sourceMappingURL=IconCurrencyEthereum.mjs.map
