/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M15 10l4.553 -2.276a1 1 0 0 1 1.447 .894v6.764a1 1 0 0 1 -1.447 .894l-4.553 -2.276v-4", "key": "svg-0" }], ["path", { "d": "M3 8a2 2 0 0 1 2 -2h8a2 2 0 0 1 2 2v8a2 2 0 0 1 -2 2h-8a2 2 0 0 1 -2 -2l0 -8", "key": "svg-1" }], ["path", { "d": "M7 12l4 0", "key": "svg-2" }]];
const IconVideoMinus = createReactComponent("outline", "video-minus", "VideoMinus", __iconNode);

export { __iconNode, IconVideoMinus as default };
//# sourceMappingURL=IconVideoMinus.mjs.map
