/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M12 17l-6 4v-14a4 4 0 0 1 4 -4h4a4 4 0 0 1 4 4v5", "key": "svg-0" }], ["path", { "d": "M16 19h6", "key": "svg-1" }], ["path", { "d": "M19 16v6", "key": "svg-2" }]];
const IconBookmarkPlus = createReactComponent("outline", "bookmark-plus", "BookmarkPlus", __iconNode);

export { __iconNode, IconBookmarkPlus as default };
//# sourceMappingURL=IconBookmarkPlus.mjs.map
