/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M4.929 4.929c3.905 -3.905 10.237 -3.905 14.142 0c3.905 3.905 3.905 10.237 0 14.142c-3.905 3.905 -10.237 3.905 -14.142 0c-3.905 -3.905 -3.905 -10.237 0 -14.142zm12.02 2.121a7 7 0 0 0 -9.899 0a1 1 0 0 0 1.414 1.414a5 5 0 0 1 7.072 0a1 1 0 0 0 1.414 -1.414z", "key": "svg-0" }]];
const IconInnerShadowTopFilled = createReactComponent("filled", "inner-shadow-top-filled", "InnerShadowTopFilled", __iconNode);

export { __iconNode, IconInnerShadowTopFilled as default };
//# sourceMappingURL=IconInnerShadowTopFilled.mjs.map
