/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["g", { "transform": "translate(1.5, 0)", "key": "svg-0" }]];
const IconVolume4 = createReactComponent("outline", "volume-4", "Volume4", __iconNode);

export { __iconNode, IconVolume4 as default };
//# sourceMappingURL=IconVolume4.mjs.map
