/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M4 12c-1.333 -1.854 -1.333 -4.146 0 -6", "key": "svg-0" }], ["path", { "d": "M8 12c-1.333 -1.854 -1.333 -4.146 0 -6", "key": "svg-1" }], ["path", { "d": "M16 18c1.333 -1.854 1.333 -4.146 0 -6", "key": "svg-2" }], ["path", { "d": "M20 18c1.333 -1.854 1.333 -4.146 0 -6", "key": "svg-3" }]];
const IconQuotes = createReactComponent("outline", "quotes", "Quotes", __iconNode);

export { __iconNode, IconQuotes as default };
//# sourceMappingURL=IconQuotes.mjs.map
