/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M15 13l-5 -10l-5 10m6 0l4 8l4 -8", "key": "svg-0" }]];
const IconBrandStrava = createReactComponent("outline", "brand-strava", "BrandStrava", __iconNode);

export { __iconNode, IconBrandStrava as default };
//# sourceMappingURL=IconBrandStrava.mjs.map
