/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

import createReactComponent from '../createReactComponent.mjs';

const __iconNode = [["path", { "d": "M3 8a5 5 0 1 0 10 0a5 5 0 1 0 -10 0", "key": "svg-0" }], ["path", { "d": "M13 17a4 4 0 1 0 8 0a4 4 0 1 0 -8 0", "key": "svg-1" }], ["path", { "d": "M4.5 4.5l7 7", "key": "svg-2" }], ["path", { "d": "M19.5 14.5l-5 5", "key": "svg-3" }]];
const IconPills = createReactComponent("outline", "pills", "Pills", __iconNode);

export { __iconNode, IconPills as default };
//# sourceMappingURL=IconPills.mjs.map
