/**
 * @license @tabler/icons-react v3.37.0 - MIT
 *
 * This source code is licensed under the MIT license.
 * See the LICENSE file in the root directory of this source tree.
 */

var dynamicImports = {
  "a-b-2": () => import('./icons/IconAB2.ts'),
  "a-b-off": () => import('./icons/IconABOff.ts'),
  "a-b": () => import('./icons/IconAB.ts'),
  "abacus-off": () => import('./icons/IconAbacusOff.ts'),
  "abacus": () => import('./icons/IconAbacus.ts'),
  "abc": () => import('./icons/IconAbc.ts'),
  "access-point-off": () => import('./icons/IconAccessPointOff.ts'),
  "access-point": () => import('./icons/IconAccessPoint.ts'),
  "accessible-off": () => import('./icons/IconAccessibleOff.ts'),
  "accessible": () => import('./icons/IconAccessible.ts'),
  "activity-heartbeat": () => import('./icons/IconActivityHeartbeat.ts'),
  "activity": () => import('./icons/IconActivity.ts'),
  "ad-2": () => import('./icons/IconAd2.ts'),
  "ad-circle-off": () => import('./icons/IconAdCircleOff.ts'),
  "ad-circle": () => import('./icons/IconAdCircle.ts'),
  "ad-off": () => import('./icons/IconAdOff.ts'),
  "ad": () => import('./icons/IconAd.ts'),
  "address-book-off": () => import('./icons/IconAddressBookOff.ts'),
  "address-book": () => import('./icons/IconAddressBook.ts'),
  "adjustments-alt": () => import('./icons/IconAdjustmentsAlt.ts'),
  "adjustments-bolt": () => import('./icons/IconAdjustmentsBolt.ts'),
  "adjustments-cancel": () => import('./icons/IconAdjustmentsCancel.ts'),
  "adjustments-check": () => import('./icons/IconAdjustmentsCheck.ts'),
  "adjustments-code": () => import('./icons/IconAdjustmentsCode.ts'),
  "adjustments-cog": () => import('./icons/IconAdjustmentsCog.ts'),
  "adjustments-dollar": () => import('./icons/IconAdjustmentsDollar.ts'),
  "adjustments-down": () => import('./icons/IconAdjustmentsDown.ts'),
  "adjustments-exclamation": () => import('./icons/IconAdjustmentsExclamation.ts'),
  "adjustments-heart": () => import('./icons/IconAdjustmentsHeart.ts'),
  "adjustments-horizontal": () => import('./icons/IconAdjustmentsHorizontal.ts'),
  "adjustments-minus": () => import('./icons/IconAdjustmentsMinus.ts'),
  "adjustments-off": () => import('./icons/IconAdjustmentsOff.ts'),
  "adjustments-pause": () => import('./icons/IconAdjustmentsPause.ts'),
  "adjustments-pin": () => import('./icons/IconAdjustmentsPin.ts'),
  "adjustments-plus": () => import('./icons/IconAdjustmentsPlus.ts'),
  "adjustments-question": () => import('./icons/IconAdjustmentsQuestion.ts'),
  "adjustments-search": () => import('./icons/IconAdjustmentsSearch.ts'),
  "adjustments-share": () => import('./icons/IconAdjustmentsShare.ts'),
  "adjustments-spark": () => import('./icons/IconAdjustmentsSpark.ts'),
  "adjustments-star": () => import('./icons/IconAdjustmentsStar.ts'),
  "adjustments-up": () => import('./icons/IconAdjustmentsUp.ts'),
  "adjustments-x": () => import('./icons/IconAdjustmentsX.ts'),
  "adjustments": () => import('./icons/IconAdjustments.ts'),
  "aerial-lift": () => import('./icons/IconAerialLift.ts'),
  "affiliate": () => import('./icons/IconAffiliate.ts'),
  "ai": () => import('./icons/IconAi.ts'),
  "air-balloon": () => import('./icons/IconAirBalloon.ts'),
  "air-conditioning-disabled": () => import('./icons/IconAirConditioningDisabled.ts'),
  "air-conditioning": () => import('./icons/IconAirConditioning.ts'),
  "air-traffic-control": () => import('./icons/IconAirTrafficControl.ts'),
  "alarm-average": () => import('./icons/IconAlarmAverage.ts'),
  "alarm-minus": () => import('./icons/IconAlarmMinus.ts'),
  "alarm-off": () => import('./icons/IconAlarmOff.ts'),
  "alarm-plus": () => import('./icons/IconAlarmPlus.ts'),
  "alarm-smoke": () => import('./icons/IconAlarmSmoke.ts'),
  "alarm-snooze": () => import('./icons/IconAlarmSnooze.ts'),
  "alarm": () => import('./icons/IconAlarm.ts'),
  "album-off": () => import('./icons/IconAlbumOff.ts'),
  "album": () => import('./icons/IconAlbum.ts'),
  "alert-circle-off": () => import('./icons/IconAlertCircleOff.ts'),
  "alert-circle": () => import('./icons/IconAlertCircle.ts'),
  "alert-hexagon-off": () => import('./icons/IconAlertHexagonOff.ts'),
  "alert-hexagon": () => import('./icons/IconAlertHexagon.ts'),
  "alert-octagon": () => import('./icons/IconAlertOctagon.ts'),
  "alert-small-off": () => import('./icons/IconAlertSmallOff.ts'),
  "alert-small": () => import('./icons/IconAlertSmall.ts'),
  "alert-square-rounded-off": () => import('./icons/IconAlertSquareRoundedOff.ts'),
  "alert-square-rounded": () => import('./icons/IconAlertSquareRounded.ts'),
  "alert-square": () => import('./icons/IconAlertSquare.ts'),
  "alert-triangle-off": () => import('./icons/IconAlertTriangleOff.ts'),
  "alert-triangle": () => import('./icons/IconAlertTriangle.ts'),
  "alien": () => import('./icons/IconAlien.ts'),
  "align-box-bottom-center": () => import('./icons/IconAlignBoxBottomCenter.ts'),
  "align-box-bottom-left": () => import('./icons/IconAlignBoxBottomLeft.ts'),
  "align-box-bottom-right": () => import('./icons/IconAlignBoxBottomRight.ts'),
  "align-box-center-bottom": () => import('./icons/IconAlignBoxCenterBottom.ts'),
  "align-box-center-middle": () => import('./icons/IconAlignBoxCenterMiddle.ts'),
  "align-box-center-stretch": () => import('./icons/IconAlignBoxCenterStretch.ts'),
  "align-box-center-top": () => import('./icons/IconAlignBoxCenterTop.ts'),
  "align-box-left-bottom": () => import('./icons/IconAlignBoxLeftBottom.ts'),
  "align-box-left-middle": () => import('./icons/IconAlignBoxLeftMiddle.ts'),
  "align-box-left-stretch": () => import('./icons/IconAlignBoxLeftStretch.ts'),
  "align-box-left-top": () => import('./icons/IconAlignBoxLeftTop.ts'),
  "align-box-right-bottom": () => import('./icons/IconAlignBoxRightBottom.ts'),
  "align-box-right-middle": () => import('./icons/IconAlignBoxRightMiddle.ts'),
  "align-box-right-stretch": () => import('./icons/IconAlignBoxRightStretch.ts'),
  "align-box-right-top": () => import('./icons/IconAlignBoxRightTop.ts'),
  "align-box-top-center": () => import('./icons/IconAlignBoxTopCenter.ts'),
  "align-box-top-left": () => import('./icons/IconAlignBoxTopLeft.ts'),
  "align-box-top-right": () => import('./icons/IconAlignBoxTopRight.ts'),
  "align-center": () => import('./icons/IconAlignCenter.ts'),
  "align-justified": () => import('./icons/IconAlignJustified.ts'),
  "align-left-2": () => import('./icons/IconAlignLeft2.ts'),
  "align-left": () => import('./icons/IconAlignLeft.ts'),
  "align-right-2": () => import('./icons/IconAlignRight2.ts'),
  "align-right": () => import('./icons/IconAlignRight.ts'),
  "alpha": () => import('./icons/IconAlpha.ts'),
  "alphabet-arabic": () => import('./icons/IconAlphabetArabic.ts'),
  "alphabet-bangla": () => import('./icons/IconAlphabetBangla.ts'),
  "alphabet-cyrillic": () => import('./icons/IconAlphabetCyrillic.ts'),
  "alphabet-greek": () => import('./icons/IconAlphabetGreek.ts'),
  "alphabet-hebrew": () => import('./icons/IconAlphabetHebrew.ts'),
  "alphabet-korean": () => import('./icons/IconAlphabetKorean.ts'),
  "alphabet-latin": () => import('./icons/IconAlphabetLatin.ts'),
  "alphabet-polish": () => import('./icons/IconAlphabetPolish.ts'),
  "alphabet-runes": () => import('./icons/IconAlphabetRunes.ts'),
  "alphabet-thai": () => import('./icons/IconAlphabetThai.ts'),
  "alt": () => import('./icons/IconAlt.ts'),
  "ambulance": () => import('./icons/IconAmbulance.ts'),
  "ampersand": () => import('./icons/IconAmpersand.ts'),
  "analyze-off": () => import('./icons/IconAnalyzeOff.ts'),
  "analyze": () => import('./icons/IconAnalyze.ts'),
  "anchor-off": () => import('./icons/IconAnchorOff.ts'),
  "anchor": () => import('./icons/IconAnchor.ts'),
  "angle": () => import('./icons/IconAngle.ts'),
  "ankh": () => import('./icons/IconAnkh.ts'),
  "antenna-bars-1": () => import('./icons/IconAntennaBars1.ts'),
  "antenna-bars-2": () => import('./icons/IconAntennaBars2.ts'),
  "antenna-bars-3": () => import('./icons/IconAntennaBars3.ts'),
  "antenna-bars-4": () => import('./icons/IconAntennaBars4.ts'),
  "antenna-bars-5": () => import('./icons/IconAntennaBars5.ts'),
  "antenna-bars-off": () => import('./icons/IconAntennaBarsOff.ts'),
  "antenna-off": () => import('./icons/IconAntennaOff.ts'),
  "antenna": () => import('./icons/IconAntenna.ts'),
  "aperture-off": () => import('./icons/IconApertureOff.ts'),
  "aperture": () => import('./icons/IconAperture.ts'),
  "api-app-off": () => import('./icons/IconApiAppOff.ts'),
  "api-app": () => import('./icons/IconApiApp.ts'),
  "api-off": () => import('./icons/IconApiOff.ts'),
  "api": () => import('./icons/IconApi.ts'),
  "app-window": () => import('./icons/IconAppWindow.ts'),
  "apple": () => import('./icons/IconApple.ts'),
  "apps-off": () => import('./icons/IconAppsOff.ts'),
  "apps": () => import('./icons/IconApps.ts'),
  "archery-arrow": () => import('./icons/IconArcheryArrow.ts'),
  "archive-off": () => import('./icons/IconArchiveOff.ts'),
  "archive": () => import('./icons/IconArchive.ts'),
  "armchair-2-off": () => import('./icons/IconArmchair2Off.ts'),
  "armchair-2": () => import('./icons/IconArmchair2.ts'),
  "armchair-off": () => import('./icons/IconArmchairOff.ts'),
  "armchair": () => import('./icons/IconArmchair.ts'),
  "arrow-autofit-content": () => import('./icons/IconArrowAutofitContent.ts'),
  "arrow-autofit-down": () => import('./icons/IconArrowAutofitDown.ts'),
  "arrow-autofit-height": () => import('./icons/IconArrowAutofitHeight.ts'),
  "arrow-autofit-left": () => import('./icons/IconArrowAutofitLeft.ts'),
  "arrow-autofit-right": () => import('./icons/IconArrowAutofitRight.ts'),
  "arrow-autofit-up": () => import('./icons/IconArrowAutofitUp.ts'),
  "arrow-autofit-width": () => import('./icons/IconArrowAutofitWidth.ts'),
  "arrow-back-up-double": () => import('./icons/IconArrowBackUpDouble.ts'),
  "arrow-back-up": () => import('./icons/IconArrowBackUp.ts'),
  "arrow-back": () => import('./icons/IconArrowBack.ts'),
  "arrow-badge-down": () => import('./icons/IconArrowBadgeDown.ts'),
  "arrow-badge-left": () => import('./icons/IconArrowBadgeLeft.ts'),
  "arrow-badge-right": () => import('./icons/IconArrowBadgeRight.ts'),
  "arrow-badge-up": () => import('./icons/IconArrowBadgeUp.ts'),
  "arrow-bar-both": () => import('./icons/IconArrowBarBoth.ts'),
  "arrow-bar-down": () => import('./icons/IconArrowBarDown.ts'),
  "arrow-bar-left": () => import('./icons/IconArrowBarLeft.ts'),
  "arrow-bar-right": () => import('./icons/IconArrowBarRight.ts'),
  "arrow-bar-to-down-dashed": () => import('./icons/IconArrowBarToDownDashed.ts'),
  "arrow-bar-to-down": () => import('./icons/IconArrowBarToDown.ts'),
  "arrow-bar-to-left-dashed": () => import('./icons/IconArrowBarToLeftDashed.ts'),
  "arrow-bar-to-left": () => import('./icons/IconArrowBarToLeft.ts'),
  "arrow-bar-to-right-dashed": () => import('./icons/IconArrowBarToRightDashed.ts'),
  "arrow-bar-to-right": () => import('./icons/IconArrowBarToRight.ts'),
  "arrow-bar-to-up-dashed": () => import('./icons/IconArrowBarToUpDashed.ts'),
  "arrow-bar-to-up": () => import('./icons/IconArrowBarToUp.ts'),
  "arrow-bar-up": () => import('./icons/IconArrowBarUp.ts'),
  "arrow-bear-left-2": () => import('./icons/IconArrowBearLeft2.ts'),
  "arrow-bear-left": () => import('./icons/IconArrowBearLeft.ts'),
  "arrow-bear-right-2": () => import('./icons/IconArrowBearRight2.ts'),
  "arrow-bear-right": () => import('./icons/IconArrowBearRight.ts'),
  "arrow-big-down-line": () => import('./icons/IconArrowBigDownLine.ts'),
  "arrow-big-down-lines": () => import('./icons/IconArrowBigDownLines.ts'),
  "arrow-big-down": () => import('./icons/IconArrowBigDown.ts'),
  "arrow-big-left-line": () => import('./icons/IconArrowBigLeftLine.ts'),
  "arrow-big-left-lines": () => import('./icons/IconArrowBigLeftLines.ts'),
  "arrow-big-left": () => import('./icons/IconArrowBigLeft.ts'),
  "arrow-big-right-line": () => import('./icons/IconArrowBigRightLine.ts'),
  "arrow-big-right-lines": () => import('./icons/IconArrowBigRightLines.ts'),
  "arrow-big-right": () => import('./icons/IconArrowBigRight.ts'),
  "arrow-big-up-line": () => import('./icons/IconArrowBigUpLine.ts'),
  "arrow-big-up-lines": () => import('./icons/IconArrowBigUpLines.ts'),
  "arrow-big-up": () => import('./icons/IconArrowBigUp.ts'),
  "arrow-bounce": () => import('./icons/IconArrowBounce.ts'),
  "arrow-capsule": () => import('./icons/IconArrowCapsule.ts'),
  "arrow-curve-left": () => import('./icons/IconArrowCurveLeft.ts'),
  "arrow-curve-right": () => import('./icons/IconArrowCurveRight.ts'),
  "arrow-down-bar": () => import('./icons/IconArrowDownBar.ts'),
  "arrow-down-circle": () => import('./icons/IconArrowDownCircle.ts'),
  "arrow-down-dashed": () => import('./icons/IconArrowDownDashed.ts'),
  "arrow-down-from-arc": () => import('./icons/IconArrowDownFromArc.ts'),
  "arrow-down-left-circle": () => import('./icons/IconArrowDownLeftCircle.ts'),
  "arrow-down-left": () => import('./icons/IconArrowDownLeft.ts'),
  "arrow-down-rhombus": () => import('./icons/IconArrowDownRhombus.ts'),
  "arrow-down-right-circle": () => import('./icons/IconArrowDownRightCircle.ts'),
  "arrow-down-right": () => import('./icons/IconArrowDownRight.ts'),
  "arrow-down-square": () => import('./icons/IconArrowDownSquare.ts'),
  "arrow-down-tail": () => import('./icons/IconArrowDownTail.ts'),
  "arrow-down-to-arc": () => import('./icons/IconArrowDownToArc.ts'),
  "arrow-down": () => import('./icons/IconArrowDown.ts'),
  "arrow-elbow-left": () => import('./icons/IconArrowElbowLeft.ts'),
  "arrow-elbow-right": () => import('./icons/IconArrowElbowRight.ts'),
  "arrow-fork": () => import('./icons/IconArrowFork.ts'),
  "arrow-forward-up-double": () => import('./icons/IconArrowForwardUpDouble.ts'),
  "arrow-forward-up": () => import('./icons/IconArrowForwardUp.ts'),
  "arrow-forward": () => import('./icons/IconArrowForward.ts'),
  "arrow-guide": () => import('./icons/IconArrowGuide.ts'),
  "arrow-iteration": () => import('./icons/IconArrowIteration.ts'),
  "arrow-left-bar": () => import('./icons/IconArrowLeftBar.ts'),
  "arrow-left-circle": () => import('./icons/IconArrowLeftCircle.ts'),
  "arrow-left-dashed": () => import('./icons/IconArrowLeftDashed.ts'),
  "arrow-left-from-arc": () => import('./icons/IconArrowLeftFromArc.ts'),
  "arrow-left-rhombus": () => import('./icons/IconArrowLeftRhombus.ts'),
  "arrow-left-right": () => import('./icons/IconArrowLeftRight.ts'),
  "arrow-left-square": () => import('./icons/IconArrowLeftSquare.ts'),
  "arrow-left-tail": () => import('./icons/IconArrowLeftTail.ts'),
  "arrow-left-to-arc": () => import('./icons/IconArrowLeftToArc.ts'),
  "arrow-left": () => import('./icons/IconArrowLeft.ts'),
  "arrow-loop-left-2": () => import('./icons/IconArrowLoopLeft2.ts'),
  "arrow-loop-left": () => import('./icons/IconArrowLoopLeft.ts'),
  "arrow-loop-right-2": () => import('./icons/IconArrowLoopRight2.ts'),
  "arrow-loop-right": () => import('./icons/IconArrowLoopRight.ts'),
  "arrow-merge-alt-left": () => import('./icons/IconArrowMergeAltLeft.ts'),
  "arrow-merge-alt-right": () => import('./icons/IconArrowMergeAltRight.ts'),
  "arrow-merge-both": () => import('./icons/IconArrowMergeBoth.ts'),
  "arrow-merge-left": () => import('./icons/IconArrowMergeLeft.ts'),
  "arrow-merge-right": () => import('./icons/IconArrowMergeRight.ts'),
  "arrow-merge": () => import('./icons/IconArrowMerge.ts'),
  "arrow-move-down": () => import('./icons/IconArrowMoveDown.ts'),
  "arrow-move-left": () => import('./icons/IconArrowMoveLeft.ts'),
  "arrow-move-right": () => import('./icons/IconArrowMoveRight.ts'),
  "arrow-move-up": () => import('./icons/IconArrowMoveUp.ts'),
  "arrow-narrow-down-dashed": () => import('./icons/IconArrowNarrowDownDashed.ts'),
  "arrow-narrow-down": () => import('./icons/IconArrowNarrowDown.ts'),
  "arrow-narrow-left-dashed": () => import('./icons/IconArrowNarrowLeftDashed.ts'),
  "arrow-narrow-left": () => import('./icons/IconArrowNarrowLeft.ts'),
  "arrow-narrow-right-dashed": () => import('./icons/IconArrowNarrowRightDashed.ts'),
  "arrow-narrow-right": () => import('./icons/IconArrowNarrowRight.ts'),
  "arrow-narrow-up-dashed": () => import('./icons/IconArrowNarrowUpDashed.ts'),
  "arrow-narrow-up": () => import('./icons/IconArrowNarrowUp.ts'),
  "arrow-ramp-left-2": () => import('./icons/IconArrowRampLeft2.ts'),
  "arrow-ramp-left-3": () => import('./icons/IconArrowRampLeft3.ts'),
  "arrow-ramp-left": () => import('./icons/IconArrowRampLeft.ts'),
  "arrow-ramp-right-2": () => import('./icons/IconArrowRampRight2.ts'),
  "arrow-ramp-right-3": () => import('./icons/IconArrowRampRight3.ts'),
  "arrow-ramp-right": () => import('./icons/IconArrowRampRight.ts'),
  "arrow-right-bar": () => import('./icons/IconArrowRightBar.ts'),
  "arrow-right-circle": () => import('./icons/IconArrowRightCircle.ts'),
  "arrow-right-dashed": () => import('./icons/IconArrowRightDashed.ts'),
  "arrow-right-from-arc": () => import('./icons/IconArrowRightFromArc.ts'),
  "arrow-right-rhombus": () => import('./icons/IconArrowRightRhombus.ts'),
  "arrow-right-square": () => import('./icons/IconArrowRightSquare.ts'),
  "arrow-right-tail": () => import('./icons/IconArrowRightTail.ts'),
  "arrow-right-to-arc": () => import('./icons/IconArrowRightToArc.ts'),
  "arrow-right": () => import('./icons/IconArrowRight.ts'),
  "arrow-rotary-first-left": () => import('./icons/IconArrowRotaryFirstLeft.ts'),
  "arrow-rotary-first-right": () => import('./icons/IconArrowRotaryFirstRight.ts'),
  "arrow-rotary-last-left": () => import('./icons/IconArrowRotaryLastLeft.ts'),
  "arrow-rotary-last-right": () => import('./icons/IconArrowRotaryLastRight.ts'),
  "arrow-rotary-left": () => import('./icons/IconArrowRotaryLeft.ts'),
  "arrow-rotary-right": () => import('./icons/IconArrowRotaryRight.ts'),
  "arrow-rotary-straight": () => import('./icons/IconArrowRotaryStraight.ts'),
  "arrow-roundabout-left": () => import('./icons/IconArrowRoundaboutLeft.ts'),
  "arrow-roundabout-right": () => import('./icons/IconArrowRoundaboutRight.ts'),
  "arrow-sharp-turn-left": () => import('./icons/IconArrowSharpTurnLeft.ts'),
  "arrow-sharp-turn-right": () => import('./icons/IconArrowSharpTurnRight.ts'),
  "arrow-up-bar": () => import('./icons/IconArrowUpBar.ts'),
  "arrow-up-circle": () => import('./icons/IconArrowUpCircle.ts'),
  "arrow-up-dashed": () => import('./icons/IconArrowUpDashed.ts'),
  "arrow-up-from-arc": () => import('./icons/IconArrowUpFromArc.ts'),
  "arrow-up-left-circle": () => import('./icons/IconArrowUpLeftCircle.ts'),
  "arrow-up-left": () => import('./icons/IconArrowUpLeft.ts'),
  "arrow-up-rhombus": () => import('./icons/IconArrowUpRhombus.ts'),
  "arrow-up-right-circle": () => import('./icons/IconArrowUpRightCircle.ts'),
  "arrow-up-right": () => import('./icons/IconArrowUpRight.ts'),
  "arrow-up-square": () => import('./icons/IconArrowUpSquare.ts'),
  "arrow-up-tail": () => import('./icons/IconArrowUpTail.ts'),
  "arrow-up-to-arc": () => import('./icons/IconArrowUpToArc.ts'),
  "arrow-up": () => import('./icons/IconArrowUp.ts'),
  "arrow-wave-left-down": () => import('./icons/IconArrowWaveLeftDown.ts'),
  "arrow-wave-left-up": () => import('./icons/IconArrowWaveLeftUp.ts'),
  "arrow-wave-right-down": () => import('./icons/IconArrowWaveRightDown.ts'),
  "arrow-wave-right-up": () => import('./icons/IconArrowWaveRightUp.ts'),
  "arrow-zig-zag": () => import('./icons/IconArrowZigZag.ts'),
  "arrows-cross": () => import('./icons/IconArrowsCross.ts'),
  "arrows-diagonal-2": () => import('./icons/IconArrowsDiagonal2.ts'),
  "arrows-diagonal-minimize-2": () => import('./icons/IconArrowsDiagonalMinimize2.ts'),
  "arrows-diagonal-minimize": () => import('./icons/IconArrowsDiagonalMinimize.ts'),
  "arrows-diagonal": () => import('./icons/IconArrowsDiagonal.ts'),
  "arrows-diff": () => import('./icons/IconArrowsDiff.ts'),
  "arrows-double-ne-sw": () => import('./icons/IconArrowsDoubleNeSw.ts'),
  "arrows-double-nw-se": () => import('./icons/IconArrowsDoubleNwSe.ts'),
  "arrows-double-se-nw": () => import('./icons/IconArrowsDoubleSeNw.ts'),
  "arrows-double-sw-ne": () => import('./icons/IconArrowsDoubleSwNe.ts'),
  "arrows-down-up": () => import('./icons/IconArrowsDownUp.ts'),
  "arrows-down": () => import('./icons/IconArrowsDown.ts'),
  "arrows-exchange-2": () => import('./icons/IconArrowsExchange2.ts'),
  "arrows-exchange": () => import('./icons/IconArrowsExchange.ts'),
  "arrows-horizontal": () => import('./icons/IconArrowsHorizontal.ts'),
  "arrows-join-2": () => import('./icons/IconArrowsJoin2.ts'),
  "arrows-join": () => import('./icons/IconArrowsJoin.ts'),
  "arrows-left-down": () => import('./icons/IconArrowsLeftDown.ts'),
  "arrows-left-right": () => import('./icons/IconArrowsLeftRight.ts'),
  "arrows-left": () => import('./icons/IconArrowsLeft.ts'),
  "arrows-maximize": () => import('./icons/IconArrowsMaximize.ts'),
  "arrows-minimize": () => import('./icons/IconArrowsMinimize.ts'),
  "arrows-move-horizontal": () => import('./icons/IconArrowsMoveHorizontal.ts'),
  "arrows-move-vertical": () => import('./icons/IconArrowsMoveVertical.ts'),
  "arrows-move": () => import('./icons/IconArrowsMove.ts'),
  "arrows-random": () => import('./icons/IconArrowsRandom.ts'),
  "arrows-right-down": () => import('./icons/IconArrowsRightDown.ts'),
  "arrows-right-left": () => import('./icons/IconArrowsRightLeft.ts'),
  "arrows-right": () => import('./icons/IconArrowsRight.ts'),
  "arrows-shuffle-2": () => import('./icons/IconArrowsShuffle2.ts'),
  "arrows-shuffle": () => import('./icons/IconArrowsShuffle.ts'),
  "arrows-sort": () => import('./icons/IconArrowsSort.ts'),
  "arrows-split-2": () => import('./icons/IconArrowsSplit2.ts'),
  "arrows-split": () => import('./icons/IconArrowsSplit.ts'),
  "arrows-transfer-down": () => import('./icons/IconArrowsTransferDown.ts'),
  "arrows-transfer-up-down": () => import('./icons/IconArrowsTransferUpDown.ts'),
  "arrows-transfer-up": () => import('./icons/IconArrowsTransferUp.ts'),
  "arrows-up-down": () => import('./icons/IconArrowsUpDown.ts'),
  "arrows-up-left": () => import('./icons/IconArrowsUpLeft.ts'),
  "arrows-up-right": () => import('./icons/IconArrowsUpRight.ts'),
  "arrows-up": () => import('./icons/IconArrowsUp.ts'),
  "arrows-vertical": () => import('./icons/IconArrowsVertical.ts'),
  "artboard-off": () => import('./icons/IconArtboardOff.ts'),
  "artboard": () => import('./icons/IconArtboard.ts'),
  "article-off": () => import('./icons/IconArticleOff.ts'),
  "article": () => import('./icons/IconArticle.ts'),
  "aspect-ratio-off": () => import('./icons/IconAspectRatioOff.ts'),
  "aspect-ratio": () => import('./icons/IconAspectRatio.ts'),
  "assembly-off": () => import('./icons/IconAssemblyOff.ts'),
  "assembly": () => import('./icons/IconAssembly.ts'),
  "asset": () => import('./icons/IconAsset.ts'),
  "asterisk-simple": () => import('./icons/IconAsteriskSimple.ts'),
  "asterisk": () => import('./icons/IconAsterisk.ts'),
  "at-off": () => import('./icons/IconAtOff.ts'),
  "at": () => import('./icons/IconAt.ts'),
  "atom-2": () => import('./icons/IconAtom2.ts'),
  "atom-off": () => import('./icons/IconAtomOff.ts'),
  "atom": () => import('./icons/IconAtom.ts'),
  "augmented-reality-2": () => import('./icons/IconAugmentedReality2.ts'),
  "augmented-reality-off": () => import('./icons/IconAugmentedRealityOff.ts'),
  "augmented-reality": () => import('./icons/IconAugmentedReality.ts'),
  "auth-2fa": () => import('./icons/IconAuth2fa.ts'),
  "automatic-gearbox": () => import('./icons/IconAutomaticGearbox.ts'),
  "automation": () => import('./icons/IconAutomation.ts'),
  "avocado": () => import('./icons/IconAvocado.ts'),
  "award-off": () => import('./icons/IconAwardOff.ts'),
  "award": () => import('./icons/IconAward.ts'),
  "axe": () => import('./icons/IconAxe.ts'),
  "axis-x": () => import('./icons/IconAxisX.ts'),
  "axis-y": () => import('./icons/IconAxisY.ts'),
  "baby-bottle": () => import('./icons/IconBabyBottle.ts'),
  "baby-carriage": () => import('./icons/IconBabyCarriage.ts'),
  "background": () => import('./icons/IconBackground.ts'),
  "backhoe": () => import('./icons/IconBackhoe.ts'),
  "backpack-off": () => import('./icons/IconBackpackOff.ts'),
  "backpack": () => import('./icons/IconBackpack.ts'),
  "backslash": () => import('./icons/IconBackslash.ts'),
  "backspace": () => import('./icons/IconBackspace.ts'),
  "badge-2k": () => import('./icons/IconBadge2k.ts'),
  "badge-3d": () => import('./icons/IconBadge3d.ts'),
  "badge-3k": () => import('./icons/IconBadge3k.ts'),
  "badge-4k": () => import('./icons/IconBadge4k.ts'),
  "badge-5k": () => import('./icons/IconBadge5k.ts'),
  "badge-8k": () => import('./icons/IconBadge8k.ts'),
  "badge-ad-off": () => import('./icons/IconBadgeAdOff.ts'),
  "badge-ad": () => import('./icons/IconBadgeAd.ts'),
  "badge-ar": () => import('./icons/IconBadgeAr.ts'),
  "badge-cc": () => import('./icons/IconBadgeCc.ts'),
  "badge-hd": () => import('./icons/IconBadgeHd.ts'),
  "badge-off": () => import('./icons/IconBadgeOff.ts'),
  "badge-sd": () => import('./icons/IconBadgeSd.ts'),
  "badge-tm": () => import('./icons/IconBadgeTm.ts'),
  "badge-vo": () => import('./icons/IconBadgeVo.ts'),
  "badge-vr": () => import('./icons/IconBadgeVr.ts'),
  "badge-wc": () => import('./icons/IconBadgeWc.ts'),
  "badge": () => import('./icons/IconBadge.ts'),
  "badges-off": () => import('./icons/IconBadgesOff.ts'),
  "badges": () => import('./icons/IconBadges.ts'),
  "baguette": () => import('./icons/IconBaguette.ts'),
  "ball-american-football-off": () => import('./icons/IconBallAmericanFootballOff.ts'),
  "ball-american-football": () => import('./icons/IconBallAmericanFootball.ts'),
  "ball-baseball": () => import('./icons/IconBallBaseball.ts'),
  "ball-basketball": () => import('./icons/IconBallBasketball.ts'),
  "ball-bowling": () => import('./icons/IconBallBowling.ts'),
  "ball-football-off": () => import('./icons/IconBallFootballOff.ts'),
  "ball-football": () => import('./icons/IconBallFootball.ts'),
  "ball-tennis": () => import('./icons/IconBallTennis.ts'),
  "ball-volleyball": () => import('./icons/IconBallVolleyball.ts'),
  "balloon-off": () => import('./icons/IconBalloonOff.ts'),
  "balloon": () => import('./icons/IconBalloon.ts'),
  "ballpen-off": () => import('./icons/IconBallpenOff.ts'),
  "ballpen": () => import('./icons/IconBallpen.ts'),
  "ban": () => import('./icons/IconBan.ts'),
  "bandage-off": () => import('./icons/IconBandageOff.ts'),
  "bandage": () => import('./icons/IconBandage.ts'),
  "barbell-off": () => import('./icons/IconBarbellOff.ts'),
  "barbell": () => import('./icons/IconBarbell.ts'),
  "barcode-off": () => import('./icons/IconBarcodeOff.ts'),
  "barcode": () => import('./icons/IconBarcode.ts'),
  "barrel-off": () => import('./icons/IconBarrelOff.ts'),
  "barrel": () => import('./icons/IconBarrel.ts'),
  "barrier-block-off": () => import('./icons/IconBarrierBlockOff.ts'),
  "barrier-block": () => import('./icons/IconBarrierBlock.ts'),
  "baseline-density-large": () => import('./icons/IconBaselineDensityLarge.ts'),
  "baseline-density-medium": () => import('./icons/IconBaselineDensityMedium.ts'),
  "baseline-density-small": () => import('./icons/IconBaselineDensitySmall.ts'),
  "baseline": () => import('./icons/IconBaseline.ts'),
  "basket-bolt": () => import('./icons/IconBasketBolt.ts'),
  "basket-cancel": () => import('./icons/IconBasketCancel.ts'),
  "basket-check": () => import('./icons/IconBasketCheck.ts'),
  "basket-code": () => import('./icons/IconBasketCode.ts'),
  "basket-cog": () => import('./icons/IconBasketCog.ts'),
  "basket-discount": () => import('./icons/IconBasketDiscount.ts'),
  "basket-dollar": () => import('./icons/IconBasketDollar.ts'),
  "basket-down": () => import('./icons/IconBasketDown.ts'),
  "basket-exclamation": () => import('./icons/IconBasketExclamation.ts'),
  "basket-heart": () => import('./icons/IconBasketHeart.ts'),
  "basket-minus": () => import('./icons/IconBasketMinus.ts'),
  "basket-off": () => import('./icons/IconBasketOff.ts'),
  "basket-pause": () => import('./icons/IconBasketPause.ts'),
  "basket-pin": () => import('./icons/IconBasketPin.ts'),
  "basket-plus": () => import('./icons/IconBasketPlus.ts'),
  "basket-question": () => import('./icons/IconBasketQuestion.ts'),
  "basket-search": () => import('./icons/IconBasketSearch.ts'),
  "basket-share": () => import('./icons/IconBasketShare.ts'),
  "basket-star": () => import('./icons/IconBasketStar.ts'),
  "basket-up": () => import('./icons/IconBasketUp.ts'),
  "basket-x": () => import('./icons/IconBasketX.ts'),
  "basket": () => import('./icons/IconBasket.ts'),
  "bat": () => import('./icons/IconBat.ts'),
  "bath-off": () => import('./icons/IconBathOff.ts'),
  "bath": () => import('./icons/IconBath.ts'),
  "battery-1": () => import('./icons/IconBattery1.ts'),
  "battery-2": () => import('./icons/IconBattery2.ts'),
  "battery-3": () => import('./icons/IconBattery3.ts'),
  "battery-4": () => import('./icons/IconBattery4.ts'),
  "battery-automotive": () => import('./icons/IconBatteryAutomotive.ts'),
  "battery-charging-2": () => import('./icons/IconBatteryCharging2.ts'),
  "battery-charging": () => import('./icons/IconBatteryCharging.ts'),
  "battery-eco": () => import('./icons/IconBatteryEco.ts'),
  "battery-exclamation": () => import('./icons/IconBatteryExclamation.ts'),
  "battery-off": () => import('./icons/IconBatteryOff.ts'),
  "battery-spark": () => import('./icons/IconBatterySpark.ts'),
  "battery-vertical-1": () => import('./icons/IconBatteryVertical1.ts'),
  "battery-vertical-2": () => import('./icons/IconBatteryVertical2.ts'),
  "battery-vertical-3": () => import('./icons/IconBatteryVertical3.ts'),
  "battery-vertical-4": () => import('./icons/IconBatteryVertical4.ts'),
  "battery-vertical-charging-2": () => import('./icons/IconBatteryVerticalCharging2.ts'),
  "battery-vertical-charging": () => import('./icons/IconBatteryVerticalCharging.ts'),
  "battery-vertical-eco": () => import('./icons/IconBatteryVerticalEco.ts'),
  "battery-vertical-exclamation": () => import('./icons/IconBatteryVerticalExclamation.ts'),
  "battery-vertical-off": () => import('./icons/IconBatteryVerticalOff.ts'),
  "battery-vertical": () => import('./icons/IconBatteryVertical.ts'),
  "battery": () => import('./icons/IconBattery.ts'),
  "beach-off": () => import('./icons/IconBeachOff.ts'),
  "beach": () => import('./icons/IconBeach.ts'),
  "bed-flat": () => import('./icons/IconBedFlat.ts'),
  "bed-off": () => import('./icons/IconBedOff.ts'),
  "bed": () => import('./icons/IconBed.ts'),
  "beer-off": () => import('./icons/IconBeerOff.ts'),
  "beer": () => import('./icons/IconBeer.ts'),
  "bell-bolt": () => import('./icons/IconBellBolt.ts'),
  "bell-cancel": () => import('./icons/IconBellCancel.ts'),
  "bell-check": () => import('./icons/IconBellCheck.ts'),
  "bell-code": () => import('./icons/IconBellCode.ts'),
  "bell-cog": () => import('./icons/IconBellCog.ts'),
  "bell-dollar": () => import('./icons/IconBellDollar.ts'),
  "bell-down": () => import('./icons/IconBellDown.ts'),
  "bell-exclamation": () => import('./icons/IconBellExclamation.ts'),
  "bell-heart": () => import('./icons/IconBellHeart.ts'),
  "bell-minus": () => import('./icons/IconBellMinus.ts'),
  "bell-off": () => import('./icons/IconBellOff.ts'),
  "bell-pause": () => import('./icons/IconBellPause.ts'),
  "bell-pin": () => import('./icons/IconBellPin.ts'),
  "bell-plus": () => import('./icons/IconBellPlus.ts'),
  "bell-question": () => import('./icons/IconBellQuestion.ts'),
  "bell-ringing-2": () => import('./icons/IconBellRinging2.ts'),
  "bell-ringing": () => import('./icons/IconBellRinging.ts'),
  "bell-school": () => import('./icons/IconBellSchool.ts'),
  "bell-search": () => import('./icons/IconBellSearch.ts'),
  "bell-share": () => import('./icons/IconBellShare.ts'),
  "bell-star": () => import('./icons/IconBellStar.ts'),
  "bell-up": () => import('./icons/IconBellUp.ts'),
  "bell-x": () => import('./icons/IconBellX.ts'),
  "bell-z": () => import('./icons/IconBellZ.ts'),
  "bell": () => import('./icons/IconBell.ts'),
  "beta": () => import('./icons/IconBeta.ts'),
  "bible": () => import('./icons/IconBible.ts'),
  "bike-off": () => import('./icons/IconBikeOff.ts'),
  "bike": () => import('./icons/IconBike.ts'),
  "binary-off": () => import('./icons/IconBinaryOff.ts'),
  "binary-tree-2": () => import('./icons/IconBinaryTree2.ts'),
  "binary-tree": () => import('./icons/IconBinaryTree.ts'),
  "binary": () => import('./icons/IconBinary.ts'),
  "binoculars": () => import('./icons/IconBinoculars.ts'),
  "biohazard-off": () => import('./icons/IconBiohazardOff.ts'),
  "biohazard": () => import('./icons/IconBiohazard.ts'),
  "blade": () => import('./icons/IconBlade.ts'),
  "bleach-chlorine": () => import('./icons/IconBleachChlorine.ts'),
  "bleach-no-chlorine": () => import('./icons/IconBleachNoChlorine.ts'),
  "bleach-off": () => import('./icons/IconBleachOff.ts'),
  "bleach": () => import('./icons/IconBleach.ts'),
  "blend-mode": () => import('./icons/IconBlendMode.ts'),
  "blender": () => import('./icons/IconBlender.ts'),
  "blind": () => import('./icons/IconBlind.ts'),
  "blob": () => import('./icons/IconBlob.ts'),
  "blockquote": () => import('./icons/IconBlockquote.ts'),
  "blocks": () => import('./icons/IconBlocks.ts'),
  "bluetooth-connected": () => import('./icons/IconBluetoothConnected.ts'),
  "bluetooth-off": () => import('./icons/IconBluetoothOff.ts'),
  "bluetooth-x": () => import('./icons/IconBluetoothX.ts'),
  "bluetooth": () => import('./icons/IconBluetooth.ts'),
  "blur-off": () => import('./icons/IconBlurOff.ts'),
  "blur": () => import('./icons/IconBlur.ts'),
  "bmp": () => import('./icons/IconBmp.ts'),
  "body-scan": () => import('./icons/IconBodyScan.ts'),
  "bold-off": () => import('./icons/IconBoldOff.ts'),
  "bold": () => import('./icons/IconBold.ts'),
  "bolt-off": () => import('./icons/IconBoltOff.ts'),
  "bolt": () => import('./icons/IconBolt.ts'),
  "bomb": () => import('./icons/IconBomb.ts'),
  "bone-off": () => import('./icons/IconBoneOff.ts'),
  "bone": () => import('./icons/IconBone.ts'),
  "bong-off": () => import('./icons/IconBongOff.ts'),
  "bong": () => import('./icons/IconBong.ts'),
  "book-2": () => import('./icons/IconBook2.ts'),
  "book-download": () => import('./icons/IconBookDownload.ts'),
  "book-off": () => import('./icons/IconBookOff.ts'),
  "book-upload": () => import('./icons/IconBookUpload.ts'),
  "book": () => import('./icons/IconBook.ts'),
  "bookmark-ai": () => import('./icons/IconBookmarkAi.ts'),
  "bookmark-edit": () => import('./icons/IconBookmarkEdit.ts'),
  "bookmark-minus": () => import('./icons/IconBookmarkMinus.ts'),
  "bookmark-off": () => import('./icons/IconBookmarkOff.ts'),
  "bookmark-plus": () => import('./icons/IconBookmarkPlus.ts'),
  "bookmark-question": () => import('./icons/IconBookmarkQuestion.ts'),
  "bookmark": () => import('./icons/IconBookmark.ts'),
  "bookmarks-off": () => import('./icons/IconBookmarksOff.ts'),
  "bookmarks": () => import('./icons/IconBookmarks.ts'),
  "books-off": () => import('./icons/IconBooksOff.ts'),
  "books": () => import('./icons/IconBooks.ts'),
  "boom": () => import('./icons/IconBoom.ts'),
  "border-all": () => import('./icons/IconBorderAll.ts'),
  "border-bottom-plus": () => import('./icons/IconBorderBottomPlus.ts'),
  "border-bottom": () => import('./icons/IconBorderBottom.ts'),
  "border-corner-ios": () => import('./icons/IconBorderCornerIos.ts'),
  "border-corner-pill": () => import('./icons/IconBorderCornerPill.ts'),
  "border-corner-rounded": () => import('./icons/IconBorderCornerRounded.ts'),
  "border-corner-square": () => import('./icons/IconBorderCornerSquare.ts'),
  "border-corners": () => import('./icons/IconBorderCorners.ts'),
  "border-horizontal": () => import('./icons/IconBorderHorizontal.ts'),
  "border-inner": () => import('./icons/IconBorderInner.ts'),
  "border-left-plus": () => import('./icons/IconBorderLeftPlus.ts'),
  "border-left": () => import('./icons/IconBorderLeft.ts'),
  "border-none": () => import('./icons/IconBorderNone.ts'),
  "border-outer": () => import('./icons/IconBorderOuter.ts'),
  "border-radius": () => import('./icons/IconBorderRadius.ts'),
  "border-right-plus": () => import('./icons/IconBorderRightPlus.ts'),
  "border-right": () => import('./icons/IconBorderRight.ts'),
  "border-sides": () => import('./icons/IconBorderSides.ts'),
  "border-style-2": () => import('./icons/IconBorderStyle2.ts'),
  "border-style": () => import('./icons/IconBorderStyle.ts'),
  "border-top-plus": () => import('./icons/IconBorderTopPlus.ts'),
  "border-top": () => import('./icons/IconBorderTop.ts'),
  "border-vertical": () => import('./icons/IconBorderVertical.ts'),
  "bottle-off": () => import('./icons/IconBottleOff.ts'),
  "bottle": () => import('./icons/IconBottle.ts'),
  "bounce-left": () => import('./icons/IconBounceLeft.ts'),
  "bounce-right": () => import('./icons/IconBounceRight.ts'),
  "bow": () => import('./icons/IconBow.ts'),
  "bowl-chopsticks": () => import('./icons/IconBowlChopsticks.ts'),
  "bowl-spoon": () => import('./icons/IconBowlSpoon.ts'),
  "bowl": () => import('./icons/IconBowl.ts'),
  "bowling": () => import('./icons/IconBowling.ts'),
  "box-align-bottom-left": () => import('./icons/IconBoxAlignBottomLeft.ts'),
  "box-align-bottom-right": () => import('./icons/IconBoxAlignBottomRight.ts'),
  "box-align-bottom": () => import('./icons/IconBoxAlignBottom.ts'),
  "box-align-left": () => import('./icons/IconBoxAlignLeft.ts'),
  "box-align-right": () => import('./icons/IconBoxAlignRight.ts'),
  "box-align-top-left": () => import('./icons/IconBoxAlignTopLeft.ts'),
  "box-align-top-right": () => import('./icons/IconBoxAlignTopRight.ts'),
  "box-align-top": () => import('./icons/IconBoxAlignTop.ts'),
  "box-margin": () => import('./icons/IconBoxMargin.ts'),
  "box-model-2-off": () => import('./icons/IconBoxModel2Off.ts'),
  "box-model-2": () => import('./icons/IconBoxModel2.ts'),
  "box-model-off": () => import('./icons/IconBoxModelOff.ts'),
  "box-model": () => import('./icons/IconBoxModel.ts'),
  "box-multiple-0": () => import('./icons/IconBoxMultiple0.ts'),
  "box-multiple-1": () => import('./icons/IconBoxMultiple1.ts'),
  "box-multiple-2": () => import('./icons/IconBoxMultiple2.ts'),
  "box-multiple-3": () => import('./icons/IconBoxMultiple3.ts'),
  "box-multiple-4": () => import('./icons/IconBoxMultiple4.ts'),
  "box-multiple-5": () => import('./icons/IconBoxMultiple5.ts'),
  "box-multiple-6": () => import('./icons/IconBoxMultiple6.ts'),
  "box-multiple-7": () => import('./icons/IconBoxMultiple7.ts'),
  "box-multiple-8": () => import('./icons/IconBoxMultiple8.ts'),
  "box-multiple-9": () => import('./icons/IconBoxMultiple9.ts'),
  "box-multiple": () => import('./icons/IconBoxMultiple.ts'),
  "box-off": () => import('./icons/IconBoxOff.ts'),
  "box-padding": () => import('./icons/IconBoxPadding.ts'),
  "box": () => import('./icons/IconBox.ts'),
  "braces-off": () => import('./icons/IconBracesOff.ts'),
  "braces": () => import('./icons/IconBraces.ts'),
  "brackets-angle-off": () => import('./icons/IconBracketsAngleOff.ts'),
  "brackets-angle": () => import('./icons/IconBracketsAngle.ts'),
  "brackets-contain-end": () => import('./icons/IconBracketsContainEnd.ts'),
  "brackets-contain-start": () => import('./icons/IconBracketsContainStart.ts'),
  "brackets-contain": () => import('./icons/IconBracketsContain.ts'),
  "brackets-off": () => import('./icons/IconBracketsOff.ts'),
  "brackets": () => import('./icons/IconBrackets.ts'),
  "braille": () => import('./icons/IconBraille.ts'),
  "brain": () => import('./icons/IconBrain.ts'),
  "brand-4chan": () => import('./icons/IconBrand4chan.ts'),
  "brand-abstract": () => import('./icons/IconBrandAbstract.ts'),
  "brand-adobe-after-effect": () => import('./icons/IconBrandAdobeAfterEffect.ts'),
  "brand-adobe-illustrator": () => import('./icons/IconBrandAdobeIllustrator.ts'),
  "brand-adobe-indesign": () => import('./icons/IconBrandAdobeIndesign.ts'),
  "brand-adobe-photoshop": () => import('./icons/IconBrandAdobePhotoshop.ts'),
  "brand-adobe-premiere": () => import('./icons/IconBrandAdobePremiere.ts'),
  "brand-adobe-xd": () => import('./icons/IconBrandAdobeXd.ts'),
  "brand-adobe": () => import('./icons/IconBrandAdobe.ts'),
  "brand-adonis-js": () => import('./icons/IconBrandAdonisJs.ts'),
  "brand-airbnb": () => import('./icons/IconBrandAirbnb.ts'),
  "brand-airtable": () => import('./icons/IconBrandAirtable.ts'),
  "brand-algolia": () => import('./icons/IconBrandAlgolia.ts'),
  "brand-alipay": () => import('./icons/IconBrandAlipay.ts'),
  "brand-alpine-js": () => import('./icons/IconBrandAlpineJs.ts'),
  "brand-amazon": () => import('./icons/IconBrandAmazon.ts'),
  "brand-amd": () => import('./icons/IconBrandAmd.ts'),
  "brand-amie": () => import('./icons/IconBrandAmie.ts'),
  "brand-amigo": () => import('./icons/IconBrandAmigo.ts'),
  "brand-among-us": () => import('./icons/IconBrandAmongUs.ts'),
  "brand-android": () => import('./icons/IconBrandAndroid.ts'),
  "brand-angular": () => import('./icons/IconBrandAngular.ts'),
  "brand-ansible": () => import('./icons/IconBrandAnsible.ts'),
  "brand-ao3": () => import('./icons/IconBrandAo3.ts'),
  "brand-appgallery": () => import('./icons/IconBrandAppgallery.ts'),
  "brand-apple-arcade": () => import('./icons/IconBrandAppleArcade.ts'),
  "brand-apple-news": () => import('./icons/IconBrandAppleNews.ts'),
  "brand-apple-podcast": () => import('./icons/IconBrandApplePodcast.ts'),
  "brand-apple": () => import('./icons/IconBrandApple.ts'),
  "brand-appstore": () => import('./icons/IconBrandAppstore.ts'),
  "brand-arc": () => import('./icons/IconBrandArc.ts'),
  "brand-asana": () => import('./icons/IconBrandAsana.ts'),
  "brand-astro": () => import('./icons/IconBrandAstro.ts'),
  "brand-auth0": () => import('./icons/IconBrandAuth0.ts'),
  "brand-aws": () => import('./icons/IconBrandAws.ts'),
  "brand-azure": () => import('./icons/IconBrandAzure.ts'),
  "brand-backbone": () => import('./icons/IconBrandBackbone.ts'),
  "brand-badoo": () => import('./icons/IconBrandBadoo.ts'),
  "brand-baidu": () => import('./icons/IconBrandBaidu.ts'),
  "brand-bandcamp": () => import('./icons/IconBrandBandcamp.ts'),
  "brand-bandlab": () => import('./icons/IconBrandBandlab.ts'),
  "brand-beats": () => import('./icons/IconBrandBeats.ts'),
  "brand-bebo": () => import('./icons/IconBrandBebo.ts'),
  "brand-behance": () => import('./icons/IconBrandBehance.ts'),
  "brand-bilibili": () => import('./icons/IconBrandBilibili.ts'),
  "brand-binance": () => import('./icons/IconBrandBinance.ts'),
  "brand-bing": () => import('./icons/IconBrandBing.ts'),
  "brand-bitbucket": () => import('./icons/IconBrandBitbucket.ts'),
  "brand-blackberry": () => import('./icons/IconBrandBlackberry.ts'),
  "brand-blender": () => import('./icons/IconBrandBlender.ts'),
  "brand-blogger": () => import('./icons/IconBrandBlogger.ts'),
  "brand-bluesky": () => import('./icons/IconBrandBluesky.ts'),
  "brand-booking": () => import('./icons/IconBrandBooking.ts'),
  "brand-bootstrap": () => import('./icons/IconBrandBootstrap.ts'),
  "brand-bulma": () => import('./icons/IconBrandBulma.ts'),
  "brand-bumble": () => import('./icons/IconBrandBumble.ts'),
  "brand-bunpo": () => import('./icons/IconBrandBunpo.ts'),
  "brand-c-sharp": () => import('./icons/IconBrandCSharp.ts'),
  "brand-cake": () => import('./icons/IconBrandCake.ts'),
  "brand-cakephp": () => import('./icons/IconBrandCakephp.ts'),
  "brand-campaignmonitor": () => import('./icons/IconBrandCampaignmonitor.ts'),
  "brand-carbon": () => import('./icons/IconBrandCarbon.ts'),
  "brand-cashapp": () => import('./icons/IconBrandCashapp.ts'),
  "brand-chrome": () => import('./icons/IconBrandChrome.ts'),
  "brand-cinema-4d": () => import('./icons/IconBrandCinema4d.ts'),
  "brand-citymapper": () => import('./icons/IconBrandCitymapper.ts'),
  "brand-cloudflare": () => import('./icons/IconBrandCloudflare.ts'),
  "brand-codecov": () => import('./icons/IconBrandCodecov.ts'),
  "brand-codepen": () => import('./icons/IconBrandCodepen.ts'),
  "brand-codesandbox": () => import('./icons/IconBrandCodesandbox.ts'),
  "brand-cohost": () => import('./icons/IconBrandCohost.ts'),
  "brand-coinbase": () => import('./icons/IconBrandCoinbase.ts'),
  "brand-comedy-central": () => import('./icons/IconBrandComedyCentral.ts'),
  "brand-coreos": () => import('./icons/IconBrandCoreos.ts'),
  "brand-couchdb": () => import('./icons/IconBrandCouchdb.ts'),
  "brand-couchsurfing": () => import('./icons/IconBrandCouchsurfing.ts'),
  "brand-cpp": () => import('./icons/IconBrandCpp.ts'),
  "brand-craft": () => import('./icons/IconBrandCraft.ts'),
  "brand-crunchbase": () => import('./icons/IconBrandCrunchbase.ts'),
  "brand-css3": () => import('./icons/IconBrandCss3.ts'),
  "brand-ctemplar": () => import('./icons/IconBrandCtemplar.ts'),
  "brand-cucumber": () => import('./icons/IconBrandCucumber.ts'),
  "brand-cupra": () => import('./icons/IconBrandCupra.ts'),
  "brand-cypress": () => import('./icons/IconBrandCypress.ts'),
  "brand-d3": () => import('./icons/IconBrandD3.ts'),
  "brand-databricks": () => import('./icons/IconBrandDatabricks.ts'),
  "brand-days-counter": () => import('./icons/IconBrandDaysCounter.ts'),
  "brand-dcos": () => import('./icons/IconBrandDcos.ts'),
  "brand-debian": () => import('./icons/IconBrandDebian.ts'),
  "brand-deezer": () => import('./icons/IconBrandDeezer.ts'),
  "brand-deliveroo": () => import('./icons/IconBrandDeliveroo.ts'),
  "brand-deno": () => import('./icons/IconBrandDeno.ts'),
  "brand-denodo": () => import('./icons/IconBrandDenodo.ts'),
  "brand-deviantart": () => import('./icons/IconBrandDeviantart.ts'),
  "brand-digg": () => import('./icons/IconBrandDigg.ts'),
  "brand-dingtalk": () => import('./icons/IconBrandDingtalk.ts'),
  "brand-discord": () => import('./icons/IconBrandDiscord.ts'),
  "brand-disney": () => import('./icons/IconBrandDisney.ts'),
  "brand-disqus": () => import('./icons/IconBrandDisqus.ts'),
  "brand-django": () => import('./icons/IconBrandDjango.ts'),
  "brand-docker": () => import('./icons/IconBrandDocker.ts'),
  "brand-doctrine": () => import('./icons/IconBrandDoctrine.ts'),
  "brand-dolby-digital": () => import('./icons/IconBrandDolbyDigital.ts'),
  "brand-douban": () => import('./icons/IconBrandDouban.ts'),
  "brand-dribbble": () => import('./icons/IconBrandDribbble.ts'),
  "brand-dropbox": () => import('./icons/IconBrandDropbox.ts'),
  "brand-drops": () => import('./icons/IconBrandDrops.ts'),
  "brand-drupal": () => import('./icons/IconBrandDrupal.ts'),
  "brand-edge": () => import('./icons/IconBrandEdge.ts'),
  "brand-elastic": () => import('./icons/IconBrandElastic.ts'),
  "brand-electronic-arts": () => import('./icons/IconBrandElectronicArts.ts'),
  "brand-ember": () => import('./icons/IconBrandEmber.ts'),
  "brand-envato": () => import('./icons/IconBrandEnvato.ts'),
  "brand-etsy": () => import('./icons/IconBrandEtsy.ts'),
  "brand-evernote": () => import('./icons/IconBrandEvernote.ts'),
  "brand-facebook": () => import('./icons/IconBrandFacebook.ts'),
  "brand-feedly": () => import('./icons/IconBrandFeedly.ts'),
  "brand-figma": () => import('./icons/IconBrandFigma.ts'),
  "brand-filezilla": () => import('./icons/IconBrandFilezilla.ts'),
  "brand-finder": () => import('./icons/IconBrandFinder.ts'),
  "brand-firebase": () => import('./icons/IconBrandFirebase.ts'),
  "brand-firefox": () => import('./icons/IconBrandFirefox.ts'),
  "brand-fiverr": () => import('./icons/IconBrandFiverr.ts'),
  "brand-flickr": () => import('./icons/IconBrandFlickr.ts'),
  "brand-flightradar24": () => import('./icons/IconBrandFlightradar24.ts'),
  "brand-flipboard": () => import('./icons/IconBrandFlipboard.ts'),
  "brand-flutter": () => import('./icons/IconBrandFlutter.ts'),
  "brand-fortnite": () => import('./icons/IconBrandFortnite.ts'),
  "brand-foursquare": () => import('./icons/IconBrandFoursquare.ts'),
  "brand-framer-motion": () => import('./icons/IconBrandFramerMotion.ts'),
  "brand-framer": () => import('./icons/IconBrandFramer.ts'),
  "brand-funimation": () => import('./icons/IconBrandFunimation.ts'),
  "brand-gatsby": () => import('./icons/IconBrandGatsby.ts'),
  "brand-git": () => import('./icons/IconBrandGit.ts'),
  "brand-github-copilot": () => import('./icons/IconBrandGithubCopilot.ts'),
  "brand-github": () => import('./icons/IconBrandGithub.ts'),
  "brand-gitlab": () => import('./icons/IconBrandGitlab.ts'),
  "brand-gmail": () => import('./icons/IconBrandGmail.ts'),
  "brand-golang": () => import('./icons/IconBrandGolang.ts'),
  "brand-google-analytics": () => import('./icons/IconBrandGoogleAnalytics.ts'),
  "brand-google-big-query": () => import('./icons/IconBrandGoogleBigQuery.ts'),
  "brand-google-drive": () => import('./icons/IconBrandGoogleDrive.ts'),
  "brand-google-fit": () => import('./icons/IconBrandGoogleFit.ts'),
  "brand-google-home": () => import('./icons/IconBrandGoogleHome.ts'),
  "brand-google-maps": () => import('./icons/IconBrandGoogleMaps.ts'),
  "brand-google-one": () => import('./icons/IconBrandGoogleOne.ts'),
  "brand-google-photos": () => import('./icons/IconBrandGooglePhotos.ts'),
  "brand-google-play": () => import('./icons/IconBrandGooglePlay.ts'),
  "brand-google-podcasts": () => import('./icons/IconBrandGooglePodcasts.ts'),
  "brand-google": () => import('./icons/IconBrandGoogle.ts'),
  "brand-grammarly": () => import('./icons/IconBrandGrammarly.ts'),
  "brand-graphql": () => import('./icons/IconBrandGraphql.ts'),
  "brand-gravatar": () => import('./icons/IconBrandGravatar.ts'),
  "brand-grindr": () => import('./icons/IconBrandGrindr.ts'),
  "brand-guardian": () => import('./icons/IconBrandGuardian.ts'),
  "brand-gumroad": () => import('./icons/IconBrandGumroad.ts'),
  "brand-hackerrank": () => import('./icons/IconBrandHackerrank.ts'),
  "brand-hbo": () => import('./icons/IconBrandHbo.ts'),
  "brand-headlessui": () => import('./icons/IconBrandHeadlessui.ts'),
  "brand-hexo": () => import('./icons/IconBrandHexo.ts'),
  "brand-hipchat": () => import('./icons/IconBrandHipchat.ts'),
  "brand-html5": () => import('./icons/IconBrandHtml5.ts'),
  "brand-inertia": () => import('./icons/IconBrandInertia.ts'),
  "brand-instagram": () => import('./icons/IconBrandInstagram.ts'),
  "brand-intercom": () => import('./icons/IconBrandIntercom.ts'),
  "brand-itch": () => import('./icons/IconBrandItch.ts'),
  "brand-javascript": () => import('./icons/IconBrandJavascript.ts'),
  "brand-juejin": () => import('./icons/IconBrandJuejin.ts'),
  "brand-kako-talk": () => import('./icons/IconBrandKakoTalk.ts'),
  "brand-kbin": () => import('./icons/IconBrandKbin.ts'),
  "brand-kick": () => import('./icons/IconBrandKick.ts'),
  "brand-kickstarter": () => import('./icons/IconBrandKickstarter.ts'),
  "brand-kotlin": () => import('./icons/IconBrandKotlin.ts'),
  "brand-laravel": () => import('./icons/IconBrandLaravel.ts'),
  "brand-lastfm": () => import('./icons/IconBrandLastfm.ts'),
  "brand-leetcode": () => import('./icons/IconBrandLeetcode.ts'),
  "brand-letterboxd": () => import('./icons/IconBrandLetterboxd.ts'),
  "brand-line": () => import('./icons/IconBrandLine.ts'),
  "brand-linkedin": () => import('./icons/IconBrandLinkedin.ts'),
  "brand-linktree": () => import('./icons/IconBrandLinktree.ts'),
  "brand-linqpad": () => import('./icons/IconBrandLinqpad.ts'),
  "brand-livewire": () => import('./icons/IconBrandLivewire.ts'),
  "brand-loom": () => import('./icons/IconBrandLoom.ts'),
  "brand-mailgun": () => import('./icons/IconBrandMailgun.ts'),
  "brand-mantine": () => import('./icons/IconBrandMantine.ts'),
  "brand-mastercard": () => import('./icons/IconBrandMastercard.ts'),
  "brand-mastodon": () => import('./icons/IconBrandMastodon.ts'),
  "brand-matrix": () => import('./icons/IconBrandMatrix.ts'),
  "brand-mcdonalds": () => import('./icons/IconBrandMcdonalds.ts'),
  "brand-medium": () => import('./icons/IconBrandMedium.ts'),
  "brand-meetup": () => import('./icons/IconBrandMeetup.ts'),
  "brand-mercedes": () => import('./icons/IconBrandMercedes.ts'),
  "brand-messenger": () => import('./icons/IconBrandMessenger.ts'),
  "brand-meta": () => import('./icons/IconBrandMeta.ts'),
  "brand-metabrainz": () => import('./icons/IconBrandMetabrainz.ts'),
  "brand-minecraft": () => import('./icons/IconBrandMinecraft.ts'),
  "brand-miniprogram": () => import('./icons/IconBrandMiniprogram.ts'),
  "brand-mixpanel": () => import('./icons/IconBrandMixpanel.ts'),
  "brand-monday": () => import('./icons/IconBrandMonday.ts'),
  "brand-mongodb": () => import('./icons/IconBrandMongodb.ts'),
  "brand-my-oppo": () => import('./icons/IconBrandMyOppo.ts'),
  "brand-mysql": () => import('./icons/IconBrandMysql.ts'),
  "brand-national-geographic": () => import('./icons/IconBrandNationalGeographic.ts'),
  "brand-nem": () => import('./icons/IconBrandNem.ts'),
  "brand-netbeans": () => import('./icons/IconBrandNetbeans.ts'),
  "brand-netease-music": () => import('./icons/IconBrandNeteaseMusic.ts'),
  "brand-netflix": () => import('./icons/IconBrandNetflix.ts'),
  "brand-nexo": () => import('./icons/IconBrandNexo.ts'),
  "brand-nextcloud": () => import('./icons/IconBrandNextcloud.ts'),
  "brand-nextjs": () => import('./icons/IconBrandNextjs.ts'),
  "brand-nodejs": () => import('./icons/IconBrandNodejs.ts'),
  "brand-nord-vpn": () => import('./icons/IconBrandNordVpn.ts'),
  "brand-notion": () => import('./icons/IconBrandNotion.ts'),
  "brand-npm": () => import('./icons/IconBrandNpm.ts'),
  "brand-nuxt": () => import('./icons/IconBrandNuxt.ts'),
  "brand-nytimes": () => import('./icons/IconBrandNytimes.ts'),
  "brand-oauth": () => import('./icons/IconBrandOauth.ts'),
  "brand-office": () => import('./icons/IconBrandOffice.ts'),
  "brand-ok-ru": () => import('./icons/IconBrandOkRu.ts'),
  "brand-onedrive": () => import('./icons/IconBrandOnedrive.ts'),
  "brand-onlyfans": () => import('./icons/IconBrandOnlyfans.ts'),
  "brand-open-source": () => import('./icons/IconBrandOpenSource.ts'),
  "brand-openai": () => import('./icons/IconBrandOpenai.ts'),
  "brand-openvpn": () => import('./icons/IconBrandOpenvpn.ts'),
  "brand-opera": () => import('./icons/IconBrandOpera.ts'),
  "brand-pagekit": () => import('./icons/IconBrandPagekit.ts'),
  "brand-parsinta": () => import('./icons/IconBrandParsinta.ts'),
  "brand-patreon": () => import('./icons/IconBrandPatreon.ts'),
  "brand-paypal": () => import('./icons/IconBrandPaypal.ts'),
  "brand-paypay": () => import('./icons/IconBrandPaypay.ts'),
  "brand-peanut": () => import('./icons/IconBrandPeanut.ts'),
  "brand-pepsi": () => import('./icons/IconBrandPepsi.ts'),
  "brand-php": () => import('./icons/IconBrandPhp.ts'),
  "brand-picsart": () => import('./icons/IconBrandPicsart.ts'),
  "brand-pinterest": () => import('./icons/IconBrandPinterest.ts'),
  "brand-planetscale": () => import('./icons/IconBrandPlanetscale.ts'),
  "brand-pnpm": () => import('./icons/IconBrandPnpm.ts'),
  "brand-pocket": () => import('./icons/IconBrandPocket.ts'),
  "brand-polymer": () => import('./icons/IconBrandPolymer.ts'),
  "brand-powershell": () => import('./icons/IconBrandPowershell.ts'),
  "brand-printables": () => import('./icons/IconBrandPrintables.ts'),
  "brand-prisma": () => import('./icons/IconBrandPrisma.ts'),
  "brand-producthunt": () => import('./icons/IconBrandProducthunt.ts'),
  "brand-pushbullet": () => import('./icons/IconBrandPushbullet.ts'),
  "brand-pushover": () => import('./icons/IconBrandPushover.ts'),
  "brand-python": () => import('./icons/IconBrandPython.ts'),
  "brand-qq": () => import('./icons/IconBrandQq.ts'),
  "brand-radix-ui": () => import('./icons/IconBrandRadixUi.ts'),
  "brand-react-native": () => import('./icons/IconBrandReactNative.ts'),
  "brand-react": () => import('./icons/IconBrandReact.ts'),
  "brand-reason": () => import('./icons/IconBrandReason.ts'),
  "brand-reddit": () => import('./icons/IconBrandReddit.ts'),
  "brand-redhat": () => import('./icons/IconBrandRedhat.ts'),
  "brand-redux": () => import('./icons/IconBrandRedux.ts'),
  "brand-revolut": () => import('./icons/IconBrandRevolut.ts'),
  "brand-rumble": () => import('./icons/IconBrandRumble.ts'),
  "brand-rust": () => import('./icons/IconBrandRust.ts'),
  "brand-safari": () => import('./icons/IconBrandSafari.ts'),
  "brand-samsungpass": () => import('./icons/IconBrandSamsungpass.ts'),
  "brand-sass": () => import('./icons/IconBrandSass.ts'),
  "brand-sentry": () => import('./icons/IconBrandSentry.ts'),
  "brand-sharik": () => import('./icons/IconBrandSharik.ts'),
  "brand-shazam": () => import('./icons/IconBrandShazam.ts'),
  "brand-shopee": () => import('./icons/IconBrandShopee.ts'),
  "brand-sketch": () => import('./icons/IconBrandSketch.ts'),
  "brand-skype": () => import('./icons/IconBrandSkype.ts'),
  "brand-slack": () => import('./icons/IconBrandSlack.ts'),
  "brand-snapchat": () => import('./icons/IconBrandSnapchat.ts'),
  "brand-snapseed": () => import('./icons/IconBrandSnapseed.ts'),
  "brand-snowflake": () => import('./icons/IconBrandSnowflake.ts'),
  "brand-socket-io": () => import('./icons/IconBrandSocketIo.ts'),
  "brand-solidjs": () => import('./icons/IconBrandSolidjs.ts'),
  "brand-soundcloud": () => import('./icons/IconBrandSoundcloud.ts'),
  "brand-spacehey": () => import('./icons/IconBrandSpacehey.ts'),
  "brand-speedtest": () => import('./icons/IconBrandSpeedtest.ts'),
  "brand-spotify": () => import('./icons/IconBrandSpotify.ts'),
  "brand-stackoverflow": () => import('./icons/IconBrandStackoverflow.ts'),
  "brand-stackshare": () => import('./icons/IconBrandStackshare.ts'),
  "brand-steam": () => import('./icons/IconBrandSteam.ts'),
  "brand-stocktwits": () => import('./icons/IconBrandStocktwits.ts'),
  "brand-storj": () => import('./icons/IconBrandStorj.ts'),
  "brand-storybook": () => import('./icons/IconBrandStorybook.ts'),
  "brand-storytel": () => import('./icons/IconBrandStorytel.ts'),
  "brand-strava": () => import('./icons/IconBrandStrava.ts'),
  "brand-stripe": () => import('./icons/IconBrandStripe.ts'),
  "brand-sublime-text": () => import('./icons/IconBrandSublimeText.ts'),
  "brand-sugarizer": () => import('./icons/IconBrandSugarizer.ts'),
  "brand-supabase": () => import('./icons/IconBrandSupabase.ts'),
  "brand-superhuman": () => import('./icons/IconBrandSuperhuman.ts'),
  "brand-supernova": () => import('./icons/IconBrandSupernova.ts'),
  "brand-surfshark": () => import('./icons/IconBrandSurfshark.ts'),
  "brand-svelte": () => import('./icons/IconBrandSvelte.ts'),
  "brand-swift": () => import('./icons/IconBrandSwift.ts'),
  "brand-symfony": () => import('./icons/IconBrandSymfony.ts'),
  "brand-tabler": () => import('./icons/IconBrandTabler.ts'),
  "brand-tabnine": () => import('./icons/IconBrandTabnine.ts'),
  "brand-tailwind": () => import('./icons/IconBrandTailwind.ts'),
  "brand-taobao": () => import('./icons/IconBrandTaobao.ts'),
  "brand-teams": () => import('./icons/IconBrandTeams.ts'),
  "brand-ted": () => import('./icons/IconBrandTed.ts'),
  "brand-telegram": () => import('./icons/IconBrandTelegram.ts'),
  "brand-terraform": () => import('./icons/IconBrandTerraform.ts'),
  "brand-tesla": () => import('./icons/IconBrandTesla.ts'),
  "brand-tether": () => import('./icons/IconBrandTether.ts'),
  "brand-thingiverse": () => import('./icons/IconBrandThingiverse.ts'),
  "brand-threads": () => import('./icons/IconBrandThreads.ts'),
  "brand-threejs": () => import('./icons/IconBrandThreejs.ts'),
  "brand-tidal": () => import('./icons/IconBrandTidal.ts'),
  "brand-tiktok": () => import('./icons/IconBrandTiktok.ts'),
  "brand-tinder": () => import('./icons/IconBrandTinder.ts'),
  "brand-topbuzz": () => import('./icons/IconBrandTopbuzz.ts'),
  "brand-torchain": () => import('./icons/IconBrandTorchain.ts'),
  "brand-toyota": () => import('./icons/IconBrandToyota.ts'),
  "brand-trello": () => import('./icons/IconBrandTrello.ts'),
  "brand-tripadvisor": () => import('./icons/IconBrandTripadvisor.ts'),
  "brand-tumblr": () => import('./icons/IconBrandTumblr.ts'),
  "brand-twilio": () => import('./icons/IconBrandTwilio.ts'),
  "brand-twitch": () => import('./icons/IconBrandTwitch.ts'),
  "brand-twitter": () => import('./icons/IconBrandTwitter.ts'),
  "brand-typescript": () => import('./icons/IconBrandTypescript.ts'),
  "brand-uber": () => import('./icons/IconBrandUber.ts'),
  "brand-ubuntu": () => import('./icons/IconBrandUbuntu.ts'),
  "brand-unity": () => import('./icons/IconBrandUnity.ts'),
  "brand-unsplash": () => import('./icons/IconBrandUnsplash.ts'),
  "brand-upwork": () => import('./icons/IconBrandUpwork.ts'),
  "brand-valorant": () => import('./icons/IconBrandValorant.ts'),
  "brand-vercel": () => import('./icons/IconBrandVercel.ts'),
  "brand-vimeo": () => import('./icons/IconBrandVimeo.ts'),
  "brand-vinted": () => import('./icons/IconBrandVinted.ts'),
  "brand-visa": () => import('./icons/IconBrandVisa.ts'),
  "brand-visual-studio": () => import('./icons/IconBrandVisualStudio.ts'),
  "brand-vite": () => import('./icons/IconBrandVite.ts'),
  "brand-vivaldi": () => import('./icons/IconBrandVivaldi.ts'),
  "brand-vk": () => import('./icons/IconBrandVk.ts'),
  "brand-vlc": () => import('./icons/IconBrandVlc.ts'),
  "brand-volkswagen": () => import('./icons/IconBrandVolkswagen.ts'),
  "brand-vsco": () => import('./icons/IconBrandVsco.ts'),
  "brand-vscode": () => import('./icons/IconBrandVscode.ts'),
  "brand-vue": () => import('./icons/IconBrandVue.ts'),
  "brand-walmart": () => import('./icons/IconBrandWalmart.ts'),
  "brand-waze": () => import('./icons/IconBrandWaze.ts'),
  "brand-webflow": () => import('./icons/IconBrandWebflow.ts'),
  "brand-wechat": () => import('./icons/IconBrandWechat.ts'),
  "brand-weibo": () => import('./icons/IconBrandWeibo.ts'),
  "brand-whatsapp": () => import('./icons/IconBrandWhatsapp.ts'),
  "brand-wikipedia": () => import('./icons/IconBrandWikipedia.ts'),
  "brand-windows": () => import('./icons/IconBrandWindows.ts'),
  "brand-windy": () => import('./icons/IconBrandWindy.ts'),
  "brand-wish": () => import('./icons/IconBrandWish.ts'),
  "brand-wix": () => import('./icons/IconBrandWix.ts'),
  "brand-wordpress": () => import('./icons/IconBrandWordpress.ts'),
  "brand-x": () => import('./icons/IconBrandX.ts'),
  "brand-xamarin": () => import('./icons/IconBrandXamarin.ts'),
  "brand-xbox": () => import('./icons/IconBrandXbox.ts'),
  "brand-xdeep": () => import('./icons/IconBrandXdeep.ts'),
  "brand-xing": () => import('./icons/IconBrandXing.ts'),
  "brand-yahoo": () => import('./icons/IconBrandYahoo.ts'),
  "brand-yandex": () => import('./icons/IconBrandYandex.ts'),
  "brand-yarn": () => import('./icons/IconBrandYarn.ts'),
  "brand-yatse": () => import('./icons/IconBrandYatse.ts'),
  "brand-ycombinator": () => import('./icons/IconBrandYcombinator.ts'),
  "brand-youtube-kids": () => import('./icons/IconBrandYoutubeKids.ts'),
  "brand-youtube": () => import('./icons/IconBrandYoutube.ts'),
  "brand-zalando": () => import('./icons/IconBrandZalando.ts'),
  "brand-zapier": () => import('./icons/IconBrandZapier.ts'),
  "brand-zeit": () => import('./icons/IconBrandZeit.ts'),
  "brand-zhihu": () => import('./icons/IconBrandZhihu.ts'),
  "brand-zoom": () => import('./icons/IconBrandZoom.ts'),
  "brand-zulip": () => import('./icons/IconBrandZulip.ts'),
  "brand-zwift": () => import('./icons/IconBrandZwift.ts'),
  "bread-off": () => import('./icons/IconBreadOff.ts'),
  "bread": () => import('./icons/IconBread.ts'),
  "briefcase-2": () => import('./icons/IconBriefcase2.ts'),
  "briefcase-off": () => import('./icons/IconBriefcaseOff.ts'),
  "briefcase": () => import('./icons/IconBriefcase.ts'),
  "brightness-2": () => import('./icons/IconBrightness2.ts'),
  "brightness-auto": () => import('./icons/IconBrightnessAuto.ts'),
  "brightness-down": () => import('./icons/IconBrightnessDown.ts'),
  "brightness-half": () => import('./icons/IconBrightnessHalf.ts'),
  "brightness-off": () => import('./icons/IconBrightnessOff.ts'),
  "brightness-up": () => import('./icons/IconBrightnessUp.ts'),
  "brightness": () => import('./icons/IconBrightness.ts'),
  "broadcast-off": () => import('./icons/IconBroadcastOff.ts'),
  "broadcast": () => import('./icons/IconBroadcast.ts'),
  "browser-check": () => import('./icons/IconBrowserCheck.ts'),
  "browser-maximize": () => import('./icons/IconBrowserMaximize.ts'),
  "browser-minus": () => import('./icons/IconBrowserMinus.ts'),
  "browser-off": () => import('./icons/IconBrowserOff.ts'),
  "browser-plus": () => import('./icons/IconBrowserPlus.ts'),
  "browser-share": () => import('./icons/IconBrowserShare.ts'),
  "browser-x": () => import('./icons/IconBrowserX.ts'),
  "browser": () => import('./icons/IconBrowser.ts'),
  "brush-off": () => import('./icons/IconBrushOff.ts'),
  "brush": () => import('./icons/IconBrush.ts'),
  "bubble-minus": () => import('./icons/IconBubbleMinus.ts'),
  "bubble-plus": () => import('./icons/IconBubblePlus.ts'),
  "bubble-tea-2": () => import('./icons/IconBubbleTea2.ts'),
  "bubble-tea": () => import('./icons/IconBubbleTea.ts'),
  "bubble-text": () => import('./icons/IconBubbleText.ts'),
  "bubble-x": () => import('./icons/IconBubbleX.ts'),
  "bubble": () => import('./icons/IconBubble.ts'),
  "bucket-droplet": () => import('./icons/IconBucketDroplet.ts'),
  "bucket-off": () => import('./icons/IconBucketOff.ts'),
  "bucket": () => import('./icons/IconBucket.ts'),
  "bug-off": () => import('./icons/IconBugOff.ts'),
  "bug": () => import('./icons/IconBug.ts'),
  "building-airport": () => import('./icons/IconBuildingAirport.ts'),
  "building-arch": () => import('./icons/IconBuildingArch.ts'),
  "building-bank": () => import('./icons/IconBuildingBank.ts'),
  "building-bridge-2": () => import('./icons/IconBuildingBridge2.ts'),
  "building-bridge": () => import('./icons/IconBuildingBridge.ts'),
  "building-broadcast-tower": () => import('./icons/IconBuildingBroadcastTower.ts'),
  "building-burj-al-arab": () => import('./icons/IconBuildingBurjAlArab.ts'),
  "building-carousel": () => import('./icons/IconBuildingCarousel.ts'),
  "building-castle": () => import('./icons/IconBuildingCastle.ts'),
  "building-church": () => import('./icons/IconBuildingChurch.ts'),
  "building-circus": () => import('./icons/IconBuildingCircus.ts'),
  "building-cog": () => import('./icons/IconBuildingCog.ts'),
  "building-community": () => import('./icons/IconBuildingCommunity.ts'),
  "building-cottage": () => import('./icons/IconBuildingCottage.ts'),
  "building-estate": () => import('./icons/IconBuildingEstate.ts'),
  "building-factory-2": () => import('./icons/IconBuildingFactory2.ts'),
  "building-factory": () => import('./icons/IconBuildingFactory.ts'),
  "building-fortress": () => import('./icons/IconBuildingFortress.ts'),
  "building-hospital": () => import('./icons/IconBuildingHospital.ts'),
  "building-lighthouse": () => import('./icons/IconBuildingLighthouse.ts'),
  "building-minus": () => import('./icons/IconBuildingMinus.ts'),
  "building-monument": () => import('./icons/IconBuildingMonument.ts'),
  "building-mosque": () => import('./icons/IconBuildingMosque.ts'),
  "building-off": () => import('./icons/IconBuildingOff.ts'),
  "building-pavilion": () => import('./icons/IconBuildingPavilion.ts'),
  "building-plus": () => import('./icons/IconBuildingPlus.ts'),
  "building-skyscraper": () => import('./icons/IconBuildingSkyscraper.ts'),
  "building-stadium": () => import('./icons/IconBuildingStadium.ts'),
  "building-store": () => import('./icons/IconBuildingStore.ts'),
  "building-tunnel": () => import('./icons/IconBuildingTunnel.ts'),
  "building-warehouse": () => import('./icons/IconBuildingWarehouse.ts'),
  "building-wind-turbine": () => import('./icons/IconBuildingWindTurbine.ts'),
  "building": () => import('./icons/IconBuilding.ts'),
  "buildings": () => import('./icons/IconBuildings.ts'),
  "bulb-off": () => import('./icons/IconBulbOff.ts'),
  "bulb": () => import('./icons/IconBulb.ts'),
  "bulldozer": () => import('./icons/IconBulldozer.ts'),
  "burger": () => import('./icons/IconBurger.ts'),
  "bus-off": () => import('./icons/IconBusOff.ts'),
  "bus-stop": () => import('./icons/IconBusStop.ts'),
  "bus": () => import('./icons/IconBus.ts'),
  "businessplan": () => import('./icons/IconBusinessplan.ts'),
  "butterfly": () => import('./icons/IconButterfly.ts'),
  "cactus-off": () => import('./icons/IconCactusOff.ts'),
  "cactus": () => import('./icons/IconCactus.ts'),
  "cake-off": () => import('./icons/IconCakeOff.ts'),
  "cake-roll": () => import('./icons/IconCakeRoll.ts'),
  "cake": () => import('./icons/IconCake.ts'),
  "calculator-off": () => import('./icons/IconCalculatorOff.ts'),
  "calculator": () => import('./icons/IconCalculator.ts'),
  "calendar-bolt": () => import('./icons/IconCalendarBolt.ts'),
  "calendar-cancel": () => import('./icons/IconCalendarCancel.ts'),
  "calendar-check": () => import('./icons/IconCalendarCheck.ts'),
  "calendar-clock": () => import('./icons/IconCalendarClock.ts'),
  "calendar-code": () => import('./icons/IconCalendarCode.ts'),
  "calendar-cog": () => import('./icons/IconCalendarCog.ts'),
  "calendar-dollar": () => import('./icons/IconCalendarDollar.ts'),
  "calendar-dot": () => import('./icons/IconCalendarDot.ts'),
  "calendar-down": () => import('./icons/IconCalendarDown.ts'),
  "calendar-due": () => import('./icons/IconCalendarDue.ts'),
  "calendar-event": () => import('./icons/IconCalendarEvent.ts'),
  "calendar-exclamation": () => import('./icons/IconCalendarExclamation.ts'),
  "calendar-heart": () => import('./icons/IconCalendarHeart.ts'),
  "calendar-minus": () => import('./icons/IconCalendarMinus.ts'),
  "calendar-month": () => import('./icons/IconCalendarMonth.ts'),
  "calendar-off": () => import('./icons/IconCalendarOff.ts'),
  "calendar-pause": () => import('./icons/IconCalendarPause.ts'),
  "calendar-pin": () => import('./icons/IconCalendarPin.ts'),
  "calendar-plus": () => import('./icons/IconCalendarPlus.ts'),
  "calendar-question": () => import('./icons/IconCalendarQuestion.ts'),
  "calendar-repeat": () => import('./icons/IconCalendarRepeat.ts'),
  "calendar-sad": () => import('./icons/IconCalendarSad.ts'),
  "calendar-search": () => import('./icons/IconCalendarSearch.ts'),
  "calendar-share": () => import('./icons/IconCalendarShare.ts'),
  "calendar-smile": () => import('./icons/IconCalendarSmile.ts'),
  "calendar-star": () => import('./icons/IconCalendarStar.ts'),
  "calendar-stats": () => import('./icons/IconCalendarStats.ts'),
  "calendar-time": () => import('./icons/IconCalendarTime.ts'),
  "calendar-up": () => import('./icons/IconCalendarUp.ts'),
  "calendar-user": () => import('./icons/IconCalendarUser.ts'),
  "calendar-week": () => import('./icons/IconCalendarWeek.ts'),
  "calendar-x": () => import('./icons/IconCalendarX.ts'),
  "calendar": () => import('./icons/IconCalendar.ts'),
  "camera-ai": () => import('./icons/IconCameraAi.ts'),
  "camera-bitcoin": () => import('./icons/IconCameraBitcoin.ts'),
  "camera-bolt": () => import('./icons/IconCameraBolt.ts'),
  "camera-cancel": () => import('./icons/IconCameraCancel.ts'),
  "camera-check": () => import('./icons/IconCameraCheck.ts'),
  "camera-code": () => import('./icons/IconCameraCode.ts'),
  "camera-cog": () => import('./icons/IconCameraCog.ts'),
  "camera-dollar": () => import('./icons/IconCameraDollar.ts'),
  "camera-down": () => import('./icons/IconCameraDown.ts'),
  "camera-exclamation": () => import('./icons/IconCameraExclamation.ts'),
  "camera-heart": () => import('./icons/IconCameraHeart.ts'),
  "camera-minus": () => import('./icons/IconCameraMinus.ts'),
  "camera-moon": () => import('./icons/IconCameraMoon.ts'),
  "camera-off": () => import('./icons/IconCameraOff.ts'),
  "camera-pause": () => import('./icons/IconCameraPause.ts'),
  "camera-pin": () => import('./icons/IconCameraPin.ts'),
  "camera-plus": () => import('./icons/IconCameraPlus.ts'),
  "camera-question": () => import('./icons/IconCameraQuestion.ts'),
  "camera-rotate": () => import('./icons/IconCameraRotate.ts'),
  "camera-search": () => import('./icons/IconCameraSearch.ts'),
  "camera-selfie": () => import('./icons/IconCameraSelfie.ts'),
  "camera-share": () => import('./icons/IconCameraShare.ts'),
  "camera-spark": () => import('./icons/IconCameraSpark.ts'),
  "camera-star": () => import('./icons/IconCameraStar.ts'),
  "camera-up": () => import('./icons/IconCameraUp.ts'),
  "camera-x": () => import('./icons/IconCameraX.ts'),
  "camera": () => import('./icons/IconCamera.ts'),
  "camper": () => import('./icons/IconCamper.ts'),
  "campfire": () => import('./icons/IconCampfire.ts'),
  "cancel": () => import('./icons/IconCancel.ts'),
  "candle": () => import('./icons/IconCandle.ts'),
  "candy-off": () => import('./icons/IconCandyOff.ts'),
  "candy": () => import('./icons/IconCandy.ts'),
  "cane": () => import('./icons/IconCane.ts'),
  "cannabis": () => import('./icons/IconCannabis.ts'),
  "cap-projecting": () => import('./icons/IconCapProjecting.ts'),
  "cap-rounded": () => import('./icons/IconCapRounded.ts'),
  "cap-straight": () => import('./icons/IconCapStraight.ts'),
  "capsule-horizontal": () => import('./icons/IconCapsuleHorizontal.ts'),
  "capsule": () => import('./icons/IconCapsule.ts'),
  "capture-off": () => import('./icons/IconCaptureOff.ts'),
  "capture": () => import('./icons/IconCapture.ts'),
  "car-4wd": () => import('./icons/IconCar4wd.ts'),
  "car-crane": () => import('./icons/IconCarCrane.ts'),
  "car-crash": () => import('./icons/IconCarCrash.ts'),
  "car-fan-1": () => import('./icons/IconCarFan1.ts'),
  "car-fan-2": () => import('./icons/IconCarFan2.ts'),
  "car-fan-3": () => import('./icons/IconCarFan3.ts'),
  "car-fan-auto": () => import('./icons/IconCarFanAuto.ts'),
  "car-fan": () => import('./icons/IconCarFan.ts'),
  "car-garage": () => import('./icons/IconCarGarage.ts'),
  "car-off": () => import('./icons/IconCarOff.ts'),
  "car-suv": () => import('./icons/IconCarSuv.ts'),
  "car-turbine": () => import('./icons/IconCarTurbine.ts'),
  "car": () => import('./icons/IconCar.ts'),
  "carambola": () => import('./icons/IconCarambola.ts'),
  "caravan": () => import('./icons/IconCaravan.ts'),
  "cardboards-off": () => import('./icons/IconCardboardsOff.ts'),
  "cardboards": () => import('./icons/IconCardboards.ts'),
  "cards": () => import('./icons/IconCards.ts'),
  "caret-down": () => import('./icons/IconCaretDown.ts'),
  "caret-left-right": () => import('./icons/IconCaretLeftRight.ts'),
  "caret-left": () => import('./icons/IconCaretLeft.ts'),
  "caret-right": () => import('./icons/IconCaretRight.ts'),
  "caret-up-down": () => import('./icons/IconCaretUpDown.ts'),
  "caret-up": () => import('./icons/IconCaretUp.ts'),
  "carousel-horizontal": () => import('./icons/IconCarouselHorizontal.ts'),
  "carousel-vertical": () => import('./icons/IconCarouselVertical.ts'),
  "carrot-off": () => import('./icons/IconCarrotOff.ts'),
  "carrot": () => import('./icons/IconCarrot.ts'),
  "cash-banknote-edit": () => import('./icons/IconCashBanknoteEdit.ts'),
  "cash-banknote-heart": () => import('./icons/IconCashBanknoteHeart.ts'),
  "cash-banknote-minus": () => import('./icons/IconCashBanknoteMinus.ts'),
  "cash-banknote-move-back": () => import('./icons/IconCashBanknoteMoveBack.ts'),
  "cash-banknote-move": () => import('./icons/IconCashBanknoteMove.ts'),
  "cash-banknote-off": () => import('./icons/IconCashBanknoteOff.ts'),
  "cash-banknote-plus": () => import('./icons/IconCashBanknotePlus.ts'),
  "cash-banknote": () => import('./icons/IconCashBanknote.ts'),
  "cash-edit": () => import('./icons/IconCashEdit.ts'),
  "cash-heart": () => import('./icons/IconCashHeart.ts'),
  "cash-minus": () => import('./icons/IconCashMinus.ts'),
  "cash-move-back": () => import('./icons/IconCashMoveBack.ts'),
  "cash-move": () => import('./icons/IconCashMove.ts'),
  "cash-off": () => import('./icons/IconCashOff.ts'),
  "cash-plus": () => import('./icons/IconCashPlus.ts'),
  "cash-register": () => import('./icons/IconCashRegister.ts'),
  "cash": () => import('./icons/IconCash.ts'),
  "cast-off": () => import('./icons/IconCastOff.ts'),
  "cast": () => import('./icons/IconCast.ts'),
  "cat": () => import('./icons/IconCat.ts'),
  "category-2": () => import('./icons/IconCategory2.ts'),
  "category-minus": () => import('./icons/IconCategoryMinus.ts'),
  "category-plus": () => import('./icons/IconCategoryPlus.ts'),
  "category": () => import('./icons/IconCategory.ts'),
  "ce-off": () => import('./icons/IconCeOff.ts'),
  "ce": () => import('./icons/IconCe.ts'),
  "cell-signal-1": () => import('./icons/IconCellSignal1.ts'),
  "cell-signal-2": () => import('./icons/IconCellSignal2.ts'),
  "cell-signal-3": () => import('./icons/IconCellSignal3.ts'),
  "cell-signal-4": () => import('./icons/IconCellSignal4.ts'),
  "cell-signal-5": () => import('./icons/IconCellSignal5.ts'),
  "cell-signal-off": () => import('./icons/IconCellSignalOff.ts'),
  "cell": () => import('./icons/IconCell.ts'),
  "certificate-2-off": () => import('./icons/IconCertificate2Off.ts'),
  "certificate-2": () => import('./icons/IconCertificate2.ts'),
  "certificate-off": () => import('./icons/IconCertificateOff.ts'),
  "certificate": () => import('./icons/IconCertificate.ts'),
  "chair-director": () => import('./icons/IconChairDirector.ts'),
  "chalkboard-off": () => import('./icons/IconChalkboardOff.ts'),
  "chalkboard-teacher": () => import('./icons/IconChalkboardTeacher.ts'),
  "chalkboard": () => import('./icons/IconChalkboard.ts'),
  "charging-pile": () => import('./icons/IconChargingPile.ts'),
  "chart-arcs-3": () => import('./icons/IconChartArcs3.ts'),
  "chart-arcs": () => import('./icons/IconChartArcs.ts'),
  "chart-area-line": () => import('./icons/IconChartAreaLine.ts'),
  "chart-area": () => import('./icons/IconChartArea.ts'),
  "chart-arrows-vertical": () => import('./icons/IconChartArrowsVertical.ts'),
  "chart-arrows": () => import('./icons/IconChartArrows.ts'),
  "chart-bar-off": () => import('./icons/IconChartBarOff.ts'),
  "chart-bar-popular": () => import('./icons/IconChartBarPopular.ts'),
  "chart-bar": () => import('./icons/IconChartBar.ts'),
  "chart-bubble": () => import('./icons/IconChartBubble.ts'),
  "chart-candle": () => import('./icons/IconChartCandle.ts'),
  "chart-circles": () => import('./icons/IconChartCircles.ts'),
  "chart-cohort": () => import('./icons/IconChartCohort.ts'),
  "chart-column": () => import('./icons/IconChartColumn.ts'),
  "chart-covariate": () => import('./icons/IconChartCovariate.ts'),
  "chart-donut-2": () => import('./icons/IconChartDonut2.ts'),
  "chart-donut-3": () => import('./icons/IconChartDonut3.ts'),
  "chart-donut-4": () => import('./icons/IconChartDonut4.ts'),
  "chart-donut": () => import('./icons/IconChartDonut.ts'),
  "chart-dots-2": () => import('./icons/IconChartDots2.ts'),
  "chart-dots-3": () => import('./icons/IconChartDots3.ts'),
  "chart-dots": () => import('./icons/IconChartDots.ts'),
  "chart-funnel": () => import('./icons/IconChartFunnel.ts'),
  "chart-grid-dots": () => import('./icons/IconChartGridDots.ts'),
  "chart-histogram": () => import('./icons/IconChartHistogram.ts'),
  "chart-infographic": () => import('./icons/IconChartInfographic.ts'),
  "chart-line": () => import('./icons/IconChartLine.ts'),
  "chart-pie-2": () => import('./icons/IconChartPie2.ts'),
  "chart-pie-3": () => import('./icons/IconChartPie3.ts'),
  "chart-pie-4": () => import('./icons/IconChartPie4.ts'),
  "chart-pie-off": () => import('./icons/IconChartPieOff.ts'),
  "chart-pie": () => import('./icons/IconChartPie.ts'),
  "chart-ppf": () => import('./icons/IconChartPpf.ts'),
  "chart-radar": () => import('./icons/IconChartRadar.ts'),
  "chart-sankey": () => import('./icons/IconChartSankey.ts'),
  "chart-scatter-3d": () => import('./icons/IconChartScatter3d.ts'),
  "chart-scatter": () => import('./icons/IconChartScatter.ts'),
  "chart-treemap": () => import('./icons/IconChartTreemap.ts'),
  "check": () => import('./icons/IconCheck.ts'),
  "checkbox": () => import('./icons/IconCheckbox.ts'),
  "checklist": () => import('./icons/IconChecklist.ts'),
  "checks": () => import('./icons/IconChecks.ts'),
  "checkup-list": () => import('./icons/IconCheckupList.ts'),
  "cheese": () => import('./icons/IconCheese.ts'),
  "chef-hat-off": () => import('./icons/IconChefHatOff.ts'),
  "chef-hat": () => import('./icons/IconChefHat.ts'),
  "cherry": () => import('./icons/IconCherry.ts'),
  "chess-bishop": () => import('./icons/IconChessBishop.ts'),
  "chess-king": () => import('./icons/IconChessKing.ts'),
  "chess-knight": () => import('./icons/IconChessKnight.ts'),
  "chess-queen": () => import('./icons/IconChessQueen.ts'),
  "chess-rook": () => import('./icons/IconChessRook.ts'),
  "chess": () => import('./icons/IconChess.ts'),
  "chevron-compact-down": () => import('./icons/IconChevronCompactDown.ts'),
  "chevron-compact-left": () => import('./icons/IconChevronCompactLeft.ts'),
  "chevron-compact-right": () => import('./icons/IconChevronCompactRight.ts'),
  "chevron-compact-up": () => import('./icons/IconChevronCompactUp.ts'),
  "chevron-down-left": () => import('./icons/IconChevronDownLeft.ts'),
  "chevron-down-right": () => import('./icons/IconChevronDownRight.ts'),
  "chevron-down": () => import('./icons/IconChevronDown.ts'),
  "chevron-left-pipe": () => import('./icons/IconChevronLeftPipe.ts'),
  "chevron-left": () => import('./icons/IconChevronLeft.ts'),
  "chevron-right-pipe": () => import('./icons/IconChevronRightPipe.ts'),
  "chevron-right": () => import('./icons/IconChevronRight.ts'),
  "chevron-up-left": () => import('./icons/IconChevronUpLeft.ts'),
  "chevron-up-right": () => import('./icons/IconChevronUpRight.ts'),
  "chevron-up": () => import('./icons/IconChevronUp.ts'),
  "chevrons-down-left": () => import('./icons/IconChevronsDownLeft.ts'),
  "chevrons-down-right": () => import('./icons/IconChevronsDownRight.ts'),
  "chevrons-down": () => import('./icons/IconChevronsDown.ts'),
  "chevrons-left": () => import('./icons/IconChevronsLeft.ts'),
  "chevrons-right": () => import('./icons/IconChevronsRight.ts'),
  "chevrons-up-left": () => import('./icons/IconChevronsUpLeft.ts'),
  "chevrons-up-right": () => import('./icons/IconChevronsUpRight.ts'),
  "chevrons-up": () => import('./icons/IconChevronsUp.ts'),
  "chisel": () => import('./icons/IconChisel.ts'),
  "christmas-ball": () => import('./icons/IconChristmasBall.ts'),
  "christmas-tree-off": () => import('./icons/IconChristmasTreeOff.ts'),
  "christmas-tree": () => import('./icons/IconChristmasTree.ts'),
  "circle-arrow-down-left": () => import('./icons/IconCircleArrowDownLeft.ts'),
  "circle-arrow-down-right": () => import('./icons/IconCircleArrowDownRight.ts'),
  "circle-arrow-down": () => import('./icons/IconCircleArrowDown.ts'),
  "circle-arrow-left": () => import('./icons/IconCircleArrowLeft.ts'),
  "circle-arrow-right": () => import('./icons/IconCircleArrowRight.ts'),
  "circle-arrow-up-left": () => import('./icons/IconCircleArrowUpLeft.ts'),
  "circle-arrow-up-right": () => import('./icons/IconCircleArrowUpRight.ts'),
  "circle-arrow-up": () => import('./icons/IconCircleArrowUp.ts'),
  "circle-asterisk": () => import('./icons/IconCircleAsterisk.ts'),
  "circle-caret-down": () => import('./icons/IconCircleCaretDown.ts'),
  "circle-caret-left": () => import('./icons/IconCircleCaretLeft.ts'),
  "circle-caret-right": () => import('./icons/IconCircleCaretRight.ts'),
  "circle-caret-up": () => import('./icons/IconCircleCaretUp.ts'),
  "circle-check": () => import('./icons/IconCircleCheck.ts'),
  "circle-chevron-down": () => import('./icons/IconCircleChevronDown.ts'),
  "circle-chevron-left": () => import('./icons/IconCircleChevronLeft.ts'),
  "circle-chevron-right": () => import('./icons/IconCircleChevronRight.ts'),
  "circle-chevron-up": () => import('./icons/IconCircleChevronUp.ts'),
  "circle-chevrons-down": () => import('./icons/IconCircleChevronsDown.ts'),
  "circle-chevrons-left": () => import('./icons/IconCircleChevronsLeft.ts'),
  "circle-chevrons-right": () => import('./icons/IconCircleChevronsRight.ts'),
  "circle-chevrons-up": () => import('./icons/IconCircleChevronsUp.ts'),
  "circle-dashed-check": () => import('./icons/IconCircleDashedCheck.ts'),
  "circle-dashed-letter-a": () => import('./icons/IconCircleDashedLetterA.ts'),
  "circle-dashed-letter-b": () => import('./icons/IconCircleDashedLetterB.ts'),
  "circle-dashed-letter-c": () => import('./icons/IconCircleDashedLetterC.ts'),
  "circle-dashed-letter-d": () => import('./icons/IconCircleDashedLetterD.ts'),
  "circle-dashed-letter-e": () => import('./icons/IconCircleDashedLetterE.ts'),
  "circle-dashed-letter-f": () => import('./icons/IconCircleDashedLetterF.ts'),
  "circle-dashed-letter-g": () => import('./icons/IconCircleDashedLetterG.ts'),
  "circle-dashed-letter-h": () => import('./icons/IconCircleDashedLetterH.ts'),
  "circle-dashed-letter-i": () => import('./icons/IconCircleDashedLetterI.ts'),
  "circle-dashed-letter-j": () => import('./icons/IconCircleDashedLetterJ.ts'),
  "circle-dashed-letter-k": () => import('./icons/IconCircleDashedLetterK.ts'),
  "circle-dashed-letter-l": () => import('./icons/IconCircleDashedLetterL.ts'),
  "circle-dashed-letter-m": () => import('./icons/IconCircleDashedLetterM.ts'),
  "circle-dashed-letter-n": () => import('./icons/IconCircleDashedLetterN.ts'),
  "circle-dashed-letter-o": () => import('./icons/IconCircleDashedLetterO.ts'),
  "circle-dashed-letter-p": () => import('./icons/IconCircleDashedLetterP.ts'),
  "circle-dashed-letter-q": () => import('./icons/IconCircleDashedLetterQ.ts'),
  "circle-dashed-letter-r": () => import('./icons/IconCircleDashedLetterR.ts'),
  "circle-dashed-letter-s": () => import('./icons/IconCircleDashedLetterS.ts'),
  "circle-dashed-letter-t": () => import('./icons/IconCircleDashedLetterT.ts'),
  "circle-dashed-letter-u": () => import('./icons/IconCircleDashedLetterU.ts'),
  "circle-dashed-letter-v": () => import('./icons/IconCircleDashedLetterV.ts'),
  "circle-dashed-letter-w": () => import('./icons/IconCircleDashedLetterW.ts'),
  "circle-dashed-letter-x": () => import('./icons/IconCircleDashedLetterX.ts'),
  "circle-dashed-letter-y": () => import('./icons/IconCircleDashedLetterY.ts'),
  "circle-dashed-letter-z": () => import('./icons/IconCircleDashedLetterZ.ts'),
  "circle-dashed-minus": () => import('./icons/IconCircleDashedMinus.ts'),
  "circle-dashed-number-0": () => import('./icons/IconCircleDashedNumber0.ts'),
  "circle-dashed-number-1": () => import('./icons/IconCircleDashedNumber1.ts'),
  "circle-dashed-number-2": () => import('./icons/IconCircleDashedNumber2.ts'),
  "circle-dashed-number-3": () => import('./icons/IconCircleDashedNumber3.ts'),
  "circle-dashed-number-4": () => import('./icons/IconCircleDashedNumber4.ts'),
  "circle-dashed-number-5": () => import('./icons/IconCircleDashedNumber5.ts'),
  "circle-dashed-number-6": () => import('./icons/IconCircleDashedNumber6.ts'),
  "circle-dashed-number-7": () => import('./icons/IconCircleDashedNumber7.ts'),
  "circle-dashed-number-8": () => import('./icons/IconCircleDashedNumber8.ts'),
  "circle-dashed-number-9": () => import('./icons/IconCircleDashedNumber9.ts'),
  "circle-dashed-percentage": () => import('./icons/IconCircleDashedPercentage.ts'),
  "circle-dashed-plus": () => import('./icons/IconCircleDashedPlus.ts'),
  "circle-dashed-x": () => import('./icons/IconCircleDashedX.ts'),
  "circle-dashed": () => import('./icons/IconCircleDashed.ts'),
  "circle-dot": () => import('./icons/IconCircleDot.ts'),
  "circle-dotted-letter-a": () => import('./icons/IconCircleDottedLetterA.ts'),
  "circle-dotted-letter-b": () => import('./icons/IconCircleDottedLetterB.ts'),
  "circle-dotted-letter-c": () => import('./icons/IconCircleDottedLetterC.ts'),
  "circle-dotted-letter-d": () => import('./icons/IconCircleDottedLetterD.ts'),
  "circle-dotted-letter-e": () => import('./icons/IconCircleDottedLetterE.ts'),
  "circle-dotted-letter-f": () => import('./icons/IconCircleDottedLetterF.ts'),
  "circle-dotted-letter-g": () => import('./icons/IconCircleDottedLetterG.ts'),
  "circle-dotted-letter-h": () => import('./icons/IconCircleDottedLetterH.ts'),
  "circle-dotted-letter-i": () => import('./icons/IconCircleDottedLetterI.ts'),
  "circle-dotted-letter-j": () => import('./icons/IconCircleDottedLetterJ.ts'),
  "circle-dotted-letter-k": () => import('./icons/IconCircleDottedLetterK.ts'),
  "circle-dotted-letter-l": () => import('./icons/IconCircleDottedLetterL.ts'),
  "circle-dotted-letter-m": () => import('./icons/IconCircleDottedLetterM.ts'),
  "circle-dotted-letter-n": () => import('./icons/IconCircleDottedLetterN.ts'),
  "circle-dotted-letter-o": () => import('./icons/IconCircleDottedLetterO.ts'),
  "circle-dotted-letter-p": () => import('./icons/IconCircleDottedLetterP.ts'),
  "circle-dotted-letter-q": () => import('./icons/IconCircleDottedLetterQ.ts'),
  "circle-dotted-letter-r": () => import('./icons/IconCircleDottedLetterR.ts'),
  "circle-dotted-letter-s": () => import('./icons/IconCircleDottedLetterS.ts'),
  "circle-dotted-letter-t": () => import('./icons/IconCircleDottedLetterT.ts'),
  "circle-dotted-letter-u": () => import('./icons/IconCircleDottedLetterU.ts'),
  "circle-dotted-letter-v": () => import('./icons/IconCircleDottedLetterV.ts'),
  "circle-dotted-letter-w": () => import('./icons/IconCircleDottedLetterW.ts'),
  "circle-dotted-letter-x": () => import('./icons/IconCircleDottedLetterX.ts'),
  "circle-dotted-letter-y": () => import('./icons/IconCircleDottedLetterY.ts'),
  "circle-dotted-letter-z": () => import('./icons/IconCircleDottedLetterZ.ts'),
  "circle-dotted": () => import('./icons/IconCircleDotted.ts'),
  "circle-half-2": () => import('./icons/IconCircleHalf2.ts'),
  "circle-half-vertical": () => import('./icons/IconCircleHalfVertical.ts'),
  "circle-half": () => import('./icons/IconCircleHalf.ts'),
  "circle-key": () => import('./icons/IconCircleKey.ts'),
  "circle-letter-a": () => import('./icons/IconCircleLetterA.ts'),
  "circle-letter-b": () => import('./icons/IconCircleLetterB.ts'),
  "circle-letter-c": () => import('./icons/IconCircleLetterC.ts'),
  "circle-letter-d": () => import('./icons/IconCircleLetterD.ts'),
  "circle-letter-e": () => import('./icons/IconCircleLetterE.ts'),
  "circle-letter-f": () => import('./icons/IconCircleLetterF.ts'),
  "circle-letter-g": () => import('./icons/IconCircleLetterG.ts'),
  "circle-letter-h": () => import('./icons/IconCircleLetterH.ts'),
  "circle-letter-i": () => import('./icons/IconCircleLetterI.ts'),
  "circle-letter-j": () => import('./icons/IconCircleLetterJ.ts'),
  "circle-letter-k": () => import('./icons/IconCircleLetterK.ts'),
  "circle-letter-l": () => import('./icons/IconCircleLetterL.ts'),
  "circle-letter-m": () => import('./icons/IconCircleLetterM.ts'),
  "circle-letter-n": () => import('./icons/IconCircleLetterN.ts'),
  "circle-letter-o": () => import('./icons/IconCircleLetterO.ts'),
  "circle-letter-p": () => import('./icons/IconCircleLetterP.ts'),
  "circle-letter-q": () => import('./icons/IconCircleLetterQ.ts'),
  "circle-letter-r": () => import('./icons/IconCircleLetterR.ts'),
  "circle-letter-s": () => import('./icons/IconCircleLetterS.ts'),
  "circle-letter-t": () => import('./icons/IconCircleLetterT.ts'),
  "circle-letter-u": () => import('./icons/IconCircleLetterU.ts'),
  "circle-letter-v": () => import('./icons/IconCircleLetterV.ts'),
  "circle-letter-w": () => import('./icons/IconCircleLetterW.ts'),
  "circle-letter-x": () => import('./icons/IconCircleLetterX.ts'),
  "circle-letter-y": () => import('./icons/IconCircleLetterY.ts'),
  "circle-letter-z": () => import('./icons/IconCircleLetterZ.ts'),
  "circle-minus-2": () => import('./icons/IconCircleMinus2.ts'),
  "circle-minus": () => import('./icons/IconCircleMinus.ts'),
  "circle-number-0": () => import('./icons/IconCircleNumber0.ts'),
  "circle-number-1": () => import('./icons/IconCircleNumber1.ts'),
  "circle-number-2": () => import('./icons/IconCircleNumber2.ts'),
  "circle-number-3": () => import('./icons/IconCircleNumber3.ts'),
  "circle-number-4": () => import('./icons/IconCircleNumber4.ts'),
  "circle-number-5": () => import('./icons/IconCircleNumber5.ts'),
  "circle-number-6": () => import('./icons/IconCircleNumber6.ts'),
  "circle-number-7": () => import('./icons/IconCircleNumber7.ts'),
  "circle-number-8": () => import('./icons/IconCircleNumber8.ts'),
  "circle-number-9": () => import('./icons/IconCircleNumber9.ts'),
  "circle-off": () => import('./icons/IconCircleOff.ts'),
  "circle-percentage": () => import('./icons/IconCirclePercentage.ts'),
  "circle-plus-2": () => import('./icons/IconCirclePlus2.ts'),
  "circle-plus": () => import('./icons/IconCirclePlus.ts'),
  "circle-rectangle-off": () => import('./icons/IconCircleRectangleOff.ts'),
  "circle-rectangle": () => import('./icons/IconCircleRectangle.ts'),
  "circle-square": () => import('./icons/IconCircleSquare.ts'),
  "circle-triangle": () => import('./icons/IconCircleTriangle.ts'),
  "circle-x": () => import('./icons/IconCircleX.ts'),
  "circle": () => import('./icons/IconCircle.ts'),
  "circles-relation": () => import('./icons/IconCirclesRelation.ts'),
  "circles": () => import('./icons/IconCircles.ts'),
  "circuit-ammeter": () => import('./icons/IconCircuitAmmeter.ts'),
  "circuit-battery": () => import('./icons/IconCircuitBattery.ts'),
  "circuit-bulb": () => import('./icons/IconCircuitBulb.ts'),
  "circuit-capacitor-polarized": () => import('./icons/IconCircuitCapacitorPolarized.ts'),
  "circuit-capacitor": () => import('./icons/IconCircuitCapacitor.ts'),
  "circuit-cell-plus": () => import('./icons/IconCircuitCellPlus.ts'),
  "circuit-cell": () => import('./icons/IconCircuitCell.ts'),
  "circuit-changeover": () => import('./icons/IconCircuitChangeover.ts'),
  "circuit-diode-zener": () => import('./icons/IconCircuitDiodeZener.ts'),
  "circuit-diode": () => import('./icons/IconCircuitDiode.ts'),
  "circuit-ground-digital": () => import('./icons/IconCircuitGroundDigital.ts'),
  "circuit-ground": () => import('./icons/IconCircuitGround.ts'),
  "circuit-inductor": () => import('./icons/IconCircuitInductor.ts'),
  "circuit-motor": () => import('./icons/IconCircuitMotor.ts'),
  "circuit-pushbutton": () => import('./icons/IconCircuitPushbutton.ts'),
  "circuit-resistor": () => import('./icons/IconCircuitResistor.ts'),
  "circuit-switch-closed": () => import('./icons/IconCircuitSwitchClosed.ts'),
  "circuit-switch-open": () => import('./icons/IconCircuitSwitchOpen.ts'),
  "circuit-voltmeter": () => import('./icons/IconCircuitVoltmeter.ts'),
  "clear-all": () => import('./icons/IconClearAll.ts'),
  "clear-formatting": () => import('./icons/IconClearFormatting.ts'),
  "click": () => import('./icons/IconClick.ts'),
  "cliff-jumping": () => import('./icons/IconCliffJumping.ts'),
  "clipboard-check": () => import('./icons/IconClipboardCheck.ts'),
  "clipboard-copy": () => import('./icons/IconClipboardCopy.ts'),
  "clipboard-data": () => import('./icons/IconClipboardData.ts'),
  "clipboard-heart": () => import('./icons/IconClipboardHeart.ts'),
  "clipboard-list": () => import('./icons/IconClipboardList.ts'),
  "clipboard-off": () => import('./icons/IconClipboardOff.ts'),
  "clipboard-plus": () => import('./icons/IconClipboardPlus.ts'),
  "clipboard-search": () => import('./icons/IconClipboardSearch.ts'),
  "clipboard-smile": () => import('./icons/IconClipboardSmile.ts'),
  "clipboard-text": () => import('./icons/IconClipboardText.ts'),
  "clipboard-typography": () => import('./icons/IconClipboardTypography.ts'),
  "clipboard-x": () => import('./icons/IconClipboardX.ts'),
  "clipboard": () => import('./icons/IconClipboard.ts'),
  "clock-12": () => import('./icons/IconClock12.ts'),
  "clock-2": () => import('./icons/IconClock2.ts'),
  "clock-24": () => import('./icons/IconClock24.ts'),
  "clock-bitcoin": () => import('./icons/IconClockBitcoin.ts'),
  "clock-bolt": () => import('./icons/IconClockBolt.ts'),
  "clock-cancel": () => import('./icons/IconClockCancel.ts'),
  "clock-check": () => import('./icons/IconClockCheck.ts'),
  "clock-code": () => import('./icons/IconClockCode.ts'),
  "clock-cog": () => import('./icons/IconClockCog.ts'),
  "clock-dollar": () => import('./icons/IconClockDollar.ts'),
  "clock-down": () => import('./icons/IconClockDown.ts'),
  "clock-edit": () => import('./icons/IconClockEdit.ts'),
  "clock-exclamation": () => import('./icons/IconClockExclamation.ts'),
  "clock-heart": () => import('./icons/IconClockHeart.ts'),
  "clock-hour-1": () => import('./icons/IconClockHour1.ts'),
  "clock-hour-10": () => import('./icons/IconClockHour10.ts'),
  "clock-hour-11": () => import('./icons/IconClockHour11.ts'),
  "clock-hour-12": () => import('./icons/IconClockHour12.ts'),
  "clock-hour-2": () => import('./icons/IconClockHour2.ts'),
  "clock-hour-3": () => import('./icons/IconClockHour3.ts'),
  "clock-hour-4": () => import('./icons/IconClockHour4.ts'),
  "clock-hour-5": () => import('./icons/IconClockHour5.ts'),
  "clock-hour-6": () => import('./icons/IconClockHour6.ts'),
  "clock-hour-7": () => import('./icons/IconClockHour7.ts'),
  "clock-hour-8": () => import('./icons/IconClockHour8.ts'),
  "clock-hour-9": () => import('./icons/IconClockHour9.ts'),
  "clock-minus": () => import('./icons/IconClockMinus.ts'),
  "clock-off": () => import('./icons/IconClockOff.ts'),
  "clock-pause": () => import('./icons/IconClockPause.ts'),
  "clock-pin": () => import('./icons/IconClockPin.ts'),
  "clock-play": () => import('./icons/IconClockPlay.ts'),
  "clock-plus": () => import('./icons/IconClockPlus.ts'),
  "clock-question": () => import('./icons/IconClockQuestion.ts'),
  "clock-record": () => import('./icons/IconClockRecord.ts'),
  "clock-search": () => import('./icons/IconClockSearch.ts'),
  "clock-share": () => import('./icons/IconClockShare.ts'),
  "clock-shield": () => import('./icons/IconClockShield.ts'),
  "clock-star": () => import('./icons/IconClockStar.ts'),
  "clock-stop": () => import('./icons/IconClockStop.ts'),
  "clock-up": () => import('./icons/IconClockUp.ts'),
  "clock-x": () => import('./icons/IconClockX.ts'),
  "clock": () => import('./icons/IconClock.ts'),
  "clothes-rack-off": () => import('./icons/IconClothesRackOff.ts'),
  "clothes-rack": () => import('./icons/IconClothesRack.ts'),
  "cloud-bitcoin": () => import('./icons/IconCloudBitcoin.ts'),
  "cloud-bolt": () => import('./icons/IconCloudBolt.ts'),
  "cloud-cancel": () => import('./icons/IconCloudCancel.ts'),
  "cloud-check": () => import('./icons/IconCloudCheck.ts'),
  "cloud-code": () => import('./icons/IconCloudCode.ts'),
  "cloud-cog": () => import('./icons/IconCloudCog.ts'),
  "cloud-computing": () => import('./icons/IconCloudComputing.ts'),
  "cloud-data-connection": () => import('./icons/IconCloudDataConnection.ts'),
  "cloud-dollar": () => import('./icons/IconCloudDollar.ts'),
  "cloud-down": () => import('./icons/IconCloudDown.ts'),
  "cloud-download": () => import('./icons/IconCloudDownload.ts'),
  "cloud-exclamation": () => import('./icons/IconCloudExclamation.ts'),
  "cloud-fog": () => import('./icons/IconCloudFog.ts'),
  "cloud-heart": () => import('./icons/IconCloudHeart.ts'),
  "cloud-lock-open": () => import('./icons/IconCloudLockOpen.ts'),
  "cloud-lock": () => import('./icons/IconCloudLock.ts'),
  "cloud-minus": () => import('./icons/IconCloudMinus.ts'),
  "cloud-network": () => import('./icons/IconCloudNetwork.ts'),
  "cloud-off": () => import('./icons/IconCloudOff.ts'),
  "cloud-pause": () => import('./icons/IconCloudPause.ts'),
  "cloud-pin": () => import('./icons/IconCloudPin.ts'),
  "cloud-plus": () => import('./icons/IconCloudPlus.ts'),
  "cloud-question": () => import('./icons/IconCloudQuestion.ts'),
  "cloud-rain": () => import('./icons/IconCloudRain.ts'),
  "cloud-search": () => import('./icons/IconCloudSearch.ts'),
  "cloud-share": () => import('./icons/IconCloudShare.ts'),
  "cloud-snow": () => import('./icons/IconCloudSnow.ts'),
  "cloud-star": () => import('./icons/IconCloudStar.ts'),
  "cloud-storm": () => import('./icons/IconCloudStorm.ts'),
  "cloud-up": () => import('./icons/IconCloudUp.ts'),
  "cloud-upload": () => import('./icons/IconCloudUpload.ts'),
  "cloud-x": () => import('./icons/IconCloudX.ts'),
  "cloud": () => import('./icons/IconCloud.ts'),
  "clover-2": () => import('./icons/IconClover2.ts'),
  "clover": () => import('./icons/IconClover.ts'),
  "clubs": () => import('./icons/IconClubs.ts'),
  "code-asterisk": () => import('./icons/IconCodeAsterisk.ts'),
  "code-circle-2": () => import('./icons/IconCodeCircle2.ts'),
  "code-circle": () => import('./icons/IconCodeCircle.ts'),
  "code-dots": () => import('./icons/IconCodeDots.ts'),
  "code-minus": () => import('./icons/IconCodeMinus.ts'),
  "code-off": () => import('./icons/IconCodeOff.ts'),
  "code-plus": () => import('./icons/IconCodePlus.ts'),
  "code-variable-minus": () => import('./icons/IconCodeVariableMinus.ts'),
  "code-variable-plus": () => import('./icons/IconCodeVariablePlus.ts'),
  "code-variable": () => import('./icons/IconCodeVariable.ts'),
  "code": () => import('./icons/IconCode.ts'),
  "coffee-off": () => import('./icons/IconCoffeeOff.ts'),
  "coffee": () => import('./icons/IconCoffee.ts'),
  "coffin": () => import('./icons/IconCoffin.ts'),
  "coin-bitcoin": () => import('./icons/IconCoinBitcoin.ts'),
  "coin-euro": () => import('./icons/IconCoinEuro.ts'),
  "coin-monero": () => import('./icons/IconCoinMonero.ts'),
  "coin-off": () => import('./icons/IconCoinOff.ts'),
  "coin-pound": () => import('./icons/IconCoinPound.ts'),
  "coin-rupee": () => import('./icons/IconCoinRupee.ts'),
  "coin-taka": () => import('./icons/IconCoinTaka.ts'),
  "coin-yen": () => import('./icons/IconCoinYen.ts'),
  "coin-yuan": () => import('./icons/IconCoinYuan.ts'),
  "coin": () => import('./icons/IconCoin.ts'),
  "coins": () => import('./icons/IconCoins.ts'),
  "color-filter": () => import('./icons/IconColorFilter.ts'),
  "color-picker-off": () => import('./icons/IconColorPickerOff.ts'),
  "color-picker": () => import('./icons/IconColorPicker.ts'),
  "color-swatch-off": () => import('./icons/IconColorSwatchOff.ts'),
  "color-swatch": () => import('./icons/IconColorSwatch.ts'),
  "column-insert-left": () => import('./icons/IconColumnInsertLeft.ts'),
  "column-insert-right": () => import('./icons/IconColumnInsertRight.ts'),
  "column-remove": () => import('./icons/IconColumnRemove.ts'),
  "columns-1": () => import('./icons/IconColumns1.ts'),
  "columns-2": () => import('./icons/IconColumns2.ts'),
  "columns-3": () => import('./icons/IconColumns3.ts'),
  "columns-off": () => import('./icons/IconColumnsOff.ts'),
  "columns": () => import('./icons/IconColumns.ts'),
  "comet": () => import('./icons/IconComet.ts'),
  "command-off": () => import('./icons/IconCommandOff.ts'),
  "command": () => import('./icons/IconCommand.ts'),
  "compass-off": () => import('./icons/IconCompassOff.ts'),
  "compass": () => import('./icons/IconCompass.ts'),
  "components-off": () => import('./icons/IconComponentsOff.ts'),
  "components": () => import('./icons/IconComponents.ts'),
  "cone-2": () => import('./icons/IconCone2.ts'),
  "cone-off": () => import('./icons/IconConeOff.ts'),
  "cone-plus": () => import('./icons/IconConePlus.ts'),
  "cone": () => import('./icons/IconCone.ts'),
  "confetti-off": () => import('./icons/IconConfettiOff.ts'),
  "confetti": () => import('./icons/IconConfetti.ts'),
  "confucius": () => import('./icons/IconConfucius.ts'),
  "congruent-to": () => import('./icons/IconCongruentTo.ts'),
  "container-off": () => import('./icons/IconContainerOff.ts'),
  "container": () => import('./icons/IconContainer.ts'),
  "contract": () => import('./icons/IconContract.ts'),
  "contrast-2-off": () => import('./icons/IconContrast2Off.ts'),
  "contrast-2": () => import('./icons/IconContrast2.ts'),
  "contrast-off": () => import('./icons/IconContrastOff.ts'),
  "contrast": () => import('./icons/IconContrast.ts'),
  "cooker": () => import('./icons/IconCooker.ts'),
  "cookie-man": () => import('./icons/IconCookieMan.ts'),
  "cookie-off": () => import('./icons/IconCookieOff.ts'),
  "cookie": () => import('./icons/IconCookie.ts'),
  "copy-check": () => import('./icons/IconCopyCheck.ts'),
  "copy-minus": () => import('./icons/IconCopyMinus.ts'),
  "copy-off": () => import('./icons/IconCopyOff.ts'),
  "copy-plus": () => import('./icons/IconCopyPlus.ts'),
  "copy-x": () => import('./icons/IconCopyX.ts'),
  "copy": () => import('./icons/IconCopy.ts'),
  "copyleft-off": () => import('./icons/IconCopyleftOff.ts'),
  "copyleft": () => import('./icons/IconCopyleft.ts'),
  "copyright-off": () => import('./icons/IconCopyrightOff.ts'),
  "copyright": () => import('./icons/IconCopyright.ts'),
  "corner-down-left-double": () => import('./icons/IconCornerDownLeftDouble.ts'),
  "corner-down-left": () => import('./icons/IconCornerDownLeft.ts'),
  "corner-down-right-double": () => import('./icons/IconCornerDownRightDouble.ts'),
  "corner-down-right": () => import('./icons/IconCornerDownRight.ts'),
  "corner-left-down-double": () => import('./icons/IconCornerLeftDownDouble.ts'),
  "corner-left-down": () => import('./icons/IconCornerLeftDown.ts'),
  "corner-left-up-double": () => import('./icons/IconCornerLeftUpDouble.ts'),
  "corner-left-up": () => import('./icons/IconCornerLeftUp.ts'),
  "corner-right-down-double": () => import('./icons/IconCornerRightDownDouble.ts'),
  "corner-right-down": () => import('./icons/IconCornerRightDown.ts'),
  "corner-right-up-double": () => import('./icons/IconCornerRightUpDouble.ts'),
  "corner-right-up": () => import('./icons/IconCornerRightUp.ts'),
  "corner-up-left-double": () => import('./icons/IconCornerUpLeftDouble.ts'),
  "corner-up-left": () => import('./icons/IconCornerUpLeft.ts'),
  "corner-up-right-double": () => import('./icons/IconCornerUpRightDouble.ts'),
  "corner-up-right": () => import('./icons/IconCornerUpRight.ts'),
  "cpu-2": () => import('./icons/IconCpu2.ts'),
  "cpu-off": () => import('./icons/IconCpuOff.ts'),
  "cpu": () => import('./icons/IconCpu.ts'),
  "crane-off": () => import('./icons/IconCraneOff.ts'),
  "crane": () => import('./icons/IconCrane.ts'),
  "creative-commons-by": () => import('./icons/IconCreativeCommonsBy.ts'),
  "creative-commons-nc": () => import('./icons/IconCreativeCommonsNc.ts'),
  "creative-commons-nd": () => import('./icons/IconCreativeCommonsNd.ts'),
  "creative-commons-off": () => import('./icons/IconCreativeCommonsOff.ts'),
  "creative-commons-sa": () => import('./icons/IconCreativeCommonsSa.ts'),
  "creative-commons-zero": () => import('./icons/IconCreativeCommonsZero.ts'),
  "creative-commons": () => import('./icons/IconCreativeCommons.ts'),
  "credit-card-off": () => import('./icons/IconCreditCardOff.ts'),
  "credit-card-pay": () => import('./icons/IconCreditCardPay.ts'),
  "credit-card-refund": () => import('./icons/IconCreditCardRefund.ts'),
  "credit-card": () => import('./icons/IconCreditCard.ts'),
  "cricket": () => import('./icons/IconCricket.ts'),
  "crop-1-1": () => import('./icons/IconCrop11.ts'),
  "crop-16-9": () => import('./icons/IconCrop169.ts'),
  "crop-3-2": () => import('./icons/IconCrop32.ts'),
  "crop-5-4": () => import('./icons/IconCrop54.ts'),
  "crop-7-5": () => import('./icons/IconCrop75.ts'),
  "crop-landscape": () => import('./icons/IconCropLandscape.ts'),
  "crop-portrait": () => import('./icons/IconCropPortrait.ts'),
  "crop": () => import('./icons/IconCrop.ts'),
  "cross-off": () => import('./icons/IconCrossOff.ts'),
  "cross": () => import('./icons/IconCross.ts'),
  "crosshair": () => import('./icons/IconCrosshair.ts'),
  "crown-off": () => import('./icons/IconCrownOff.ts'),
  "crown": () => import('./icons/IconCrown.ts'),
  "crutches-off": () => import('./icons/IconCrutchesOff.ts'),
  "crutches": () => import('./icons/IconCrutches.ts'),
  "crystal-ball": () => import('./icons/IconCrystalBall.ts'),
  "csv": () => import('./icons/IconCsv.ts'),
  "cube-3d-sphere-off": () => import('./icons/IconCube3dSphereOff.ts'),
  "cube-3d-sphere": () => import('./icons/IconCube3dSphere.ts'),
  "cube-off": () => import('./icons/IconCubeOff.ts'),
  "cube-plus": () => import('./icons/IconCubePlus.ts'),
  "cube-send": () => import('./icons/IconCubeSend.ts'),
  "cube-spark": () => import('./icons/IconCubeSpark.ts'),
  "cube-unfolded": () => import('./icons/IconCubeUnfolded.ts'),
  "cube": () => import('./icons/IconCube.ts'),
  "cup-off": () => import('./icons/IconCupOff.ts'),
  "cup": () => import('./icons/IconCup.ts'),
  "curling": () => import('./icons/IconCurling.ts'),
  "curly-loop": () => import('./icons/IconCurlyLoop.ts'),
  "currency-afghani": () => import('./icons/IconCurrencyAfghani.ts'),
  "currency-bahraini": () => import('./icons/IconCurrencyBahraini.ts'),
  "currency-baht": () => import('./icons/IconCurrencyBaht.ts'),
  "currency-bitcoin": () => import('./icons/IconCurrencyBitcoin.ts'),
  "currency-cent": () => import('./icons/IconCurrencyCent.ts'),
  "currency-dinar": () => import('./icons/IconCurrencyDinar.ts'),
  "currency-dirham": () => import('./icons/IconCurrencyDirham.ts'),
  "currency-dogecoin": () => import('./icons/IconCurrencyDogecoin.ts'),
  "currency-dollar-australian": () => import('./icons/IconCurrencyDollarAustralian.ts'),
  "currency-dollar-brunei": () => import('./icons/IconCurrencyDollarBrunei.ts'),
  "currency-dollar-canadian": () => import('./icons/IconCurrencyDollarCanadian.ts'),
  "currency-dollar-guyanese": () => import('./icons/IconCurrencyDollarGuyanese.ts'),
  "currency-dollar-off": () => import('./icons/IconCurrencyDollarOff.ts'),
  "currency-dollar-singapore": () => import('./icons/IconCurrencyDollarSingapore.ts'),
  "currency-dollar-zimbabwean": () => import('./icons/IconCurrencyDollarZimbabwean.ts'),
  "currency-dollar": () => import('./icons/IconCurrencyDollar.ts'),
  "currency-dong": () => import('./icons/IconCurrencyDong.ts'),
  "currency-dram": () => import('./icons/IconCurrencyDram.ts'),
  "currency-ethereum": () => import('./icons/IconCurrencyEthereum.ts'),
  "currency-euro-off": () => import('./icons/IconCurrencyEuroOff.ts'),
  "currency-euro": () => import('./icons/IconCurrencyEuro.ts'),
  "currency-florin": () => import('./icons/IconCurrencyFlorin.ts'),
  "currency-forint": () => import('./icons/IconCurrencyForint.ts'),
  "currency-frank": () => import('./icons/IconCurrencyFrank.ts'),
  "currency-guarani": () => import('./icons/IconCurrencyGuarani.ts'),
  "currency-hryvnia": () => import('./icons/IconCurrencyHryvnia.ts'),
  "currency-iranian-rial": () => import('./icons/IconCurrencyIranianRial.ts'),
  "currency-kip": () => import('./icons/IconCurrencyKip.ts'),
  "currency-krone-czech": () => import('./icons/IconCurrencyKroneCzech.ts'),
  "currency-krone-danish": () => import('./icons/IconCurrencyKroneDanish.ts'),
  "currency-krone-swedish": () => import('./icons/IconCurrencyKroneSwedish.ts'),
  "currency-lari": () => import('./icons/IconCurrencyLari.ts'),
  "currency-leu": () => import('./icons/IconCurrencyLeu.ts'),
  "currency-lira": () => import('./icons/IconCurrencyLira.ts'),
  "currency-litecoin": () => import('./icons/IconCurrencyLitecoin.ts'),
  "currency-lyd": () => import('./icons/IconCurrencyLyd.ts'),
  "currency-manat": () => import('./icons/IconCurrencyManat.ts'),
  "currency-monero": () => import('./icons/IconCurrencyMonero.ts'),
  "currency-naira": () => import('./icons/IconCurrencyNaira.ts'),
  "currency-nano": () => import('./icons/IconCurrencyNano.ts'),
  "currency-off": () => import('./icons/IconCurrencyOff.ts'),
  "currency-paanga": () => import('./icons/IconCurrencyPaanga.ts'),
  "currency-peso": () => import('./icons/IconCurrencyPeso.ts'),
  "currency-pound-off": () => import('./icons/IconCurrencyPoundOff.ts'),
  "currency-pound": () => import('./icons/IconCurrencyPound.ts'),
  "currency-quetzal": () => import('./icons/IconCurrencyQuetzal.ts'),
  "currency-real": () => import('./icons/IconCurrencyReal.ts'),
  "currency-renminbi": () => import('./icons/IconCurrencyRenminbi.ts'),
  "currency-ripple": () => import('./icons/IconCurrencyRipple.ts'),
  "currency-riyal": () => import('./icons/IconCurrencyRiyal.ts'),
  "currency-rubel": () => import('./icons/IconCurrencyRubel.ts'),
  "currency-rufiyaa": () => import('./icons/IconCurrencyRufiyaa.ts'),
  "currency-rupee-nepalese": () => import('./icons/IconCurrencyRupeeNepalese.ts'),
  "currency-rupee": () => import('./icons/IconCurrencyRupee.ts'),
  "currency-shekel": () => import('./icons/IconCurrencyShekel.ts'),
  "currency-solana": () => import('./icons/IconCurrencySolana.ts'),
  "currency-som": () => import('./icons/IconCurrencySom.ts'),
  "currency-taka": () => import('./icons/IconCurrencyTaka.ts'),
  "currency-tenge": () => import('./icons/IconCurrencyTenge.ts'),
  "currency-tugrik": () => import('./icons/IconCurrencyTugrik.ts'),
  "currency-won": () => import('./icons/IconCurrencyWon.ts'),
  "currency-xrp": () => import('./icons/IconCurrencyXrp.ts'),
  "currency-yen-off": () => import('./icons/IconCurrencyYenOff.ts'),
  "currency-yen": () => import('./icons/IconCurrencyYen.ts'),
  "currency-yuan": () => import('./icons/IconCurrencyYuan.ts'),
  "currency-zloty": () => import('./icons/IconCurrencyZloty.ts'),
  "currency": () => import('./icons/IconCurrency.ts'),
  "current-location-off": () => import('./icons/IconCurrentLocationOff.ts'),
  "current-location": () => import('./icons/IconCurrentLocation.ts'),
  "cursor-off": () => import('./icons/IconCursorOff.ts'),
  "cursor-text": () => import('./icons/IconCursorText.ts'),
  "cut": () => import('./icons/IconCut.ts'),
  "cylinder-off": () => import('./icons/IconCylinderOff.ts'),
  "cylinder-plus": () => import('./icons/IconCylinderPlus.ts'),
  "cylinder": () => import('./icons/IconCylinder.ts'),
  "dashboard-off": () => import('./icons/IconDashboardOff.ts'),
  "dashboard": () => import('./icons/IconDashboard.ts'),
  "database-cog": () => import('./icons/IconDatabaseCog.ts'),
  "database-dollar": () => import('./icons/IconDatabaseDollar.ts'),
  "database-edit": () => import('./icons/IconDatabaseEdit.ts'),
  "database-exclamation": () => import('./icons/IconDatabaseExclamation.ts'),
  "database-export": () => import('./icons/IconDatabaseExport.ts'),
  "database-heart": () => import('./icons/IconDatabaseHeart.ts'),
  "database-import": () => import('./icons/IconDatabaseImport.ts'),
  "database-leak": () => import('./icons/IconDatabaseLeak.ts'),
  "database-minus": () => import('./icons/IconDatabaseMinus.ts'),
  "database-off": () => import('./icons/IconDatabaseOff.ts'),
  "database-plus": () => import('./icons/IconDatabasePlus.ts'),
  "database-search": () => import('./icons/IconDatabaseSearch.ts'),
  "database-share": () => import('./icons/IconDatabaseShare.ts'),
  "database-smile": () => import('./icons/IconDatabaseSmile.ts'),
  "database-star": () => import('./icons/IconDatabaseStar.ts'),
  "database-x": () => import('./icons/IconDatabaseX.ts'),
  "database": () => import('./icons/IconDatabase.ts'),
  "deaf": () => import('./icons/IconDeaf.ts'),
  "decimal": () => import('./icons/IconDecimal.ts'),
  "deer": () => import('./icons/IconDeer.ts'),
  "delta": () => import('./icons/IconDelta.ts'),
  "dental-broken": () => import('./icons/IconDentalBroken.ts'),
  "dental-off": () => import('./icons/IconDentalOff.ts'),
  "dental": () => import('./icons/IconDental.ts'),
  "deselect": () => import('./icons/IconDeselect.ts'),
  "desk": () => import('./icons/IconDesk.ts'),
  "details-off": () => import('./icons/IconDetailsOff.ts'),
  "details": () => import('./icons/IconDetails.ts'),
  "device-airpods-case": () => import('./icons/IconDeviceAirpodsCase.ts'),
  "device-airpods": () => import('./icons/IconDeviceAirpods.ts'),
  "device-airtag": () => import('./icons/IconDeviceAirtag.ts'),
  "device-analytics": () => import('./icons/IconDeviceAnalytics.ts'),
  "device-audio-tape": () => import('./icons/IconDeviceAudioTape.ts'),
  "device-camera-phone": () => import('./icons/IconDeviceCameraPhone.ts'),
  "device-cctv-off": () => import('./icons/IconDeviceCctvOff.ts'),
  "device-cctv": () => import('./icons/IconDeviceCctv.ts'),
  "device-computer-camera-off": () => import('./icons/IconDeviceComputerCameraOff.ts'),
  "device-computer-camera": () => import('./icons/IconDeviceComputerCamera.ts'),
  "device-desktop-analytics": () => import('./icons/IconDeviceDesktopAnalytics.ts'),
  "device-desktop-bolt": () => import('./icons/IconDeviceDesktopBolt.ts'),
  "device-desktop-cancel": () => import('./icons/IconDeviceDesktopCancel.ts'),
  "device-desktop-check": () => import('./icons/IconDeviceDesktopCheck.ts'),
  "device-desktop-code": () => import('./icons/IconDeviceDesktopCode.ts'),
  "device-desktop-cog": () => import('./icons/IconDeviceDesktopCog.ts'),
  "device-desktop-dollar": () => import('./icons/IconDeviceDesktopDollar.ts'),
  "device-desktop-down": () => import('./icons/IconDeviceDesktopDown.ts'),
  "device-desktop-exclamation": () => import('./icons/IconDeviceDesktopExclamation.ts'),
  "device-desktop-heart": () => import('./icons/IconDeviceDesktopHeart.ts'),
  "device-desktop-minus": () => import('./icons/IconDeviceDesktopMinus.ts'),
  "device-desktop-off": () => import('./icons/IconDeviceDesktopOff.ts'),
  "device-desktop-pause": () => import('./icons/IconDeviceDesktopPause.ts'),
  "device-desktop-pin": () => import('./icons/IconDeviceDesktopPin.ts'),
  "device-desktop-plus": () => import('./icons/IconDeviceDesktopPlus.ts'),
  "device-desktop-question": () => import('./icons/IconDeviceDesktopQuestion.ts'),
  "device-desktop-search": () => import('./icons/IconDeviceDesktopSearch.ts'),
  "device-desktop-share": () => import('./icons/IconDeviceDesktopShare.ts'),
  "device-desktop-star": () => import('./icons/IconDeviceDesktopStar.ts'),
  "device-desktop-up": () => import('./icons/IconDeviceDesktopUp.ts'),
  "device-desktop-x": () => import('./icons/IconDeviceDesktopX.ts'),
  "device-desktop": () => import('./icons/IconDeviceDesktop.ts'),
  "device-floppy": () => import('./icons/IconDeviceFloppy.ts'),
  "device-gamepad-2": () => import('./icons/IconDeviceGamepad2.ts'),
  "device-gamepad-3": () => import('./icons/IconDeviceGamepad3.ts'),
  "device-gamepad": () => import('./icons/IconDeviceGamepad.ts'),
  "device-heart-monitor": () => import('./icons/IconDeviceHeartMonitor.ts'),
  "device-imac-bolt": () => import('./icons/IconDeviceImacBolt.ts'),
  "device-imac-cancel": () => import('./icons/IconDeviceImacCancel.ts'),
  "device-imac-check": () => import('./icons/IconDeviceImacCheck.ts'),
  "device-imac-code": () => import('./icons/IconDeviceImacCode.ts'),
  "device-imac-cog": () => import('./icons/IconDeviceImacCog.ts'),
  "device-imac-dollar": () => import('./icons/IconDeviceImacDollar.ts'),
  "device-imac-down": () => import('./icons/IconDeviceImacDown.ts'),
  "device-imac-exclamation": () => import('./icons/IconDeviceImacExclamation.ts'),
  "device-imac-heart": () => import('./icons/IconDeviceImacHeart.ts'),
  "device-imac-minus": () => import('./icons/IconDeviceImacMinus.ts'),
  "device-imac-off": () => import('./icons/IconDeviceImacOff.ts'),
  "device-imac-pause": () => import('./icons/IconDeviceImacPause.ts'),
  "device-imac-pin": () => import('./icons/IconDeviceImacPin.ts'),
  "device-imac-plus": () => import('./icons/IconDeviceImacPlus.ts'),
  "device-imac-question": () => import('./icons/IconDeviceImacQuestion.ts'),
  "device-imac-search": () => import('./icons/IconDeviceImacSearch.ts'),
  "device-imac-share": () => import('./icons/IconDeviceImacShare.ts'),
  "device-imac-star": () => import('./icons/IconDeviceImacStar.ts'),
  "device-imac-up": () => import('./icons/IconDeviceImacUp.ts'),
  "device-imac-x": () => import('./icons/IconDeviceImacX.ts'),
  "device-imac": () => import('./icons/IconDeviceImac.ts'),
  "device-ipad-bolt": () => import('./icons/IconDeviceIpadBolt.ts'),
  "device-ipad-cancel": () => import('./icons/IconDeviceIpadCancel.ts'),
  "device-ipad-check": () => import('./icons/IconDeviceIpadCheck.ts'),
  "device-ipad-code": () => import('./icons/IconDeviceIpadCode.ts'),
  "device-ipad-cog": () => import('./icons/IconDeviceIpadCog.ts'),
  "device-ipad-dollar": () => import('./icons/IconDeviceIpadDollar.ts'),
  "device-ipad-down": () => import('./icons/IconDeviceIpadDown.ts'),
  "device-ipad-exclamation": () => import('./icons/IconDeviceIpadExclamation.ts'),
  "device-ipad-heart": () => import('./icons/IconDeviceIpadHeart.ts'),
  "device-ipad-horizontal-bolt": () => import('./icons/IconDeviceIpadHorizontalBolt.ts'),
  "device-ipad-horizontal-cancel": () => import('./icons/IconDeviceIpadHorizontalCancel.ts'),
  "device-ipad-horizontal-check": () => import('./icons/IconDeviceIpadHorizontalCheck.ts'),
  "device-ipad-horizontal-code": () => import('./icons/IconDeviceIpadHorizontalCode.ts'),
  "device-ipad-horizontal-cog": () => import('./icons/IconDeviceIpadHorizontalCog.ts'),
  "device-ipad-horizontal-dollar": () => import('./icons/IconDeviceIpadHorizontalDollar.ts'),
  "device-ipad-horizontal-down": () => import('./icons/IconDeviceIpadHorizontalDown.ts'),
  "device-ipad-horizontal-exclamation": () => import('./icons/IconDeviceIpadHorizontalExclamation.ts'),
  "device-ipad-horizontal-heart": () => import('./icons/IconDeviceIpadHorizontalHeart.ts'),
  "device-ipad-horizontal-minus": () => import('./icons/IconDeviceIpadHorizontalMinus.ts'),
  "device-ipad-horizontal-off": () => import('./icons/IconDeviceIpadHorizontalOff.ts'),
  "device-ipad-horizontal-pause": () => import('./icons/IconDeviceIpadHorizontalPause.ts'),
  "device-ipad-horizontal-pin": () => import('./icons/IconDeviceIpadHorizontalPin.ts'),
  "device-ipad-horizontal-plus": () => import('./icons/IconDeviceIpadHorizontalPlus.ts'),
  "device-ipad-horizontal-question": () => import('./icons/IconDeviceIpadHorizontalQuestion.ts'),
  "device-ipad-horizontal-search": () => import('./icons/IconDeviceIpadHorizontalSearch.ts'),
  "device-ipad-horizontal-share": () => import('./icons/IconDeviceIpadHorizontalShare.ts'),
  "device-ipad-horizontal-star": () => import('./icons/IconDeviceIpadHorizontalStar.ts'),
  "device-ipad-horizontal-up": () => import('./icons/IconDeviceIpadHorizontalUp.ts'),
  "device-ipad-horizontal-x": () => import('./icons/IconDeviceIpadHorizontalX.ts'),
  "device-ipad-horizontal": () => import('./icons/IconDeviceIpadHorizontal.ts'),
  "device-ipad-minus": () => import('./icons/IconDeviceIpadMinus.ts'),
  "device-ipad-off": () => import('./icons/IconDeviceIpadOff.ts'),
  "device-ipad-pause": () => import('./icons/IconDeviceIpadPause.ts'),
  "device-ipad-pin": () => import('./icons/IconDeviceIpadPin.ts'),
  "device-ipad-plus": () => import('./icons/IconDeviceIpadPlus.ts'),
  "device-ipad-question": () => import('./icons/IconDeviceIpadQuestion.ts'),
  "device-ipad-search": () => import('./icons/IconDeviceIpadSearch.ts'),
  "device-ipad-share": () => import('./icons/IconDeviceIpadShare.ts'),
  "device-ipad-star": () => import('./icons/IconDeviceIpadStar.ts'),
  "device-ipad-up": () => import('./icons/IconDeviceIpadUp.ts'),
  "device-ipad-x": () => import('./icons/IconDeviceIpadX.ts'),
  "device-ipad": () => import('./icons/IconDeviceIpad.ts'),
  "device-landline-phone": () => import('./icons/IconDeviceLandlinePhone.ts'),
  "device-laptop-off": () => import('./icons/IconDeviceLaptopOff.ts'),
  "device-laptop": () => import('./icons/IconDeviceLaptop.ts'),
  "device-mobile-bolt": () => import('./icons/IconDeviceMobileBolt.ts'),
  "device-mobile-cancel": () => import('./icons/IconDeviceMobileCancel.ts'),
  "device-mobile-charging": () => import('./icons/IconDeviceMobileCharging.ts'),
  "device-mobile-check": () => import('./icons/IconDeviceMobileCheck.ts'),
  "device-mobile-code": () => import('./icons/IconDeviceMobileCode.ts'),
  "device-mobile-cog": () => import('./icons/IconDeviceMobileCog.ts'),
  "device-mobile-dollar": () => import('./icons/IconDeviceMobileDollar.ts'),
  "device-mobile-down": () => import('./icons/IconDeviceMobileDown.ts'),
  "device-mobile-exclamation": () => import('./icons/IconDeviceMobileExclamation.ts'),
  "device-mobile-heart": () => import('./icons/IconDeviceMobileHeart.ts'),
  "device-mobile-message": () => import('./icons/IconDeviceMobileMessage.ts'),
  "device-mobile-minus": () => import('./icons/IconDeviceMobileMinus.ts'),
  "device-mobile-off": () => import('./icons/IconDeviceMobileOff.ts'),
  "device-mobile-pause": () => import('./icons/IconDeviceMobilePause.ts'),
  "device-mobile-pin": () => import('./icons/IconDeviceMobilePin.ts'),
  "device-mobile-plus": () => import('./icons/IconDeviceMobilePlus.ts'),
  "device-mobile-question": () => import('./icons/IconDeviceMobileQuestion.ts'),
  "device-mobile-rotated": () => import('./icons/IconDeviceMobileRotated.ts'),
  "device-mobile-search": () => import('./icons/IconDeviceMobileSearch.ts'),
  "device-mobile-share": () => import('./icons/IconDeviceMobileShare.ts'),
  "device-mobile-star": () => import('./icons/IconDeviceMobileStar.ts'),
  "device-mobile-up": () => import('./icons/IconDeviceMobileUp.ts'),
  "device-mobile-vibration": () => import('./icons/IconDeviceMobileVibration.ts'),
  "device-mobile-x": () => import('./icons/IconDeviceMobileX.ts'),
  "device-mobile": () => import('./icons/IconDeviceMobile.ts'),
  "device-nintendo-off": () => import('./icons/IconDeviceNintendoOff.ts'),
  "device-nintendo": () => import('./icons/IconDeviceNintendo.ts'),
  "device-projector": () => import('./icons/IconDeviceProjector.ts'),
  "device-remote": () => import('./icons/IconDeviceRemote.ts'),
  "device-sd-card": () => import('./icons/IconDeviceSdCard.ts'),
  "device-sim-1": () => import('./icons/IconDeviceSim1.ts'),
  "device-sim-2": () => import('./icons/IconDeviceSim2.ts'),
  "device-sim-3": () => import('./icons/IconDeviceSim3.ts'),
  "device-sim": () => import('./icons/IconDeviceSim.ts'),
  "device-speaker-off": () => import('./icons/IconDeviceSpeakerOff.ts'),
  "device-speaker": () => import('./icons/IconDeviceSpeaker.ts'),
  "device-tablet-bolt": () => import('./icons/IconDeviceTabletBolt.ts'),
  "device-tablet-cancel": () => import('./icons/IconDeviceTabletCancel.ts'),
  "device-tablet-check": () => import('./icons/IconDeviceTabletCheck.ts'),
  "device-tablet-code": () => import('./icons/IconDeviceTabletCode.ts'),
  "device-tablet-cog": () => import('./icons/IconDeviceTabletCog.ts'),
  "device-tablet-dollar": () => import('./icons/IconDeviceTabletDollar.ts'),
  "device-tablet-down": () => import('./icons/IconDeviceTabletDown.ts'),
  "device-tablet-exclamation": () => import('./icons/IconDeviceTabletExclamation.ts'),
  "device-tablet-heart": () => import('./icons/IconDeviceTabletHeart.ts'),
  "device-tablet-minus": () => import('./icons/IconDeviceTabletMinus.ts'),
  "device-tablet-off": () => import('./icons/IconDeviceTabletOff.ts'),
  "device-tablet-pause": () => import('./icons/IconDeviceTabletPause.ts'),
  "device-tablet-pin": () => import('./icons/IconDeviceTabletPin.ts'),
  "device-tablet-plus": () => import('./icons/IconDeviceTabletPlus.ts'),
  "device-tablet-question": () => import('./icons/IconDeviceTabletQuestion.ts'),
  "device-tablet-search": () => import('./icons/IconDeviceTabletSearch.ts'),
  "device-tablet-share": () => import('./icons/IconDeviceTabletShare.ts'),
  "device-tablet-star": () => import('./icons/IconDeviceTabletStar.ts'),
  "device-tablet-up": () => import('./icons/IconDeviceTabletUp.ts'),
  "device-tablet-x": () => import('./icons/IconDeviceTabletX.ts'),
  "device-tablet": () => import('./icons/IconDeviceTablet.ts'),
  "device-tv-off": () => import('./icons/IconDeviceTvOff.ts'),
  "device-tv-old": () => import('./icons/IconDeviceTvOld.ts'),
  "device-tv": () => import('./icons/IconDeviceTv.ts'),
  "device-unknown": () => import('./icons/IconDeviceUnknown.ts'),
  "device-usb": () => import('./icons/IconDeviceUsb.ts'),
  "device-vision-pro": () => import('./icons/IconDeviceVisionPro.ts'),
  "device-watch-bolt": () => import('./icons/IconDeviceWatchBolt.ts'),
  "device-watch-cancel": () => import('./icons/IconDeviceWatchCancel.ts'),
  "device-watch-check": () => import('./icons/IconDeviceWatchCheck.ts'),
  "device-watch-code": () => import('./icons/IconDeviceWatchCode.ts'),
  "device-watch-cog": () => import('./icons/IconDeviceWatchCog.ts'),
  "device-watch-dollar": () => import('./icons/IconDeviceWatchDollar.ts'),
  "device-watch-down": () => import('./icons/IconDeviceWatchDown.ts'),
  "device-watch-exclamation": () => import('./icons/IconDeviceWatchExclamation.ts'),
  "device-watch-heart": () => import('./icons/IconDeviceWatchHeart.ts'),
  "device-watch-minus": () => import('./icons/IconDeviceWatchMinus.ts'),
  "device-watch-off": () => import('./icons/IconDeviceWatchOff.ts'),
  "device-watch-pause": () => import('./icons/IconDeviceWatchPause.ts'),
  "device-watch-pin": () => import('./icons/IconDeviceWatchPin.ts'),
  "device-watch-plus": () => import('./icons/IconDeviceWatchPlus.ts'),
  "device-watch-question": () => import('./icons/IconDeviceWatchQuestion.ts'),
  "device-watch-search": () => import('./icons/IconDeviceWatchSearch.ts'),
  "device-watch-share": () => import('./icons/IconDeviceWatchShare.ts'),
  "device-watch-star": () => import('./icons/IconDeviceWatchStar.ts'),
  "device-watch-stats-2": () => import('./icons/IconDeviceWatchStats2.ts'),
  "device-watch-stats": () => import('./icons/IconDeviceWatchStats.ts'),
  "device-watch-up": () => import('./icons/IconDeviceWatchUp.ts'),
  "device-watch-x": () => import('./icons/IconDeviceWatchX.ts'),
  "device-watch": () => import('./icons/IconDeviceWatch.ts'),
  "devices-2": () => import('./icons/IconDevices2.ts'),
  "devices-bolt": () => import('./icons/IconDevicesBolt.ts'),
  "devices-cancel": () => import('./icons/IconDevicesCancel.ts'),
  "devices-check": () => import('./icons/IconDevicesCheck.ts'),
  "devices-code": () => import('./icons/IconDevicesCode.ts'),
  "devices-cog": () => import('./icons/IconDevicesCog.ts'),
  "devices-dollar": () => import('./icons/IconDevicesDollar.ts'),
  "devices-down": () => import('./icons/IconDevicesDown.ts'),
  "devices-exclamation": () => import('./icons/IconDevicesExclamation.ts'),
  "devices-heart": () => import('./icons/IconDevicesHeart.ts'),
  "devices-minus": () => import('./icons/IconDevicesMinus.ts'),
  "devices-off": () => import('./icons/IconDevicesOff.ts'),
  "devices-pause": () => import('./icons/IconDevicesPause.ts'),
  "devices-pc-off": () => import('./icons/IconDevicesPcOff.ts'),
  "devices-pc": () => import('./icons/IconDevicesPc.ts'),
  "devices-pin": () => import('./icons/IconDevicesPin.ts'),
  "devices-plus": () => import('./icons/IconDevicesPlus.ts'),
  "devices-question": () => import('./icons/IconDevicesQuestion.ts'),
  "devices-search": () => import('./icons/IconDevicesSearch.ts'),
  "devices-share": () => import('./icons/IconDevicesShare.ts'),
  "devices-star": () => import('./icons/IconDevicesStar.ts'),
  "devices-up": () => import('./icons/IconDevicesUp.ts'),
  "devices-x": () => import('./icons/IconDevicesX.ts'),
  "devices": () => import('./icons/IconDevices.ts'),
  "diabolo-off": () => import('./icons/IconDiaboloOff.ts'),
  "diabolo-plus": () => import('./icons/IconDiaboloPlus.ts'),
  "diabolo": () => import('./icons/IconDiabolo.ts'),
  "dialpad-off": () => import('./icons/IconDialpadOff.ts'),
  "dialpad": () => import('./icons/IconDialpad.ts'),
  "diamond-off": () => import('./icons/IconDiamondOff.ts'),
  "diamond": () => import('./icons/IconDiamond.ts'),
  "diamonds": () => import('./icons/IconDiamonds.ts'),
  "diaper": () => import('./icons/IconDiaper.ts'),
  "dice-1": () => import('./icons/IconDice1.ts'),
  "dice-2": () => import('./icons/IconDice2.ts'),
  "dice-3": () => import('./icons/IconDice3.ts'),
  "dice-4": () => import('./icons/IconDice4.ts'),
  "dice-5": () => import('./icons/IconDice5.ts'),
  "dice-6": () => import('./icons/IconDice6.ts'),
  "dice": () => import('./icons/IconDice.ts'),
  "dimensions": () => import('./icons/IconDimensions.ts'),
  "direction-arrows": () => import('./icons/IconDirectionArrows.ts'),
  "direction-horizontal": () => import('./icons/IconDirectionHorizontal.ts'),
  "direction-sign-off": () => import('./icons/IconDirectionSignOff.ts'),
  "direction-sign": () => import('./icons/IconDirectionSign.ts'),
  "direction": () => import('./icons/IconDirection.ts'),
  "directions-off": () => import('./icons/IconDirectionsOff.ts'),
  "directions": () => import('./icons/IconDirections.ts'),
  "disabled-2": () => import('./icons/IconDisabled2.ts'),
  "disabled-off": () => import('./icons/IconDisabledOff.ts'),
  "disabled": () => import('./icons/IconDisabled.ts'),
  "disc-golf": () => import('./icons/IconDiscGolf.ts'),
  "disc-off": () => import('./icons/IconDiscOff.ts'),
  "disc": () => import('./icons/IconDisc.ts'),
  "discount-off": () => import('./icons/IconDiscountOff.ts'),
  "discount": () => import('./icons/IconDiscount.ts'),
  "divide": () => import('./icons/IconDivide.ts'),
  "dna-2-off": () => import('./icons/IconDna2Off.ts'),
  "dna-2": () => import('./icons/IconDna2.ts'),
  "dna-off": () => import('./icons/IconDnaOff.ts'),
  "dna": () => import('./icons/IconDna.ts'),
  "dog-bowl": () => import('./icons/IconDogBowl.ts'),
  "dog": () => import('./icons/IconDog.ts'),
  "door-enter": () => import('./icons/IconDoorEnter.ts'),
  "door-exit": () => import('./icons/IconDoorExit.ts'),
  "door-off": () => import('./icons/IconDoorOff.ts'),
  "door": () => import('./icons/IconDoor.ts'),
  "dots-circle-horizontal": () => import('./icons/IconDotsCircleHorizontal.ts'),
  "dots-diagonal-2": () => import('./icons/IconDotsDiagonal2.ts'),
  "dots-diagonal": () => import('./icons/IconDotsDiagonal.ts'),
  "dots-vertical": () => import('./icons/IconDotsVertical.ts'),
  "dots": () => import('./icons/IconDots.ts'),
  "download-off": () => import('./icons/IconDownloadOff.ts'),
  "download": () => import('./icons/IconDownload.ts'),
  "drag-drop-2": () => import('./icons/IconDragDrop2.ts'),
  "drag-drop": () => import('./icons/IconDragDrop.ts'),
  "drone-off": () => import('./icons/IconDroneOff.ts'),
  "drone": () => import('./icons/IconDrone.ts'),
  "drop-circle": () => import('./icons/IconDropCircle.ts'),
  "droplet-bolt": () => import('./icons/IconDropletBolt.ts'),
  "droplet-cancel": () => import('./icons/IconDropletCancel.ts'),
  "droplet-check": () => import('./icons/IconDropletCheck.ts'),
  "droplet-code": () => import('./icons/IconDropletCode.ts'),
  "droplet-cog": () => import('./icons/IconDropletCog.ts'),
  "droplet-dollar": () => import('./icons/IconDropletDollar.ts'),
  "droplet-down": () => import('./icons/IconDropletDown.ts'),
  "droplet-exclamation": () => import('./icons/IconDropletExclamation.ts'),
  "droplet-half-2": () => import('./icons/IconDropletHalf2.ts'),
  "droplet-half": () => import('./icons/IconDropletHalf.ts'),
  "droplet-heart": () => import('./icons/IconDropletHeart.ts'),
  "droplet-minus": () => import('./icons/IconDropletMinus.ts'),
  "droplet-off": () => import('./icons/IconDropletOff.ts'),
  "droplet-pause": () => import('./icons/IconDropletPause.ts'),
  "droplet-pin": () => import('./icons/IconDropletPin.ts'),
  "droplet-plus": () => import('./icons/IconDropletPlus.ts'),
  "droplet-question": () => import('./icons/IconDropletQuestion.ts'),
  "droplet-search": () => import('./icons/IconDropletSearch.ts'),
  "droplet-share": () => import('./icons/IconDropletShare.ts'),
  "droplet-star": () => import('./icons/IconDropletStar.ts'),
  "droplet-up": () => import('./icons/IconDropletUp.ts'),
  "droplet-x": () => import('./icons/IconDropletX.ts'),
  "droplet": () => import('./icons/IconDroplet.ts'),
  "droplets": () => import('./icons/IconDroplets.ts'),
  "dual-screen": () => import('./icons/IconDualScreen.ts'),
  "dumpling": () => import('./icons/IconDumpling.ts'),
  "e-passport": () => import('./icons/IconEPassport.ts'),
  "ear-off": () => import('./icons/IconEarOff.ts'),
  "ear-scan": () => import('./icons/IconEarScan.ts'),
  "ear": () => import('./icons/IconEar.ts'),
  "ease-in-control-point": () => import('./icons/IconEaseInControlPoint.ts'),
  "ease-in-out-control-points": () => import('./icons/IconEaseInOutControlPoints.ts'),
  "ease-in-out": () => import('./icons/IconEaseInOut.ts'),
  "ease-in": () => import('./icons/IconEaseIn.ts'),
  "ease-out-control-point": () => import('./icons/IconEaseOutControlPoint.ts'),
  "ease-out": () => import('./icons/IconEaseOut.ts'),
  "edit-circle-off": () => import('./icons/IconEditCircleOff.ts'),
  "edit-circle": () => import('./icons/IconEditCircle.ts'),
  "edit-off": () => import('./icons/IconEditOff.ts'),
  "edit": () => import('./icons/IconEdit.ts'),
  "egg-cracked": () => import('./icons/IconEggCracked.ts'),
  "egg-fried": () => import('./icons/IconEggFried.ts'),
  "egg-off": () => import('./icons/IconEggOff.ts'),
  "egg": () => import('./icons/IconEgg.ts'),
  "eggs": () => import('./icons/IconEggs.ts'),
  "elevator-off": () => import('./icons/IconElevatorOff.ts'),
  "elevator": () => import('./icons/IconElevator.ts'),
  "emergency-bed": () => import('./icons/IconEmergencyBed.ts'),
  "empathize-off": () => import('./icons/IconEmpathizeOff.ts'),
  "empathize": () => import('./icons/IconEmpathize.ts'),
  "emphasis": () => import('./icons/IconEmphasis.ts'),
  "engine-off": () => import('./icons/IconEngineOff.ts'),
  "engine": () => import('./icons/IconEngine.ts'),
  "equal-double": () => import('./icons/IconEqualDouble.ts'),
  "equal-not": () => import('./icons/IconEqualNot.ts'),
  "equal": () => import('./icons/IconEqual.ts'),
  "eraser-off": () => import('./icons/IconEraserOff.ts'),
  "eraser": () => import('./icons/IconEraser.ts'),
  "error-404-off": () => import('./icons/IconError404Off.ts'),
  "error-404": () => import('./icons/IconError404.ts'),
  "escalator-down": () => import('./icons/IconEscalatorDown.ts'),
  "escalator-up": () => import('./icons/IconEscalatorUp.ts'),
  "escalator": () => import('./icons/IconEscalator.ts'),
  "exchange-off": () => import('./icons/IconExchangeOff.ts'),
  "exchange": () => import('./icons/IconExchange.ts'),
  "exclamation-circle": () => import('./icons/IconExclamationCircle.ts'),
  "exclamation-mark-off": () => import('./icons/IconExclamationMarkOff.ts'),
  "exclamation-mark": () => import('./icons/IconExclamationMark.ts'),
  "explicit-off": () => import('./icons/IconExplicitOff.ts'),
  "explicit": () => import('./icons/IconExplicit.ts'),
  "exposure-0": () => import('./icons/IconExposure0.ts'),
  "exposure-minus-1": () => import('./icons/IconExposureMinus1.ts'),
  "exposure-minus-2": () => import('./icons/IconExposureMinus2.ts'),
  "exposure-off": () => import('./icons/IconExposureOff.ts'),
  "exposure-plus-1": () => import('./icons/IconExposurePlus1.ts'),
  "exposure-plus-2": () => import('./icons/IconExposurePlus2.ts'),
  "exposure": () => import('./icons/IconExposure.ts'),
  "external-link-off": () => import('./icons/IconExternalLinkOff.ts'),
  "external-link": () => import('./icons/IconExternalLink.ts'),
  "eye-bitcoin": () => import('./icons/IconEyeBitcoin.ts'),
  "eye-bolt": () => import('./icons/IconEyeBolt.ts'),
  "eye-cancel": () => import('./icons/IconEyeCancel.ts'),
  "eye-check": () => import('./icons/IconEyeCheck.ts'),
  "eye-closed": () => import('./icons/IconEyeClosed.ts'),
  "eye-code": () => import('./icons/IconEyeCode.ts'),
  "eye-cog": () => import('./icons/IconEyeCog.ts'),
  "eye-discount": () => import('./icons/IconEyeDiscount.ts'),
  "eye-dollar": () => import('./icons/IconEyeDollar.ts'),
  "eye-dotted": () => import('./icons/IconEyeDotted.ts'),
  "eye-down": () => import('./icons/IconEyeDown.ts'),
  "eye-edit": () => import('./icons/IconEyeEdit.ts'),
  "eye-exclamation": () => import('./icons/IconEyeExclamation.ts'),
  "eye-heart": () => import('./icons/IconEyeHeart.ts'),
  "eye-minus": () => import('./icons/IconEyeMinus.ts'),
  "eye-off": () => import('./icons/IconEyeOff.ts'),
  "eye-pause": () => import('./icons/IconEyePause.ts'),
  "eye-pin": () => import('./icons/IconEyePin.ts'),
  "eye-plus": () => import('./icons/IconEyePlus.ts'),
  "eye-question": () => import('./icons/IconEyeQuestion.ts'),
  "eye-search": () => import('./icons/IconEyeSearch.ts'),
  "eye-share": () => import('./icons/IconEyeShare.ts'),
  "eye-spark": () => import('./icons/IconEyeSpark.ts'),
  "eye-star": () => import('./icons/IconEyeStar.ts'),
  "eye-table": () => import('./icons/IconEyeTable.ts'),
  "eye-up": () => import('./icons/IconEyeUp.ts'),
  "eye-x": () => import('./icons/IconEyeX.ts'),
  "eye": () => import('./icons/IconEye.ts'),
  "eyeglass-2": () => import('./icons/IconEyeglass2.ts'),
  "eyeglass-off": () => import('./icons/IconEyeglassOff.ts'),
  "eyeglass": () => import('./icons/IconEyeglass.ts'),
  "face-id-error": () => import('./icons/IconFaceIdError.ts'),
  "face-id": () => import('./icons/IconFaceId.ts'),
  "face-mask-off": () => import('./icons/IconFaceMaskOff.ts'),
  "face-mask": () => import('./icons/IconFaceMask.ts'),
  "fall": () => import('./icons/IconFall.ts'),
  "favicon": () => import('./icons/IconFavicon.ts'),
  "feather-off": () => import('./icons/IconFeatherOff.ts'),
  "feather": () => import('./icons/IconFeather.ts'),
  "fence-off": () => import('./icons/IconFenceOff.ts'),
  "fence": () => import('./icons/IconFence.ts'),
  "ferry": () => import('./icons/IconFerry.ts'),
  "fidget-spinner": () => import('./icons/IconFidgetSpinner.ts'),
  "file-3d": () => import('./icons/IconFile3d.ts'),
  "file-ai": () => import('./icons/IconFileAi.ts'),
  "file-alert": () => import('./icons/IconFileAlert.ts'),
  "file-analytics": () => import('./icons/IconFileAnalytics.ts'),
  "file-arrow-left": () => import('./icons/IconFileArrowLeft.ts'),
  "file-arrow-right": () => import('./icons/IconFileArrowRight.ts'),
  "file-barcode": () => import('./icons/IconFileBarcode.ts'),
  "file-bitcoin": () => import('./icons/IconFileBitcoin.ts'),
  "file-broken": () => import('./icons/IconFileBroken.ts'),
  "file-certificate": () => import('./icons/IconFileCertificate.ts'),
  "file-chart": () => import('./icons/IconFileChart.ts'),
  "file-check": () => import('./icons/IconFileCheck.ts'),
  "file-code-2": () => import('./icons/IconFileCode2.ts'),
  "file-code": () => import('./icons/IconFileCode.ts'),
  "file-cv": () => import('./icons/IconFileCv.ts'),
  "file-database": () => import('./icons/IconFileDatabase.ts'),
  "file-delta": () => import('./icons/IconFileDelta.ts'),
  "file-description": () => import('./icons/IconFileDescription.ts'),
  "file-diff": () => import('./icons/IconFileDiff.ts'),
  "file-digit": () => import('./icons/IconFileDigit.ts'),
  "file-dislike": () => import('./icons/IconFileDislike.ts'),
  "file-dollar": () => import('./icons/IconFileDollar.ts'),
  "file-dots": () => import('./icons/IconFileDots.ts'),
  "file-download": () => import('./icons/IconFileDownload.ts'),
  "file-euro": () => import('./icons/IconFileEuro.ts'),
  "file-excel": () => import('./icons/IconFileExcel.ts'),
  "file-export": () => import('./icons/IconFileExport.ts'),
  "file-function": () => import('./icons/IconFileFunction.ts'),
  "file-horizontal": () => import('./icons/IconFileHorizontal.ts'),
  "file-import": () => import('./icons/IconFileImport.ts'),
  "file-infinity": () => import('./icons/IconFileInfinity.ts'),
  "file-info": () => import('./icons/IconFileInfo.ts'),
  "file-invoice": () => import('./icons/IconFileInvoice.ts'),
  "file-isr": () => import('./icons/IconFileIsr.ts'),
  "file-lambda": () => import('./icons/IconFileLambda.ts'),
  "file-like": () => import('./icons/IconFileLike.ts'),
  "file-minus": () => import('./icons/IconFileMinus.ts'),
  "file-music": () => import('./icons/IconFileMusic.ts'),
  "file-neutral": () => import('./icons/IconFileNeutral.ts'),
  "file-off": () => import('./icons/IconFileOff.ts'),
  "file-orientation": () => import('./icons/IconFileOrientation.ts'),
  "file-pencil": () => import('./icons/IconFilePencil.ts'),
  "file-percent": () => import('./icons/IconFilePercent.ts'),
  "file-phone": () => import('./icons/IconFilePhone.ts'),
  "file-plus": () => import('./icons/IconFilePlus.ts'),
  "file-power": () => import('./icons/IconFilePower.ts'),
  "file-report": () => import('./icons/IconFileReport.ts'),
  "file-rss": () => import('./icons/IconFileRss.ts'),
  "file-sad": () => import('./icons/IconFileSad.ts'),
  "file-scissors": () => import('./icons/IconFileScissors.ts'),
  "file-search": () => import('./icons/IconFileSearch.ts'),
  "file-settings": () => import('./icons/IconFileSettings.ts'),
  "file-shredder": () => import('./icons/IconFileShredder.ts'),
  "file-signal": () => import('./icons/IconFileSignal.ts'),
  "file-smile": () => import('./icons/IconFileSmile.ts'),
  "file-spark": () => import('./icons/IconFileSpark.ts'),
  "file-spreadsheet": () => import('./icons/IconFileSpreadsheet.ts'),
  "file-stack": () => import('./icons/IconFileStack.ts'),
  "file-star": () => import('./icons/IconFileStar.ts'),
  "file-symlink": () => import('./icons/IconFileSymlink.ts'),
  "file-text-ai": () => import('./icons/IconFileTextAi.ts'),
  "file-text-shield": () => import('./icons/IconFileTextShield.ts'),
  "file-text-spark": () => import('./icons/IconFileTextSpark.ts'),
  "file-text": () => import('./icons/IconFileText.ts'),
  "file-time": () => import('./icons/IconFileTime.ts'),
  "file-type-bmp": () => import('./icons/IconFileTypeBmp.ts'),
  "file-type-css": () => import('./icons/IconFileTypeCss.ts'),
  "file-type-csv": () => import('./icons/IconFileTypeCsv.ts'),
  "file-type-doc": () => import('./icons/IconFileTypeDoc.ts'),
  "file-type-docx": () => import('./icons/IconFileTypeDocx.ts'),
  "file-type-html": () => import('./icons/IconFileTypeHtml.ts'),
  "file-type-jpg": () => import('./icons/IconFileTypeJpg.ts'),
  "file-type-js": () => import('./icons/IconFileTypeJs.ts'),
  "file-type-jsx": () => import('./icons/IconFileTypeJsx.ts'),
  "file-type-pdf": () => import('./icons/IconFileTypePdf.ts'),
  "file-type-php": () => import('./icons/IconFileTypePhp.ts'),
  "file-type-png": () => import('./icons/IconFileTypePng.ts'),
  "file-type-ppt": () => import('./icons/IconFileTypePpt.ts'),
  "file-type-rs": () => import('./icons/IconFileTypeRs.ts'),
  "file-type-sql": () => import('./icons/IconFileTypeSql.ts'),
  "file-type-svg": () => import('./icons/IconFileTypeSvg.ts'),
  "file-type-ts": () => import('./icons/IconFileTypeTs.ts'),
  "file-type-tsx": () => import('./icons/IconFileTypeTsx.ts'),
  "file-type-txt": () => import('./icons/IconFileTypeTxt.ts'),
  "file-type-vue": () => import('./icons/IconFileTypeVue.ts'),
  "file-type-xls": () => import('./icons/IconFileTypeXls.ts'),
  "file-type-xml": () => import('./icons/IconFileTypeXml.ts'),
  "file-type-zip": () => import('./icons/IconFileTypeZip.ts'),
  "file-typography": () => import('./icons/IconFileTypography.ts'),
  "file-unknown": () => import('./icons/IconFileUnknown.ts'),
  "file-upload": () => import('./icons/IconFileUpload.ts'),
  "file-vector": () => import('./icons/IconFileVector.ts'),
  "file-word": () => import('./icons/IconFileWord.ts'),
  "file-x": () => import('./icons/IconFileX.ts'),
  "file-zip": () => import('./icons/IconFileZip.ts'),
  "file": () => import('./icons/IconFile.ts'),
  "files-off": () => import('./icons/IconFilesOff.ts'),
  "files": () => import('./icons/IconFiles.ts'),
  "filter-2-bolt": () => import('./icons/IconFilter2Bolt.ts'),
  "filter-2-cancel": () => import('./icons/IconFilter2Cancel.ts'),
  "filter-2-check": () => import('./icons/IconFilter2Check.ts'),
  "filter-2-code": () => import('./icons/IconFilter2Code.ts'),
  "filter-2-cog": () => import('./icons/IconFilter2Cog.ts'),
  "filter-2-discount": () => import('./icons/IconFilter2Discount.ts'),
  "filter-2-dollar": () => import('./icons/IconFilter2Dollar.ts'),
  "filter-2-down": () => import('./icons/IconFilter2Down.ts'),
  "filter-2-edit": () => import('./icons/IconFilter2Edit.ts'),
  "filter-2-exclamation": () => import('./icons/IconFilter2Exclamation.ts'),
  "filter-2-minus": () => import('./icons/IconFilter2Minus.ts'),
  "filter-2-pause": () => import('./icons/IconFilter2Pause.ts'),
  "filter-2-pin": () => import('./icons/IconFilter2Pin.ts'),
  "filter-2-plus": () => import('./icons/IconFilter2Plus.ts'),
  "filter-2-question": () => import('./icons/IconFilter2Question.ts'),
  "filter-2-search": () => import('./icons/IconFilter2Search.ts'),
  "filter-2-share": () => import('./icons/IconFilter2Share.ts'),
  "filter-2-spark": () => import('./icons/IconFilter2Spark.ts'),
  "filter-2-up": () => import('./icons/IconFilter2Up.ts'),
  "filter-2-x": () => import('./icons/IconFilter2X.ts'),
  "filter-2": () => import('./icons/IconFilter2.ts'),
  "filter-bolt": () => import('./icons/IconFilterBolt.ts'),
  "filter-cancel": () => import('./icons/IconFilterCancel.ts'),
  "filter-check": () => import('./icons/IconFilterCheck.ts'),
  "filter-code": () => import('./icons/IconFilterCode.ts'),
  "filter-cog": () => import('./icons/IconFilterCog.ts'),
  "filter-discount": () => import('./icons/IconFilterDiscount.ts'),
  "filter-dollar": () => import('./icons/IconFilterDollar.ts'),
  "filter-down": () => import('./icons/IconFilterDown.ts'),
  "filter-edit": () => import('./icons/IconFilterEdit.ts'),
  "filter-exclamation": () => import('./icons/IconFilterExclamation.ts'),
  "filter-heart": () => import('./icons/IconFilterHeart.ts'),
  "filter-minus": () => import('./icons/IconFilterMinus.ts'),
  "filter-off": () => import('./icons/IconFilterOff.ts'),
  "filter-pause": () => import('./icons/IconFilterPause.ts'),
  "filter-pin": () => import('./icons/IconFilterPin.ts'),
  "filter-plus": () => import('./icons/IconFilterPlus.ts'),
  "filter-question": () => import('./icons/IconFilterQuestion.ts'),
  "filter-search": () => import('./icons/IconFilterSearch.ts'),
  "filter-share": () => import('./icons/IconFilterShare.ts'),
  "filter-spark": () => import('./icons/IconFilterSpark.ts'),
  "filter-star": () => import('./icons/IconFilterStar.ts'),
  "filter-up": () => import('./icons/IconFilterUp.ts'),
  "filter-x": () => import('./icons/IconFilterX.ts'),
  "filter": () => import('./icons/IconFilter.ts'),
  "filters": () => import('./icons/IconFilters.ts'),
  "fingerprint-off": () => import('./icons/IconFingerprintOff.ts'),
  "fingerprint-scan": () => import('./icons/IconFingerprintScan.ts'),
  "fingerprint": () => import('./icons/IconFingerprint.ts'),
  "fire-extinguisher": () => import('./icons/IconFireExtinguisher.ts'),
  "fire-hydrant-off": () => import('./icons/IconFireHydrantOff.ts'),
  "fire-hydrant": () => import('./icons/IconFireHydrant.ts'),
  "firetruck": () => import('./icons/IconFiretruck.ts'),
  "first-aid-kit-off": () => import('./icons/IconFirstAidKitOff.ts'),
  "first-aid-kit": () => import('./icons/IconFirstAidKit.ts'),
  "fish-bone": () => import('./icons/IconFishBone.ts'),
  "fish-christianity": () => import('./icons/IconFishChristianity.ts'),
  "fish-hook-off": () => import('./icons/IconFishHookOff.ts'),
  "fish-hook": () => import('./icons/IconFishHook.ts'),
  "fish-off": () => import('./icons/IconFishOff.ts'),
  "fish": () => import('./icons/IconFish.ts'),
  "flag-2-off": () => import('./icons/IconFlag2Off.ts'),
  "flag-2": () => import('./icons/IconFlag2.ts'),
  "flag-3": () => import('./icons/IconFlag3.ts'),
  "flag-bitcoin": () => import('./icons/IconFlagBitcoin.ts'),
  "flag-bolt": () => import('./icons/IconFlagBolt.ts'),
  "flag-cancel": () => import('./icons/IconFlagCancel.ts'),
  "flag-check": () => import('./icons/IconFlagCheck.ts'),
  "flag-code": () => import('./icons/IconFlagCode.ts'),
  "flag-cog": () => import('./icons/IconFlagCog.ts'),
  "flag-discount": () => import('./icons/IconFlagDiscount.ts'),
  "flag-dollar": () => import('./icons/IconFlagDollar.ts'),
  "flag-down": () => import('./icons/IconFlagDown.ts'),
  "flag-exclamation": () => import('./icons/IconFlagExclamation.ts'),
  "flag-heart": () => import('./icons/IconFlagHeart.ts'),
  "flag-minus": () => import('./icons/IconFlagMinus.ts'),
  "flag-off": () => import('./icons/IconFlagOff.ts'),
  "flag-pause": () => import('./icons/IconFlagPause.ts'),
  "flag-pin": () => import('./icons/IconFlagPin.ts'),
  "flag-plus": () => import('./icons/IconFlagPlus.ts'),
  "flag-question": () => import('./icons/IconFlagQuestion.ts'),
  "flag-search": () => import('./icons/IconFlagSearch.ts'),
  "flag-share": () => import('./icons/IconFlagShare.ts'),
  "flag-spark": () => import('./icons/IconFlagSpark.ts'),
  "flag-star": () => import('./icons/IconFlagStar.ts'),
  "flag-up": () => import('./icons/IconFlagUp.ts'),
  "flag-x": () => import('./icons/IconFlagX.ts'),
  "flag": () => import('./icons/IconFlag.ts'),
  "flame-off": () => import('./icons/IconFlameOff.ts'),
  "flame": () => import('./icons/IconFlame.ts'),
  "flare": () => import('./icons/IconFlare.ts'),
  "flask-2-off": () => import('./icons/IconFlask2Off.ts'),
  "flask-2": () => import('./icons/IconFlask2.ts'),
  "flask-off": () => import('./icons/IconFlaskOff.ts'),
  "flask": () => import('./icons/IconFlask.ts'),
  "flip-flops": () => import('./icons/IconFlipFlops.ts'),
  "flip-horizontal": () => import('./icons/IconFlipHorizontal.ts'),
  "flip-vertical": () => import('./icons/IconFlipVertical.ts'),
  "float-center": () => import('./icons/IconFloatCenter.ts'),
  "float-left": () => import('./icons/IconFloatLeft.ts'),
  "float-none": () => import('./icons/IconFloatNone.ts'),
  "float-right": () => import('./icons/IconFloatRight.ts'),
  "flower-off": () => import('./icons/IconFlowerOff.ts'),
  "flower": () => import('./icons/IconFlower.ts'),
  "focus-2": () => import('./icons/IconFocus2.ts'),
  "focus-auto": () => import('./icons/IconFocusAuto.ts'),
  "focus-centered": () => import('./icons/IconFocusCentered.ts'),
  "focus": () => import('./icons/IconFocus.ts'),
  "fold-down": () => import('./icons/IconFoldDown.ts'),
  "fold-up": () => import('./icons/IconFoldUp.ts'),
  "fold": () => import('./icons/IconFold.ts'),
  "folder-bolt": () => import('./icons/IconFolderBolt.ts'),
  "folder-cancel": () => import('./icons/IconFolderCancel.ts'),
  "folder-check": () => import('./icons/IconFolderCheck.ts'),
  "folder-code": () => import('./icons/IconFolderCode.ts'),
  "folder-cog": () => import('./icons/IconFolderCog.ts'),
  "folder-dollar": () => import('./icons/IconFolderDollar.ts'),
  "folder-down": () => import('./icons/IconFolderDown.ts'),
  "folder-exclamation": () => import('./icons/IconFolderExclamation.ts'),
  "folder-heart": () => import('./icons/IconFolderHeart.ts'),
  "folder-minus": () => import('./icons/IconFolderMinus.ts'),
  "folder-off": () => import('./icons/IconFolderOff.ts'),
  "folder-open": () => import('./icons/IconFolderOpen.ts'),
  "folder-pause": () => import('./icons/IconFolderPause.ts'),
  "folder-pin": () => import('./icons/IconFolderPin.ts'),
  "folder-plus": () => import('./icons/IconFolderPlus.ts'),
  "folder-question": () => import('./icons/IconFolderQuestion.ts'),
  "folder-root": () => import('./icons/IconFolderRoot.ts'),
  "folder-search": () => import('./icons/IconFolderSearch.ts'),
  "folder-share": () => import('./icons/IconFolderShare.ts'),
  "folder-star": () => import('./icons/IconFolderStar.ts'),
  "folder-symlink": () => import('./icons/IconFolderSymlink.ts'),
  "folder-up": () => import('./icons/IconFolderUp.ts'),
  "folder-x": () => import('./icons/IconFolderX.ts'),
  "folder": () => import('./icons/IconFolder.ts'),
  "folders-off": () => import('./icons/IconFoldersOff.ts'),
  "folders": () => import('./icons/IconFolders.ts'),
  "forbid-2": () => import('./icons/IconForbid2.ts'),
  "forbid": () => import('./icons/IconForbid.ts'),
  "forklift": () => import('./icons/IconForklift.ts'),
  "forms": () => import('./icons/IconForms.ts'),
  "fountain-off": () => import('./icons/IconFountainOff.ts'),
  "fountain": () => import('./icons/IconFountain.ts'),
  "frame-off": () => import('./icons/IconFrameOff.ts'),
  "frame": () => import('./icons/IconFrame.ts'),
  "free-rights": () => import('./icons/IconFreeRights.ts'),
  "freeze-column": () => import('./icons/IconFreezeColumn.ts'),
  "freeze-row-column": () => import('./icons/IconFreezeRowColumn.ts'),
  "freeze-row": () => import('./icons/IconFreezeRow.ts'),
  "fridge-off": () => import('./icons/IconFridgeOff.ts'),
  "fridge": () => import('./icons/IconFridge.ts'),
  "friends-off": () => import('./icons/IconFriendsOff.ts'),
  "friends": () => import('./icons/IconFriends.ts'),
  "frustum-off": () => import('./icons/IconFrustumOff.ts'),
  "frustum-plus": () => import('./icons/IconFrustumPlus.ts'),
  "frustum": () => import('./icons/IconFrustum.ts'),
  "function-off": () => import('./icons/IconFunctionOff.ts'),
  "function": () => import('./icons/IconFunction.ts'),
  "galaxy": () => import('./icons/IconGalaxy.ts'),
  "garden-cart-off": () => import('./icons/IconGardenCartOff.ts'),
  "garden-cart": () => import('./icons/IconGardenCart.ts'),
  "gas-station-off": () => import('./icons/IconGasStationOff.ts'),
  "gas-station": () => import('./icons/IconGasStation.ts'),
  "gauge-off": () => import('./icons/IconGaugeOff.ts'),
  "gauge": () => import('./icons/IconGauge.ts'),
  "gavel": () => import('./icons/IconGavel.ts'),
  "gender-agender": () => import('./icons/IconGenderAgender.ts'),
  "gender-androgyne": () => import('./icons/IconGenderAndrogyne.ts'),
  "gender-bigender": () => import('./icons/IconGenderBigender.ts'),
  "gender-demiboy": () => import('./icons/IconGenderDemiboy.ts'),
  "gender-demigirl": () => import('./icons/IconGenderDemigirl.ts'),
  "gender-epicene": () => import('./icons/IconGenderEpicene.ts'),
  "gender-female": () => import('./icons/IconGenderFemale.ts'),
  "gender-femme": () => import('./icons/IconGenderFemme.ts'),
  "gender-genderfluid": () => import('./icons/IconGenderGenderfluid.ts'),
  "gender-genderless": () => import('./icons/IconGenderGenderless.ts'),
  "gender-genderqueer": () => import('./icons/IconGenderGenderqueer.ts'),
  "gender-hermaphrodite": () => import('./icons/IconGenderHermaphrodite.ts'),
  "gender-intergender": () => import('./icons/IconGenderIntergender.ts'),
  "gender-male": () => import('./icons/IconGenderMale.ts'),
  "gender-neutrois": () => import('./icons/IconGenderNeutrois.ts'),
  "gender-third": () => import('./icons/IconGenderThird.ts'),
  "gender-transgender": () => import('./icons/IconGenderTransgender.ts'),
  "gender-trasvesti": () => import('./icons/IconGenderTrasvesti.ts'),
  "geometry": () => import('./icons/IconGeometry.ts'),
  "ghost-2": () => import('./icons/IconGhost2.ts'),
  "ghost-3": () => import('./icons/IconGhost3.ts'),
  "ghost-off": () => import('./icons/IconGhostOff.ts'),
  "ghost": () => import('./icons/IconGhost.ts'),
  "gif": () => import('./icons/IconGif.ts'),
  "gift-card": () => import('./icons/IconGiftCard.ts'),
  "gift-off": () => import('./icons/IconGiftOff.ts'),
  "gift": () => import('./icons/IconGift.ts'),
  "git-branch-deleted": () => import('./icons/IconGitBranchDeleted.ts'),
  "git-branch": () => import('./icons/IconGitBranch.ts'),
  "git-cherry-pick": () => import('./icons/IconGitCherryPick.ts'),
  "git-commit": () => import('./icons/IconGitCommit.ts'),
  "git-compare": () => import('./icons/IconGitCompare.ts'),
  "git-fork": () => import('./icons/IconGitFork.ts'),
  "git-merge": () => import('./icons/IconGitMerge.ts'),
  "git-pull-request-closed": () => import('./icons/IconGitPullRequestClosed.ts'),
  "git-pull-request-draft": () => import('./icons/IconGitPullRequestDraft.ts'),
  "git-pull-request": () => import('./icons/IconGitPullRequest.ts'),
  "gizmo": () => import('./icons/IconGizmo.ts'),
  "glass-champagne": () => import('./icons/IconGlassChampagne.ts'),
  "glass-cocktail": () => import('./icons/IconGlassCocktail.ts'),
  "glass-full": () => import('./icons/IconGlassFull.ts'),
  "glass-gin": () => import('./icons/IconGlassGin.ts'),
  "glass-off": () => import('./icons/IconGlassOff.ts'),
  "glass": () => import('./icons/IconGlass.ts'),
  "globe-off": () => import('./icons/IconGlobeOff.ts'),
  "globe": () => import('./icons/IconGlobe.ts'),
  "go-game": () => import('./icons/IconGoGame.ts'),
  "golf-off": () => import('./icons/IconGolfOff.ts'),
  "golf": () => import('./icons/IconGolf.ts'),
  "gps": () => import('./icons/IconGps.ts'),
  "gradienter": () => import('./icons/IconGradienter.ts'),
  "grain": () => import('./icons/IconGrain.ts'),
  "graph-off": () => import('./icons/IconGraphOff.ts'),
  "graph": () => import('./icons/IconGraph.ts'),
  "grave-2": () => import('./icons/IconGrave2.ts'),
  "grave": () => import('./icons/IconGrave.ts'),
  "grid-3x3": () => import('./icons/IconGrid3x3.ts'),
  "grid-4x4": () => import('./icons/IconGrid4x4.ts'),
  "grid-dots": () => import('./icons/IconGridDots.ts'),
  "grid-goldenratio": () => import('./icons/IconGridGoldenratio.ts'),
  "grid-pattern": () => import('./icons/IconGridPattern.ts'),
  "grid-scan": () => import('./icons/IconGridScan.ts'),
  "grill-fork": () => import('./icons/IconGrillFork.ts'),
  "grill-off": () => import('./icons/IconGrillOff.ts'),
  "grill-spatula": () => import('./icons/IconGrillSpatula.ts'),
  "grill": () => import('./icons/IconGrill.ts'),
  "grip-horizontal": () => import('./icons/IconGripHorizontal.ts'),
  "grip-vertical": () => import('./icons/IconGripVertical.ts'),
  "growth": () => import('./icons/IconGrowth.ts'),
  "guitar-pick": () => import('./icons/IconGuitarPick.ts'),
  "gymnastics": () => import('./icons/IconGymnastics.ts'),
  "h-1": () => import('./icons/IconH1.ts'),
  "h-2": () => import('./icons/IconH2.ts'),
  "h-3": () => import('./icons/IconH3.ts'),
  "h-4": () => import('./icons/IconH4.ts'),
  "h-5": () => import('./icons/IconH5.ts'),
  "h-6": () => import('./icons/IconH6.ts'),
  "hammer-off": () => import('./icons/IconHammerOff.ts'),
  "hammer": () => import('./icons/IconHammer.ts'),
  "hand-click-off": () => import('./icons/IconHandClickOff.ts'),
  "hand-click": () => import('./icons/IconHandClick.ts'),
  "hand-finger-down": () => import('./icons/IconHandFingerDown.ts'),
  "hand-finger-left": () => import('./icons/IconHandFingerLeft.ts'),
  "hand-finger-off": () => import('./icons/IconHandFingerOff.ts'),
  "hand-finger-right": () => import('./icons/IconHandFingerRight.ts'),
  "hand-finger": () => import('./icons/IconHandFinger.ts'),
  "hand-grab": () => import('./icons/IconHandGrab.ts'),
  "hand-little-finger": () => import('./icons/IconHandLittleFinger.ts'),
  "hand-love-you": () => import('./icons/IconHandLoveYou.ts'),
  "hand-middle-finger": () => import('./icons/IconHandMiddleFinger.ts'),
  "hand-move": () => import('./icons/IconHandMove.ts'),
  "hand-off": () => import('./icons/IconHandOff.ts'),
  "hand-ring-finger": () => import('./icons/IconHandRingFinger.ts'),
  "hand-sanitizer": () => import('./icons/IconHandSanitizer.ts'),
  "hand-stop": () => import('./icons/IconHandStop.ts'),
  "hand-three-fingers": () => import('./icons/IconHandThreeFingers.ts'),
  "hand-two-fingers": () => import('./icons/IconHandTwoFingers.ts'),
  "hanger-2": () => import('./icons/IconHanger2.ts'),
  "hanger-off": () => import('./icons/IconHangerOff.ts'),
  "hanger": () => import('./icons/IconHanger.ts'),
  "hash": () => import('./icons/IconHash.ts'),
  "haze-moon": () => import('./icons/IconHazeMoon.ts'),
  "haze": () => import('./icons/IconHaze.ts'),
  "hdr": () => import('./icons/IconHdr.ts'),
  "heading-off": () => import('./icons/IconHeadingOff.ts'),
  "heading": () => import('./icons/IconHeading.ts'),
  "headphones-off": () => import('./icons/IconHeadphonesOff.ts'),
  "headphones": () => import('./icons/IconHeadphones.ts'),
  "headset-off": () => import('./icons/IconHeadsetOff.ts'),
  "headset": () => import('./icons/IconHeadset.ts'),
  "health-recognition": () => import('./icons/IconHealthRecognition.ts'),
  "heart-bitcoin": () => import('./icons/IconHeartBitcoin.ts'),
  "heart-bolt": () => import('./icons/IconHeartBolt.ts'),
  "heart-broken": () => import('./icons/IconHeartBroken.ts'),
  "heart-cancel": () => import('./icons/IconHeartCancel.ts'),
  "heart-check": () => import('./icons/IconHeartCheck.ts'),
  "heart-code": () => import('./icons/IconHeartCode.ts'),
  "heart-cog": () => import('./icons/IconHeartCog.ts'),
  "heart-discount": () => import('./icons/IconHeartDiscount.ts'),
  "heart-dollar": () => import('./icons/IconHeartDollar.ts'),
  "heart-down": () => import('./icons/IconHeartDown.ts'),
  "heart-exclamation": () => import('./icons/IconHeartExclamation.ts'),
  "heart-handshake": () => import('./icons/IconHeartHandshake.ts'),
  "heart-minus": () => import('./icons/IconHeartMinus.ts'),
  "heart-off": () => import('./icons/IconHeartOff.ts'),
  "heart-pause": () => import('./icons/IconHeartPause.ts'),
  "heart-pin": () => import('./icons/IconHeartPin.ts'),
  "heart-plus": () => import('./icons/IconHeartPlus.ts'),
  "heart-question": () => import('./icons/IconHeartQuestion.ts'),
  "heart-rate-monitor": () => import('./icons/IconHeartRateMonitor.ts'),
  "heart-search": () => import('./icons/IconHeartSearch.ts'),
  "heart-share": () => import('./icons/IconHeartShare.ts'),
  "heart-spark": () => import('./icons/IconHeartSpark.ts'),
  "heart-star": () => import('./icons/IconHeartStar.ts'),
  "heart-up": () => import('./icons/IconHeartUp.ts'),
  "heart-x": () => import('./icons/IconHeartX.ts'),
  "heart": () => import('./icons/IconHeart.ts'),
  "heartbeat": () => import('./icons/IconHeartbeat.ts'),
  "hearts-off": () => import('./icons/IconHeartsOff.ts'),
  "hearts": () => import('./icons/IconHearts.ts'),
  "helicopter-landing": () => import('./icons/IconHelicopterLanding.ts'),
  "helicopter": () => import('./icons/IconHelicopter.ts'),
  "helmet-off": () => import('./icons/IconHelmetOff.ts'),
  "helmet": () => import('./icons/IconHelmet.ts'),
  "help-circle": () => import('./icons/IconHelpCircle.ts'),
  "help-hexagon": () => import('./icons/IconHelpHexagon.ts'),
  "help-octagon": () => import('./icons/IconHelpOctagon.ts'),
  "help-off": () => import('./icons/IconHelpOff.ts'),
  "help-small": () => import('./icons/IconHelpSmall.ts'),
  "help-square-rounded": () => import('./icons/IconHelpSquareRounded.ts'),
  "help-square": () => import('./icons/IconHelpSquare.ts'),
  "help-triangle": () => import('./icons/IconHelpTriangle.ts'),
  "help": () => import('./icons/IconHelp.ts'),
  "hemisphere-off": () => import('./icons/IconHemisphereOff.ts'),
  "hemisphere-plus": () => import('./icons/IconHemispherePlus.ts'),
  "hemisphere": () => import('./icons/IconHemisphere.ts'),
  "hexagon-3d": () => import('./icons/IconHexagon3d.ts'),
  "hexagon-asterisk": () => import('./icons/IconHexagonAsterisk.ts'),
  "hexagon-letter-a": () => import('./icons/IconHexagonLetterA.ts'),
  "hexagon-letter-b": () => import('./icons/IconHexagonLetterB.ts'),
  "hexagon-letter-c": () => import('./icons/IconHexagonLetterC.ts'),
  "hexagon-letter-d": () => import('./icons/IconHexagonLetterD.ts'),
  "hexagon-letter-e": () => import('./icons/IconHexagonLetterE.ts'),
  "hexagon-letter-f": () => import('./icons/IconHexagonLetterF.ts'),
  "hexagon-letter-g": () => import('./icons/IconHexagonLetterG.ts'),
  "hexagon-letter-h": () => import('./icons/IconHexagonLetterH.ts'),
  "hexagon-letter-i": () => import('./icons/IconHexagonLetterI.ts'),
  "hexagon-letter-j": () => import('./icons/IconHexagonLetterJ.ts'),
  "hexagon-letter-k": () => import('./icons/IconHexagonLetterK.ts'),
  "hexagon-letter-l": () => import('./icons/IconHexagonLetterL.ts'),
  "hexagon-letter-m": () => import('./icons/IconHexagonLetterM.ts'),
  "hexagon-letter-n": () => import('./icons/IconHexagonLetterN.ts'),
  "hexagon-letter-o": () => import('./icons/IconHexagonLetterO.ts'),
  "hexagon-letter-p": () => import('./icons/IconHexagonLetterP.ts'),
  "hexagon-letter-q": () => import('./icons/IconHexagonLetterQ.ts'),
  "hexagon-letter-r": () => import('./icons/IconHexagonLetterR.ts'),
  "hexagon-letter-s": () => import('./icons/IconHexagonLetterS.ts'),
  "hexagon-letter-t": () => import('./icons/IconHexagonLetterT.ts'),
  "hexagon-letter-u": () => import('./icons/IconHexagonLetterU.ts'),
  "hexagon-letter-v": () => import('./icons/IconHexagonLetterV.ts'),
  "hexagon-letter-w": () => import('./icons/IconHexagonLetterW.ts'),
  "hexagon-letter-x": () => import('./icons/IconHexagonLetterX.ts'),
  "hexagon-letter-y": () => import('./icons/IconHexagonLetterY.ts'),
  "hexagon-letter-z": () => import('./icons/IconHexagonLetterZ.ts'),
  "hexagon-minus-2": () => import('./icons/IconHexagonMinus2.ts'),
  "hexagon-minus": () => import('./icons/IconHexagonMinus.ts'),
  "hexagon-number-0": () => import('./icons/IconHexagonNumber0.ts'),
  "hexagon-number-1": () => import('./icons/IconHexagonNumber1.ts'),
  "hexagon-number-2": () => import('./icons/IconHexagonNumber2.ts'),
  "hexagon-number-3": () => import('./icons/IconHexagonNumber3.ts'),
  "hexagon-number-4": () => import('./icons/IconHexagonNumber4.ts'),
  "hexagon-number-5": () => import('./icons/IconHexagonNumber5.ts'),
  "hexagon-number-6": () => import('./icons/IconHexagonNumber6.ts'),
  "hexagon-number-7": () => import('./icons/IconHexagonNumber7.ts'),
  "hexagon-number-8": () => import('./icons/IconHexagonNumber8.ts'),
  "hexagon-number-9": () => import('./icons/IconHexagonNumber9.ts'),
  "hexagon-off": () => import('./icons/IconHexagonOff.ts'),
  "hexagon-plus-2": () => import('./icons/IconHexagonPlus2.ts'),
  "hexagon-plus": () => import('./icons/IconHexagonPlus.ts'),
  "hexagon": () => import('./icons/IconHexagon.ts'),
  "hexagonal-prism-off": () => import('./icons/IconHexagonalPrismOff.ts'),
  "hexagonal-prism-plus": () => import('./icons/IconHexagonalPrismPlus.ts'),
  "hexagonal-prism": () => import('./icons/IconHexagonalPrism.ts'),
  "hexagonal-pyramid-off": () => import('./icons/IconHexagonalPyramidOff.ts'),
  "hexagonal-pyramid-plus": () => import('./icons/IconHexagonalPyramidPlus.ts'),
  "hexagonal-pyramid": () => import('./icons/IconHexagonalPyramid.ts'),
  "hexagons-off": () => import('./icons/IconHexagonsOff.ts'),
  "hexagons": () => import('./icons/IconHexagons.ts'),
  "hierarchy-2": () => import('./icons/IconHierarchy2.ts'),
  "hierarchy-3": () => import('./icons/IconHierarchy3.ts'),
  "hierarchy-off": () => import('./icons/IconHierarchyOff.ts'),
  "hierarchy": () => import('./icons/IconHierarchy.ts'),
  "highlight-off": () => import('./icons/IconHighlightOff.ts'),
  "highlight": () => import('./icons/IconHighlight.ts'),
  "history-off": () => import('./icons/IconHistoryOff.ts'),
  "history-toggle": () => import('./icons/IconHistoryToggle.ts'),
  "history": () => import('./icons/IconHistory.ts'),
  "home-2": () => import('./icons/IconHome2.ts'),
  "home-bitcoin": () => import('./icons/IconHomeBitcoin.ts'),
  "home-bolt": () => import('./icons/IconHomeBolt.ts'),
  "home-cancel": () => import('./icons/IconHomeCancel.ts'),
  "home-check": () => import('./icons/IconHomeCheck.ts'),
  "home-cog": () => import('./icons/IconHomeCog.ts'),
  "home-dollar": () => import('./icons/IconHomeDollar.ts'),
  "home-dot": () => import('./icons/IconHomeDot.ts'),
  "home-down": () => import('./icons/IconHomeDown.ts'),
  "home-eco": () => import('./icons/IconHomeEco.ts'),
  "home-edit": () => import('./icons/IconHomeEdit.ts'),
  "home-exclamation": () => import('./icons/IconHomeExclamation.ts'),
  "home-hand": () => import('./icons/IconHomeHand.ts'),
  "home-heart": () => import('./icons/IconHomeHeart.ts'),
  "home-infinity": () => import('./icons/IconHomeInfinity.ts'),
  "home-link": () => import('./icons/IconHomeLink.ts'),
  "home-minus": () => import('./icons/IconHomeMinus.ts'),
  "home-move": () => import('./icons/IconHomeMove.ts'),
  "home-off": () => import('./icons/IconHomeOff.ts'),
  "home-plus": () => import('./icons/IconHomePlus.ts'),
  "home-question": () => import('./icons/IconHomeQuestion.ts'),
  "home-ribbon": () => import('./icons/IconHomeRibbon.ts'),
  "home-search": () => import('./icons/IconHomeSearch.ts'),
  "home-share": () => import('./icons/IconHomeShare.ts'),
  "home-shield": () => import('./icons/IconHomeShield.ts'),
  "home-signal": () => import('./icons/IconHomeSignal.ts'),
  "home-spark": () => import('./icons/IconHomeSpark.ts'),
  "home-star": () => import('./icons/IconHomeStar.ts'),
  "home-stats": () => import('./icons/IconHomeStats.ts'),
  "home-up": () => import('./icons/IconHomeUp.ts'),
  "home-x": () => import('./icons/IconHomeX.ts'),
  "home": () => import('./icons/IconHome.ts'),
  "horse-toy": () => import('./icons/IconHorseToy.ts'),
  "horse": () => import('./icons/IconHorse.ts'),
  "horseshoe": () => import('./icons/IconHorseshoe.ts'),
  "hospital-circle": () => import('./icons/IconHospitalCircle.ts'),
  "hospital": () => import('./icons/IconHospital.ts'),
  "hotel-service": () => import('./icons/IconHotelService.ts'),
  "hourglass-empty": () => import('./icons/IconHourglassEmpty.ts'),
  "hourglass-high": () => import('./icons/IconHourglassHigh.ts'),
  "hourglass-low": () => import('./icons/IconHourglassLow.ts'),
  "hourglass-off": () => import('./icons/IconHourglassOff.ts'),
  "hourglass": () => import('./icons/IconHourglass.ts'),
  "hours-12": () => import('./icons/IconHours12.ts'),
  "hours-24": () => import('./icons/IconHours24.ts'),
  "html": () => import('./icons/IconHtml.ts'),
  "http-connect-off": () => import('./icons/IconHttpConnectOff.ts'),
  "http-connect": () => import('./icons/IconHttpConnect.ts'),
  "http-delete-off": () => import('./icons/IconHttpDeleteOff.ts'),
  "http-delete": () => import('./icons/IconHttpDelete.ts'),
  "http-get-off": () => import('./icons/IconHttpGetOff.ts'),
  "http-get": () => import('./icons/IconHttpGet.ts'),
  "http-head-off": () => import('./icons/IconHttpHeadOff.ts'),
  "http-head": () => import('./icons/IconHttpHead.ts'),
  "http-options-off": () => import('./icons/IconHttpOptionsOff.ts'),
  "http-options": () => import('./icons/IconHttpOptions.ts'),
  "http-patch-off": () => import('./icons/IconHttpPatchOff.ts'),
  "http-patch": () => import('./icons/IconHttpPatch.ts'),
  "http-post-off": () => import('./icons/IconHttpPostOff.ts'),
  "http-post": () => import('./icons/IconHttpPost.ts'),
  "http-put-off": () => import('./icons/IconHttpPutOff.ts'),
  "http-put": () => import('./icons/IconHttpPut.ts'),
  "http-que-off": () => import('./icons/IconHttpQueOff.ts'),
  "http-que": () => import('./icons/IconHttpQue.ts'),
  "http-trace-off": () => import('./icons/IconHttpTraceOff.ts'),
  "http-trace": () => import('./icons/IconHttpTrace.ts'),
  "ice-cream-2": () => import('./icons/IconIceCream2.ts'),
  "ice-cream-off": () => import('./icons/IconIceCreamOff.ts'),
  "ice-cream": () => import('./icons/IconIceCream.ts'),
  "ice-skating": () => import('./icons/IconIceSkating.ts'),
  "icons-off": () => import('./icons/IconIconsOff.ts'),
  "icons": () => import('./icons/IconIcons.ts'),
  "id-badge-2": () => import('./icons/IconIdBadge2.ts'),
  "id-badge-off": () => import('./icons/IconIdBadgeOff.ts'),
  "id-badge": () => import('./icons/IconIdBadge.ts'),
  "id-off": () => import('./icons/IconIdOff.ts'),
  "id": () => import('./icons/IconId.ts'),
  "ikosaedr": () => import('./icons/IconIkosaedr.ts'),
  "image-in-picture": () => import('./icons/IconImageInPicture.ts'),
  "inbox-off": () => import('./icons/IconInboxOff.ts'),
  "inbox": () => import('./icons/IconInbox.ts'),
  "indent-decrease": () => import('./icons/IconIndentDecrease.ts'),
  "indent-increase": () => import('./icons/IconIndentIncrease.ts'),
  "infinity-off": () => import('./icons/IconInfinityOff.ts'),
  "infinity": () => import('./icons/IconInfinity.ts'),
  "info-circle": () => import('./icons/IconInfoCircle.ts'),
  "info-hexagon": () => import('./icons/IconInfoHexagon.ts'),
  "info-octagon": () => import('./icons/IconInfoOctagon.ts'),
  "info-small": () => import('./icons/IconInfoSmall.ts'),
  "info-square-rounded": () => import('./icons/IconInfoSquareRounded.ts'),
  "info-square": () => import('./icons/IconInfoSquare.ts'),
  "info-triangle": () => import('./icons/IconInfoTriangle.ts'),
  "inner-shadow-bottom-left": () => import('./icons/IconInnerShadowBottomLeft.ts'),
  "inner-shadow-bottom-right": () => import('./icons/IconInnerShadowBottomRight.ts'),
  "inner-shadow-bottom": () => import('./icons/IconInnerShadowBottom.ts'),
  "inner-shadow-left": () => import('./icons/IconInnerShadowLeft.ts'),
  "inner-shadow-right": () => import('./icons/IconInnerShadowRight.ts'),
  "inner-shadow-top-left": () => import('./icons/IconInnerShadowTopLeft.ts'),
  "inner-shadow-top-right": () => import('./icons/IconInnerShadowTopRight.ts'),
  "inner-shadow-top": () => import('./icons/IconInnerShadowTop.ts'),
  "input-ai": () => import('./icons/IconInputAi.ts'),
  "input-check": () => import('./icons/IconInputCheck.ts'),
  "input-search": () => import('./icons/IconInputSearch.ts'),
  "input-spark": () => import('./icons/IconInputSpark.ts'),
  "input-x": () => import('./icons/IconInputX.ts'),
  "invoice": () => import('./icons/IconInvoice.ts'),
  "ironing-1": () => import('./icons/IconIroning1.ts'),
  "ironing-2": () => import('./icons/IconIroning2.ts'),
  "ironing-3": () => import('./icons/IconIroning3.ts'),
  "ironing-off": () => import('./icons/IconIroningOff.ts'),
  "ironing-steam-off": () => import('./icons/IconIroningSteamOff.ts'),
  "ironing-steam": () => import('./icons/IconIroningSteam.ts'),
  "ironing": () => import('./icons/IconIroning.ts'),
  "irregular-polyhedron-off": () => import('./icons/IconIrregularPolyhedronOff.ts'),
  "irregular-polyhedron-plus": () => import('./icons/IconIrregularPolyhedronPlus.ts'),
  "irregular-polyhedron": () => import('./icons/IconIrregularPolyhedron.ts'),
  "italic": () => import('./icons/IconItalic.ts'),
  "jacket": () => import('./icons/IconJacket.ts'),
  "jetpack": () => import('./icons/IconJetpack.ts'),
  "jewish-star": () => import('./icons/IconJewishStar.ts'),
  "join-bevel": () => import('./icons/IconJoinBevel.ts'),
  "join-round": () => import('./icons/IconJoinRound.ts'),
  "join-straight": () => import('./icons/IconJoinStraight.ts'),
  "joker": () => import('./icons/IconJoker.ts'),
  "jpg": () => import('./icons/IconJpg.ts'),
  "json": () => import('./icons/IconJson.ts'),
  "jump-rope": () => import('./icons/IconJumpRope.ts'),
  "karate": () => import('./icons/IconKarate.ts'),
  "kayak": () => import('./icons/IconKayak.ts'),
  "kerning": () => import('./icons/IconKerning.ts'),
  "key-off": () => import('./icons/IconKeyOff.ts'),
  "key": () => import('./icons/IconKey.ts'),
  "keyboard-hide": () => import('./icons/IconKeyboardHide.ts'),
  "keyboard-off": () => import('./icons/IconKeyboardOff.ts'),
  "keyboard-show": () => import('./icons/IconKeyboardShow.ts'),
  "keyboard": () => import('./icons/IconKeyboard.ts'),
  "keyframe-align-center": () => import('./icons/IconKeyframeAlignCenter.ts'),
  "keyframe-align-horizontal": () => import('./icons/IconKeyframeAlignHorizontal.ts'),
  "keyframe-align-vertical": () => import('./icons/IconKeyframeAlignVertical.ts'),
  "keyframe": () => import('./icons/IconKeyframe.ts'),
  "keyframes": () => import('./icons/IconKeyframes.ts'),
  "label-important": () => import('./icons/IconLabelImportant.ts'),
  "label-off": () => import('./icons/IconLabelOff.ts'),
  "label": () => import('./icons/IconLabel.ts'),
  "ladder-off": () => import('./icons/IconLadderOff.ts'),
  "ladder": () => import('./icons/IconLadder.ts'),
  "ladle": () => import('./icons/IconLadle.ts'),
  "lambda": () => import('./icons/IconLambda.ts'),
  "lamp-2": () => import('./icons/IconLamp2.ts'),
  "lamp-off": () => import('./icons/IconLampOff.ts'),
  "lamp": () => import('./icons/IconLamp.ts'),
  "lane": () => import('./icons/IconLane.ts'),
  "language-hiragana": () => import('./icons/IconLanguageHiragana.ts'),
  "language-katakana": () => import('./icons/IconLanguageKatakana.ts'),
  "language-off": () => import('./icons/IconLanguageOff.ts'),
  "language": () => import('./icons/IconLanguage.ts'),
  "lasso-off": () => import('./icons/IconLassoOff.ts'),
  "lasso-polygon": () => import('./icons/IconLassoPolygon.ts'),
  "lasso": () => import('./icons/IconLasso.ts'),
  "laurel-wreath-1": () => import('./icons/IconLaurelWreath1.ts'),
  "laurel-wreath-2": () => import('./icons/IconLaurelWreath2.ts'),
  "laurel-wreath-3": () => import('./icons/IconLaurelWreath3.ts'),
  "laurel-wreath": () => import('./icons/IconLaurelWreath.ts'),
  "layers-difference": () => import('./icons/IconLayersDifference.ts'),
  "layers-intersect-2": () => import('./icons/IconLayersIntersect2.ts'),
  "layers-intersect": () => import('./icons/IconLayersIntersect.ts'),
  "layers-linked": () => import('./icons/IconLayersLinked.ts'),
  "layers-off": () => import('./icons/IconLayersOff.ts'),
  "layers-selected-bottom": () => import('./icons/IconLayersSelectedBottom.ts'),
  "layers-selected": () => import('./icons/IconLayersSelected.ts'),
  "layers-subtract": () => import('./icons/IconLayersSubtract.ts'),
  "layers-union": () => import('./icons/IconLayersUnion.ts'),
  "layout-2": () => import('./icons/IconLayout2.ts'),
  "layout-align-bottom": () => import('./icons/IconLayoutAlignBottom.ts'),
  "layout-align-center": () => import('./icons/IconLayoutAlignCenter.ts'),
  "layout-align-left": () => import('./icons/IconLayoutAlignLeft.ts'),
  "layout-align-middle": () => import('./icons/IconLayoutAlignMiddle.ts'),
  "layout-align-right": () => import('./icons/IconLayoutAlignRight.ts'),
  "layout-align-top": () => import('./icons/IconLayoutAlignTop.ts'),
  "layout-board-split": () => import('./icons/IconLayoutBoardSplit.ts'),
  "layout-board": () => import('./icons/IconLayoutBoard.ts'),
  "layout-bottombar-collapse": () => import('./icons/IconLayoutBottombarCollapse.ts'),
  "layout-bottombar-expand": () => import('./icons/IconLayoutBottombarExpand.ts'),
  "layout-bottombar-inactive": () => import('./icons/IconLayoutBottombarInactive.ts'),
  "layout-bottombar": () => import('./icons/IconLayoutBottombar.ts'),
  "layout-cards": () => import('./icons/IconLayoutCards.ts'),
  "layout-collage": () => import('./icons/IconLayoutCollage.ts'),
  "layout-columns": () => import('./icons/IconLayoutColumns.ts'),
  "layout-dashboard": () => import('./icons/IconLayoutDashboard.ts'),
  "layout-distribute-horizontal": () => import('./icons/IconLayoutDistributeHorizontal.ts'),
  "layout-distribute-vertical": () => import('./icons/IconLayoutDistributeVertical.ts'),
  "layout-grid-add": () => import('./icons/IconLayoutGridAdd.ts'),
  "layout-grid-remove": () => import('./icons/IconLayoutGridRemove.ts'),
  "layout-grid": () => import('./icons/IconLayoutGrid.ts'),
  "layout-kanban": () => import('./icons/IconLayoutKanban.ts'),
  "layout-list": () => import('./icons/IconLayoutList.ts'),
  "layout-navbar-collapse": () => import('./icons/IconLayoutNavbarCollapse.ts'),
  "layout-navbar-expand": () => import('./icons/IconLayoutNavbarExpand.ts'),
  "layout-navbar-inactive": () => import('./icons/IconLayoutNavbarInactive.ts'),
  "layout-navbar": () => import('./icons/IconLayoutNavbar.ts'),
  "layout-off": () => import('./icons/IconLayoutOff.ts'),
  "layout-rows": () => import('./icons/IconLayoutRows.ts'),
  "layout-sidebar-inactive": () => import('./icons/IconLayoutSidebarInactive.ts'),
  "layout-sidebar-left-collapse": () => import('./icons/IconLayoutSidebarLeftCollapse.ts'),
  "layout-sidebar-left-expand": () => import('./icons/IconLayoutSidebarLeftExpand.ts'),
  "layout-sidebar-right-collapse": () => import('./icons/IconLayoutSidebarRightCollapse.ts'),
  "layout-sidebar-right-expand": () => import('./icons/IconLayoutSidebarRightExpand.ts'),
  "layout-sidebar-right-inactive": () => import('./icons/IconLayoutSidebarRightInactive.ts'),
  "layout-sidebar-right": () => import('./icons/IconLayoutSidebarRight.ts'),
  "layout-sidebar": () => import('./icons/IconLayoutSidebar.ts'),
  "layout": () => import('./icons/IconLayout.ts'),
  "leaf-2": () => import('./icons/IconLeaf2.ts'),
  "leaf-off": () => import('./icons/IconLeafOff.ts'),
  "leaf": () => import('./icons/IconLeaf.ts'),
  "lego-off": () => import('./icons/IconLegoOff.ts'),
  "lego": () => import('./icons/IconLego.ts'),
  "lemon-2": () => import('./icons/IconLemon2.ts'),
  "lemon": () => import('./icons/IconLemon.ts'),
  "letter-a-small": () => import('./icons/IconLetterASmall.ts'),
  "letter-a": () => import('./icons/IconLetterA.ts'),
  "letter-b-small": () => import('./icons/IconLetterBSmall.ts'),
  "letter-b": () => import('./icons/IconLetterB.ts'),
  "letter-c-small": () => import('./icons/IconLetterCSmall.ts'),
  "letter-c": () => import('./icons/IconLetterC.ts'),
  "letter-case-lower": () => import('./icons/IconLetterCaseLower.ts'),
  "letter-case-toggle": () => import('./icons/IconLetterCaseToggle.ts'),
  "letter-case-upper": () => import('./icons/IconLetterCaseUpper.ts'),
  "letter-case": () => import('./icons/IconLetterCase.ts'),
  "letter-d-small": () => import('./icons/IconLetterDSmall.ts'),
  "letter-d": () => import('./icons/IconLetterD.ts'),
  "letter-e-small": () => import('./icons/IconLetterESmall.ts'),
  "letter-e": () => import('./icons/IconLetterE.ts'),
  "letter-f-small": () => import('./icons/IconLetterFSmall.ts'),
  "letter-f": () => import('./icons/IconLetterF.ts'),
  "letter-g-small": () => import('./icons/IconLetterGSmall.ts'),
  "letter-g": () => import('./icons/IconLetterG.ts'),
  "letter-h-small": () => import('./icons/IconLetterHSmall.ts'),
  "letter-h": () => import('./icons/IconLetterH.ts'),
  "letter-i-small": () => import('./icons/IconLetterISmall.ts'),
  "letter-i": () => import('./icons/IconLetterI.ts'),
  "letter-j-small": () => import('./icons/IconLetterJSmall.ts'),
  "letter-j": () => import('./icons/IconLetterJ.ts'),
  "letter-k-small": () => import('./icons/IconLetterKSmall.ts'),
  "letter-k": () => import('./icons/IconLetterK.ts'),
  "letter-l-small": () => import('./icons/IconLetterLSmall.ts'),
  "letter-l": () => import('./icons/IconLetterL.ts'),
  "letter-m-small": () => import('./icons/IconLetterMSmall.ts'),
  "letter-m": () => import('./icons/IconLetterM.ts'),
  "letter-n-small": () => import('./icons/IconLetterNSmall.ts'),
  "letter-n": () => import('./icons/IconLetterN.ts'),
  "letter-o-small": () => import('./icons/IconLetterOSmall.ts'),
  "letter-o": () => import('./icons/IconLetterO.ts'),
  "letter-p-small": () => import('./icons/IconLetterPSmall.ts'),
  "letter-p": () => import('./icons/IconLetterP.ts'),
  "letter-q-small": () => import('./icons/IconLetterQSmall.ts'),
  "letter-q": () => import('./icons/IconLetterQ.ts'),
  "letter-r-small": () => import('./icons/IconLetterRSmall.ts'),
  "letter-r": () => import('./icons/IconLetterR.ts'),
  "letter-s-small": () => import('./icons/IconLetterSSmall.ts'),
  "letter-s": () => import('./icons/IconLetterS.ts'),
  "letter-spacing": () => import('./icons/IconLetterSpacing.ts'),
  "letter-t-small": () => import('./icons/IconLetterTSmall.ts'),
  "letter-t": () => import('./icons/IconLetterT.ts'),
  "letter-u-small": () => import('./icons/IconLetterUSmall.ts'),
  "letter-u": () => import('./icons/IconLetterU.ts'),
  "letter-v-small": () => import('./icons/IconLetterVSmall.ts'),
  "letter-v": () => import('./icons/IconLetterV.ts'),
  "letter-w-small": () => import('./icons/IconLetterWSmall.ts'),
  "letter-w": () => import('./icons/IconLetterW.ts'),
  "letter-x-small": () => import('./icons/IconLetterXSmall.ts'),
  "letter-x": () => import('./icons/IconLetterX.ts'),
  "letter-y-small": () => import('./icons/IconLetterYSmall.ts'),
  "letter-y": () => import('./icons/IconLetterY.ts'),
  "letter-z-small": () => import('./icons/IconLetterZSmall.ts'),
  "letter-z": () => import('./icons/IconLetterZ.ts'),
  "library-minus": () => import('./icons/IconLibraryMinus.ts'),
  "library-photo": () => import('./icons/IconLibraryPhoto.ts'),
  "library-plus": () => import('./icons/IconLibraryPlus.ts'),
  "library": () => import('./icons/IconLibrary.ts'),
  "license-off": () => import('./icons/IconLicenseOff.ts'),
  "license": () => import('./icons/IconLicense.ts'),
  "lifebuoy-off": () => import('./icons/IconLifebuoyOff.ts'),
  "lifebuoy": () => import('./icons/IconLifebuoy.ts'),
  "lighter": () => import('./icons/IconLighter.ts'),
  "line-dashed": () => import('./icons/IconLineDashed.ts'),
  "line-dotted": () => import('./icons/IconLineDotted.ts'),
  "line-height": () => import('./icons/IconLineHeight.ts'),
  "line-scan": () => import('./icons/IconLineScan.ts'),
  "line": () => import('./icons/IconLine.ts'),
  "link-minus": () => import('./icons/IconLinkMinus.ts'),
  "link-off": () => import('./icons/IconLinkOff.ts'),
  "link-plus": () => import('./icons/IconLinkPlus.ts'),
  "link": () => import('./icons/IconLink.ts'),
  "list-check": () => import('./icons/IconListCheck.ts'),
  "list-details": () => import('./icons/IconListDetails.ts'),
  "list-letters": () => import('./icons/IconListLetters.ts'),
  "list-numbers": () => import('./icons/IconListNumbers.ts'),
  "list-search": () => import('./icons/IconListSearch.ts'),
  "list-tree": () => import('./icons/IconListTree.ts'),
  "list": () => import('./icons/IconList.ts'),
  "live-photo-off": () => import('./icons/IconLivePhotoOff.ts'),
  "live-photo": () => import('./icons/IconLivePhoto.ts'),
  "live-view": () => import('./icons/IconLiveView.ts'),
  "load-balancer": () => import('./icons/IconLoadBalancer.ts'),
  "loader-2": () => import('./icons/IconLoader2.ts'),
  "loader-3": () => import('./icons/IconLoader3.ts'),
  "loader-quarter": () => import('./icons/IconLoaderQuarter.ts'),
  "loader": () => import('./icons/IconLoader.ts'),
  "location-bolt": () => import('./icons/IconLocationBolt.ts'),
  "location-broken": () => import('./icons/IconLocationBroken.ts'),
  "location-cancel": () => import('./icons/IconLocationCancel.ts'),
  "location-check": () => import('./icons/IconLocationCheck.ts'),
  "location-code": () => import('./icons/IconLocationCode.ts'),
  "location-cog": () => import('./icons/IconLocationCog.ts'),
  "location-discount": () => import('./icons/IconLocationDiscount.ts'),
  "location-dollar": () => import('./icons/IconLocationDollar.ts'),
  "location-down": () => import('./icons/IconLocationDown.ts'),
  "location-exclamation": () => import('./icons/IconLocationExclamation.ts'),
  "location-heart": () => import('./icons/IconLocationHeart.ts'),
  "location-minus": () => import('./icons/IconLocationMinus.ts'),
  "location-off": () => import('./icons/IconLocationOff.ts'),
  "location-pause": () => import('./icons/IconLocationPause.ts'),
  "location-pin": () => import('./icons/IconLocationPin.ts'),
  "location-plus": () => import('./icons/IconLocationPlus.ts'),
  "location-question": () => import('./icons/IconLocationQuestion.ts'),
  "location-search": () => import('./icons/IconLocationSearch.ts'),
  "location-share": () => import('./icons/IconLocationShare.ts'),
  "location-star": () => import('./icons/IconLocationStar.ts'),
  "location-up": () => import('./icons/IconLocationUp.ts'),
  "location-x": () => import('./icons/IconLocationX.ts'),
  "location": () => import('./icons/IconLocation.ts'),
  "lock-access-off": () => import('./icons/IconLockAccessOff.ts'),
  "lock-access": () => import('./icons/IconLockAccess.ts'),
  "lock-bitcoin": () => import('./icons/IconLockBitcoin.ts'),
  "lock-bolt": () => import('./icons/IconLockBolt.ts'),
  "lock-cancel": () => import('./icons/IconLockCancel.ts'),
  "lock-check": () => import('./icons/IconLockCheck.ts'),
  "lock-code": () => import('./icons/IconLockCode.ts'),
  "lock-cog": () => import('./icons/IconLockCog.ts'),
  "lock-dollar": () => import('./icons/IconLockDollar.ts'),
  "lock-down": () => import('./icons/IconLockDown.ts'),
  "lock-exclamation": () => import('./icons/IconLockExclamation.ts'),
  "lock-heart": () => import('./icons/IconLockHeart.ts'),
  "lock-minus": () => import('./icons/IconLockMinus.ts'),
  "lock-off": () => import('./icons/IconLockOff.ts'),
  "lock-open-2": () => import('./icons/IconLockOpen2.ts'),
  "lock-open-off": () => import('./icons/IconLockOpenOff.ts'),
  "lock-open": () => import('./icons/IconLockOpen.ts'),
  "lock-password": () => import('./icons/IconLockPassword.ts'),
  "lock-pause": () => import('./icons/IconLockPause.ts'),
  "lock-pin": () => import('./icons/IconLockPin.ts'),
  "lock-plus": () => import('./icons/IconLockPlus.ts'),
  "lock-question": () => import('./icons/IconLockQuestion.ts'),
  "lock-search": () => import('./icons/IconLockSearch.ts'),
  "lock-share": () => import('./icons/IconLockShare.ts'),
  "lock-square-rounded": () => import('./icons/IconLockSquareRounded.ts'),
  "lock-square": () => import('./icons/IconLockSquare.ts'),
  "lock-star": () => import('./icons/IconLockStar.ts'),
  "lock-up": () => import('./icons/IconLockUp.ts'),
  "lock-x": () => import('./icons/IconLockX.ts'),
  "lock": () => import('./icons/IconLock.ts'),
  "logic-and": () => import('./icons/IconLogicAnd.ts'),
  "logic-buffer": () => import('./icons/IconLogicBuffer.ts'),
  "logic-nand": () => import('./icons/IconLogicNand.ts'),
  "logic-nor": () => import('./icons/IconLogicNor.ts'),
  "logic-not": () => import('./icons/IconLogicNot.ts'),
  "logic-or": () => import('./icons/IconLogicOr.ts'),
  "logic-xnor": () => import('./icons/IconLogicXnor.ts'),
  "logic-xor": () => import('./icons/IconLogicXor.ts'),
  "login-2": () => import('./icons/IconLogin2.ts'),
  "login": () => import('./icons/IconLogin.ts'),
  "logout-2": () => import('./icons/IconLogout2.ts'),
  "logout": () => import('./icons/IconLogout.ts'),
  "logs": () => import('./icons/IconLogs.ts'),
  "lollipop-off": () => import('./icons/IconLollipopOff.ts'),
  "lollipop": () => import('./icons/IconLollipop.ts'),
  "luggage-off": () => import('./icons/IconLuggageOff.ts'),
  "luggage": () => import('./icons/IconLuggage.ts'),
  "lungs-off": () => import('./icons/IconLungsOff.ts'),
  "lungs": () => import('./icons/IconLungs.ts'),
  "macro-off": () => import('./icons/IconMacroOff.ts'),
  "macro": () => import('./icons/IconMacro.ts'),
  "magnet-off": () => import('./icons/IconMagnetOff.ts'),
  "magnet": () => import('./icons/IconMagnet.ts'),
  "magnetic": () => import('./icons/IconMagnetic.ts'),
  "mail-ai": () => import('./icons/IconMailAi.ts'),
  "mail-bitcoin": () => import('./icons/IconMailBitcoin.ts'),
  "mail-bolt": () => import('./icons/IconMailBolt.ts'),
  "mail-cancel": () => import('./icons/IconMailCancel.ts'),
  "mail-check": () => import('./icons/IconMailCheck.ts'),
  "mail-code": () => import('./icons/IconMailCode.ts'),
  "mail-cog": () => import('./icons/IconMailCog.ts'),
  "mail-dollar": () => import('./icons/IconMailDollar.ts'),
  "mail-down": () => import('./icons/IconMailDown.ts'),
  "mail-exclamation": () => import('./icons/IconMailExclamation.ts'),
  "mail-fast": () => import('./icons/IconMailFast.ts'),
  "mail-forward": () => import('./icons/IconMailForward.ts'),
  "mail-heart": () => import('./icons/IconMailHeart.ts'),
  "mail-minus": () => import('./icons/IconMailMinus.ts'),
  "mail-off": () => import('./icons/IconMailOff.ts'),
  "mail-opened": () => import('./icons/IconMailOpened.ts'),
  "mail-pause": () => import('./icons/IconMailPause.ts'),
  "mail-pin": () => import('./icons/IconMailPin.ts'),
  "mail-plus": () => import('./icons/IconMailPlus.ts'),
  "mail-question": () => import('./icons/IconMailQuestion.ts'),
  "mail-search": () => import('./icons/IconMailSearch.ts'),
  "mail-share": () => import('./icons/IconMailShare.ts'),
  "mail-spark": () => import('./icons/IconMailSpark.ts'),
  "mail-star": () => import('./icons/IconMailStar.ts'),
  "mail-up": () => import('./icons/IconMailUp.ts'),
  "mail-x": () => import('./icons/IconMailX.ts'),
  "mail": () => import('./icons/IconMail.ts'),
  "mailbox-off": () => import('./icons/IconMailboxOff.ts'),
  "mailbox": () => import('./icons/IconMailbox.ts'),
  "man": () => import('./icons/IconMan.ts'),
  "manual-gearbox": () => import('./icons/IconManualGearbox.ts'),
  "map-2": () => import('./icons/IconMap2.ts'),
  "map-bolt": () => import('./icons/IconMapBolt.ts'),
  "map-cancel": () => import('./icons/IconMapCancel.ts'),
  "map-check": () => import('./icons/IconMapCheck.ts'),
  "map-code": () => import('./icons/IconMapCode.ts'),
  "map-cog": () => import('./icons/IconMapCog.ts'),
  "map-discount": () => import('./icons/IconMapDiscount.ts'),
  "map-dollar": () => import('./icons/IconMapDollar.ts'),
  "map-down": () => import('./icons/IconMapDown.ts'),
  "map-east": () => import('./icons/IconMapEast.ts'),
  "map-exclamation": () => import('./icons/IconMapExclamation.ts'),
  "map-heart": () => import('./icons/IconMapHeart.ts'),
  "map-minus": () => import('./icons/IconMapMinus.ts'),
  "map-north": () => import('./icons/IconMapNorth.ts'),
  "map-off": () => import('./icons/IconMapOff.ts'),
  "map-pause": () => import('./icons/IconMapPause.ts'),
  "map-pin-2": () => import('./icons/IconMapPin2.ts'),
  "map-pin-bolt": () => import('./icons/IconMapPinBolt.ts'),
  "map-pin-cancel": () => import('./icons/IconMapPinCancel.ts'),
  "map-pin-check": () => import('./icons/IconMapPinCheck.ts'),
  "map-pin-code": () => import('./icons/IconMapPinCode.ts'),
  "map-pin-cog": () => import('./icons/IconMapPinCog.ts'),
  "map-pin-dollar": () => import('./icons/IconMapPinDollar.ts'),
  "map-pin-down": () => import('./icons/IconMapPinDown.ts'),
  "map-pin-exclamation": () => import('./icons/IconMapPinExclamation.ts'),
  "map-pin-heart": () => import('./icons/IconMapPinHeart.ts'),
  "map-pin-minus": () => import('./icons/IconMapPinMinus.ts'),
  "map-pin-off": () => import('./icons/IconMapPinOff.ts'),
  "map-pin-pause": () => import('./icons/IconMapPinPause.ts'),
  "map-pin-pin": () => import('./icons/IconMapPinPin.ts'),
  "map-pin-plus": () => import('./icons/IconMapPinPlus.ts'),
  "map-pin-question": () => import('./icons/IconMapPinQuestion.ts'),
  "map-pin-search": () => import('./icons/IconMapPinSearch.ts'),
  "map-pin-share": () => import('./icons/IconMapPinShare.ts'),
  "map-pin-star": () => import('./icons/IconMapPinStar.ts'),
  "map-pin-up": () => import('./icons/IconMapPinUp.ts'),
  "map-pin-x": () => import('./icons/IconMapPinX.ts'),
  "map-pin": () => import('./icons/IconMapPin.ts'),
  "map-pins": () => import('./icons/IconMapPins.ts'),
  "map-plus": () => import('./icons/IconMapPlus.ts'),
  "map-question": () => import('./icons/IconMapQuestion.ts'),
  "map-route": () => import('./icons/IconMapRoute.ts'),
  "map-search": () => import('./icons/IconMapSearch.ts'),
  "map-share": () => import('./icons/IconMapShare.ts'),
  "map-south": () => import('./icons/IconMapSouth.ts'),
  "map-star": () => import('./icons/IconMapStar.ts'),
  "map-up": () => import('./icons/IconMapUp.ts'),
  "map-west": () => import('./icons/IconMapWest.ts'),
  "map-x": () => import('./icons/IconMapX.ts'),
  "map": () => import('./icons/IconMap.ts'),
  "markdown-off": () => import('./icons/IconMarkdownOff.ts'),
  "markdown": () => import('./icons/IconMarkdown.ts'),
  "marquee-2": () => import('./icons/IconMarquee2.ts'),
  "marquee-off": () => import('./icons/IconMarqueeOff.ts'),
  "marquee": () => import('./icons/IconMarquee.ts'),
  "mars": () => import('./icons/IconMars.ts'),
  "mask-off": () => import('./icons/IconMaskOff.ts'),
  "mask": () => import('./icons/IconMask.ts'),
  "masks-theater-off": () => import('./icons/IconMasksTheaterOff.ts'),
  "masks-theater": () => import('./icons/IconMasksTheater.ts'),
  "massage": () => import('./icons/IconMassage.ts'),
  "matchstick": () => import('./icons/IconMatchstick.ts'),
  "math-1-divide-2": () => import('./icons/IconMath1Divide2.ts'),
  "math-1-divide-3": () => import('./icons/IconMath1Divide3.ts'),
  "math-avg": () => import('./icons/IconMathAvg.ts'),
  "math-cos": () => import('./icons/IconMathCos.ts'),
  "math-ctg": () => import('./icons/IconMathCtg.ts'),
  "math-equal-greater": () => import('./icons/IconMathEqualGreater.ts'),
  "math-equal-lower": () => import('./icons/IconMathEqualLower.ts'),
  "math-function-off": () => import('./icons/IconMathFunctionOff.ts'),
  "math-function-y": () => import('./icons/IconMathFunctionY.ts'),
  "math-function": () => import('./icons/IconMathFunction.ts'),
  "math-greater": () => import('./icons/IconMathGreater.ts'),
  "math-integral-x": () => import('./icons/IconMathIntegralX.ts'),
  "math-integral": () => import('./icons/IconMathIntegral.ts'),
  "math-integrals": () => import('./icons/IconMathIntegrals.ts'),
  "math-lower": () => import('./icons/IconMathLower.ts'),
  "math-max-min": () => import('./icons/IconMathMaxMin.ts'),
  "math-max": () => import('./icons/IconMathMax.ts'),
  "math-min": () => import('./icons/IconMathMin.ts'),
  "math-not": () => import('./icons/IconMathNot.ts'),
  "math-off": () => import('./icons/IconMathOff.ts'),
  "math-pi-divide-2": () => import('./icons/IconMathPiDivide2.ts'),
  "math-pi": () => import('./icons/IconMathPi.ts'),
  "math-sec": () => import('./icons/IconMathSec.ts'),
  "math-sin": () => import('./icons/IconMathSin.ts'),
  "math-symbols": () => import('./icons/IconMathSymbols.ts'),
  "math-tg": () => import('./icons/IconMathTg.ts'),
  "math-x-divide-2": () => import('./icons/IconMathXDivide2.ts'),
  "math-x-divide-y-2": () => import('./icons/IconMathXDivideY2.ts'),
  "math-x-divide-y": () => import('./icons/IconMathXDivideY.ts'),
  "math-x-floor-divide-y": () => import('./icons/IconMathXFloorDivideY.ts'),
  "math-x-minus-x": () => import('./icons/IconMathXMinusX.ts'),
  "math-x-minus-y": () => import('./icons/IconMathXMinusY.ts'),
  "math-x-plus-x": () => import('./icons/IconMathXPlusX.ts'),
  "math-x-plus-y": () => import('./icons/IconMathXPlusY.ts'),
  "math-xy": () => import('./icons/IconMathXy.ts'),
  "math-y-minus-y": () => import('./icons/IconMathYMinusY.ts'),
  "math-y-plus-y": () => import('./icons/IconMathYPlusY.ts'),
  "math": () => import('./icons/IconMath.ts'),
  "matrix": () => import('./icons/IconMatrix.ts'),
  "maximize-off": () => import('./icons/IconMaximizeOff.ts'),
  "maximize": () => import('./icons/IconMaximize.ts'),
  "meat-off": () => import('./icons/IconMeatOff.ts'),
  "meat": () => import('./icons/IconMeat.ts'),
  "medal-2": () => import('./icons/IconMedal2.ts'),
  "medal": () => import('./icons/IconMedal.ts'),
  "medical-cross-circle": () => import('./icons/IconMedicalCrossCircle.ts'),
  "medical-cross-off": () => import('./icons/IconMedicalCrossOff.ts'),
  "medical-cross": () => import('./icons/IconMedicalCross.ts'),
  "medicine-syrup": () => import('./icons/IconMedicineSyrup.ts'),
  "meeple": () => import('./icons/IconMeeple.ts'),
  "melon": () => import('./icons/IconMelon.ts'),
  "menorah": () => import('./icons/IconMenorah.ts'),
  "menu-2": () => import('./icons/IconMenu2.ts'),
  "menu-3": () => import('./icons/IconMenu3.ts'),
  "menu-4": () => import('./icons/IconMenu4.ts'),
  "menu-deep": () => import('./icons/IconMenuDeep.ts'),
  "menu-order": () => import('./icons/IconMenuOrder.ts'),
  "menu": () => import('./icons/IconMenu.ts'),
  "message-2-bolt": () => import('./icons/IconMessage2Bolt.ts'),
  "message-2-cancel": () => import('./icons/IconMessage2Cancel.ts'),
  "message-2-check": () => import('./icons/IconMessage2Check.ts'),
  "message-2-code": () => import('./icons/IconMessage2Code.ts'),
  "message-2-cog": () => import('./icons/IconMessage2Cog.ts'),
  "message-2-dollar": () => import('./icons/IconMessage2Dollar.ts'),
  "message-2-down": () => import('./icons/IconMessage2Down.ts'),
  "message-2-exclamation": () => import('./icons/IconMessage2Exclamation.ts'),
  "message-2-heart": () => import('./icons/IconMessage2Heart.ts'),
  "message-2-minus": () => import('./icons/IconMessage2Minus.ts'),
  "message-2-off": () => import('./icons/IconMessage2Off.ts'),
  "message-2-pause": () => import('./icons/IconMessage2Pause.ts'),
  "message-2-pin": () => import('./icons/IconMessage2Pin.ts'),
  "message-2-plus": () => import('./icons/IconMessage2Plus.ts'),
  "message-2-question": () => import('./icons/IconMessage2Question.ts'),
  "message-2-search": () => import('./icons/IconMessage2Search.ts'),
  "message-2-share": () => import('./icons/IconMessage2Share.ts'),
  "message-2-star": () => import('./icons/IconMessage2Star.ts'),
  "message-2-up": () => import('./icons/IconMessage2Up.ts'),
  "message-2-x": () => import('./icons/IconMessage2X.ts'),
  "message-2": () => import('./icons/IconMessage2.ts'),
  "message-bolt": () => import('./icons/IconMessageBolt.ts'),
  "message-cancel": () => import('./icons/IconMessageCancel.ts'),
  "message-chatbot": () => import('./icons/IconMessageChatbot.ts'),
  "message-check": () => import('./icons/IconMessageCheck.ts'),
  "message-circle-bolt": () => import('./icons/IconMessageCircleBolt.ts'),
  "message-circle-cancel": () => import('./icons/IconMessageCircleCancel.ts'),
  "message-circle-check": () => import('./icons/IconMessageCircleCheck.ts'),
  "message-circle-code": () => import('./icons/IconMessageCircleCode.ts'),
  "message-circle-cog": () => import('./icons/IconMessageCircleCog.ts'),
  "message-circle-dollar": () => import('./icons/IconMessageCircleDollar.ts'),
  "message-circle-down": () => import('./icons/IconMessageCircleDown.ts'),
  "message-circle-exclamation": () => import('./icons/IconMessageCircleExclamation.ts'),
  "message-circle-heart": () => import('./icons/IconMessageCircleHeart.ts'),
  "message-circle-minus": () => import('./icons/IconMessageCircleMinus.ts'),
  "message-circle-off": () => import('./icons/IconMessageCircleOff.ts'),
  "message-circle-pause": () => import('./icons/IconMessageCirclePause.ts'),
  "message-circle-pin": () => import('./icons/IconMessageCirclePin.ts'),
  "message-circle-plus": () => import('./icons/IconMessageCirclePlus.ts'),
  "message-circle-question": () => import('./icons/IconMessageCircleQuestion.ts'),
  "message-circle-search": () => import('./icons/IconMessageCircleSearch.ts'),
  "message-circle-share": () => import('./icons/IconMessageCircleShare.ts'),
  "message-circle-star": () => import('./icons/IconMessageCircleStar.ts'),
  "message-circle-up": () => import('./icons/IconMessageCircleUp.ts'),
  "message-circle-user": () => import('./icons/IconMessageCircleUser.ts'),
  "message-circle-x": () => import('./icons/IconMessageCircleX.ts'),
  "message-circle": () => import('./icons/IconMessageCircle.ts'),
  "message-code": () => import('./icons/IconMessageCode.ts'),
  "message-cog": () => import('./icons/IconMessageCog.ts'),
  "message-dollar": () => import('./icons/IconMessageDollar.ts'),
  "message-dots": () => import('./icons/IconMessageDots.ts'),
  "message-down": () => import('./icons/IconMessageDown.ts'),
  "message-exclamation": () => import('./icons/IconMessageExclamation.ts'),
  "message-forward": () => import('./icons/IconMessageForward.ts'),
  "message-heart": () => import('./icons/IconMessageHeart.ts'),
  "message-language": () => import('./icons/IconMessageLanguage.ts'),
  "message-minus": () => import('./icons/IconMessageMinus.ts'),
  "message-off": () => import('./icons/IconMessageOff.ts'),
  "message-pause": () => import('./icons/IconMessagePause.ts'),
  "message-pin": () => import('./icons/IconMessagePin.ts'),
  "message-plus": () => import('./icons/IconMessagePlus.ts'),
  "message-question": () => import('./icons/IconMessageQuestion.ts'),
  "message-reply": () => import('./icons/IconMessageReply.ts'),
  "message-report": () => import('./icons/IconMessageReport.ts'),
  "message-search": () => import('./icons/IconMessageSearch.ts'),
  "message-share": () => import('./icons/IconMessageShare.ts'),
  "message-star": () => import('./icons/IconMessageStar.ts'),
  "message-up": () => import('./icons/IconMessageUp.ts'),
  "message-user": () => import('./icons/IconMessageUser.ts'),
  "message-x": () => import('./icons/IconMessageX.ts'),
  "message": () => import('./icons/IconMessage.ts'),
  "messages-off": () => import('./icons/IconMessagesOff.ts'),
  "messages": () => import('./icons/IconMessages.ts'),
  "meteor-off": () => import('./icons/IconMeteorOff.ts'),
  "meteor": () => import('./icons/IconMeteor.ts'),
  "meter-cube": () => import('./icons/IconMeterCube.ts'),
  "meter-square": () => import('./icons/IconMeterSquare.ts'),
  "metronome": () => import('./icons/IconMetronome.ts'),
  "michelin-bib-gourmand": () => import('./icons/IconMichelinBibGourmand.ts'),
  "michelin-star-green": () => import('./icons/IconMichelinStarGreen.ts'),
  "michelin-star": () => import('./icons/IconMichelinStar.ts'),
  "mickey": () => import('./icons/IconMickey.ts'),
  "microphone-2-off": () => import('./icons/IconMicrophone2Off.ts'),
  "microphone-2": () => import('./icons/IconMicrophone2.ts'),
  "microphone-off": () => import('./icons/IconMicrophoneOff.ts'),
  "microphone": () => import('./icons/IconMicrophone.ts'),
  "microscope-off": () => import('./icons/IconMicroscopeOff.ts'),
  "microscope": () => import('./icons/IconMicroscope.ts'),
  "microwave-off": () => import('./icons/IconMicrowaveOff.ts'),
  "microwave": () => import('./icons/IconMicrowave.ts'),
  "military-award": () => import('./icons/IconMilitaryAward.ts'),
  "military-rank": () => import('./icons/IconMilitaryRank.ts'),
  "milk-off": () => import('./icons/IconMilkOff.ts'),
  "milk": () => import('./icons/IconMilk.ts'),
  "milkshake": () => import('./icons/IconMilkshake.ts'),
  "minimize": () => import('./icons/IconMinimize.ts'),
  "minus-vertical": () => import('./icons/IconMinusVertical.ts'),
  "minus": () => import('./icons/IconMinus.ts'),
  "mist-off": () => import('./icons/IconMistOff.ts'),
  "mist": () => import('./icons/IconMist.ts'),
  "mobiledata-off": () => import('./icons/IconMobiledataOff.ts'),
  "mobiledata": () => import('./icons/IconMobiledata.ts'),
  "moneybag-edit": () => import('./icons/IconMoneybagEdit.ts'),
  "moneybag-heart": () => import('./icons/IconMoneybagHeart.ts'),
  "moneybag-minus": () => import('./icons/IconMoneybagMinus.ts'),
  "moneybag-move-back": () => import('./icons/IconMoneybagMoveBack.ts'),
  "moneybag-move": () => import('./icons/IconMoneybagMove.ts'),
  "moneybag-plus": () => import('./icons/IconMoneybagPlus.ts'),
  "moneybag": () => import('./icons/IconMoneybag.ts'),
  "monkeybar": () => import('./icons/IconMonkeybar.ts'),
  "mood-angry": () => import('./icons/IconMoodAngry.ts'),
  "mood-annoyed-2": () => import('./icons/IconMoodAnnoyed2.ts'),
  "mood-annoyed": () => import('./icons/IconMoodAnnoyed.ts'),
  "mood-bitcoin": () => import('./icons/IconMoodBitcoin.ts'),
  "mood-boy": () => import('./icons/IconMoodBoy.ts'),
  "mood-check": () => import('./icons/IconMoodCheck.ts'),
  "mood-cog": () => import('./icons/IconMoodCog.ts'),
  "mood-confuzed": () => import('./icons/IconMoodConfuzed.ts'),
  "mood-crazy-happy": () => import('./icons/IconMoodCrazyHappy.ts'),
  "mood-cry": () => import('./icons/IconMoodCry.ts'),
  "mood-dollar": () => import('./icons/IconMoodDollar.ts'),
  "mood-edit": () => import('./icons/IconMoodEdit.ts'),
  "mood-empty": () => import('./icons/IconMoodEmpty.ts'),
  "mood-happy": () => import('./icons/IconMoodHappy.ts'),
  "mood-heart": () => import('./icons/IconMoodHeart.ts'),
  "mood-kid": () => import('./icons/IconMoodKid.ts'),
  "mood-look-down": () => import('./icons/IconMoodLookDown.ts'),
  "mood-look-left": () => import('./icons/IconMoodLookLeft.ts'),
  "mood-look-right": () => import('./icons/IconMoodLookRight.ts'),
  "mood-look-up": () => import('./icons/IconMoodLookUp.ts'),
  "mood-minus": () => import('./icons/IconMoodMinus.ts'),
  "mood-nerd": () => import('./icons/IconMoodNerd.ts'),
  "mood-nervous": () => import('./icons/IconMoodNervous.ts'),
  "mood-neutral": () => import('./icons/IconMoodNeutral.ts'),
  "mood-off": () => import('./icons/IconMoodOff.ts'),
  "mood-pin": () => import('./icons/IconMoodPin.ts'),
  "mood-plus": () => import('./icons/IconMoodPlus.ts'),
  "mood-puzzled": () => import('./icons/IconMoodPuzzled.ts'),
  "mood-sad-2": () => import('./icons/IconMoodSad2.ts'),
  "mood-sad-dizzy": () => import('./icons/IconMoodSadDizzy.ts'),
  "mood-sad-squint": () => import('./icons/IconMoodSadSquint.ts'),
  "mood-sad": () => import('./icons/IconMoodSad.ts'),
  "mood-search": () => import('./icons/IconMoodSearch.ts'),
  "mood-share": () => import('./icons/IconMoodShare.ts'),
  "mood-sick": () => import('./icons/IconMoodSick.ts'),
  "mood-silence": () => import('./icons/IconMoodSilence.ts'),
  "mood-sing": () => import('./icons/IconMoodSing.ts'),
  "mood-smile-beam": () => import('./icons/IconMoodSmileBeam.ts'),
  "mood-smile-dizzy": () => import('./icons/IconMoodSmileDizzy.ts'),
  "mood-smile": () => import('./icons/IconMoodSmile.ts'),
  "mood-spark": () => import('./icons/IconMoodSpark.ts'),
  "mood-surprised": () => import('./icons/IconMoodSurprised.ts'),
  "mood-tongue-wink-2": () => import('./icons/IconMoodTongueWink2.ts'),
  "mood-tongue-wink": () => import('./icons/IconMoodTongueWink.ts'),
  "mood-tongue": () => import('./icons/IconMoodTongue.ts'),
  "mood-unamused": () => import('./icons/IconMoodUnamused.ts'),
  "mood-up": () => import('./icons/IconMoodUp.ts'),
  "mood-wink-2": () => import('./icons/IconMoodWink2.ts'),
  "mood-wink": () => import('./icons/IconMoodWink.ts'),
  "mood-wrrr": () => import('./icons/IconMoodWrrr.ts'),
  "mood-x": () => import('./icons/IconMoodX.ts'),
  "mood-xd": () => import('./icons/IconMoodXd.ts'),
  "moon-2": () => import('./icons/IconMoon2.ts'),
  "moon-off": () => import('./icons/IconMoonOff.ts'),
  "moon-stars": () => import('./icons/IconMoonStars.ts'),
  "moon": () => import('./icons/IconMoon.ts'),
  "moped": () => import('./icons/IconMoped.ts'),
  "motorbike": () => import('./icons/IconMotorbike.ts'),
  "mountain-off": () => import('./icons/IconMountainOff.ts'),
  "mountain": () => import('./icons/IconMountain.ts'),
  "mouse-2": () => import('./icons/IconMouse2.ts'),
  "mouse-off": () => import('./icons/IconMouseOff.ts'),
  "mouse": () => import('./icons/IconMouse.ts'),
  "moustache": () => import('./icons/IconMoustache.ts'),
  "movie-off": () => import('./icons/IconMovieOff.ts'),
  "movie": () => import('./icons/IconMovie.ts'),
  "mug-off": () => import('./icons/IconMugOff.ts'),
  "mug": () => import('./icons/IconMug.ts'),
  "multiplier-0-5x": () => import('./icons/IconMultiplier05x.ts'),
  "multiplier-1-5x": () => import('./icons/IconMultiplier15x.ts'),
  "multiplier-1x": () => import('./icons/IconMultiplier1x.ts'),
  "multiplier-2x": () => import('./icons/IconMultiplier2x.ts'),
  "mushroom-off": () => import('./icons/IconMushroomOff.ts'),
  "mushroom": () => import('./icons/IconMushroom.ts'),
  "music-bolt": () => import('./icons/IconMusicBolt.ts'),
  "music-cancel": () => import('./icons/IconMusicCancel.ts'),
  "music-check": () => import('./icons/IconMusicCheck.ts'),
  "music-code": () => import('./icons/IconMusicCode.ts'),
  "music-cog": () => import('./icons/IconMusicCog.ts'),
  "music-discount": () => import('./icons/IconMusicDiscount.ts'),
  "music-dollar": () => import('./icons/IconMusicDollar.ts'),
  "music-down": () => import('./icons/IconMusicDown.ts'),
  "music-exclamation": () => import('./icons/IconMusicExclamation.ts'),
  "music-heart": () => import('./icons/IconMusicHeart.ts'),
  "music-minus": () => import('./icons/IconMusicMinus.ts'),
  "music-off": () => import('./icons/IconMusicOff.ts'),
  "music-pause": () => import('./icons/IconMusicPause.ts'),
  "music-pin": () => import('./icons/IconMusicPin.ts'),
  "music-plus": () => import('./icons/IconMusicPlus.ts'),
  "music-question": () => import('./icons/IconMusicQuestion.ts'),
  "music-search": () => import('./icons/IconMusicSearch.ts'),
  "music-share": () => import('./icons/IconMusicShare.ts'),
  "music-star": () => import('./icons/IconMusicStar.ts'),
  "music-up": () => import('./icons/IconMusicUp.ts'),
  "music-x": () => import('./icons/IconMusicX.ts'),
  "music": () => import('./icons/IconMusic.ts'),
  "navigation-bolt": () => import('./icons/IconNavigationBolt.ts'),
  "navigation-cancel": () => import('./icons/IconNavigationCancel.ts'),
  "navigation-check": () => import('./icons/IconNavigationCheck.ts'),
  "navigation-code": () => import('./icons/IconNavigationCode.ts'),
  "navigation-cog": () => import('./icons/IconNavigationCog.ts'),
  "navigation-discount": () => import('./icons/IconNavigationDiscount.ts'),
  "navigation-dollar": () => import('./icons/IconNavigationDollar.ts'),
  "navigation-down": () => import('./icons/IconNavigationDown.ts'),
  "navigation-east": () => import('./icons/IconNavigationEast.ts'),
  "navigation-exclamation": () => import('./icons/IconNavigationExclamation.ts'),
  "navigation-heart": () => import('./icons/IconNavigationHeart.ts'),
  "navigation-minus": () => import('./icons/IconNavigationMinus.ts'),
  "navigation-north": () => import('./icons/IconNavigationNorth.ts'),
  "navigation-off": () => import('./icons/IconNavigationOff.ts'),
  "navigation-pause": () => import('./icons/IconNavigationPause.ts'),
  "navigation-pin": () => import('./icons/IconNavigationPin.ts'),
  "navigation-plus": () => import('./icons/IconNavigationPlus.ts'),
  "navigation-question": () => import('./icons/IconNavigationQuestion.ts'),
  "navigation-search": () => import('./icons/IconNavigationSearch.ts'),
  "navigation-share": () => import('./icons/IconNavigationShare.ts'),
  "navigation-south": () => import('./icons/IconNavigationSouth.ts'),
  "navigation-star": () => import('./icons/IconNavigationStar.ts'),
  "navigation-top": () => import('./icons/IconNavigationTop.ts'),
  "navigation-up": () => import('./icons/IconNavigationUp.ts'),
  "navigation-west": () => import('./icons/IconNavigationWest.ts'),
  "navigation-x": () => import('./icons/IconNavigationX.ts'),
  "navigation": () => import('./icons/IconNavigation.ts'),
  "needle-thread": () => import('./icons/IconNeedleThread.ts'),
  "needle": () => import('./icons/IconNeedle.ts'),
  "network-off": () => import('./icons/IconNetworkOff.ts'),
  "network": () => import('./icons/IconNetwork.ts'),
  "new-section": () => import('./icons/IconNewSection.ts'),
  "news-off": () => import('./icons/IconNewsOff.ts'),
  "news": () => import('./icons/IconNews.ts'),
  "nfc-off": () => import('./icons/IconNfcOff.ts'),
  "nfc": () => import('./icons/IconNfc.ts'),
  "no-copyright": () => import('./icons/IconNoCopyright.ts'),
  "no-creative-commons": () => import('./icons/IconNoCreativeCommons.ts'),
  "no-derivatives": () => import('./icons/IconNoDerivatives.ts'),
  "north-star": () => import('./icons/IconNorthStar.ts'),
  "note-off": () => import('./icons/IconNoteOff.ts'),
  "note": () => import('./icons/IconNote.ts'),
  "notebook-off": () => import('./icons/IconNotebookOff.ts'),
  "notebook": () => import('./icons/IconNotebook.ts'),
  "notes-off": () => import('./icons/IconNotesOff.ts'),
  "notes": () => import('./icons/IconNotes.ts'),
  "notification-off": () => import('./icons/IconNotificationOff.ts'),
  "notification": () => import('./icons/IconNotification.ts'),
  "number-0-small": () => import('./icons/IconNumber0Small.ts'),
  "number-0": () => import('./icons/IconNumber0.ts'),
  "number-1-small": () => import('./icons/IconNumber1Small.ts'),
  "number-1": () => import('./icons/IconNumber1.ts'),
  "number-10-small": () => import('./icons/IconNumber10Small.ts'),
  "number-10": () => import('./icons/IconNumber10.ts'),
  "number-100-small": () => import('./icons/IconNumber100Small.ts'),
  "number-11-small": () => import('./icons/IconNumber11Small.ts'),
  "number-11": () => import('./icons/IconNumber11.ts'),
  "number-12-small": () => import('./icons/IconNumber12Small.ts'),
  "number-123": () => import('./icons/IconNumber123.ts'),
  "number-13-small": () => import('./icons/IconNumber13Small.ts'),
  "number-14-small": () => import('./icons/IconNumber14Small.ts'),
  "number-15-small": () => import('./icons/IconNumber15Small.ts'),
  "number-16-small": () => import('./icons/IconNumber16Small.ts'),
  "number-17-small": () => import('./icons/IconNumber17Small.ts'),
  "number-18-small": () => import('./icons/IconNumber18Small.ts'),
  "number-19-small": () => import('./icons/IconNumber19Small.ts'),
  "number-2-small": () => import('./icons/IconNumber2Small.ts'),
  "number-2": () => import('./icons/IconNumber2.ts'),
  "number-20-small": () => import('./icons/IconNumber20Small.ts'),
  "number-21-small": () => import('./icons/IconNumber21Small.ts'),
  "number-22-small": () => import('./icons/IconNumber22Small.ts'),
  "number-23-small": () => import('./icons/IconNumber23Small.ts'),
  "number-24-small": () => import('./icons/IconNumber24Small.ts'),
  "number-25-small": () => import('./icons/IconNumber25Small.ts'),
  "number-26-small": () => import('./icons/IconNumber26Small.ts'),
  "number-27-small": () => import('./icons/IconNumber27Small.ts'),
  "number-28-small": () => import('./icons/IconNumber28Small.ts'),
  "number-29-small": () => import('./icons/IconNumber29Small.ts'),
  "number-3-small": () => import('./icons/IconNumber3Small.ts'),
  "number-3": () => import('./icons/IconNumber3.ts'),
  "number-30-small": () => import('./icons/IconNumber30Small.ts'),
  "number-31-small": () => import('./icons/IconNumber31Small.ts'),
  "number-32-small": () => import('./icons/IconNumber32Small.ts'),
  "number-33-small": () => import('./icons/IconNumber33Small.ts'),
  "number-34-small": () => import('./icons/IconNumber34Small.ts'),
  "number-35-small": () => import('./icons/IconNumber35Small.ts'),
  "number-36-small": () => import('./icons/IconNumber36Small.ts'),
  "number-37-small": () => import('./icons/IconNumber37Small.ts'),
  "number-38-small": () => import('./icons/IconNumber38Small.ts'),
  "number-39-small": () => import('./icons/IconNumber39Small.ts'),
  "number-4-small": () => import('./icons/IconNumber4Small.ts'),
  "number-4": () => import('./icons/IconNumber4.ts'),
  "number-40-small": () => import('./icons/IconNumber40Small.ts'),
  "number-41-small": () => import('./icons/IconNumber41Small.ts'),
  "number-42-small": () => import('./icons/IconNumber42Small.ts'),
  "number-43-small": () => import('./icons/IconNumber43Small.ts'),
  "number-44-small": () => import('./icons/IconNumber44Small.ts'),
  "number-45-small": () => import('./icons/IconNumber45Small.ts'),
  "number-46-small": () => import('./icons/IconNumber46Small.ts'),
  "number-47-small": () => import('./icons/IconNumber47Small.ts'),
  "number-48-small": () => import('./icons/IconNumber48Small.ts'),
  "number-49-small": () => import('./icons/IconNumber49Small.ts'),
  "number-5-small": () => import('./icons/IconNumber5Small.ts'),
  "number-5": () => import('./icons/IconNumber5.ts'),
  "number-50-small": () => import('./icons/IconNumber50Small.ts'),
  "number-51-small": () => import('./icons/IconNumber51Small.ts'),
  "number-52-small": () => import('./icons/IconNumber52Small.ts'),
  "number-53-small": () => import('./icons/IconNumber53Small.ts'),
  "number-54-small": () => import('./icons/IconNumber54Small.ts'),
  "number-55-small": () => import('./icons/IconNumber55Small.ts'),
  "number-56-small": () => import('./icons/IconNumber56Small.ts'),
  "number-57-small": () => import('./icons/IconNumber57Small.ts'),
  "number-58-small": () => import('./icons/IconNumber58Small.ts'),
  "number-59-small": () => import('./icons/IconNumber59Small.ts'),
  "number-6-small": () => import('./icons/IconNumber6Small.ts'),
  "number-6": () => import('./icons/IconNumber6.ts'),
  "number-60-small": () => import('./icons/IconNumber60Small.ts'),
  "number-61-small": () => import('./icons/IconNumber61Small.ts'),
  "number-62-small": () => import('./icons/IconNumber62Small.ts'),
  "number-63-small": () => import('./icons/IconNumber63Small.ts'),
  "number-64-small": () => import('./icons/IconNumber64Small.ts'),
  "number-65-small": () => import('./icons/IconNumber65Small.ts'),
  "number-66-small": () => import('./icons/IconNumber66Small.ts'),
  "number-67-small": () => import('./icons/IconNumber67Small.ts'),
  "number-68-small": () => import('./icons/IconNumber68Small.ts'),
  "number-69-small": () => import('./icons/IconNumber69Small.ts'),
  "number-7-small": () => import('./icons/IconNumber7Small.ts'),
  "number-7": () => import('./icons/IconNumber7.ts'),
  "number-70-small": () => import('./icons/IconNumber70Small.ts'),
  "number-71-small": () => import('./icons/IconNumber71Small.ts'),
  "number-72-small": () => import('./icons/IconNumber72Small.ts'),
  "number-73-small": () => import('./icons/IconNumber73Small.ts'),
  "number-74-small": () => import('./icons/IconNumber74Small.ts'),
  "number-75-small": () => import('./icons/IconNumber75Small.ts'),
  "number-76-small": () => import('./icons/IconNumber76Small.ts'),
  "number-77-small": () => import('./icons/IconNumber77Small.ts'),
  "number-78-small": () => import('./icons/IconNumber78Small.ts'),
  "number-79-small": () => import('./icons/IconNumber79Small.ts'),
  "number-8-small": () => import('./icons/IconNumber8Small.ts'),
  "number-8": () => import('./icons/IconNumber8.ts'),
  "number-80-small": () => import('./icons/IconNumber80Small.ts'),
  "number-81-small": () => import('./icons/IconNumber81Small.ts'),
  "number-82-small": () => import('./icons/IconNumber82Small.ts'),
  "number-83-small": () => import('./icons/IconNumber83Small.ts'),
  "number-84-small": () => import('./icons/IconNumber84Small.ts'),
  "number-85-small": () => import('./icons/IconNumber85Small.ts'),
  "number-86-small": () => import('./icons/IconNumber86Small.ts'),
  "number-87-small": () => import('./icons/IconNumber87Small.ts'),
  "number-88-small": () => import('./icons/IconNumber88Small.ts'),
  "number-89-small": () => import('./icons/IconNumber89Small.ts'),
  "number-9-small": () => import('./icons/IconNumber9Small.ts'),
  "number-9": () => import('./icons/IconNumber9.ts'),
  "number-90-small": () => import('./icons/IconNumber90Small.ts'),
  "number-91-small": () => import('./icons/IconNumber91Small.ts'),
  "number-92-small": () => import('./icons/IconNumber92Small.ts'),
  "number-93-small": () => import('./icons/IconNumber93Small.ts'),
  "number-94-small": () => import('./icons/IconNumber94Small.ts'),
  "number-95-small": () => import('./icons/IconNumber95Small.ts'),
  "number-96-small": () => import('./icons/IconNumber96Small.ts'),
  "number-97-small": () => import('./icons/IconNumber97Small.ts'),
  "number-98-small": () => import('./icons/IconNumber98Small.ts'),
  "number-99-small": () => import('./icons/IconNumber99Small.ts'),
  "number": () => import('./icons/IconNumber.ts'),
  "numbers": () => import('./icons/IconNumbers.ts'),
  "nurse": () => import('./icons/IconNurse.ts'),
  "nut": () => import('./icons/IconNut.ts'),
  "object-scan": () => import('./icons/IconObjectScan.ts'),
  "octagon-minus-2": () => import('./icons/IconOctagonMinus2.ts'),
  "octagon-minus": () => import('./icons/IconOctagonMinus.ts'),
  "octagon-off": () => import('./icons/IconOctagonOff.ts'),
  "octagon-plus-2": () => import('./icons/IconOctagonPlus2.ts'),
  "octagon-plus": () => import('./icons/IconOctagonPlus.ts'),
  "octagon": () => import('./icons/IconOctagon.ts'),
  "octahedron-off": () => import('./icons/IconOctahedronOff.ts'),
  "octahedron-plus": () => import('./icons/IconOctahedronPlus.ts'),
  "octahedron": () => import('./icons/IconOctahedron.ts'),
  "old": () => import('./icons/IconOld.ts'),
  "olympics-off": () => import('./icons/IconOlympicsOff.ts'),
  "olympics": () => import('./icons/IconOlympics.ts'),
  "om": () => import('./icons/IconOm.ts'),
  "omega": () => import('./icons/IconOmega.ts'),
  "option": () => import('./icons/IconOption.ts'),
  "outbound": () => import('./icons/IconOutbound.ts'),
  "outlet": () => import('./icons/IconOutlet.ts'),
  "oval-vertical": () => import('./icons/IconOvalVertical.ts'),
  "oval": () => import('./icons/IconOval.ts'),
  "overline": () => import('./icons/IconOverline.ts'),
  "package-export": () => import('./icons/IconPackageExport.ts'),
  "package-import": () => import('./icons/IconPackageImport.ts'),
  "package-off": () => import('./icons/IconPackageOff.ts'),
  "package": () => import('./icons/IconPackage.ts'),
  "packages": () => import('./icons/IconPackages.ts'),
  "pacman": () => import('./icons/IconPacman.ts'),
  "page-break": () => import('./icons/IconPageBreak.ts'),
  "paint-off": () => import('./icons/IconPaintOff.ts'),
  "paint": () => import('./icons/IconPaint.ts'),
  "palette-off": () => import('./icons/IconPaletteOff.ts'),
  "palette": () => import('./icons/IconPalette.ts'),
  "panorama-horizontal-off": () => import('./icons/IconPanoramaHorizontalOff.ts'),
  "panorama-horizontal": () => import('./icons/IconPanoramaHorizontal.ts'),
  "panorama-vertical-off": () => import('./icons/IconPanoramaVerticalOff.ts'),
  "panorama-vertical": () => import('./icons/IconPanoramaVertical.ts'),
  "paper-bag-off": () => import('./icons/IconPaperBagOff.ts'),
  "paper-bag": () => import('./icons/IconPaperBag.ts'),
  "paperclip": () => import('./icons/IconPaperclip.ts'),
  "parachute-off": () => import('./icons/IconParachuteOff.ts'),
  "parachute": () => import('./icons/IconParachute.ts'),
  "parentheses-off": () => import('./icons/IconParenthesesOff.ts'),
  "parentheses": () => import('./icons/IconParentheses.ts'),
  "parking-circle": () => import('./icons/IconParkingCircle.ts'),
  "parking-off": () => import('./icons/IconParkingOff.ts'),
  "parking": () => import('./icons/IconParking.ts'),
  "password-fingerprint": () => import('./icons/IconPasswordFingerprint.ts'),
  "password-mobile-phone": () => import('./icons/IconPasswordMobilePhone.ts'),
  "password-user": () => import('./icons/IconPasswordUser.ts'),
  "password": () => import('./icons/IconPassword.ts'),
  "paw-off": () => import('./icons/IconPawOff.ts'),
  "paw": () => import('./icons/IconPaw.ts'),
  "paywall": () => import('./icons/IconPaywall.ts'),
  "pdf": () => import('./icons/IconPdf.ts'),
  "peace": () => import('./icons/IconPeace.ts'),
  "pencil-bolt": () => import('./icons/IconPencilBolt.ts'),
  "pencil-cancel": () => import('./icons/IconPencilCancel.ts'),
  "pencil-check": () => import('./icons/IconPencilCheck.ts'),
  "pencil-code": () => import('./icons/IconPencilCode.ts'),
  "pencil-cog": () => import('./icons/IconPencilCog.ts'),
  "pencil-discount": () => import('./icons/IconPencilDiscount.ts'),
  "pencil-dollar": () => import('./icons/IconPencilDollar.ts'),
  "pencil-down": () => import('./icons/IconPencilDown.ts'),
  "pencil-exclamation": () => import('./icons/IconPencilExclamation.ts'),
  "pencil-heart": () => import('./icons/IconPencilHeart.ts'),
  "pencil-minus": () => import('./icons/IconPencilMinus.ts'),
  "pencil-off": () => import('./icons/IconPencilOff.ts'),
  "pencil-pause": () => import('./icons/IconPencilPause.ts'),
  "pencil-pin": () => import('./icons/IconPencilPin.ts'),
  "pencil-plus": () => import('./icons/IconPencilPlus.ts'),
  "pencil-question": () => import('./icons/IconPencilQuestion.ts'),
  "pencil-search": () => import('./icons/IconPencilSearch.ts'),
  "pencil-share": () => import('./icons/IconPencilShare.ts'),
  "pencil-star": () => import('./icons/IconPencilStar.ts'),
  "pencil-up": () => import('./icons/IconPencilUp.ts'),
  "pencil-x": () => import('./icons/IconPencilX.ts'),
  "pencil": () => import('./icons/IconPencil.ts'),
  "pennant-2": () => import('./icons/IconPennant2.ts'),
  "pennant-off": () => import('./icons/IconPennantOff.ts'),
  "pennant": () => import('./icons/IconPennant.ts'),
  "pentagon-minus": () => import('./icons/IconPentagonMinus.ts'),
  "pentagon-number-0": () => import('./icons/IconPentagonNumber0.ts'),
  "pentagon-number-1": () => import('./icons/IconPentagonNumber1.ts'),
  "pentagon-number-2": () => import('./icons/IconPentagonNumber2.ts'),
  "pentagon-number-3": () => import('./icons/IconPentagonNumber3.ts'),
  "pentagon-number-4": () => import('./icons/IconPentagonNumber4.ts'),
  "pentagon-number-5": () => import('./icons/IconPentagonNumber5.ts'),
  "pentagon-number-6": () => import('./icons/IconPentagonNumber6.ts'),
  "pentagon-number-7": () => import('./icons/IconPentagonNumber7.ts'),
  "pentagon-number-8": () => import('./icons/IconPentagonNumber8.ts'),
  "pentagon-number-9": () => import('./icons/IconPentagonNumber9.ts'),
  "pentagon-off": () => import('./icons/IconPentagonOff.ts'),
  "pentagon-plus": () => import('./icons/IconPentagonPlus.ts'),
  "pentagon-x": () => import('./icons/IconPentagonX.ts'),
  "pentagon": () => import('./icons/IconPentagon.ts'),
  "pentagram": () => import('./icons/IconPentagram.ts'),
  "pepper-off": () => import('./icons/IconPepperOff.ts'),
  "pepper": () => import('./icons/IconPepper.ts'),
  "percentage-0": () => import('./icons/IconPercentage0.ts'),
  "percentage-10": () => import('./icons/IconPercentage10.ts'),
  "percentage-100": () => import('./icons/IconPercentage100.ts'),
  "percentage-20": () => import('./icons/IconPercentage20.ts'),
  "percentage-25": () => import('./icons/IconPercentage25.ts'),
  "percentage-30": () => import('./icons/IconPercentage30.ts'),
  "percentage-33": () => import('./icons/IconPercentage33.ts'),
  "percentage-40": () => import('./icons/IconPercentage40.ts'),
  "percentage-50": () => import('./icons/IconPercentage50.ts'),
  "percentage-60": () => import('./icons/IconPercentage60.ts'),
  "percentage-66": () => import('./icons/IconPercentage66.ts'),
  "percentage-70": () => import('./icons/IconPercentage70.ts'),
  "percentage-75": () => import('./icons/IconPercentage75.ts'),
  "percentage-80": () => import('./icons/IconPercentage80.ts'),
  "percentage-90": () => import('./icons/IconPercentage90.ts'),
  "percentage": () => import('./icons/IconPercentage.ts'),
  "perfume": () => import('./icons/IconPerfume.ts'),
  "perspective-off": () => import('./icons/IconPerspectiveOff.ts'),
  "perspective": () => import('./icons/IconPerspective.ts'),
  "phone-call": () => import('./icons/IconPhoneCall.ts'),
  "phone-calling": () => import('./icons/IconPhoneCalling.ts'),
  "phone-check": () => import('./icons/IconPhoneCheck.ts'),
  "phone-done": () => import('./icons/IconPhoneDone.ts'),
  "phone-end": () => import('./icons/IconPhoneEnd.ts'),
  "phone-incoming": () => import('./icons/IconPhoneIncoming.ts'),
  "phone-off": () => import('./icons/IconPhoneOff.ts'),
  "phone-outgoing": () => import('./icons/IconPhoneOutgoing.ts'),
  "phone-pause": () => import('./icons/IconPhonePause.ts'),
  "phone-plus": () => import('./icons/IconPhonePlus.ts'),
  "phone-ringing": () => import('./icons/IconPhoneRinging.ts'),
  "phone-spark": () => import('./icons/IconPhoneSpark.ts'),
  "phone-x": () => import('./icons/IconPhoneX.ts'),
  "phone": () => import('./icons/IconPhone.ts'),
  "photo-ai": () => import('./icons/IconPhotoAi.ts'),
  "photo-bitcoin": () => import('./icons/IconPhotoBitcoin.ts'),
  "photo-bolt": () => import('./icons/IconPhotoBolt.ts'),
  "photo-cancel": () => import('./icons/IconPhotoCancel.ts'),
  "photo-check": () => import('./icons/IconPhotoCheck.ts'),
  "photo-circle-minus": () => import('./icons/IconPhotoCircleMinus.ts'),
  "photo-circle-plus": () => import('./icons/IconPhotoCirclePlus.ts'),
  "photo-circle": () => import('./icons/IconPhotoCircle.ts'),
  "photo-code": () => import('./icons/IconPhotoCode.ts'),
  "photo-cog": () => import('./icons/IconPhotoCog.ts'),
  "photo-dollar": () => import('./icons/IconPhotoDollar.ts'),
  "photo-down": () => import('./icons/IconPhotoDown.ts'),
  "photo-edit": () => import('./icons/IconPhotoEdit.ts'),
  "photo-exclamation": () => import('./icons/IconPhotoExclamation.ts'),
  "photo-heart": () => import('./icons/IconPhotoHeart.ts'),
  "photo-hexagon": () => import('./icons/IconPhotoHexagon.ts'),
  "photo-minus": () => import('./icons/IconPhotoMinus.ts'),
  "photo-off": () => import('./icons/IconPhotoOff.ts'),
  "photo-pause": () => import('./icons/IconPhotoPause.ts'),
  "photo-pentagon": () => import('./icons/IconPhotoPentagon.ts'),
  "photo-pin": () => import('./icons/IconPhotoPin.ts'),
  "photo-plus": () => import('./icons/IconPhotoPlus.ts'),
  "photo-question": () => import('./icons/IconPhotoQuestion.ts'),
  "photo-scan": () => import('./icons/IconPhotoScan.ts'),
  "photo-search": () => import('./icons/IconPhotoSearch.ts'),
  "photo-sensor-2": () => import('./icons/IconPhotoSensor2.ts'),
  "photo-sensor-3": () => import('./icons/IconPhotoSensor3.ts'),
  "photo-sensor": () => import('./icons/IconPhotoSensor.ts'),
  "photo-share": () => import('./icons/IconPhotoShare.ts'),
  "photo-shield": () => import('./icons/IconPhotoShield.ts'),
  "photo-spark": () => import('./icons/IconPhotoSpark.ts'),
  "photo-square-rounded": () => import('./icons/IconPhotoSquareRounded.ts'),
  "photo-star": () => import('./icons/IconPhotoStar.ts'),
  "photo-up": () => import('./icons/IconPhotoUp.ts'),
  "photo-video": () => import('./icons/IconPhotoVideo.ts'),
  "photo-x": () => import('./icons/IconPhotoX.ts'),
  "photo": () => import('./icons/IconPhoto.ts'),
  "physotherapist": () => import('./icons/IconPhysotherapist.ts'),
  "piano": () => import('./icons/IconPiano.ts'),
  "pick": () => import('./icons/IconPick.ts'),
  "picnic-table": () => import('./icons/IconPicnicTable.ts'),
  "picture-in-picture-off": () => import('./icons/IconPictureInPictureOff.ts'),
  "picture-in-picture-on": () => import('./icons/IconPictureInPictureOn.ts'),
  "picture-in-picture-top": () => import('./icons/IconPictureInPictureTop.ts'),
  "picture-in-picture": () => import('./icons/IconPictureInPicture.ts'),
  "pig-money": () => import('./icons/IconPigMoney.ts'),
  "pig-off": () => import('./icons/IconPigOff.ts'),
  "pig": () => import('./icons/IconPig.ts'),
  "pilcrow-left": () => import('./icons/IconPilcrowLeft.ts'),
  "pilcrow-right": () => import('./icons/IconPilcrowRight.ts'),
  "pilcrow": () => import('./icons/IconPilcrow.ts'),
  "pill-off": () => import('./icons/IconPillOff.ts'),
  "pill": () => import('./icons/IconPill.ts'),
  "pills": () => import('./icons/IconPills.ts'),
  "pin-end": () => import('./icons/IconPinEnd.ts'),
  "pin-invoke": () => import('./icons/IconPinInvoke.ts'),
  "pin": () => import('./icons/IconPin.ts'),
  "ping-pong": () => import('./icons/IconPingPong.ts'),
  "pinned-off": () => import('./icons/IconPinnedOff.ts'),
  "pinned": () => import('./icons/IconPinned.ts'),
  "pizza-off": () => import('./icons/IconPizzaOff.ts'),
  "pizza": () => import('./icons/IconPizza.ts'),
  "placeholder": () => import('./icons/IconPlaceholder.ts'),
  "plane-arrival": () => import('./icons/IconPlaneArrival.ts'),
  "plane-departure": () => import('./icons/IconPlaneDeparture.ts'),
  "plane-inflight": () => import('./icons/IconPlaneInflight.ts'),
  "plane-off": () => import('./icons/IconPlaneOff.ts'),
  "plane-tilt": () => import('./icons/IconPlaneTilt.ts'),
  "plane": () => import('./icons/IconPlane.ts'),
  "planet-off": () => import('./icons/IconPlanetOff.ts'),
  "planet": () => import('./icons/IconPlanet.ts'),
  "plant-2-off": () => import('./icons/IconPlant2Off.ts'),
  "plant-2": () => import('./icons/IconPlant2.ts'),
  "plant-off": () => import('./icons/IconPlantOff.ts'),
  "plant": () => import('./icons/IconPlant.ts'),
  "play-basketball": () => import('./icons/IconPlayBasketball.ts'),
  "play-card-1": () => import('./icons/IconPlayCard1.ts'),
  "play-card-10": () => import('./icons/IconPlayCard10.ts'),
  "play-card-2": () => import('./icons/IconPlayCard2.ts'),
  "play-card-3": () => import('./icons/IconPlayCard3.ts'),
  "play-card-4": () => import('./icons/IconPlayCard4.ts'),
  "play-card-5": () => import('./icons/IconPlayCard5.ts'),
  "play-card-6": () => import('./icons/IconPlayCard6.ts'),
  "play-card-7": () => import('./icons/IconPlayCard7.ts'),
  "play-card-8": () => import('./icons/IconPlayCard8.ts'),
  "play-card-9": () => import('./icons/IconPlayCard9.ts'),
  "play-card-a": () => import('./icons/IconPlayCardA.ts'),
  "play-card-j": () => import('./icons/IconPlayCardJ.ts'),
  "play-card-k": () => import('./icons/IconPlayCardK.ts'),
  "play-card-off": () => import('./icons/IconPlayCardOff.ts'),
  "play-card-q": () => import('./icons/IconPlayCardQ.ts'),
  "play-card-star": () => import('./icons/IconPlayCardStar.ts'),
  "play-card": () => import('./icons/IconPlayCard.ts'),
  "play-football": () => import('./icons/IconPlayFootball.ts'),
  "play-handball": () => import('./icons/IconPlayHandball.ts'),
  "play-volleyball": () => import('./icons/IconPlayVolleyball.ts'),
  "player-eject": () => import('./icons/IconPlayerEject.ts'),
  "player-pause": () => import('./icons/IconPlayerPause.ts'),
  "player-play": () => import('./icons/IconPlayerPlay.ts'),
  "player-record": () => import('./icons/IconPlayerRecord.ts'),
  "player-skip-back": () => import('./icons/IconPlayerSkipBack.ts'),
  "player-skip-forward": () => import('./icons/IconPlayerSkipForward.ts'),
  "player-stop": () => import('./icons/IconPlayerStop.ts'),
  "player-track-next": () => import('./icons/IconPlayerTrackNext.ts'),
  "player-track-prev": () => import('./icons/IconPlayerTrackPrev.ts'),
  "playlist-add": () => import('./icons/IconPlaylistAdd.ts'),
  "playlist-off": () => import('./icons/IconPlaylistOff.ts'),
  "playlist-x": () => import('./icons/IconPlaylistX.ts'),
  "playlist": () => import('./icons/IconPlaylist.ts'),
  "playstation-circle": () => import('./icons/IconPlaystationCircle.ts'),
  "playstation-square": () => import('./icons/IconPlaystationSquare.ts'),
  "playstation-triangle": () => import('./icons/IconPlaystationTriangle.ts'),
  "playstation-x": () => import('./icons/IconPlaystationX.ts'),
  "plug-connected-x": () => import('./icons/IconPlugConnectedX.ts'),
  "plug-connected": () => import('./icons/IconPlugConnected.ts'),
  "plug-off": () => import('./icons/IconPlugOff.ts'),
  "plug-x": () => import('./icons/IconPlugX.ts'),
  "plug": () => import('./icons/IconPlug.ts'),
  "plus-equal": () => import('./icons/IconPlusEqual.ts'),
  "plus-minus": () => import('./icons/IconPlusMinus.ts'),
  "plus": () => import('./icons/IconPlus.ts'),
  "png": () => import('./icons/IconPng.ts'),
  "podium-off": () => import('./icons/IconPodiumOff.ts'),
  "podium": () => import('./icons/IconPodium.ts'),
  "point-off": () => import('./icons/IconPointOff.ts'),
  "point": () => import('./icons/IconPoint.ts'),
  "pointer-bolt": () => import('./icons/IconPointerBolt.ts'),
  "pointer-cancel": () => import('./icons/IconPointerCancel.ts'),
  "pointer-check": () => import('./icons/IconPointerCheck.ts'),
  "pointer-code": () => import('./icons/IconPointerCode.ts'),
  "pointer-cog": () => import('./icons/IconPointerCog.ts'),
  "pointer-dollar": () => import('./icons/IconPointerDollar.ts'),
  "pointer-down": () => import('./icons/IconPointerDown.ts'),
  "pointer-exclamation": () => import('./icons/IconPointerExclamation.ts'),
  "pointer-heart": () => import('./icons/IconPointerHeart.ts'),
  "pointer-minus": () => import('./icons/IconPointerMinus.ts'),
  "pointer-off": () => import('./icons/IconPointerOff.ts'),
  "pointer-pause": () => import('./icons/IconPointerPause.ts'),
  "pointer-pin": () => import('./icons/IconPointerPin.ts'),
  "pointer-plus": () => import('./icons/IconPointerPlus.ts'),
  "pointer-question": () => import('./icons/IconPointerQuestion.ts'),
  "pointer-search": () => import('./icons/IconPointerSearch.ts'),
  "pointer-share": () => import('./icons/IconPointerShare.ts'),
  "pointer-star": () => import('./icons/IconPointerStar.ts'),
  "pointer-up": () => import('./icons/IconPointerUp.ts'),
  "pointer-x": () => import('./icons/IconPointerX.ts'),
  "pointer": () => import('./icons/IconPointer.ts'),
  "pokeball-off": () => import('./icons/IconPokeballOff.ts'),
  "pokeball": () => import('./icons/IconPokeball.ts'),
  "poker-chip": () => import('./icons/IconPokerChip.ts'),
  "polaroid": () => import('./icons/IconPolaroid.ts'),
  "polygon-off": () => import('./icons/IconPolygonOff.ts'),
  "polygon": () => import('./icons/IconPolygon.ts'),
  "poo": () => import('./icons/IconPoo.ts'),
  "pool-off": () => import('./icons/IconPoolOff.ts'),
  "pool": () => import('./icons/IconPool.ts'),
  "power": () => import('./icons/IconPower.ts'),
  "pray": () => import('./icons/IconPray.ts'),
  "premium-rights": () => import('./icons/IconPremiumRights.ts'),
  "prescription": () => import('./icons/IconPrescription.ts'),
  "presentation-analytics": () => import('./icons/IconPresentationAnalytics.ts'),
  "presentation-off": () => import('./icons/IconPresentationOff.ts'),
  "presentation": () => import('./icons/IconPresentation.ts'),
  "printer-off": () => import('./icons/IconPrinterOff.ts'),
  "printer": () => import('./icons/IconPrinter.ts'),
  "prism-light": () => import('./icons/IconPrismLight.ts'),
  "prism-off": () => import('./icons/IconPrismOff.ts'),
  "prism-plus": () => import('./icons/IconPrismPlus.ts'),
  "prism": () => import('./icons/IconPrism.ts'),
  "prison": () => import('./icons/IconPrison.ts'),
  "progress-alert": () => import('./icons/IconProgressAlert.ts'),
  "progress-bolt": () => import('./icons/IconProgressBolt.ts'),
  "progress-check": () => import('./icons/IconProgressCheck.ts'),
  "progress-down": () => import('./icons/IconProgressDown.ts'),
  "progress-help": () => import('./icons/IconProgressHelp.ts'),
  "progress-x": () => import('./icons/IconProgressX.ts'),
  "progress": () => import('./icons/IconProgress.ts'),
  "prompt": () => import('./icons/IconPrompt.ts'),
  "prong": () => import('./icons/IconProng.ts'),
  "propeller-off": () => import('./icons/IconPropellerOff.ts'),
  "propeller": () => import('./icons/IconPropeller.ts'),
  "protocol": () => import('./icons/IconProtocol.ts'),
  "pumpkin-scary": () => import('./icons/IconPumpkinScary.ts'),
  "puzzle-2": () => import('./icons/IconPuzzle2.ts'),
  "puzzle-off": () => import('./icons/IconPuzzleOff.ts'),
  "puzzle": () => import('./icons/IconPuzzle.ts'),
  "pyramid-off": () => import('./icons/IconPyramidOff.ts'),
  "pyramid-plus": () => import('./icons/IconPyramidPlus.ts'),
  "pyramid": () => import('./icons/IconPyramid.ts'),
  "qrcode-off": () => import('./icons/IconQrcodeOff.ts'),
  "qrcode": () => import('./icons/IconQrcode.ts'),
  "question-mark": () => import('./icons/IconQuestionMark.ts'),
  "quote-off": () => import('./icons/IconQuoteOff.ts'),
  "quote": () => import('./icons/IconQuote.ts'),
  "quotes": () => import('./icons/IconQuotes.ts'),
  "radar-2": () => import('./icons/IconRadar2.ts'),
  "radar-off": () => import('./icons/IconRadarOff.ts'),
  "radar": () => import('./icons/IconRadar.ts'),
  "radio-off": () => import('./icons/IconRadioOff.ts'),
  "radio": () => import('./icons/IconRadio.ts'),
  "radioactive-off": () => import('./icons/IconRadioactiveOff.ts'),
  "radioactive": () => import('./icons/IconRadioactive.ts'),
  "radius-bottom-left": () => import('./icons/IconRadiusBottomLeft.ts'),
  "radius-bottom-right": () => import('./icons/IconRadiusBottomRight.ts'),
  "radius-top-left": () => import('./icons/IconRadiusTopLeft.ts'),
  "radius-top-right": () => import('./icons/IconRadiusTopRight.ts'),
  "rainbow-off": () => import('./icons/IconRainbowOff.ts'),
  "rainbow": () => import('./icons/IconRainbow.ts'),
  "rating-12-plus": () => import('./icons/IconRating12Plus.ts'),
  "rating-14-plus": () => import('./icons/IconRating14Plus.ts'),
  "rating-16-plus": () => import('./icons/IconRating16Plus.ts'),
  "rating-18-plus": () => import('./icons/IconRating18Plus.ts'),
  "rating-21-plus": () => import('./icons/IconRating21Plus.ts'),
  "razor-electric": () => import('./icons/IconRazorElectric.ts'),
  "razor": () => import('./icons/IconRazor.ts'),
  "receipt-2": () => import('./icons/IconReceipt2.ts'),
  "receipt-bitcoin": () => import('./icons/IconReceiptBitcoin.ts'),
  "receipt-dollar": () => import('./icons/IconReceiptDollar.ts'),
  "receipt-euro": () => import('./icons/IconReceiptEuro.ts'),
  "receipt-off": () => import('./icons/IconReceiptOff.ts'),
  "receipt-pound": () => import('./icons/IconReceiptPound.ts'),
  "receipt-refund": () => import('./icons/IconReceiptRefund.ts'),
  "receipt-rupee": () => import('./icons/IconReceiptRupee.ts'),
  "receipt-tax": () => import('./icons/IconReceiptTax.ts'),
  "receipt-yen": () => import('./icons/IconReceiptYen.ts'),
  "receipt-yuan": () => import('./icons/IconReceiptYuan.ts'),
  "receipt": () => import('./icons/IconReceipt.ts'),
  "recharging": () => import('./icons/IconRecharging.ts'),
  "record-mail-off": () => import('./icons/IconRecordMailOff.ts'),
  "record-mail": () => import('./icons/IconRecordMail.ts'),
  "rectangle-rounded-bottom": () => import('./icons/IconRectangleRoundedBottom.ts'),
  "rectangle-rounded-top": () => import('./icons/IconRectangleRoundedTop.ts'),
  "rectangle-vertical": () => import('./icons/IconRectangleVertical.ts'),
  "rectangle": () => import('./icons/IconRectangle.ts'),
  "rectangular-prism-off": () => import('./icons/IconRectangularPrismOff.ts'),
  "rectangular-prism-plus": () => import('./icons/IconRectangularPrismPlus.ts'),
  "rectangular-prism": () => import('./icons/IconRectangularPrism.ts'),
  "recycle-off": () => import('./icons/IconRecycleOff.ts'),
  "recycle": () => import('./icons/IconRecycle.ts'),
  "refresh-alert": () => import('./icons/IconRefreshAlert.ts'),
  "refresh-dot": () => import('./icons/IconRefreshDot.ts'),
  "refresh-off": () => import('./icons/IconRefreshOff.ts'),
  "refresh": () => import('./icons/IconRefresh.ts'),
  "regex-off": () => import('./icons/IconRegexOff.ts'),
  "regex": () => import('./icons/IconRegex.ts'),
  "registered": () => import('./icons/IconRegistered.ts'),
  "relation-many-to-many": () => import('./icons/IconRelationManyToMany.ts'),
  "relation-one-to-many": () => import('./icons/IconRelationOneToMany.ts'),
  "relation-one-to-one": () => import('./icons/IconRelationOneToOne.ts'),
  "reload": () => import('./icons/IconReload.ts'),
  "reorder": () => import('./icons/IconReorder.ts'),
  "repeat-off": () => import('./icons/IconRepeatOff.ts'),
  "repeat-once": () => import('./icons/IconRepeatOnce.ts'),
  "repeat": () => import('./icons/IconRepeat.ts'),
  "replace-off": () => import('./icons/IconReplaceOff.ts'),
  "replace-user": () => import('./icons/IconReplaceUser.ts'),
  "replace": () => import('./icons/IconReplace.ts'),
  "report-analytics": () => import('./icons/IconReportAnalytics.ts'),
  "report-medical": () => import('./icons/IconReportMedical.ts'),
  "report-money": () => import('./icons/IconReportMoney.ts'),
  "report-off": () => import('./icons/IconReportOff.ts'),
  "report-search": () => import('./icons/IconReportSearch.ts'),
  "report": () => import('./icons/IconReport.ts'),
  "reserved-line": () => import('./icons/IconReservedLine.ts'),
  "resize": () => import('./icons/IconResize.ts'),
  "restore": () => import('./icons/IconRestore.ts'),
  "rewind-backward-10": () => import('./icons/IconRewindBackward10.ts'),
  "rewind-backward-15": () => import('./icons/IconRewindBackward15.ts'),
  "rewind-backward-20": () => import('./icons/IconRewindBackward20.ts'),
  "rewind-backward-30": () => import('./icons/IconRewindBackward30.ts'),
  "rewind-backward-40": () => import('./icons/IconRewindBackward40.ts'),
  "rewind-backward-5": () => import('./icons/IconRewindBackward5.ts'),
  "rewind-backward-50": () => import('./icons/IconRewindBackward50.ts'),
  "rewind-backward-60": () => import('./icons/IconRewindBackward60.ts'),
  "rewind-forward-10": () => import('./icons/IconRewindForward10.ts'),
  "rewind-forward-15": () => import('./icons/IconRewindForward15.ts'),
  "rewind-forward-20": () => import('./icons/IconRewindForward20.ts'),
  "rewind-forward-30": () => import('./icons/IconRewindForward30.ts'),
  "rewind-forward-40": () => import('./icons/IconRewindForward40.ts'),
  "rewind-forward-5": () => import('./icons/IconRewindForward5.ts'),
  "rewind-forward-50": () => import('./icons/IconRewindForward50.ts'),
  "rewind-forward-60": () => import('./icons/IconRewindForward60.ts'),
  "ribbon-health": () => import('./icons/IconRibbonHealth.ts'),
  "rings": () => import('./icons/IconRings.ts'),
  "ripple-down": () => import('./icons/IconRippleDown.ts'),
  "ripple-off": () => import('./icons/IconRippleOff.ts'),
  "ripple-up": () => import('./icons/IconRippleUp.ts'),
  "ripple": () => import('./icons/IconRipple.ts'),
  "road-off": () => import('./icons/IconRoadOff.ts'),
  "road-sign": () => import('./icons/IconRoadSign.ts'),
  "road": () => import('./icons/IconRoad.ts'),
  "robot-face": () => import('./icons/IconRobotFace.ts'),
  "robot-off": () => import('./icons/IconRobotOff.ts'),
  "robot": () => import('./icons/IconRobot.ts'),
  "rocket-off": () => import('./icons/IconRocketOff.ts'),
  "rocket": () => import('./icons/IconRocket.ts'),
  "roller-skating": () => import('./icons/IconRollerSkating.ts'),
  "rollercoaster-off": () => import('./icons/IconRollercoasterOff.ts'),
  "rollercoaster": () => import('./icons/IconRollercoaster.ts'),
  "rosette-asterisk": () => import('./icons/IconRosetteAsterisk.ts'),
  "rosette-discount-check-off": () => import('./icons/IconRosetteDiscountCheckOff.ts'),
  "rosette-discount-check": () => import('./icons/IconRosetteDiscountCheck.ts'),
  "rosette-discount-off": () => import('./icons/IconRosetteDiscountOff.ts'),
  "rosette-discount": () => import('./icons/IconRosetteDiscount.ts'),
  "rosette-number-0": () => import('./icons/IconRosetteNumber0.ts'),
  "rosette-number-1": () => import('./icons/IconRosetteNumber1.ts'),
  "rosette-number-2": () => import('./icons/IconRosetteNumber2.ts'),
  "rosette-number-3": () => import('./icons/IconRosetteNumber3.ts'),
  "rosette-number-4": () => import('./icons/IconRosetteNumber4.ts'),
  "rosette-number-5": () => import('./icons/IconRosetteNumber5.ts'),
  "rosette-number-6": () => import('./icons/IconRosetteNumber6.ts'),
  "rosette-number-7": () => import('./icons/IconRosetteNumber7.ts'),
  "rosette-number-8": () => import('./icons/IconRosetteNumber8.ts'),
  "rosette-number-9": () => import('./icons/IconRosetteNumber9.ts'),
  "rosette": () => import('./icons/IconRosette.ts'),
  "rotate-2": () => import('./icons/IconRotate2.ts'),
  "rotate-360": () => import('./icons/IconRotate360.ts'),
  "rotate-3d": () => import('./icons/IconRotate3d.ts'),
  "rotate-clockwise-2": () => import('./icons/IconRotateClockwise2.ts'),
  "rotate-clockwise": () => import('./icons/IconRotateClockwise.ts'),
  "rotate-dot": () => import('./icons/IconRotateDot.ts'),
  "rotate-rectangle": () => import('./icons/IconRotateRectangle.ts'),
  "rotate": () => import('./icons/IconRotate.ts'),
  "route-2": () => import('./icons/IconRoute2.ts'),
  "route-alt-left": () => import('./icons/IconRouteAltLeft.ts'),
  "route-alt-right": () => import('./icons/IconRouteAltRight.ts'),
  "route-off": () => import('./icons/IconRouteOff.ts'),
  "route-scan": () => import('./icons/IconRouteScan.ts'),
  "route-square-2": () => import('./icons/IconRouteSquare2.ts'),
  "route-square": () => import('./icons/IconRouteSquare.ts'),
  "route-x-2": () => import('./icons/IconRouteX2.ts'),
  "route-x": () => import('./icons/IconRouteX.ts'),
  "route": () => import('./icons/IconRoute.ts'),
  "router-off": () => import('./icons/IconRouterOff.ts'),
  "router": () => import('./icons/IconRouter.ts'),
  "row-insert-bottom": () => import('./icons/IconRowInsertBottom.ts'),
  "row-insert-top": () => import('./icons/IconRowInsertTop.ts'),
  "row-remove": () => import('./icons/IconRowRemove.ts'),
  "rss": () => import('./icons/IconRss.ts'),
  "rubber-stamp-off": () => import('./icons/IconRubberStampOff.ts'),
  "rubber-stamp": () => import('./icons/IconRubberStamp.ts'),
  "ruler-2-off": () => import('./icons/IconRuler2Off.ts'),
  "ruler-2": () => import('./icons/IconRuler2.ts'),
  "ruler-3": () => import('./icons/IconRuler3.ts'),
  "ruler-measure-2": () => import('./icons/IconRulerMeasure2.ts'),
  "ruler-measure": () => import('./icons/IconRulerMeasure.ts'),
  "ruler-off": () => import('./icons/IconRulerOff.ts'),
  "ruler": () => import('./icons/IconRuler.ts'),
  "run": () => import('./icons/IconRun.ts'),
  "rv-truck": () => import('./icons/IconRvTruck.ts'),
  "s-turn-down": () => import('./icons/IconSTurnDown.ts'),
  "s-turn-left": () => import('./icons/IconSTurnLeft.ts'),
  "s-turn-right": () => import('./icons/IconSTurnRight.ts'),
  "s-turn-up": () => import('./icons/IconSTurnUp.ts'),
  "sailboat-2": () => import('./icons/IconSailboat2.ts'),
  "sailboat-off": () => import('./icons/IconSailboatOff.ts'),
  "sailboat": () => import('./icons/IconSailboat.ts'),
  "salad": () => import('./icons/IconSalad.ts'),
  "salt": () => import('./icons/IconSalt.ts'),
  "sandbox": () => import('./icons/IconSandbox.ts'),
  "satellite-off": () => import('./icons/IconSatelliteOff.ts'),
  "satellite": () => import('./icons/IconSatellite.ts'),
  "sausage": () => import('./icons/IconSausage.ts'),
  "scale-off": () => import('./icons/IconScaleOff.ts'),
  "scale-outline-off": () => import('./icons/IconScaleOutlineOff.ts'),
  "scale-outline": () => import('./icons/IconScaleOutline.ts'),
  "scale": () => import('./icons/IconScale.ts'),
  "scan-eye": () => import('./icons/IconScanEye.ts'),
  "scan-position": () => import('./icons/IconScanPosition.ts'),
  "scan": () => import('./icons/IconScan.ts'),
  "schema-off": () => import('./icons/IconSchemaOff.ts'),
  "schema": () => import('./icons/IconSchema.ts'),
  "school-bell": () => import('./icons/IconSchoolBell.ts'),
  "school-off": () => import('./icons/IconSchoolOff.ts'),
  "school": () => import('./icons/IconSchool.ts'),
  "scissors-off": () => import('./icons/IconScissorsOff.ts'),
  "scissors": () => import('./icons/IconScissors.ts'),
  "scooter-electric": () => import('./icons/IconScooterElectric.ts'),
  "scooter": () => import('./icons/IconScooter.ts'),
  "scoreboard": () => import('./icons/IconScoreboard.ts'),
  "screen-share-off": () => import('./icons/IconScreenShareOff.ts'),
  "screen-share": () => import('./icons/IconScreenShare.ts'),
  "screenshot": () => import('./icons/IconScreenshot.ts'),
  "scribble-off": () => import('./icons/IconScribbleOff.ts'),
  "scribble": () => import('./icons/IconScribble.ts'),
  "script-minus": () => import('./icons/IconScriptMinus.ts'),
  "script-plus": () => import('./icons/IconScriptPlus.ts'),
  "script-x": () => import('./icons/IconScriptX.ts'),
  "script": () => import('./icons/IconScript.ts'),
  "scuba-diving-tank": () => import('./icons/IconScubaDivingTank.ts'),
  "scuba-diving": () => import('./icons/IconScubaDiving.ts'),
  "scuba-mask-off": () => import('./icons/IconScubaMaskOff.ts'),
  "scuba-mask": () => import('./icons/IconScubaMask.ts'),
  "sdk": () => import('./icons/IconSdk.ts'),
  "search-off": () => import('./icons/IconSearchOff.ts'),
  "search": () => import('./icons/IconSearch.ts'),
  "section-sign": () => import('./icons/IconSectionSign.ts'),
  "section": () => import('./icons/IconSection.ts'),
  "seedling-off": () => import('./icons/IconSeedlingOff.ts'),
  "seedling": () => import('./icons/IconSeedling.ts'),
  "select-all": () => import('./icons/IconSelectAll.ts'),
  "select": () => import('./icons/IconSelect.ts'),
  "selector": () => import('./icons/IconSelector.ts'),
  "send-2": () => import('./icons/IconSend2.ts'),
  "send-off": () => import('./icons/IconSendOff.ts'),
  "send": () => import('./icons/IconSend.ts'),
  "seo": () => import('./icons/IconSeo.ts'),
  "separator-horizontal": () => import('./icons/IconSeparatorHorizontal.ts'),
  "separator-vertical": () => import('./icons/IconSeparatorVertical.ts'),
  "separator": () => import('./icons/IconSeparator.ts'),
  "server-2": () => import('./icons/IconServer2.ts'),
  "server-bolt": () => import('./icons/IconServerBolt.ts'),
  "server-cog": () => import('./icons/IconServerCog.ts'),
  "server-off": () => import('./icons/IconServerOff.ts'),
  "server-spark": () => import('./icons/IconServerSpark.ts'),
  "server": () => import('./icons/IconServer.ts'),
  "servicemark": () => import('./icons/IconServicemark.ts'),
  "settings-2": () => import('./icons/IconSettings2.ts'),
  "settings-ai": () => import('./icons/IconSettingsAi.ts'),
  "settings-automation": () => import('./icons/IconSettingsAutomation.ts'),
  "settings-bolt": () => import('./icons/IconSettingsBolt.ts'),
  "settings-cancel": () => import('./icons/IconSettingsCancel.ts'),
  "settings-check": () => import('./icons/IconSettingsCheck.ts'),
  "settings-code": () => import('./icons/IconSettingsCode.ts'),
  "settings-cog": () => import('./icons/IconSettingsCog.ts'),
  "settings-dollar": () => import('./icons/IconSettingsDollar.ts'),
  "settings-down": () => import('./icons/IconSettingsDown.ts'),
  "settings-exclamation": () => import('./icons/IconSettingsExclamation.ts'),
  "settings-heart": () => import('./icons/IconSettingsHeart.ts'),
  "settings-minus": () => import('./icons/IconSettingsMinus.ts'),
  "settings-off": () => import('./icons/IconSettingsOff.ts'),
  "settings-pause": () => import('./icons/IconSettingsPause.ts'),
  "settings-pin": () => import('./icons/IconSettingsPin.ts'),
  "settings-plus": () => import('./icons/IconSettingsPlus.ts'),
  "settings-question": () => import('./icons/IconSettingsQuestion.ts'),
  "settings-search": () => import('./icons/IconSettingsSearch.ts'),
  "settings-share": () => import('./icons/IconSettingsShare.ts'),
  "settings-spark": () => import('./icons/IconSettingsSpark.ts'),
  "settings-star": () => import('./icons/IconSettingsStar.ts'),
  "settings-up": () => import('./icons/IconSettingsUp.ts'),
  "settings-x": () => import('./icons/IconSettingsX.ts'),
  "settings": () => import('./icons/IconSettings.ts'),
  "shadow-off": () => import('./icons/IconShadowOff.ts'),
  "shadow": () => import('./icons/IconShadow.ts'),
  "shape-2": () => import('./icons/IconShape2.ts'),
  "shape-3": () => import('./icons/IconShape3.ts'),
  "shape-off": () => import('./icons/IconShapeOff.ts'),
  "shape": () => import('./icons/IconShape.ts'),
  "share-2": () => import('./icons/IconShare2.ts'),
  "share-3": () => import('./icons/IconShare3.ts'),
  "share-off": () => import('./icons/IconShareOff.ts'),
  "share": () => import('./icons/IconShare.ts'),
  "shareplay": () => import('./icons/IconShareplay.ts'),
  "shield-bolt": () => import('./icons/IconShieldBolt.ts'),
  "shield-cancel": () => import('./icons/IconShieldCancel.ts'),
  "shield-check": () => import('./icons/IconShieldCheck.ts'),
  "shield-checkered": () => import('./icons/IconShieldCheckered.ts'),
  "shield-chevron": () => import('./icons/IconShieldChevron.ts'),
  "shield-code": () => import('./icons/IconShieldCode.ts'),
  "shield-cog": () => import('./icons/IconShieldCog.ts'),
  "shield-dollar": () => import('./icons/IconShieldDollar.ts'),
  "shield-down": () => import('./icons/IconShieldDown.ts'),
  "shield-exclamation": () => import('./icons/IconShieldExclamation.ts'),
  "shield-half": () => import('./icons/IconShieldHalf.ts'),
  "shield-heart": () => import('./icons/IconShieldHeart.ts'),
  "shield-lock": () => import('./icons/IconShieldLock.ts'),
  "shield-minus": () => import('./icons/IconShieldMinus.ts'),
  "shield-off": () => import('./icons/IconShieldOff.ts'),
  "shield-pause": () => import('./icons/IconShieldPause.ts'),
  "shield-pin": () => import('./icons/IconShieldPin.ts'),
  "shield-plus": () => import('./icons/IconShieldPlus.ts'),
  "shield-question": () => import('./icons/IconShieldQuestion.ts'),
  "shield-search": () => import('./icons/IconShieldSearch.ts'),
  "shield-share": () => import('./icons/IconShieldShare.ts'),
  "shield-star": () => import('./icons/IconShieldStar.ts'),
  "shield-up": () => import('./icons/IconShieldUp.ts'),
  "shield-x": () => import('./icons/IconShieldX.ts'),
  "shield": () => import('./icons/IconShield.ts'),
  "ship-off": () => import('./icons/IconShipOff.ts'),
  "ship": () => import('./icons/IconShip.ts'),
  "shirt-off": () => import('./icons/IconShirtOff.ts'),
  "shirt-sport": () => import('./icons/IconShirtSport.ts'),
  "shirt": () => import('./icons/IconShirt.ts'),
  "shoe-off": () => import('./icons/IconShoeOff.ts'),
  "shoe": () => import('./icons/IconShoe.ts'),
  "shopping-bag-check": () => import('./icons/IconShoppingBagCheck.ts'),
  "shopping-bag-discount": () => import('./icons/IconShoppingBagDiscount.ts'),
  "shopping-bag-edit": () => import('./icons/IconShoppingBagEdit.ts'),
  "shopping-bag-exclamation": () => import('./icons/IconShoppingBagExclamation.ts'),
  "shopping-bag-heart": () => import('./icons/IconShoppingBagHeart.ts'),
  "shopping-bag-minus": () => import('./icons/IconShoppingBagMinus.ts'),
  "shopping-bag-plus": () => import('./icons/IconShoppingBagPlus.ts'),
  "shopping-bag-search": () => import('./icons/IconShoppingBagSearch.ts'),
  "shopping-bag-x": () => import('./icons/IconShoppingBagX.ts'),
  "shopping-bag": () => import('./icons/IconShoppingBag.ts'),
  "shopping-cart-bolt": () => import('./icons/IconShoppingCartBolt.ts'),
  "shopping-cart-cancel": () => import('./icons/IconShoppingCartCancel.ts'),
  "shopping-cart-check": () => import('./icons/IconShoppingCartCheck.ts'),
  "shopping-cart-code": () => import('./icons/IconShoppingCartCode.ts'),
  "shopping-cart-cog": () => import('./icons/IconShoppingCartCog.ts'),
  "shopping-cart-copy": () => import('./icons/IconShoppingCartCopy.ts'),
  "shopping-cart-discount": () => import('./icons/IconShoppingCartDiscount.ts'),
  "shopping-cart-dollar": () => import('./icons/IconShoppingCartDollar.ts'),
  "shopping-cart-down": () => import('./icons/IconShoppingCartDown.ts'),
  "shopping-cart-exclamation": () => import('./icons/IconShoppingCartExclamation.ts'),
  "shopping-cart-heart": () => import('./icons/IconShoppingCartHeart.ts'),
  "shopping-cart-minus": () => import('./icons/IconShoppingCartMinus.ts'),
  "shopping-cart-off": () => import('./icons/IconShoppingCartOff.ts'),
  "shopping-cart-pause": () => import('./icons/IconShoppingCartPause.ts'),
  "shopping-cart-pin": () => import('./icons/IconShoppingCartPin.ts'),
  "shopping-cart-plus": () => import('./icons/IconShoppingCartPlus.ts'),
  "shopping-cart-question": () => import('./icons/IconShoppingCartQuestion.ts'),
  "shopping-cart-search": () => import('./icons/IconShoppingCartSearch.ts'),
  "shopping-cart-share": () => import('./icons/IconShoppingCartShare.ts'),
  "shopping-cart-star": () => import('./icons/IconShoppingCartStar.ts'),
  "shopping-cart-up": () => import('./icons/IconShoppingCartUp.ts'),
  "shopping-cart-x": () => import('./icons/IconShoppingCartX.ts'),
  "shopping-cart": () => import('./icons/IconShoppingCart.ts'),
  "shovel-pitchforks": () => import('./icons/IconShovelPitchforks.ts'),
  "shovel": () => import('./icons/IconShovel.ts'),
  "shredder": () => import('./icons/IconShredder.ts'),
  "sign-left": () => import('./icons/IconSignLeft.ts'),
  "sign-right": () => import('./icons/IconSignRight.ts'),
  "signal-2g": () => import('./icons/IconSignal2g.ts'),
  "signal-3g": () => import('./icons/IconSignal3g.ts'),
  "signal-4g-plus": () => import('./icons/IconSignal4gPlus.ts'),
  "signal-4g": () => import('./icons/IconSignal4g.ts'),
  "signal-5g": () => import('./icons/IconSignal5g.ts'),
  "signal-6g": () => import('./icons/IconSignal6g.ts'),
  "signal-e": () => import('./icons/IconSignalE.ts'),
  "signal-g": () => import('./icons/IconSignalG.ts'),
  "signal-h-plus": () => import('./icons/IconSignalHPlus.ts'),
  "signal-h": () => import('./icons/IconSignalH.ts'),
  "signal-lte": () => import('./icons/IconSignalLte.ts'),
  "signature-off": () => import('./icons/IconSignatureOff.ts'),
  "signature": () => import('./icons/IconSignature.ts'),
  "sitemap-off": () => import('./icons/IconSitemapOff.ts'),
  "sitemap": () => import('./icons/IconSitemap.ts'),
  "skateboard-off": () => import('./icons/IconSkateboardOff.ts'),
  "skateboard": () => import('./icons/IconSkateboard.ts'),
  "skateboarding": () => import('./icons/IconSkateboarding.ts'),
  "skew-x": () => import('./icons/IconSkewX.ts'),
  "skew-y": () => import('./icons/IconSkewY.ts'),
  "ski-jumping": () => import('./icons/IconSkiJumping.ts'),
  "skull": () => import('./icons/IconSkull.ts'),
  "slash": () => import('./icons/IconSlash.ts'),
  "slashes": () => import('./icons/IconSlashes.ts'),
  "sleigh": () => import('./icons/IconSleigh.ts'),
  "slice": () => import('./icons/IconSlice.ts'),
  "slideshow": () => import('./icons/IconSlideshow.ts'),
  "smart-home-off": () => import('./icons/IconSmartHomeOff.ts'),
  "smart-home": () => import('./icons/IconSmartHome.ts'),
  "smoking-no": () => import('./icons/IconSmokingNo.ts'),
  "smoking": () => import('./icons/IconSmoking.ts'),
  "snowboarding": () => import('./icons/IconSnowboarding.ts'),
  "snowflake-off": () => import('./icons/IconSnowflakeOff.ts'),
  "snowflake": () => import('./icons/IconSnowflake.ts'),
  "snowman": () => import('./icons/IconSnowman.ts'),
  "soccer-field": () => import('./icons/IconSoccerField.ts'),
  "social-off": () => import('./icons/IconSocialOff.ts'),
  "social": () => import('./icons/IconSocial.ts'),
  "sock": () => import('./icons/IconSock.ts'),
  "sofa-off": () => import('./icons/IconSofaOff.ts'),
  "sofa": () => import('./icons/IconSofa.ts'),
  "solar-electricity": () => import('./icons/IconSolarElectricity.ts'),
  "solar-panel-2": () => import('./icons/IconSolarPanel2.ts'),
  "solar-panel": () => import('./icons/IconSolarPanel.ts'),
  "sort-0-9": () => import('./icons/IconSort09.ts'),
  "sort-9-0": () => import('./icons/IconSort90.ts'),
  "sort-a-z": () => import('./icons/IconSortAZ.ts'),
  "sort-ascending-2": () => import('./icons/IconSortAscending2.ts'),
  "sort-ascending-letters": () => import('./icons/IconSortAscendingLetters.ts'),
  "sort-ascending-numbers": () => import('./icons/IconSortAscendingNumbers.ts'),
  "sort-ascending-shapes": () => import('./icons/IconSortAscendingShapes.ts'),
  "sort-ascending-small-big": () => import('./icons/IconSortAscendingSmallBig.ts'),
  "sort-ascending": () => import('./icons/IconSortAscending.ts'),
  "sort-descending-2": () => import('./icons/IconSortDescending2.ts'),
  "sort-descending-letters": () => import('./icons/IconSortDescendingLetters.ts'),
  "sort-descending-numbers": () => import('./icons/IconSortDescendingNumbers.ts'),
  "sort-descending-shapes": () => import('./icons/IconSortDescendingShapes.ts'),
  "sort-descending-small-big": () => import('./icons/IconSortDescendingSmallBig.ts'),
  "sort-descending": () => import('./icons/IconSortDescending.ts'),
  "sort-z-a": () => import('./icons/IconSortZA.ts'),
  "sos": () => import('./icons/IconSos.ts'),
  "soup-off": () => import('./icons/IconSoupOff.ts'),
  "soup": () => import('./icons/IconSoup.ts'),
  "source-code": () => import('./icons/IconSourceCode.ts'),
  "space-off": () => import('./icons/IconSpaceOff.ts'),
  "space": () => import('./icons/IconSpace.ts'),
  "spaces": () => import('./icons/IconSpaces.ts'),
  "spacing-horizontal": () => import('./icons/IconSpacingHorizontal.ts'),
  "spacing-vertical": () => import('./icons/IconSpacingVertical.ts'),
  "spade": () => import('./icons/IconSpade.ts'),
  "sparkles-2": () => import('./icons/IconSparkles2.ts'),
  "sparkles": () => import('./icons/IconSparkles.ts'),
  "speakerphone": () => import('./icons/IconSpeakerphone.ts'),
  "speedboat": () => import('./icons/IconSpeedboat.ts'),
  "sphere-off": () => import('./icons/IconSphereOff.ts'),
  "sphere-plus": () => import('./icons/IconSpherePlus.ts'),
  "sphere": () => import('./icons/IconSphere.ts'),
  "spider": () => import('./icons/IconSpider.ts'),
  "spiral-off": () => import('./icons/IconSpiralOff.ts'),
  "spiral": () => import('./icons/IconSpiral.ts'),
  "sport-billard": () => import('./icons/IconSportBillard.ts'),
  "spray": () => import('./icons/IconSpray.ts'),
  "spy-off": () => import('./icons/IconSpyOff.ts'),
  "spy": () => import('./icons/IconSpy.ts'),
  "sql": () => import('./icons/IconSql.ts'),
  "square-arrow-down": () => import('./icons/IconSquareArrowDown.ts'),
  "square-arrow-left": () => import('./icons/IconSquareArrowLeft.ts'),
  "square-arrow-right": () => import('./icons/IconSquareArrowRight.ts'),
  "square-arrow-up": () => import('./icons/IconSquareArrowUp.ts'),
  "square-asterisk": () => import('./icons/IconSquareAsterisk.ts'),
  "square-check": () => import('./icons/IconSquareCheck.ts'),
  "square-chevron-down": () => import('./icons/IconSquareChevronDown.ts'),
  "square-chevron-left": () => import('./icons/IconSquareChevronLeft.ts'),
  "square-chevron-right": () => import('./icons/IconSquareChevronRight.ts'),
  "square-chevron-up": () => import('./icons/IconSquareChevronUp.ts'),
  "square-chevrons-down": () => import('./icons/IconSquareChevronsDown.ts'),
  "square-chevrons-left": () => import('./icons/IconSquareChevronsLeft.ts'),
  "square-chevrons-right": () => import('./icons/IconSquareChevronsRight.ts'),
  "square-chevrons-up": () => import('./icons/IconSquareChevronsUp.ts'),
  "square-dashed": () => import('./icons/IconSquareDashed.ts'),
  "square-dot": () => import('./icons/IconSquareDot.ts'),
  "square-f0": () => import('./icons/IconSquareF0.ts'),
  "square-f1": () => import('./icons/IconSquareF1.ts'),
  "square-f2": () => import('./icons/IconSquareF2.ts'),
  "square-f3": () => import('./icons/IconSquareF3.ts'),
  "square-f4": () => import('./icons/IconSquareF4.ts'),
  "square-f5": () => import('./icons/IconSquareF5.ts'),
  "square-f6": () => import('./icons/IconSquareF6.ts'),
  "square-f7": () => import('./icons/IconSquareF7.ts'),
  "square-f8": () => import('./icons/IconSquareF8.ts'),
  "square-f9": () => import('./icons/IconSquareF9.ts'),
  "square-forbid-2": () => import('./icons/IconSquareForbid2.ts'),
  "square-forbid": () => import('./icons/IconSquareForbid.ts'),
  "square-half": () => import('./icons/IconSquareHalf.ts'),
  "square-key": () => import('./icons/IconSquareKey.ts'),
  "square-letter-a": () => import('./icons/IconSquareLetterA.ts'),
  "square-letter-b": () => import('./icons/IconSquareLetterB.ts'),
  "square-letter-c": () => import('./icons/IconSquareLetterC.ts'),
  "square-letter-d": () => import('./icons/IconSquareLetterD.ts'),
  "square-letter-e": () => import('./icons/IconSquareLetterE.ts'),
  "square-letter-f": () => import('./icons/IconSquareLetterF.ts'),
  "square-letter-g": () => import('./icons/IconSquareLetterG.ts'),
  "square-letter-h": () => import('./icons/IconSquareLetterH.ts'),
  "square-letter-i": () => import('./icons/IconSquareLetterI.ts'),
  "square-letter-j": () => import('./icons/IconSquareLetterJ.ts'),
  "square-letter-k": () => import('./icons/IconSquareLetterK.ts'),
  "square-letter-l": () => import('./icons/IconSquareLetterL.ts'),
  "square-letter-m": () => import('./icons/IconSquareLetterM.ts'),
  "square-letter-n": () => import('./icons/IconSquareLetterN.ts'),
  "square-letter-o": () => import('./icons/IconSquareLetterO.ts'),
  "square-letter-p": () => import('./icons/IconSquareLetterP.ts'),
  "square-letter-q": () => import('./icons/IconSquareLetterQ.ts'),
  "square-letter-r": () => import('./icons/IconSquareLetterR.ts'),
  "square-letter-s": () => import('./icons/IconSquareLetterS.ts'),
  "square-letter-t": () => import('./icons/IconSquareLetterT.ts'),
  "square-letter-u": () => import('./icons/IconSquareLetterU.ts'),
  "square-letter-v": () => import('./icons/IconSquareLetterV.ts'),
  "square-letter-w": () => import('./icons/IconSquareLetterW.ts'),
  "square-letter-x": () => import('./icons/IconSquareLetterX.ts'),
  "square-letter-y": () => import('./icons/IconSquareLetterY.ts'),
  "square-letter-z": () => import('./icons/IconSquareLetterZ.ts'),
  "square-minus-2": () => import('./icons/IconSquareMinus2.ts'),
  "square-minus": () => import('./icons/IconSquareMinus.ts'),
  "square-number-0": () => import('./icons/IconSquareNumber0.ts'),
  "square-number-1": () => import('./icons/IconSquareNumber1.ts'),
  "square-number-2": () => import('./icons/IconSquareNumber2.ts'),
  "square-number-3": () => import('./icons/IconSquareNumber3.ts'),
  "square-number-4": () => import('./icons/IconSquareNumber4.ts'),
  "square-number-5": () => import('./icons/IconSquareNumber5.ts'),
  "square-number-6": () => import('./icons/IconSquareNumber6.ts'),
  "square-number-7": () => import('./icons/IconSquareNumber7.ts'),
  "square-number-8": () => import('./icons/IconSquareNumber8.ts'),
  "square-number-9": () => import('./icons/IconSquareNumber9.ts'),
  "square-off": () => import('./icons/IconSquareOff.ts'),
  "square-percentage": () => import('./icons/IconSquarePercentage.ts'),
  "square-plus-2": () => import('./icons/IconSquarePlus2.ts'),
  "square-plus": () => import('./icons/IconSquarePlus.ts'),
  "square-root-2": () => import('./icons/IconSquareRoot2.ts'),
  "square-root": () => import('./icons/IconSquareRoot.ts'),
  "square-rotated-asterisk": () => import('./icons/IconSquareRotatedAsterisk.ts'),
  "square-rotated-forbid-2": () => import('./icons/IconSquareRotatedForbid2.ts'),
  "square-rotated-forbid": () => import('./icons/IconSquareRotatedForbid.ts'),
  "square-rotated-off": () => import('./icons/IconSquareRotatedOff.ts'),
  "square-rotated": () => import('./icons/IconSquareRotated.ts'),
  "square-rounded-arrow-down": () => import('./icons/IconSquareRoundedArrowDown.ts'),
  "square-rounded-arrow-left": () => import('./icons/IconSquareRoundedArrowLeft.ts'),
  "square-rounded-arrow-right": () => import('./icons/IconSquareRoundedArrowRight.ts'),
  "square-rounded-arrow-up": () => import('./icons/IconSquareRoundedArrowUp.ts'),
  "square-rounded-check": () => import('./icons/IconSquareRoundedCheck.ts'),
  "square-rounded-chevron-down": () => import('./icons/IconSquareRoundedChevronDown.ts'),
  "square-rounded-chevron-left": () => import('./icons/IconSquareRoundedChevronLeft.ts'),
  "square-rounded-chevron-right": () => import('./icons/IconSquareRoundedChevronRight.ts'),
  "square-rounded-chevron-up": () => import('./icons/IconSquareRoundedChevronUp.ts'),
  "square-rounded-chevrons-down": () => import('./icons/IconSquareRoundedChevronsDown.ts'),
  "square-rounded-chevrons-left": () => import('./icons/IconSquareRoundedChevronsLeft.ts'),
  "square-rounded-chevrons-right": () => import('./icons/IconSquareRoundedChevronsRight.ts'),
  "square-rounded-chevrons-up": () => import('./icons/IconSquareRoundedChevronsUp.ts'),
  "square-rounded-letter-a": () => import('./icons/IconSquareRoundedLetterA.ts'),
  "square-rounded-letter-b": () => import('./icons/IconSquareRoundedLetterB.ts'),
  "square-rounded-letter-c": () => import('./icons/IconSquareRoundedLetterC.ts'),
  "square-rounded-letter-d": () => import('./icons/IconSquareRoundedLetterD.ts'),
  "square-rounded-letter-e": () => import('./icons/IconSquareRoundedLetterE.ts'),
  "square-rounded-letter-f": () => import('./icons/IconSquareRoundedLetterF.ts'),
  "square-rounded-letter-g": () => import('./icons/IconSquareRoundedLetterG.ts'),
  "square-rounded-letter-h": () => import('./icons/IconSquareRoundedLetterH.ts'),
  "square-rounded-letter-i": () => import('./icons/IconSquareRoundedLetterI.ts'),
  "square-rounded-letter-j": () => import('./icons/IconSquareRoundedLetterJ.ts'),
  "square-rounded-letter-k": () => import('./icons/IconSquareRoundedLetterK.ts'),
  "square-rounded-letter-l": () => import('./icons/IconSquareRoundedLetterL.ts'),
  "square-rounded-letter-m": () => import('./icons/IconSquareRoundedLetterM.ts'),
  "square-rounded-letter-n": () => import('./icons/IconSquareRoundedLetterN.ts'),
  "square-rounded-letter-o": () => import('./icons/IconSquareRoundedLetterO.ts'),
  "square-rounded-letter-p": () => import('./icons/IconSquareRoundedLetterP.ts'),
  "square-rounded-letter-q": () => import('./icons/IconSquareRoundedLetterQ.ts'),
  "square-rounded-letter-r": () => import('./icons/IconSquareRoundedLetterR.ts'),
  "square-rounded-letter-s": () => import('./icons/IconSquareRoundedLetterS.ts'),
  "square-rounded-letter-t": () => import('./icons/IconSquareRoundedLetterT.ts'),
  "square-rounded-letter-u": () => import('./icons/IconSquareRoundedLetterU.ts'),
  "square-rounded-letter-v": () => import('./icons/IconSquareRoundedLetterV.ts'),
  "square-rounded-letter-w": () => import('./icons/IconSquareRoundedLetterW.ts'),
  "square-rounded-letter-x": () => import('./icons/IconSquareRoundedLetterX.ts'),
  "square-rounded-letter-y": () => import('./icons/IconSquareRoundedLetterY.ts'),
  "square-rounded-letter-z": () => import('./icons/IconSquareRoundedLetterZ.ts'),
  "square-rounded-minus-2": () => import('./icons/IconSquareRoundedMinus2.ts'),
  "square-rounded-minus": () => import('./icons/IconSquareRoundedMinus.ts'),
  "square-rounded-number-0": () => import('./icons/IconSquareRoundedNumber0.ts'),
  "square-rounded-number-1": () => import('./icons/IconSquareRoundedNumber1.ts'),
  "square-rounded-number-2": () => import('./icons/IconSquareRoundedNumber2.ts'),
  "square-rounded-number-3": () => import('./icons/IconSquareRoundedNumber3.ts'),
  "square-rounded-number-4": () => import('./icons/IconSquareRoundedNumber4.ts'),
  "square-rounded-number-5": () => import('./icons/IconSquareRoundedNumber5.ts'),
  "square-rounded-number-6": () => import('./icons/IconSquareRoundedNumber6.ts'),
  "square-rounded-number-7": () => import('./icons/IconSquareRoundedNumber7.ts'),
  "square-rounded-number-8": () => import('./icons/IconSquareRoundedNumber8.ts'),
  "square-rounded-number-9": () => import('./icons/IconSquareRoundedNumber9.ts'),
  "square-rounded-percentage": () => import('./icons/IconSquareRoundedPercentage.ts'),
  "square-rounded-plus-2": () => import('./icons/IconSquareRoundedPlus2.ts'),
  "square-rounded-plus": () => import('./icons/IconSquareRoundedPlus.ts'),
  "square-rounded-x": () => import('./icons/IconSquareRoundedX.ts'),
  "square-rounded": () => import('./icons/IconSquareRounded.ts'),
  "square-toggle-horizontal": () => import('./icons/IconSquareToggleHorizontal.ts'),
  "square-toggle": () => import('./icons/IconSquareToggle.ts'),
  "square-x": () => import('./icons/IconSquareX.ts'),
  "square": () => import('./icons/IconSquare.ts'),
  "squares-diagonal": () => import('./icons/IconSquaresDiagonal.ts'),
  "squares-selected": () => import('./icons/IconSquaresSelected.ts'),
  "squares": () => import('./icons/IconSquares.ts'),
  "stack-2": () => import('./icons/IconStack2.ts'),
  "stack-3": () => import('./icons/IconStack3.ts'),
  "stack-back": () => import('./icons/IconStackBack.ts'),
  "stack-backward": () => import('./icons/IconStackBackward.ts'),
  "stack-forward": () => import('./icons/IconStackForward.ts'),
  "stack-front": () => import('./icons/IconStackFront.ts'),
  "stack-middle": () => import('./icons/IconStackMiddle.ts'),
  "stack-pop": () => import('./icons/IconStackPop.ts'),
  "stack-push": () => import('./icons/IconStackPush.ts'),
  "stack": () => import('./icons/IconStack.ts'),
  "stairs-down": () => import('./icons/IconStairsDown.ts'),
  "stairs-up": () => import('./icons/IconStairsUp.ts'),
  "stairs": () => import('./icons/IconStairs.ts'),
  "star-half": () => import('./icons/IconStarHalf.ts'),
  "star-off": () => import('./icons/IconStarOff.ts'),
  "star": () => import('./icons/IconStar.ts'),
  "stars-off": () => import('./icons/IconStarsOff.ts'),
  "stars": () => import('./icons/IconStars.ts'),
  "status-change": () => import('./icons/IconStatusChange.ts'),
  "steam": () => import('./icons/IconSteam.ts'),
  "steering-wheel-off": () => import('./icons/IconSteeringWheelOff.ts'),
  "steering-wheel": () => import('./icons/IconSteeringWheel.ts'),
  "step-into": () => import('./icons/IconStepInto.ts'),
  "step-out": () => import('./icons/IconStepOut.ts'),
  "stereo-glasses": () => import('./icons/IconStereoGlasses.ts'),
  "stethoscope-off": () => import('./icons/IconStethoscopeOff.ts'),
  "stethoscope": () => import('./icons/IconStethoscope.ts'),
  "sticker-2": () => import('./icons/IconSticker2.ts'),
  "sticker": () => import('./icons/IconSticker.ts'),
  "stopwatch": () => import('./icons/IconStopwatch.ts'),
  "storm-off": () => import('./icons/IconStormOff.ts'),
  "storm": () => import('./icons/IconStorm.ts'),
  "stretching-2": () => import('./icons/IconStretching2.ts'),
  "stretching": () => import('./icons/IconStretching.ts'),
  "strikethrough": () => import('./icons/IconStrikethrough.ts'),
  "submarine": () => import('./icons/IconSubmarine.ts'),
  "subscript": () => import('./icons/IconSubscript.ts'),
  "subtask": () => import('./icons/IconSubtask.ts'),
  "subtitles-ai": () => import('./icons/IconSubtitlesAi.ts'),
  "subtitles-edit": () => import('./icons/IconSubtitlesEdit.ts'),
  "subtitles-off": () => import('./icons/IconSubtitlesOff.ts'),
  "subtitles": () => import('./icons/IconSubtitles.ts'),
  "sum-off": () => import('./icons/IconSumOff.ts'),
  "sum": () => import('./icons/IconSum.ts'),
  "sun-electricity": () => import('./icons/IconSunElectricity.ts'),
  "sun-high": () => import('./icons/IconSunHigh.ts'),
  "sun-low": () => import('./icons/IconSunLow.ts'),
  "sun-moon": () => import('./icons/IconSunMoon.ts'),
  "sun-off": () => import('./icons/IconSunOff.ts'),
  "sun-wind": () => import('./icons/IconSunWind.ts'),
  "sun": () => import('./icons/IconSun.ts'),
  "sunglasses": () => import('./icons/IconSunglasses.ts'),
  "sunrise": () => import('./icons/IconSunrise.ts'),
  "sunset-2": () => import('./icons/IconSunset2.ts'),
  "sunset": () => import('./icons/IconSunset.ts'),
  "superscript": () => import('./icons/IconSuperscript.ts'),
  "svg": () => import('./icons/IconSvg.ts'),
  "swimming": () => import('./icons/IconSwimming.ts'),
  "swipe-down": () => import('./icons/IconSwipeDown.ts'),
  "swipe-left": () => import('./icons/IconSwipeLeft.ts'),
  "swipe-right": () => import('./icons/IconSwipeRight.ts'),
  "swipe-up": () => import('./icons/IconSwipeUp.ts'),
  "swipe": () => import('./icons/IconSwipe.ts'),
  "switch-2": () => import('./icons/IconSwitch2.ts'),
  "switch-3": () => import('./icons/IconSwitch3.ts'),
  "switch-horizontal": () => import('./icons/IconSwitchHorizontal.ts'),
  "switch-vertical": () => import('./icons/IconSwitchVertical.ts'),
  "switch": () => import('./icons/IconSwitch.ts'),
  "sword-off": () => import('./icons/IconSwordOff.ts'),
  "sword": () => import('./icons/IconSword.ts'),
  "swords": () => import('./icons/IconSwords.ts'),
  "table-alias": () => import('./icons/IconTableAlias.ts'),
  "table-column": () => import('./icons/IconTableColumn.ts'),
  "table-dashed": () => import('./icons/IconTableDashed.ts'),
  "table-down": () => import('./icons/IconTableDown.ts'),
  "table-export": () => import('./icons/IconTableExport.ts'),
  "table-heart": () => import('./icons/IconTableHeart.ts'),
  "table-import": () => import('./icons/IconTableImport.ts'),
  "table-minus": () => import('./icons/IconTableMinus.ts'),
  "table-off": () => import('./icons/IconTableOff.ts'),
  "table-options": () => import('./icons/IconTableOptions.ts'),
  "table-plus": () => import('./icons/IconTablePlus.ts'),
  "table-row": () => import('./icons/IconTableRow.ts'),
  "table-share": () => import('./icons/IconTableShare.ts'),
  "table-shortcut": () => import('./icons/IconTableShortcut.ts'),
  "table-spark": () => import('./icons/IconTableSpark.ts'),
  "table": () => import('./icons/IconTable.ts'),
  "tag-minus": () => import('./icons/IconTagMinus.ts'),
  "tag-off": () => import('./icons/IconTagOff.ts'),
  "tag-plus": () => import('./icons/IconTagPlus.ts'),
  "tag-starred": () => import('./icons/IconTagStarred.ts'),
  "tag": () => import('./icons/IconTag.ts'),
  "tags-off": () => import('./icons/IconTagsOff.ts'),
  "tags": () => import('./icons/IconTags.ts'),
  "tallymark-1": () => import('./icons/IconTallymark1.ts'),
  "tallymark-2": () => import('./icons/IconTallymark2.ts'),
  "tallymark-3": () => import('./icons/IconTallymark3.ts'),
  "tallymark-4": () => import('./icons/IconTallymark4.ts'),
  "tallymarks": () => import('./icons/IconTallymarks.ts'),
  "tank": () => import('./icons/IconTank.ts'),
  "target-arrow": () => import('./icons/IconTargetArrow.ts'),
  "target-off": () => import('./icons/IconTargetOff.ts'),
  "target": () => import('./icons/IconTarget.ts'),
  "tax-euro": () => import('./icons/IconTaxEuro.ts'),
  "tax-pound": () => import('./icons/IconTaxPound.ts'),
  "tax": () => import('./icons/IconTax.ts'),
  "teapot": () => import('./icons/IconTeapot.ts'),
  "telescope-off": () => import('./icons/IconTelescopeOff.ts'),
  "telescope": () => import('./icons/IconTelescope.ts'),
  "temperature-celsius": () => import('./icons/IconTemperatureCelsius.ts'),
  "temperature-fahrenheit": () => import('./icons/IconTemperatureFahrenheit.ts'),
  "temperature-minus": () => import('./icons/IconTemperatureMinus.ts'),
  "temperature-off": () => import('./icons/IconTemperatureOff.ts'),
  "temperature-plus": () => import('./icons/IconTemperaturePlus.ts'),
  "temperature-snow": () => import('./icons/IconTemperatureSnow.ts'),
  "temperature-sun": () => import('./icons/IconTemperatureSun.ts'),
  "temperature": () => import('./icons/IconTemperature.ts'),
  "template-off": () => import('./icons/IconTemplateOff.ts'),
  "template": () => import('./icons/IconTemplate.ts'),
  "tent-off": () => import('./icons/IconTentOff.ts'),
  "tent": () => import('./icons/IconTent.ts'),
  "terminal-2": () => import('./icons/IconTerminal2.ts'),
  "terminal": () => import('./icons/IconTerminal.ts'),
  "test-pipe-2": () => import('./icons/IconTestPipe2.ts'),
  "test-pipe-off": () => import('./icons/IconTestPipeOff.ts'),
  "test-pipe": () => import('./icons/IconTestPipe.ts'),
  "tex": () => import('./icons/IconTex.ts'),
  "text-caption": () => import('./icons/IconTextCaption.ts'),
  "text-color": () => import('./icons/IconTextColor.ts'),
  "text-decrease": () => import('./icons/IconTextDecrease.ts'),
  "text-direction-ltr": () => import('./icons/IconTextDirectionLtr.ts'),
  "text-direction-rtl": () => import('./icons/IconTextDirectionRtl.ts'),
  "text-grammar": () => import('./icons/IconTextGrammar.ts'),
  "text-increase": () => import('./icons/IconTextIncrease.ts'),
  "text-orientation": () => import('./icons/IconTextOrientation.ts'),
  "text-plus": () => import('./icons/IconTextPlus.ts'),
  "text-recognition": () => import('./icons/IconTextRecognition.ts'),
  "text-resize": () => import('./icons/IconTextResize.ts'),
  "text-scan-2": () => import('./icons/IconTextScan2.ts'),
  "text-size": () => import('./icons/IconTextSize.ts'),
  "text-spellcheck": () => import('./icons/IconTextSpellcheck.ts'),
  "text-wrap-column": () => import('./icons/IconTextWrapColumn.ts'),
  "text-wrap-disabled": () => import('./icons/IconTextWrapDisabled.ts'),
  "text-wrap": () => import('./icons/IconTextWrap.ts'),
  "texture": () => import('./icons/IconTexture.ts'),
  "theater": () => import('./icons/IconTheater.ts'),
  "thermometer": () => import('./icons/IconThermometer.ts'),
  "thumb-down-off": () => import('./icons/IconThumbDownOff.ts'),
  "thumb-down": () => import('./icons/IconThumbDown.ts'),
  "thumb-up-off": () => import('./icons/IconThumbUpOff.ts'),
  "thumb-up": () => import('./icons/IconThumbUp.ts'),
  "tic-tac": () => import('./icons/IconTicTac.ts'),
  "ticket-off": () => import('./icons/IconTicketOff.ts'),
  "ticket": () => import('./icons/IconTicket.ts'),
  "tie": () => import('./icons/IconTie.ts'),
  "tilde": () => import('./icons/IconTilde.ts'),
  "tilt-shift-off": () => import('./icons/IconTiltShiftOff.ts'),
  "tilt-shift": () => import('./icons/IconTiltShift.ts'),
  "time-duration-0": () => import('./icons/IconTimeDuration0.ts'),
  "time-duration-10": () => import('./icons/IconTimeDuration10.ts'),
  "time-duration-15": () => import('./icons/IconTimeDuration15.ts'),
  "time-duration-30": () => import('./icons/IconTimeDuration30.ts'),
  "time-duration-45": () => import('./icons/IconTimeDuration45.ts'),
  "time-duration-5": () => import('./icons/IconTimeDuration5.ts'),
  "time-duration-60": () => import('./icons/IconTimeDuration60.ts'),
  "time-duration-90": () => import('./icons/IconTimeDuration90.ts'),
  "time-duration-off": () => import('./icons/IconTimeDurationOff.ts'),
  "timeline-event-exclamation": () => import('./icons/IconTimelineEventExclamation.ts'),
  "timeline-event-minus": () => import('./icons/IconTimelineEventMinus.ts'),
  "timeline-event-plus": () => import('./icons/IconTimelineEventPlus.ts'),
  "timeline-event-text": () => import('./icons/IconTimelineEventText.ts'),
  "timeline-event-x": () => import('./icons/IconTimelineEventX.ts'),
  "timeline-event": () => import('./icons/IconTimelineEvent.ts'),
  "timeline": () => import('./icons/IconTimeline.ts'),
  "timezone": () => import('./icons/IconTimezone.ts'),
  "tip-jar-euro": () => import('./icons/IconTipJarEuro.ts'),
  "tip-jar-pound": () => import('./icons/IconTipJarPound.ts'),
  "tip-jar": () => import('./icons/IconTipJar.ts'),
  "tir": () => import('./icons/IconTir.ts'),
  "toggle-left": () => import('./icons/IconToggleLeft.ts'),
  "toggle-right": () => import('./icons/IconToggleRight.ts'),
  "toilet-paper-off": () => import('./icons/IconToiletPaperOff.ts'),
  "toilet-paper": () => import('./icons/IconToiletPaper.ts'),
  "toml": () => import('./icons/IconToml.ts'),
  "tool": () => import('./icons/IconTool.ts'),
  "tools-kitchen-2-off": () => import('./icons/IconToolsKitchen2Off.ts'),
  "tools-kitchen-2": () => import('./icons/IconToolsKitchen2.ts'),
  "tools-kitchen-3": () => import('./icons/IconToolsKitchen3.ts'),
  "tools-kitchen-off": () => import('./icons/IconToolsKitchenOff.ts'),
  "tools-kitchen": () => import('./icons/IconToolsKitchen.ts'),
  "tools-off": () => import('./icons/IconToolsOff.ts'),
  "tools": () => import('./icons/IconTools.ts'),
  "tooltip": () => import('./icons/IconTooltip.ts'),
  "topology-bus": () => import('./icons/IconTopologyBus.ts'),
  "topology-complex": () => import('./icons/IconTopologyComplex.ts'),
  "topology-full-hierarchy": () => import('./icons/IconTopologyFullHierarchy.ts'),
  "topology-full": () => import('./icons/IconTopologyFull.ts'),
  "topology-ring-2": () => import('./icons/IconTopologyRing2.ts'),
  "topology-ring-3": () => import('./icons/IconTopologyRing3.ts'),
  "topology-ring": () => import('./icons/IconTopologyRing.ts'),
  "topology-star-2": () => import('./icons/IconTopologyStar2.ts'),
  "topology-star-3": () => import('./icons/IconTopologyStar3.ts'),
  "topology-star-ring-2": () => import('./icons/IconTopologyStarRing2.ts'),
  "topology-star-ring-3": () => import('./icons/IconTopologyStarRing3.ts'),
  "topology-star-ring": () => import('./icons/IconTopologyStarRing.ts'),
  "topology-star": () => import('./icons/IconTopologyStar.ts'),
  "torii": () => import('./icons/IconTorii.ts'),
  "tornado": () => import('./icons/IconTornado.ts'),
  "tournament": () => import('./icons/IconTournament.ts'),
  "tower-off": () => import('./icons/IconTowerOff.ts'),
  "tower": () => import('./icons/IconTower.ts'),
  "track": () => import('./icons/IconTrack.ts'),
  "tractor": () => import('./icons/IconTractor.ts'),
  "trademark": () => import('./icons/IconTrademark.ts'),
  "traffic-cone-off": () => import('./icons/IconTrafficConeOff.ts'),
  "traffic-cone": () => import('./icons/IconTrafficCone.ts'),
  "traffic-lights-off": () => import('./icons/IconTrafficLightsOff.ts'),
  "traffic-lights": () => import('./icons/IconTrafficLights.ts'),
  "train": () => import('./icons/IconTrain.ts'),
  "transaction-bitcoin": () => import('./icons/IconTransactionBitcoin.ts'),
  "transaction-dollar": () => import('./icons/IconTransactionDollar.ts'),
  "transaction-euro": () => import('./icons/IconTransactionEuro.ts'),
  "transaction-pound": () => import('./icons/IconTransactionPound.ts'),
  "transaction-rupee": () => import('./icons/IconTransactionRupee.ts'),
  "transaction-yen": () => import('./icons/IconTransactionYen.ts'),
  "transaction-yuan": () => import('./icons/IconTransactionYuan.ts'),
  "transfer-in": () => import('./icons/IconTransferIn.ts'),
  "transfer-out": () => import('./icons/IconTransferOut.ts'),
  "transfer-vertical": () => import('./icons/IconTransferVertical.ts'),
  "transfer": () => import('./icons/IconTransfer.ts'),
  "transform-point-bottom-left": () => import('./icons/IconTransformPointBottomLeft.ts'),
  "transform-point-bottom-right": () => import('./icons/IconTransformPointBottomRight.ts'),
  "transform-point-top-left": () => import('./icons/IconTransformPointTopLeft.ts'),
  "transform-point-top-right": () => import('./icons/IconTransformPointTopRight.ts'),
  "transform-point": () => import('./icons/IconTransformPoint.ts'),
  "transform": () => import('./icons/IconTransform.ts'),
  "transition-bottom": () => import('./icons/IconTransitionBottom.ts'),
  "transition-left": () => import('./icons/IconTransitionLeft.ts'),
  "transition-right": () => import('./icons/IconTransitionRight.ts'),
  "transition-top": () => import('./icons/IconTransitionTop.ts'),
  "trash-off": () => import('./icons/IconTrashOff.ts'),
  "trash-x": () => import('./icons/IconTrashX.ts'),
  "trash": () => import('./icons/IconTrash.ts'),
  "treadmill": () => import('./icons/IconTreadmill.ts'),
  "tree": () => import('./icons/IconTree.ts'),
  "trees": () => import('./icons/IconTrees.ts'),
  "trekking": () => import('./icons/IconTrekking.ts'),
  "trending-down-2": () => import('./icons/IconTrendingDown2.ts'),
  "trending-down-3": () => import('./icons/IconTrendingDown3.ts'),
  "trending-down": () => import('./icons/IconTrendingDown.ts'),
  "trending-up-2": () => import('./icons/IconTrendingUp2.ts'),
  "trending-up-3": () => import('./icons/IconTrendingUp3.ts'),
  "trending-up": () => import('./icons/IconTrendingUp.ts'),
  "triangle-inverted": () => import('./icons/IconTriangleInverted.ts'),
  "triangle-minus-2": () => import('./icons/IconTriangleMinus2.ts'),
  "triangle-minus": () => import('./icons/IconTriangleMinus.ts'),
  "triangle-off": () => import('./icons/IconTriangleOff.ts'),
  "triangle-plus-2": () => import('./icons/IconTrianglePlus2.ts'),
  "triangle-plus": () => import('./icons/IconTrianglePlus.ts'),
  "triangle-square-circle": () => import('./icons/IconTriangleSquareCircle.ts'),
  "triangle": () => import('./icons/IconTriangle.ts'),
  "triangles": () => import('./icons/IconTriangles.ts'),
  "trident": () => import('./icons/IconTrident.ts'),
  "trolley": () => import('./icons/IconTrolley.ts'),
  "trophy-off": () => import('./icons/IconTrophyOff.ts'),
  "trophy": () => import('./icons/IconTrophy.ts'),
  "trowel": () => import('./icons/IconTrowel.ts'),
  "truck-delivery": () => import('./icons/IconTruckDelivery.ts'),
  "truck-loading": () => import('./icons/IconTruckLoading.ts'),
  "truck-off": () => import('./icons/IconTruckOff.ts'),
  "truck-return": () => import('./icons/IconTruckReturn.ts'),
  "truck": () => import('./icons/IconTruck.ts'),
  "txt": () => import('./icons/IconTxt.ts'),
  "typeface": () => import('./icons/IconTypeface.ts'),
  "typography-off": () => import('./icons/IconTypographyOff.ts'),
  "typography": () => import('./icons/IconTypography.ts'),
  "u-turn-left": () => import('./icons/IconUTurnLeft.ts'),
  "u-turn-right": () => import('./icons/IconUTurnRight.ts'),
  "ufo-off": () => import('./icons/IconUfoOff.ts'),
  "ufo": () => import('./icons/IconUfo.ts'),
  "uhd": () => import('./icons/IconUhd.ts'),
  "umbrella-2": () => import('./icons/IconUmbrella2.ts'),
  "umbrella-closed-2": () => import('./icons/IconUmbrellaClosed2.ts'),
  "umbrella-closed": () => import('./icons/IconUmbrellaClosed.ts'),
  "umbrella-off": () => import('./icons/IconUmbrellaOff.ts'),
  "umbrella": () => import('./icons/IconUmbrella.ts'),
  "underline": () => import('./icons/IconUnderline.ts'),
  "universe": () => import('./icons/IconUniverse.ts'),
  "unlink": () => import('./icons/IconUnlink.ts'),
  "upload": () => import('./icons/IconUpload.ts'),
  "urgent": () => import('./icons/IconUrgent.ts'),
  "usb": () => import('./icons/IconUsb.ts'),
  "user-bitcoin": () => import('./icons/IconUserBitcoin.ts'),
  "user-bolt": () => import('./icons/IconUserBolt.ts'),
  "user-cancel": () => import('./icons/IconUserCancel.ts'),
  "user-check": () => import('./icons/IconUserCheck.ts'),
  "user-circle": () => import('./icons/IconUserCircle.ts'),
  "user-code": () => import('./icons/IconUserCode.ts'),
  "user-cog": () => import('./icons/IconUserCog.ts'),
  "user-dollar": () => import('./icons/IconUserDollar.ts'),
  "user-down": () => import('./icons/IconUserDown.ts'),
  "user-edit": () => import('./icons/IconUserEdit.ts'),
  "user-exclamation": () => import('./icons/IconUserExclamation.ts'),
  "user-heart": () => import('./icons/IconUserHeart.ts'),
  "user-hexagon": () => import('./icons/IconUserHexagon.ts'),
  "user-minus": () => import('./icons/IconUserMinus.ts'),
  "user-off": () => import('./icons/IconUserOff.ts'),
  "user-pause": () => import('./icons/IconUserPause.ts'),
  "user-pentagon": () => import('./icons/IconUserPentagon.ts'),
  "user-pin": () => import('./icons/IconUserPin.ts'),
  "user-plus": () => import('./icons/IconUserPlus.ts'),
  "user-question": () => import('./icons/IconUserQuestion.ts'),
  "user-scan": () => import('./icons/IconUserScan.ts'),
  "user-screen": () => import('./icons/IconUserScreen.ts'),
  "user-search": () => import('./icons/IconUserSearch.ts'),
  "user-share": () => import('./icons/IconUserShare.ts'),
  "user-shield": () => import('./icons/IconUserShield.ts'),
  "user-square-rounded": () => import('./icons/IconUserSquareRounded.ts'),
  "user-square": () => import('./icons/IconUserSquare.ts'),
  "user-star": () => import('./icons/IconUserStar.ts'),
  "user-up": () => import('./icons/IconUserUp.ts'),
  "user-x": () => import('./icons/IconUserX.ts'),
  "user": () => import('./icons/IconUser.ts'),
  "users-group": () => import('./icons/IconUsersGroup.ts'),
  "users-minus": () => import('./icons/IconUsersMinus.ts'),
  "users-plus": () => import('./icons/IconUsersPlus.ts'),
  "users": () => import('./icons/IconUsers.ts'),
  "uv-index": () => import('./icons/IconUvIndex.ts'),
  "ux-circle": () => import('./icons/IconUxCircle.ts'),
  "vaccine-bottle-off": () => import('./icons/IconVaccineBottleOff.ts'),
  "vaccine-bottle": () => import('./icons/IconVaccineBottle.ts'),
  "vaccine-off": () => import('./icons/IconVaccineOff.ts'),
  "vaccine": () => import('./icons/IconVaccine.ts'),
  "vacuum-cleaner": () => import('./icons/IconVacuumCleaner.ts'),
  "variable-minus": () => import('./icons/IconVariableMinus.ts'),
  "variable-off": () => import('./icons/IconVariableOff.ts'),
  "variable-plus": () => import('./icons/IconVariablePlus.ts'),
  "variable": () => import('./icons/IconVariable.ts'),
  "vector-bezier-2": () => import('./icons/IconVectorBezier2.ts'),
  "vector-bezier-arc": () => import('./icons/IconVectorBezierArc.ts'),
  "vector-bezier-circle": () => import('./icons/IconVectorBezierCircle.ts'),
  "vector-bezier": () => import('./icons/IconVectorBezier.ts'),
  "vector-off": () => import('./icons/IconVectorOff.ts'),
  "vector-spline": () => import('./icons/IconVectorSpline.ts'),
  "vector-triangle-off": () => import('./icons/IconVectorTriangleOff.ts'),
  "vector-triangle": () => import('./icons/IconVectorTriangle.ts'),
  "vector": () => import('./icons/IconVector.ts'),
  "venus": () => import('./icons/IconVenus.ts'),
  "versions-off": () => import('./icons/IconVersionsOff.ts'),
  "versions": () => import('./icons/IconVersions.ts'),
  "video-minus": () => import('./icons/IconVideoMinus.ts'),
  "video-off": () => import('./icons/IconVideoOff.ts'),
  "video-plus": () => import('./icons/IconVideoPlus.ts'),
  "video": () => import('./icons/IconVideo.ts'),
  "view-360-arrow": () => import('./icons/IconView360Arrow.ts'),
  "view-360-number": () => import('./icons/IconView360Number.ts'),
  "view-360-off": () => import('./icons/IconView360Off.ts'),
  "view-360": () => import('./icons/IconView360.ts'),
  "viewfinder-off": () => import('./icons/IconViewfinderOff.ts'),
  "viewfinder": () => import('./icons/IconViewfinder.ts'),
  "viewport-narrow": () => import('./icons/IconViewportNarrow.ts'),
  "viewport-short": () => import('./icons/IconViewportShort.ts'),
  "viewport-tall": () => import('./icons/IconViewportTall.ts'),
  "viewport-wide": () => import('./icons/IconViewportWide.ts'),
  "vinyl": () => import('./icons/IconVinyl.ts'),
  "vip-off": () => import('./icons/IconVipOff.ts'),
  "vip": () => import('./icons/IconVip.ts'),
  "virus-off": () => import('./icons/IconVirusOff.ts'),
  "virus-search": () => import('./icons/IconVirusSearch.ts'),
  "virus": () => import('./icons/IconVirus.ts'),
  "vocabulary-off": () => import('./icons/IconVocabularyOff.ts'),
  "vocabulary": () => import('./icons/IconVocabulary.ts'),
  "volcano": () => import('./icons/IconVolcano.ts'),
  "volume-2": () => import('./icons/IconVolume2.ts'),
  "volume-3": () => import('./icons/IconVolume3.ts'),
  "volume-4": () => import('./icons/IconVolume4.ts'),
  "volume-off": () => import('./icons/IconVolumeOff.ts'),
  "volume": () => import('./icons/IconVolume.ts'),
  "vs": () => import('./icons/IconVs.ts'),
  "walk": () => import('./icons/IconWalk.ts'),
  "wall-off": () => import('./icons/IconWallOff.ts'),
  "wall": () => import('./icons/IconWall.ts'),
  "wallet-off": () => import('./icons/IconWalletOff.ts'),
  "wallet": () => import('./icons/IconWallet.ts'),
  "wallpaper-off": () => import('./icons/IconWallpaperOff.ts'),
  "wallpaper": () => import('./icons/IconWallpaper.ts'),
  "wand-off": () => import('./icons/IconWandOff.ts'),
  "wand": () => import('./icons/IconWand.ts'),
  "wash-dry-1": () => import('./icons/IconWashDry1.ts'),
  "wash-dry-2": () => import('./icons/IconWashDry2.ts'),
  "wash-dry-3": () => import('./icons/IconWashDry3.ts'),
  "wash-dry-a": () => import('./icons/IconWashDryA.ts'),
  "wash-dry-dip": () => import('./icons/IconWashDryDip.ts'),
  "wash-dry-f": () => import('./icons/IconWashDryF.ts'),
  "wash-dry-flat": () => import('./icons/IconWashDryFlat.ts'),
  "wash-dry-hang": () => import('./icons/IconWashDryHang.ts'),
  "wash-dry-off": () => import('./icons/IconWashDryOff.ts'),
  "wash-dry-p": () => import('./icons/IconWashDryP.ts'),
  "wash-dry-shade": () => import('./icons/IconWashDryShade.ts'),
  "wash-dry-w": () => import('./icons/IconWashDryW.ts'),
  "wash-dry": () => import('./icons/IconWashDry.ts'),
  "wash-dryclean-off": () => import('./icons/IconWashDrycleanOff.ts'),
  "wash-dryclean": () => import('./icons/IconWashDryclean.ts'),
  "wash-eco": () => import('./icons/IconWashEco.ts'),
  "wash-gentle": () => import('./icons/IconWashGentle.ts'),
  "wash-hand": () => import('./icons/IconWashHand.ts'),
  "wash-machine": () => import('./icons/IconWashMachine.ts'),
  "wash-off": () => import('./icons/IconWashOff.ts'),
  "wash-press": () => import('./icons/IconWashPress.ts'),
  "wash-temperature-1": () => import('./icons/IconWashTemperature1.ts'),
  "wash-temperature-2": () => import('./icons/IconWashTemperature2.ts'),
  "wash-temperature-3": () => import('./icons/IconWashTemperature3.ts'),
  "wash-temperature-4": () => import('./icons/IconWashTemperature4.ts'),
  "wash-temperature-5": () => import('./icons/IconWashTemperature5.ts'),
  "wash-temperature-6": () => import('./icons/IconWashTemperature6.ts'),
  "wash-tumble-dry": () => import('./icons/IconWashTumbleDry.ts'),
  "wash-tumble-off": () => import('./icons/IconWashTumbleOff.ts'),
  "wash": () => import('./icons/IconWash.ts'),
  "waterpolo": () => import('./icons/IconWaterpolo.ts'),
  "wave-saw-tool": () => import('./icons/IconWaveSawTool.ts'),
  "wave-sine": () => import('./icons/IconWaveSine.ts'),
  "wave-square": () => import('./icons/IconWaveSquare.ts'),
  "waves-electricity": () => import('./icons/IconWavesElectricity.ts'),
  "webhook-off": () => import('./icons/IconWebhookOff.ts'),
  "webhook": () => import('./icons/IconWebhook.ts'),
  "weight": () => import('./icons/IconWeight.ts'),
  "wheat-off": () => import('./icons/IconWheatOff.ts'),
  "wheat": () => import('./icons/IconWheat.ts'),
  "wheel": () => import('./icons/IconWheel.ts'),
  "wheelchair-off": () => import('./icons/IconWheelchairOff.ts'),
  "wheelchair": () => import('./icons/IconWheelchair.ts'),
  "whirl": () => import('./icons/IconWhirl.ts'),
  "whisk": () => import('./icons/IconWhisk.ts'),
  "wifi-0": () => import('./icons/IconWifi0.ts'),
  "wifi-1": () => import('./icons/IconWifi1.ts'),
  "wifi-2": () => import('./icons/IconWifi2.ts'),
  "wifi-off": () => import('./icons/IconWifiOff.ts'),
  "wifi": () => import('./icons/IconWifi.ts'),
  "wind-electricity": () => import('./icons/IconWindElectricity.ts'),
  "wind-off": () => import('./icons/IconWindOff.ts'),
  "wind": () => import('./icons/IconWind.ts'),
  "windmill-off": () => import('./icons/IconWindmillOff.ts'),
  "windmill": () => import('./icons/IconWindmill.ts'),
  "window-maximize": () => import('./icons/IconWindowMaximize.ts'),
  "window-minimize": () => import('./icons/IconWindowMinimize.ts'),
  "window-off": () => import('./icons/IconWindowOff.ts'),
  "window": () => import('./icons/IconWindow.ts'),
  "windsock": () => import('./icons/IconWindsock.ts'),
  "wiper-wash": () => import('./icons/IconWiperWash.ts'),
  "wiper": () => import('./icons/IconWiper.ts'),
  "woman": () => import('./icons/IconWoman.ts'),
  "wood": () => import('./icons/IconWood.ts'),
  "world-bolt": () => import('./icons/IconWorldBolt.ts'),
  "world-cancel": () => import('./icons/IconWorldCancel.ts'),
  "world-check": () => import('./icons/IconWorldCheck.ts'),
  "world-code": () => import('./icons/IconWorldCode.ts'),
  "world-cog": () => import('./icons/IconWorldCog.ts'),
  "world-dollar": () => import('./icons/IconWorldDollar.ts'),
  "world-down": () => import('./icons/IconWorldDown.ts'),
  "world-download": () => import('./icons/IconWorldDownload.ts'),
  "world-exclamation": () => import('./icons/IconWorldExclamation.ts'),
  "world-heart": () => import('./icons/IconWorldHeart.ts'),
  "world-latitude": () => import('./icons/IconWorldLatitude.ts'),
  "world-longitude": () => import('./icons/IconWorldLongitude.ts'),
  "world-minus": () => import('./icons/IconWorldMinus.ts'),
  "world-off": () => import('./icons/IconWorldOff.ts'),
  "world-pause": () => import('./icons/IconWorldPause.ts'),
  "world-pin": () => import('./icons/IconWorldPin.ts'),
  "world-plus": () => import('./icons/IconWorldPlus.ts'),
  "world-question": () => import('./icons/IconWorldQuestion.ts'),
  "world-search": () => import('./icons/IconWorldSearch.ts'),
  "world-share": () => import('./icons/IconWorldShare.ts'),
  "world-star": () => import('./icons/IconWorldStar.ts'),
  "world-up": () => import('./icons/IconWorldUp.ts'),
  "world-upload": () => import('./icons/IconWorldUpload.ts'),
  "world-www": () => import('./icons/IconWorldWww.ts'),
  "world-x": () => import('./icons/IconWorldX.ts'),
  "world": () => import('./icons/IconWorld.ts'),
  "wrecking-ball": () => import('./icons/IconWreckingBall.ts'),
  "writing-off": () => import('./icons/IconWritingOff.ts'),
  "writing-sign-off": () => import('./icons/IconWritingSignOff.ts'),
  "writing-sign": () => import('./icons/IconWritingSign.ts'),
  "writing": () => import('./icons/IconWriting.ts'),
  "x-power-y": () => import('./icons/IconXPowerY.ts'),
  "x": () => import('./icons/IconX.ts'),
  "xbox-a": () => import('./icons/IconXboxA.ts'),
  "xbox-b": () => import('./icons/IconXboxB.ts'),
  "xbox-x": () => import('./icons/IconXboxX.ts'),
  "xbox-y": () => import('./icons/IconXboxY.ts'),
  "xd": () => import('./icons/IconXd.ts'),
  "xxx": () => import('./icons/IconXxx.ts'),
  "yin-yang": () => import('./icons/IconYinYang.ts'),
  "yoga": () => import('./icons/IconYoga.ts'),
  "zeppelin-off": () => import('./icons/IconZeppelinOff.ts'),
  "zeppelin": () => import('./icons/IconZeppelin.ts'),
  "zip": () => import('./icons/IconZip.ts'),
  "zodiac-aquarius": () => import('./icons/IconZodiacAquarius.ts'),
  "zodiac-aries": () => import('./icons/IconZodiacAries.ts'),
  "zodiac-cancer": () => import('./icons/IconZodiacCancer.ts'),
  "zodiac-capricorn": () => import('./icons/IconZodiacCapricorn.ts'),
  "zodiac-gemini": () => import('./icons/IconZodiacGemini.ts'),
  "zodiac-leo": () => import('./icons/IconZodiacLeo.ts'),
  "zodiac-libra": () => import('./icons/IconZodiacLibra.ts'),
  "zodiac-pisces": () => import('./icons/IconZodiacPisces.ts'),
  "zodiac-sagittarius": () => import('./icons/IconZodiacSagittarius.ts'),
  "zodiac-scorpio": () => import('./icons/IconZodiacScorpio.ts'),
  "zodiac-taurus": () => import('./icons/IconZodiacTaurus.ts'),
  "zodiac-virgo": () => import('./icons/IconZodiacVirgo.ts'),
  "zoom-cancel": () => import('./icons/IconZoomCancel.ts'),
  "zoom-check": () => import('./icons/IconZoomCheck.ts'),
  "zoom-code": () => import('./icons/IconZoomCode.ts'),
  "zoom-exclamation": () => import('./icons/IconZoomExclamation.ts'),
  "zoom-in-area": () => import('./icons/IconZoomInArea.ts'),
  "zoom-in": () => import('./icons/IconZoomIn.ts'),
  "zoom-money": () => import('./icons/IconZoomMoney.ts'),
  "zoom-out-area": () => import('./icons/IconZoomOutArea.ts'),
  "zoom-out": () => import('./icons/IconZoomOut.ts'),
  "zoom-pan": () => import('./icons/IconZoomPan.ts'),
  "zoom-question": () => import('./icons/IconZoomQuestion.ts'),
  "zoom-replace": () => import('./icons/IconZoomReplace.ts'),
  "zoom-reset": () => import('./icons/IconZoomReset.ts'),
  "zoom-scan": () => import('./icons/IconZoomScan.ts'),
  "zoom": () => import('./icons/IconZoom.ts'),
  "zzz-off": () => import('./icons/IconZzzOff.ts'),
  "zzz": () => import('./icons/IconZzz.ts'),
  "accessible-filled": () => import('./icons/IconAccessibleFilled.ts'),
  "ad-circle-filled": () => import('./icons/IconAdCircleFilled.ts'),
  "ad-filled": () => import('./icons/IconAdFilled.ts'),
  "adjustments-filled": () => import('./icons/IconAdjustmentsFilled.ts'),
  "aerial-lift-filled": () => import('./icons/IconAerialLiftFilled.ts'),
  "affiliate-filled": () => import('./icons/IconAffiliateFilled.ts'),
  "air-balloon-filled": () => import('./icons/IconAirBalloonFilled.ts'),
  "alarm-minus-filled": () => import('./icons/IconAlarmMinusFilled.ts'),
  "alarm-plus-filled": () => import('./icons/IconAlarmPlusFilled.ts'),
  "alarm-snooze-filled": () => import('./icons/IconAlarmSnoozeFilled.ts'),
  "alarm-filled": () => import('./icons/IconAlarmFilled.ts'),
  "alert-circle-filled": () => import('./icons/IconAlertCircleFilled.ts'),
  "alert-hexagon-filled": () => import('./icons/IconAlertHexagonFilled.ts'),
  "alert-octagon-filled": () => import('./icons/IconAlertOctagonFilled.ts'),
  "alert-square-rounded-filled": () => import('./icons/IconAlertSquareRoundedFilled.ts'),
  "alert-square-filled": () => import('./icons/IconAlertSquareFilled.ts'),
  "alert-triangle-filled": () => import('./icons/IconAlertTriangleFilled.ts'),
  "alien-filled": () => import('./icons/IconAlienFilled.ts'),
  "align-box-bottom-center-filled": () => import('./icons/IconAlignBoxBottomCenterFilled.ts'),
  "align-box-bottom-left-filled": () => import('./icons/IconAlignBoxBottomLeftFilled.ts'),
  "align-box-bottom-right-filled": () => import('./icons/IconAlignBoxBottomRightFilled.ts'),
  "align-box-center-middle-filled": () => import('./icons/IconAlignBoxCenterMiddleFilled.ts'),
  "align-box-left-bottom-filled": () => import('./icons/IconAlignBoxLeftBottomFilled.ts'),
  "align-box-left-middle-filled": () => import('./icons/IconAlignBoxLeftMiddleFilled.ts'),
  "align-box-left-top-filled": () => import('./icons/IconAlignBoxLeftTopFilled.ts'),
  "align-box-right-bottom-filled": () => import('./icons/IconAlignBoxRightBottomFilled.ts'),
  "align-box-right-middle-filled": () => import('./icons/IconAlignBoxRightMiddleFilled.ts'),
  "align-box-right-top-filled": () => import('./icons/IconAlignBoxRightTopFilled.ts'),
  "align-box-top-center-filled": () => import('./icons/IconAlignBoxTopCenterFilled.ts'),
  "align-box-top-left-filled": () => import('./icons/IconAlignBoxTopLeftFilled.ts'),
  "align-box-top-right-filled": () => import('./icons/IconAlignBoxTopRightFilled.ts'),
  "analyze-filled": () => import('./icons/IconAnalyzeFilled.ts'),
  "app-window-filled": () => import('./icons/IconAppWindowFilled.ts'),
  "apple-filled": () => import('./icons/IconAppleFilled.ts'),
  "apps-filled": () => import('./icons/IconAppsFilled.ts'),
  "archive-filled": () => import('./icons/IconArchiveFilled.ts'),
  "arrow-autofit-content-filled": () => import('./icons/IconArrowAutofitContentFilled.ts'),
  "arrow-autofit-down-filled": () => import('./icons/IconArrowAutofitDownFilled.ts'),
  "arrow-autofit-height-filled": () => import('./icons/IconArrowAutofitHeightFilled.ts'),
  "arrow-autofit-left-filled": () => import('./icons/IconArrowAutofitLeftFilled.ts'),
  "arrow-autofit-right-filled": () => import('./icons/IconArrowAutofitRightFilled.ts'),
  "arrow-autofit-up-filled": () => import('./icons/IconArrowAutofitUpFilled.ts'),
  "arrow-autofit-width-filled": () => import('./icons/IconArrowAutofitWidthFilled.ts'),
  "arrow-badge-down-filled": () => import('./icons/IconArrowBadgeDownFilled.ts'),
  "arrow-badge-left-filled": () => import('./icons/IconArrowBadgeLeftFilled.ts'),
  "arrow-badge-right-filled": () => import('./icons/IconArrowBadgeRightFilled.ts'),
  "arrow-badge-up-filled": () => import('./icons/IconArrowBadgeUpFilled.ts'),
  "arrow-big-down-line-filled": () => import('./icons/IconArrowBigDownLineFilled.ts'),
  "arrow-big-down-lines-filled": () => import('./icons/IconArrowBigDownLinesFilled.ts'),
  "arrow-big-down-filled": () => import('./icons/IconArrowBigDownFilled.ts'),
  "arrow-big-left-line-filled": () => import('./icons/IconArrowBigLeftLineFilled.ts'),
  "arrow-big-left-lines-filled": () => import('./icons/IconArrowBigLeftLinesFilled.ts'),
  "arrow-big-left-filled": () => import('./icons/IconArrowBigLeftFilled.ts'),
  "arrow-big-right-line-filled": () => import('./icons/IconArrowBigRightLineFilled.ts'),
  "arrow-big-right-lines-filled": () => import('./icons/IconArrowBigRightLinesFilled.ts'),
  "arrow-big-right-filled": () => import('./icons/IconArrowBigRightFilled.ts'),
  "arrow-big-up-line-filled": () => import('./icons/IconArrowBigUpLineFilled.ts'),
  "arrow-big-up-lines-filled": () => import('./icons/IconArrowBigUpLinesFilled.ts'),
  "arrow-big-up-filled": () => import('./icons/IconArrowBigUpFilled.ts'),
  "arrow-down-circle-filled": () => import('./icons/IconArrowDownCircleFilled.ts'),
  "arrow-down-rhombus-filled": () => import('./icons/IconArrowDownRhombusFilled.ts'),
  "arrow-down-square-filled": () => import('./icons/IconArrowDownSquareFilled.ts'),
  "arrow-guide-filled": () => import('./icons/IconArrowGuideFilled.ts'),
  "arrow-left-circle-filled": () => import('./icons/IconArrowLeftCircleFilled.ts'),
  "arrow-left-rhombus-filled": () => import('./icons/IconArrowLeftRhombusFilled.ts'),
  "arrow-left-square-filled": () => import('./icons/IconArrowLeftSquareFilled.ts'),
  "arrow-move-down-filled": () => import('./icons/IconArrowMoveDownFilled.ts'),
  "arrow-move-left-filled": () => import('./icons/IconArrowMoveLeftFilled.ts'),
  "arrow-move-right-filled": () => import('./icons/IconArrowMoveRightFilled.ts'),
  "arrow-move-up-filled": () => import('./icons/IconArrowMoveUpFilled.ts'),
  "arrow-right-circle-filled": () => import('./icons/IconArrowRightCircleFilled.ts'),
  "arrow-right-rhombus-filled": () => import('./icons/IconArrowRightRhombusFilled.ts'),
  "arrow-right-square-filled": () => import('./icons/IconArrowRightSquareFilled.ts'),
  "arrow-up-circle-filled": () => import('./icons/IconArrowUpCircleFilled.ts'),
  "arrow-up-rhombus-filled": () => import('./icons/IconArrowUpRhombusFilled.ts'),
  "arrow-up-square-filled": () => import('./icons/IconArrowUpSquareFilled.ts'),
  "artboard-filled": () => import('./icons/IconArtboardFilled.ts'),
  "article-filled": () => import('./icons/IconArticleFilled.ts'),
  "aspect-ratio-filled": () => import('./icons/IconAspectRatioFilled.ts'),
  "assembly-filled": () => import('./icons/IconAssemblyFilled.ts'),
  "asset-filled": () => import('./icons/IconAssetFilled.ts'),
  "atom-2-filled": () => import('./icons/IconAtom2Filled.ts'),
  "automatic-gearbox-filled": () => import('./icons/IconAutomaticGearboxFilled.ts'),
  "award-filled": () => import('./icons/IconAwardFilled.ts'),
  "baby-carriage-filled": () => import('./icons/IconBabyCarriageFilled.ts'),
  "backspace-filled": () => import('./icons/IconBackspaceFilled.ts'),
  "badge-3d-filled": () => import('./icons/IconBadge3dFilled.ts'),
  "badge-4k-filled": () => import('./icons/IconBadge4kFilled.ts'),
  "badge-8k-filled": () => import('./icons/IconBadge8kFilled.ts'),
  "badge-ad-filled": () => import('./icons/IconBadgeAdFilled.ts'),
  "badge-ar-filled": () => import('./icons/IconBadgeArFilled.ts'),
  "badge-cc-filled": () => import('./icons/IconBadgeCcFilled.ts'),
  "badge-hd-filled": () => import('./icons/IconBadgeHdFilled.ts'),
  "badge-sd-filled": () => import('./icons/IconBadgeSdFilled.ts'),
  "badge-tm-filled": () => import('./icons/IconBadgeTmFilled.ts'),
  "badge-vo-filled": () => import('./icons/IconBadgeVoFilled.ts'),
  "badge-vr-filled": () => import('./icons/IconBadgeVrFilled.ts'),
  "badge-wc-filled": () => import('./icons/IconBadgeWcFilled.ts'),
  "badge-filled": () => import('./icons/IconBadgeFilled.ts'),
  "badges-filled": () => import('./icons/IconBadgesFilled.ts'),
  "ball-bowling-filled": () => import('./icons/IconBallBowlingFilled.ts'),
  "balloon-filled": () => import('./icons/IconBalloonFilled.ts'),
  "ballpen-filled": () => import('./icons/IconBallpenFilled.ts'),
  "bandage-filled": () => import('./icons/IconBandageFilled.ts'),
  "barbell-filled": () => import('./icons/IconBarbellFilled.ts'),
  "barrier-block-filled": () => import('./icons/IconBarrierBlockFilled.ts'),
  "basket-filled": () => import('./icons/IconBasketFilled.ts'),
  "bath-filled": () => import('./icons/IconBathFilled.ts'),
  "battery-1-filled": () => import('./icons/IconBattery1Filled.ts'),
  "battery-2-filled": () => import('./icons/IconBattery2Filled.ts'),
  "battery-3-filled": () => import('./icons/IconBattery3Filled.ts'),
  "battery-4-filled": () => import('./icons/IconBattery4Filled.ts'),
  "battery-automotive-filled": () => import('./icons/IconBatteryAutomotiveFilled.ts'),
  "battery-vertical-1-filled": () => import('./icons/IconBatteryVertical1Filled.ts'),
  "battery-vertical-2-filled": () => import('./icons/IconBatteryVertical2Filled.ts'),
  "battery-vertical-3-filled": () => import('./icons/IconBatteryVertical3Filled.ts'),
  "battery-vertical-4-filled": () => import('./icons/IconBatteryVertical4Filled.ts'),
  "battery-vertical-filled": () => import('./icons/IconBatteryVerticalFilled.ts'),
  "battery-filled": () => import('./icons/IconBatteryFilled.ts'),
  "bed-flat-filled": () => import('./icons/IconBedFlatFilled.ts'),
  "bed-filled": () => import('./icons/IconBedFilled.ts'),
  "beer-filled": () => import('./icons/IconBeerFilled.ts'),
  "bell-minus-filled": () => import('./icons/IconBellMinusFilled.ts'),
  "bell-plus-filled": () => import('./icons/IconBellPlusFilled.ts'),
  "bell-ringing-2-filled": () => import('./icons/IconBellRinging2Filled.ts'),
  "bell-ringing-filled": () => import('./icons/IconBellRingingFilled.ts'),
  "bell-x-filled": () => import('./icons/IconBellXFilled.ts'),
  "bell-z-filled": () => import('./icons/IconBellZFilled.ts'),
  "bell-filled": () => import('./icons/IconBellFilled.ts'),
  "bike-filled": () => import('./icons/IconBikeFilled.ts'),
  "binary-tree-2-filled": () => import('./icons/IconBinaryTree2Filled.ts'),
  "binary-tree-filled": () => import('./icons/IconBinaryTreeFilled.ts'),
  "binoculars-filled": () => import('./icons/IconBinocularsFilled.ts'),
  "biohazard-filled": () => import('./icons/IconBiohazardFilled.ts'),
  "blade-filled": () => import('./icons/IconBladeFilled.ts'),
  "blender-filled": () => import('./icons/IconBlenderFilled.ts'),
  "blob-filled": () => import('./icons/IconBlobFilled.ts'),
  "bolt-filled": () => import('./icons/IconBoltFilled.ts'),
  "bomb-filled": () => import('./icons/IconBombFilled.ts'),
  "bone-filled": () => import('./icons/IconBoneFilled.ts'),
  "bong-filled": () => import('./icons/IconBongFilled.ts'),
  "book-filled": () => import('./icons/IconBookFilled.ts'),
  "bookmark-filled": () => import('./icons/IconBookmarkFilled.ts'),
  "bookmarks-filled": () => import('./icons/IconBookmarksFilled.ts'),
  "boom-filled": () => import('./icons/IconBoomFilled.ts'),
  "bottle-filled": () => import('./icons/IconBottleFilled.ts'),
  "bounce-left-filled": () => import('./icons/IconBounceLeftFilled.ts'),
  "bounce-right-filled": () => import('./icons/IconBounceRightFilled.ts'),
  "bow-filled": () => import('./icons/IconBowFilled.ts'),
  "bowl-chopsticks-filled": () => import('./icons/IconBowlChopsticksFilled.ts'),
  "bowl-spoon-filled": () => import('./icons/IconBowlSpoonFilled.ts'),
  "bowl-filled": () => import('./icons/IconBowlFilled.ts'),
  "box-align-bottom-left-filled": () => import('./icons/IconBoxAlignBottomLeftFilled.ts'),
  "box-align-bottom-right-filled": () => import('./icons/IconBoxAlignBottomRightFilled.ts'),
  "box-align-bottom-filled": () => import('./icons/IconBoxAlignBottomFilled.ts'),
  "box-align-left-filled": () => import('./icons/IconBoxAlignLeftFilled.ts'),
  "box-align-right-filled": () => import('./icons/IconBoxAlignRightFilled.ts'),
  "box-align-top-left-filled": () => import('./icons/IconBoxAlignTopLeftFilled.ts'),
  "box-align-top-right-filled": () => import('./icons/IconBoxAlignTopRightFilled.ts'),
  "box-align-top-filled": () => import('./icons/IconBoxAlignTopFilled.ts'),
  "box-multiple-filled": () => import('./icons/IconBoxMultipleFilled.ts'),
  "brand-angular-filled": () => import('./icons/IconBrandAngularFilled.ts'),
  "brand-apple-filled": () => import('./icons/IconBrandAppleFilled.ts'),
  "brand-bitbucket-filled": () => import('./icons/IconBrandBitbucketFilled.ts'),
  "brand-discord-filled": () => import('./icons/IconBrandDiscordFilled.ts'),
  "brand-dribbble-filled": () => import('./icons/IconBrandDribbbleFilled.ts'),
  "brand-facebook-filled": () => import('./icons/IconBrandFacebookFilled.ts'),
  "brand-github-filled": () => import('./icons/IconBrandGithubFilled.ts'),
  "brand-google-filled": () => import('./icons/IconBrandGoogleFilled.ts'),
  "brand-instagram-filled": () => import('./icons/IconBrandInstagramFilled.ts'),
  "brand-kick-filled": () => import('./icons/IconBrandKickFilled.ts'),
  "brand-linkedin-filled": () => import('./icons/IconBrandLinkedinFilled.ts'),
  "brand-messenger-filled": () => import('./icons/IconBrandMessengerFilled.ts'),
  "brand-open-source-filled": () => import('./icons/IconBrandOpenSourceFilled.ts'),
  "brand-opera-filled": () => import('./icons/IconBrandOperaFilled.ts'),
  "brand-patreon-filled": () => import('./icons/IconBrandPatreonFilled.ts'),
  "brand-paypal-filled": () => import('./icons/IconBrandPaypalFilled.ts'),
  "brand-pinterest-filled": () => import('./icons/IconBrandPinterestFilled.ts'),
  "brand-sketch-filled": () => import('./icons/IconBrandSketchFilled.ts'),
  "brand-snapchat-filled": () => import('./icons/IconBrandSnapchatFilled.ts'),
  "brand-spotify-filled": () => import('./icons/IconBrandSpotifyFilled.ts'),
  "brand-steam-filled": () => import('./icons/IconBrandSteamFilled.ts'),
  "brand-stripe-filled": () => import('./icons/IconBrandStripeFilled.ts'),
  "brand-tabler-filled": () => import('./icons/IconBrandTablerFilled.ts'),
  "brand-tiktok-filled": () => import('./icons/IconBrandTiktokFilled.ts'),
  "brand-tinder-filled": () => import('./icons/IconBrandTinderFilled.ts'),
  "brand-tumblr-filled": () => import('./icons/IconBrandTumblrFilled.ts'),
  "brand-twitter-filled": () => import('./icons/IconBrandTwitterFilled.ts'),
  "brand-vercel-filled": () => import('./icons/IconBrandVercelFilled.ts'),
  "brand-vimeo-filled": () => import('./icons/IconBrandVimeoFilled.ts'),
  "brand-weibo-filled": () => import('./icons/IconBrandWeiboFilled.ts'),
  "brand-whatsapp-filled": () => import('./icons/IconBrandWhatsappFilled.ts'),
  "brand-windows-filled": () => import('./icons/IconBrandWindowsFilled.ts'),
  "brand-x-filled": () => import('./icons/IconBrandXFilled.ts'),
  "brand-youtube-filled": () => import('./icons/IconBrandYoutubeFilled.ts'),
  "bread-filled": () => import('./icons/IconBreadFilled.ts'),
  "briefcase-2-filled": () => import('./icons/IconBriefcase2Filled.ts'),
  "briefcase-filled": () => import('./icons/IconBriefcaseFilled.ts'),
  "brightness-auto-filled": () => import('./icons/IconBrightnessAutoFilled.ts'),
  "brightness-down-filled": () => import('./icons/IconBrightnessDownFilled.ts'),
  "brightness-up-filled": () => import('./icons/IconBrightnessUpFilled.ts'),
  "brightness-filled": () => import('./icons/IconBrightnessFilled.ts'),
  "bubble-text-filled": () => import('./icons/IconBubbleTextFilled.ts'),
  "bubble-filled": () => import('./icons/IconBubbleFilled.ts'),
  "bug-filled": () => import('./icons/IconBugFilled.ts'),
  "building-bridge-2-filled": () => import('./icons/IconBuildingBridge2Filled.ts'),
  "building-broadcast-tower-filled": () => import('./icons/IconBuildingBroadcastTowerFilled.ts'),
  "bulb-filled": () => import('./icons/IconBulbFilled.ts'),
  "bus-filled": () => import('./icons/IconBusFilled.ts'),
  "butterfly-filled": () => import('./icons/IconButterflyFilled.ts'),
  "cactus-filled": () => import('./icons/IconCactusFilled.ts'),
  "calculator-filled": () => import('./icons/IconCalculatorFilled.ts'),
  "calendar-event-filled": () => import('./icons/IconCalendarEventFilled.ts'),
  "calendar-month-filled": () => import('./icons/IconCalendarMonthFilled.ts'),
  "calendar-week-filled": () => import('./icons/IconCalendarWeekFilled.ts'),
  "calendar-filled": () => import('./icons/IconCalendarFilled.ts'),
  "camera-filled": () => import('./icons/IconCameraFilled.ts'),
  "campfire-filled": () => import('./icons/IconCampfireFilled.ts'),
  "candle-filled": () => import('./icons/IconCandleFilled.ts'),
  "cannabis-filled": () => import('./icons/IconCannabisFilled.ts'),
  "capsule-horizontal-filled": () => import('./icons/IconCapsuleHorizontalFilled.ts'),
  "capsule-filled": () => import('./icons/IconCapsuleFilled.ts'),
  "capture-filled": () => import('./icons/IconCaptureFilled.ts'),
  "car-4wd-filled": () => import('./icons/IconCar4wdFilled.ts'),
  "car-crane-filled": () => import('./icons/IconCarCraneFilled.ts'),
  "car-fan-filled": () => import('./icons/IconCarFanFilled.ts'),
  "car-suv-filled": () => import('./icons/IconCarSuvFilled.ts'),
  "car-filled": () => import('./icons/IconCarFilled.ts'),
  "carambola-filled": () => import('./icons/IconCarambolaFilled.ts'),
  "caravan-filled": () => import('./icons/IconCaravanFilled.ts'),
  "cardboards-filled": () => import('./icons/IconCardboardsFilled.ts'),
  "cards-filled": () => import('./icons/IconCardsFilled.ts'),
  "caret-down-filled": () => import('./icons/IconCaretDownFilled.ts'),
  "caret-left-right-filled": () => import('./icons/IconCaretLeftRightFilled.ts'),
  "caret-left-filled": () => import('./icons/IconCaretLeftFilled.ts'),
  "caret-right-filled": () => import('./icons/IconCaretRightFilled.ts'),
  "caret-up-down-filled": () => import('./icons/IconCaretUpDownFilled.ts'),
  "caret-up-filled": () => import('./icons/IconCaretUpFilled.ts'),
  "carousel-horizontal-filled": () => import('./icons/IconCarouselHorizontalFilled.ts'),
  "carousel-vertical-filled": () => import('./icons/IconCarouselVerticalFilled.ts'),
  "cash-banknote-filled": () => import('./icons/IconCashBanknoteFilled.ts'),
  "category-filled": () => import('./icons/IconCategoryFilled.ts'),
  "charging-pile-filled": () => import('./icons/IconChargingPileFilled.ts'),
  "chart-area-line-filled": () => import('./icons/IconChartAreaLineFilled.ts'),
  "chart-area-filled": () => import('./icons/IconChartAreaFilled.ts'),
  "chart-bubble-filled": () => import('./icons/IconChartBubbleFilled.ts'),
  "chart-candle-filled": () => import('./icons/IconChartCandleFilled.ts'),
  "chart-donut-filled": () => import('./icons/IconChartDonutFilled.ts'),
  "chart-dots-2-filled": () => import('./icons/IconChartDots2Filled.ts'),
  "chart-dots-3-filled": () => import('./icons/IconChartDots3Filled.ts'),
  "chart-dots-filled": () => import('./icons/IconChartDotsFilled.ts'),
  "chart-funnel-filled": () => import('./icons/IconChartFunnelFilled.ts'),
  "chart-grid-dots-filled": () => import('./icons/IconChartGridDotsFilled.ts'),
  "chart-pie-2-filled": () => import('./icons/IconChartPie2Filled.ts'),
  "chart-pie-3-filled": () => import('./icons/IconChartPie3Filled.ts'),
  "chart-pie-4-filled": () => import('./icons/IconChartPie4Filled.ts'),
  "chart-pie-filled": () => import('./icons/IconChartPieFilled.ts'),
  "chef-hat-filled": () => import('./icons/IconChefHatFilled.ts'),
  "cherry-filled": () => import('./icons/IconCherryFilled.ts'),
  "chess-bishop-filled": () => import('./icons/IconChessBishopFilled.ts'),
  "chess-king-filled": () => import('./icons/IconChessKingFilled.ts'),
  "chess-knight-filled": () => import('./icons/IconChessKnightFilled.ts'),
  "chess-queen-filled": () => import('./icons/IconChessQueenFilled.ts'),
  "chess-rook-filled": () => import('./icons/IconChessRookFilled.ts'),
  "chess-filled": () => import('./icons/IconChessFilled.ts'),
  "christmas-tree-filled": () => import('./icons/IconChristmasTreeFilled.ts'),
  "circle-arrow-down-left-filled": () => import('./icons/IconCircleArrowDownLeftFilled.ts'),
  "circle-arrow-down-right-filled": () => import('./icons/IconCircleArrowDownRightFilled.ts'),
  "circle-arrow-down-filled": () => import('./icons/IconCircleArrowDownFilled.ts'),
  "circle-arrow-left-filled": () => import('./icons/IconCircleArrowLeftFilled.ts'),
  "circle-arrow-right-filled": () => import('./icons/IconCircleArrowRightFilled.ts'),
  "circle-arrow-up-left-filled": () => import('./icons/IconCircleArrowUpLeftFilled.ts'),
  "circle-arrow-up-right-filled": () => import('./icons/IconCircleArrowUpRightFilled.ts'),
  "circle-arrow-up-filled": () => import('./icons/IconCircleArrowUpFilled.ts'),
  "circle-caret-down-filled": () => import('./icons/IconCircleCaretDownFilled.ts'),
  "circle-caret-left-filled": () => import('./icons/IconCircleCaretLeftFilled.ts'),
  "circle-caret-right-filled": () => import('./icons/IconCircleCaretRightFilled.ts'),
  "circle-caret-up-filled": () => import('./icons/IconCircleCaretUpFilled.ts'),
  "circle-check-filled": () => import('./icons/IconCircleCheckFilled.ts'),
  "circle-chevron-down-filled": () => import('./icons/IconCircleChevronDownFilled.ts'),
  "circle-chevron-left-filled": () => import('./icons/IconCircleChevronLeftFilled.ts'),
  "circle-chevron-right-filled": () => import('./icons/IconCircleChevronRightFilled.ts'),
  "circle-chevron-up-filled": () => import('./icons/IconCircleChevronUpFilled.ts'),
  "circle-chevrons-down-filled": () => import('./icons/IconCircleChevronsDownFilled.ts'),
  "circle-chevrons-left-filled": () => import('./icons/IconCircleChevronsLeftFilled.ts'),
  "circle-chevrons-right-filled": () => import('./icons/IconCircleChevronsRightFilled.ts'),
  "circle-chevrons-up-filled": () => import('./icons/IconCircleChevronsUpFilled.ts'),
  "circle-dot-filled": () => import('./icons/IconCircleDotFilled.ts'),
  "circle-key-filled": () => import('./icons/IconCircleKeyFilled.ts'),
  "circle-letter-a-filled": () => import('./icons/IconCircleLetterAFilled.ts'),
  "circle-letter-b-filled": () => import('./icons/IconCircleLetterBFilled.ts'),
  "circle-letter-c-filled": () => import('./icons/IconCircleLetterCFilled.ts'),
  "circle-letter-d-filled": () => import('./icons/IconCircleLetterDFilled.ts'),
  "circle-letter-e-filled": () => import('./icons/IconCircleLetterEFilled.ts'),
  "circle-letter-f-filled": () => import('./icons/IconCircleLetterFFilled.ts'),
  "circle-letter-g-filled": () => import('./icons/IconCircleLetterGFilled.ts'),
  "circle-letter-h-filled": () => import('./icons/IconCircleLetterHFilled.ts'),
  "circle-letter-i-filled": () => import('./icons/IconCircleLetterIFilled.ts'),
  "circle-letter-j-filled": () => import('./icons/IconCircleLetterJFilled.ts'),
  "circle-letter-k-filled": () => import('./icons/IconCircleLetterKFilled.ts'),
  "circle-letter-l-filled": () => import('./icons/IconCircleLetterLFilled.ts'),
  "circle-letter-m-filled": () => import('./icons/IconCircleLetterMFilled.ts'),
  "circle-letter-n-filled": () => import('./icons/IconCircleLetterNFilled.ts'),
  "circle-letter-o-filled": () => import('./icons/IconCircleLetterOFilled.ts'),
  "circle-letter-p-filled": () => import('./icons/IconCircleLetterPFilled.ts'),
  "circle-letter-q-filled": () => import('./icons/IconCircleLetterQFilled.ts'),
  "circle-letter-r-filled": () => import('./icons/IconCircleLetterRFilled.ts'),
  "circle-letter-s-filled": () => import('./icons/IconCircleLetterSFilled.ts'),
  "circle-letter-t-filled": () => import('./icons/IconCircleLetterTFilled.ts'),
  "circle-letter-u-filled": () => import('./icons/IconCircleLetterUFilled.ts'),
  "circle-letter-v-filled": () => import('./icons/IconCircleLetterVFilled.ts'),
  "circle-letter-w-filled": () => import('./icons/IconCircleLetterWFilled.ts'),
  "circle-letter-x-filled": () => import('./icons/IconCircleLetterXFilled.ts'),
  "circle-letter-y-filled": () => import('./icons/IconCircleLetterYFilled.ts'),
  "circle-letter-z-filled": () => import('./icons/IconCircleLetterZFilled.ts'),
  "circle-number-0-filled": () => import('./icons/IconCircleNumber0Filled.ts'),
  "circle-number-1-filled": () => import('./icons/IconCircleNumber1Filled.ts'),
  "circle-number-2-filled": () => import('./icons/IconCircleNumber2Filled.ts'),
  "circle-number-3-filled": () => import('./icons/IconCircleNumber3Filled.ts'),
  "circle-number-4-filled": () => import('./icons/IconCircleNumber4Filled.ts'),
  "circle-number-5-filled": () => import('./icons/IconCircleNumber5Filled.ts'),
  "circle-number-6-filled": () => import('./icons/IconCircleNumber6Filled.ts'),
  "circle-number-7-filled": () => import('./icons/IconCircleNumber7Filled.ts'),
  "circle-number-8-filled": () => import('./icons/IconCircleNumber8Filled.ts'),
  "circle-number-9-filled": () => import('./icons/IconCircleNumber9Filled.ts'),
  "circle-percentage-filled": () => import('./icons/IconCirclePercentageFilled.ts'),
  "circle-plus-filled": () => import('./icons/IconCirclePlusFilled.ts'),
  "circle-rectangle-filled": () => import('./icons/IconCircleRectangleFilled.ts'),
  "circle-x-filled": () => import('./icons/IconCircleXFilled.ts'),
  "circle-filled": () => import('./icons/IconCircleFilled.ts'),
  "circles-filled": () => import('./icons/IconCirclesFilled.ts'),
  "clipboard-check-filled": () => import('./icons/IconClipboardCheckFilled.ts'),
  "clipboard-data-filled": () => import('./icons/IconClipboardDataFilled.ts'),
  "clipboard-list-filled": () => import('./icons/IconClipboardListFilled.ts'),
  "clipboard-plus-filled": () => import('./icons/IconClipboardPlusFilled.ts'),
  "clipboard-smile-filled": () => import('./icons/IconClipboardSmileFilled.ts'),
  "clipboard-text-filled": () => import('./icons/IconClipboardTextFilled.ts'),
  "clipboard-typography-filled": () => import('./icons/IconClipboardTypographyFilled.ts'),
  "clipboard-x-filled": () => import('./icons/IconClipboardXFilled.ts'),
  "clipboard-filled": () => import('./icons/IconClipboardFilled.ts'),
  "clock-hour-1-filled": () => import('./icons/IconClockHour1Filled.ts'),
  "clock-hour-10-filled": () => import('./icons/IconClockHour10Filled.ts'),
  "clock-hour-11-filled": () => import('./icons/IconClockHour11Filled.ts'),
  "clock-hour-12-filled": () => import('./icons/IconClockHour12Filled.ts'),
  "clock-hour-2-filled": () => import('./icons/IconClockHour2Filled.ts'),
  "clock-hour-3-filled": () => import('./icons/IconClockHour3Filled.ts'),
  "clock-hour-4-filled": () => import('./icons/IconClockHour4Filled.ts'),
  "clock-hour-5-filled": () => import('./icons/IconClockHour5Filled.ts'),
  "clock-hour-6-filled": () => import('./icons/IconClockHour6Filled.ts'),
  "clock-hour-7-filled": () => import('./icons/IconClockHour7Filled.ts'),
  "clock-hour-8-filled": () => import('./icons/IconClockHour8Filled.ts'),
  "clock-hour-9-filled": () => import('./icons/IconClockHour9Filled.ts'),
  "clock-filled": () => import('./icons/IconClockFilled.ts'),
  "cloud-computing-filled": () => import('./icons/IconCloudComputingFilled.ts'),
  "cloud-data-connection-filled": () => import('./icons/IconCloudDataConnectionFilled.ts'),
  "cloud-filled": () => import('./icons/IconCloudFilled.ts'),
  "clover-filled": () => import('./icons/IconCloverFilled.ts'),
  "clubs-filled": () => import('./icons/IconClubsFilled.ts'),
  "code-circle-2-filled": () => import('./icons/IconCodeCircle2Filled.ts'),
  "code-circle-filled": () => import('./icons/IconCodeCircleFilled.ts'),
  "coin-bitcoin-filled": () => import('./icons/IconCoinBitcoinFilled.ts'),
  "coin-euro-filled": () => import('./icons/IconCoinEuroFilled.ts'),
  "coin-monero-filled": () => import('./icons/IconCoinMoneroFilled.ts'),
  "coin-pound-filled": () => import('./icons/IconCoinPoundFilled.ts'),
  "coin-rupee-filled": () => import('./icons/IconCoinRupeeFilled.ts'),
  "coin-taka-filled": () => import('./icons/IconCoinTakaFilled.ts'),
  "coin-yen-filled": () => import('./icons/IconCoinYenFilled.ts'),
  "coin-yuan-filled": () => import('./icons/IconCoinYuanFilled.ts'),
  "coin-filled": () => import('./icons/IconCoinFilled.ts'),
  "columns-1-filled": () => import('./icons/IconColumns1Filled.ts'),
  "columns-2-filled": () => import('./icons/IconColumns2Filled.ts'),
  "columns-3-filled": () => import('./icons/IconColumns3Filled.ts'),
  "compass-filled": () => import('./icons/IconCompassFilled.ts'),
  "cone-2-filled": () => import('./icons/IconCone2Filled.ts'),
  "cone-filled": () => import('./icons/IconConeFilled.ts'),
  "confetti-filled": () => import('./icons/IconConfettiFilled.ts'),
  "container-filled": () => import('./icons/IconContainerFilled.ts'),
  "contrast-2-filled": () => import('./icons/IconContrast2Filled.ts'),
  "contrast-filled": () => import('./icons/IconContrastFilled.ts'),
  "cookie-man-filled": () => import('./icons/IconCookieManFilled.ts'),
  "cookie-filled": () => import('./icons/IconCookieFilled.ts'),
  "copy-check-filled": () => import('./icons/IconCopyCheckFilled.ts'),
  "copy-minus-filled": () => import('./icons/IconCopyMinusFilled.ts'),
  "copy-plus-filled": () => import('./icons/IconCopyPlusFilled.ts'),
  "copy-x-filled": () => import('./icons/IconCopyXFilled.ts'),
  "copyleft-filled": () => import('./icons/IconCopyleftFilled.ts'),
  "copyright-filled": () => import('./icons/IconCopyrightFilled.ts'),
  "credit-card-filled": () => import('./icons/IconCreditCardFilled.ts'),
  "crop-1-1-filled": () => import('./icons/IconCrop11Filled.ts'),
  "crop-16-9-filled": () => import('./icons/IconCrop169Filled.ts'),
  "crop-3-2-filled": () => import('./icons/IconCrop32Filled.ts'),
  "crop-5-4-filled": () => import('./icons/IconCrop54Filled.ts'),
  "crop-7-5-filled": () => import('./icons/IconCrop75Filled.ts'),
  "crop-landscape-filled": () => import('./icons/IconCropLandscapeFilled.ts'),
  "crop-portrait-filled": () => import('./icons/IconCropPortraitFilled.ts'),
  "cross-filled": () => import('./icons/IconCrossFilled.ts'),
  "crown-filled": () => import('./icons/IconCrownFilled.ts'),
  "current-location-filled": () => import('./icons/IconCurrentLocationFilled.ts'),
  "dashboard-filled": () => import('./icons/IconDashboardFilled.ts'),
  "device-cctv-filled": () => import('./icons/IconDeviceCctvFilled.ts'),
  "device-desktop-filled": () => import('./icons/IconDeviceDesktopFilled.ts'),
  "device-gamepad-3-filled": () => import('./icons/IconDeviceGamepad3Filled.ts'),
  "device-gamepad-filled": () => import('./icons/IconDeviceGamepadFilled.ts'),
  "device-heart-monitor-filled": () => import('./icons/IconDeviceHeartMonitorFilled.ts'),
  "device-imac-filled": () => import('./icons/IconDeviceImacFilled.ts'),
  "device-ipad-filled": () => import('./icons/IconDeviceIpadFilled.ts'),
  "device-mobile-filled": () => import('./icons/IconDeviceMobileFilled.ts'),
  "device-remote-filled": () => import('./icons/IconDeviceRemoteFilled.ts'),
  "device-speaker-filled": () => import('./icons/IconDeviceSpeakerFilled.ts'),
  "device-tablet-filled": () => import('./icons/IconDeviceTabletFilled.ts'),
  "device-tv-old-filled": () => import('./icons/IconDeviceTvOldFilled.ts'),
  "device-tv-filled": () => import('./icons/IconDeviceTvFilled.ts'),
  "device-unknown-filled": () => import('./icons/IconDeviceUnknownFilled.ts'),
  "device-usb-filled": () => import('./icons/IconDeviceUsbFilled.ts'),
  "device-vision-pro-filled": () => import('./icons/IconDeviceVisionProFilled.ts'),
  "device-watch-filled": () => import('./icons/IconDeviceWatchFilled.ts'),
  "dialpad-filled": () => import('./icons/IconDialpadFilled.ts'),
  "diamond-filled": () => import('./icons/IconDiamondFilled.ts'),
  "diamonds-filled": () => import('./icons/IconDiamondsFilled.ts'),
  "dice-1-filled": () => import('./icons/IconDice1Filled.ts'),
  "dice-2-filled": () => import('./icons/IconDice2Filled.ts'),
  "dice-3-filled": () => import('./icons/IconDice3Filled.ts'),
  "dice-4-filled": () => import('./icons/IconDice4Filled.ts'),
  "dice-5-filled": () => import('./icons/IconDice5Filled.ts'),
  "dice-6-filled": () => import('./icons/IconDice6Filled.ts'),
  "dice-filled": () => import('./icons/IconDiceFilled.ts'),
  "direction-arrows-filled": () => import('./icons/IconDirectionArrowsFilled.ts'),
  "direction-sign-filled": () => import('./icons/IconDirectionSignFilled.ts'),
  "directions-filled": () => import('./icons/IconDirectionsFilled.ts'),
  "disc-filled": () => import('./icons/IconDiscFilled.ts'),
  "discount-filled": () => import('./icons/IconDiscountFilled.ts'),
  "drop-circle-filled": () => import('./icons/IconDropCircleFilled.ts'),
  "droplet-half-2-filled": () => import('./icons/IconDropletHalf2Filled.ts'),
  "droplet-half-filled": () => import('./icons/IconDropletHalfFilled.ts'),
  "droplet-filled": () => import('./icons/IconDropletFilled.ts'),
  "droplets-filled": () => import('./icons/IconDropletsFilled.ts'),
  "dual-screen-filled": () => import('./icons/IconDualScreenFilled.ts'),
  "dumpling-filled": () => import('./icons/IconDumplingFilled.ts'),
  "ease-in-control-point-filled": () => import('./icons/IconEaseInControlPointFilled.ts'),
  "ease-in-out-control-points-filled": () => import('./icons/IconEaseInOutControlPointsFilled.ts'),
  "ease-out-control-point-filled": () => import('./icons/IconEaseOutControlPointFilled.ts'),
  "egg-cracked-filled": () => import('./icons/IconEggCrackedFilled.ts'),
  "egg-fried-filled": () => import('./icons/IconEggFriedFilled.ts'),
  "egg-filled": () => import('./icons/IconEggFilled.ts'),
  "elevator-filled": () => import('./icons/IconElevatorFilled.ts'),
  "engine-filled": () => import('./icons/IconEngineFilled.ts'),
  "escalator-down-filled": () => import('./icons/IconEscalatorDownFilled.ts'),
  "escalator-up-filled": () => import('./icons/IconEscalatorUpFilled.ts'),
  "escalator-filled": () => import('./icons/IconEscalatorFilled.ts'),
  "exchange-filled": () => import('./icons/IconExchangeFilled.ts'),
  "exclamation-circle-filled": () => import('./icons/IconExclamationCircleFilled.ts'),
  "explicit-filled": () => import('./icons/IconExplicitFilled.ts'),
  "exposure-filled": () => import('./icons/IconExposureFilled.ts'),
  "eye-table-filled": () => import('./icons/IconEyeTableFilled.ts'),
  "eye-filled": () => import('./icons/IconEyeFilled.ts'),
  "eyeglass-2-filled": () => import('./icons/IconEyeglass2Filled.ts'),
  "eyeglass-filled": () => import('./icons/IconEyeglassFilled.ts'),
  "face-mask-filled": () => import('./icons/IconFaceMaskFilled.ts'),
  "favicon-filled": () => import('./icons/IconFaviconFilled.ts'),
  "feather-filled": () => import('./icons/IconFeatherFilled.ts'),
  "fence-filled": () => import('./icons/IconFenceFilled.ts'),
  "ferry-filled": () => import('./icons/IconFerryFilled.ts'),
  "fidget-spinner-filled": () => import('./icons/IconFidgetSpinnerFilled.ts'),
  "file-analytics-filled": () => import('./icons/IconFileAnalyticsFilled.ts'),
  "file-check-filled": () => import('./icons/IconFileCheckFilled.ts'),
  "file-code-2-filled": () => import('./icons/IconFileCode2Filled.ts'),
  "file-code-filled": () => import('./icons/IconFileCodeFilled.ts'),
  "file-cv-filled": () => import('./icons/IconFileCvFilled.ts'),
  "file-delta-filled": () => import('./icons/IconFileDeltaFilled.ts'),
  "file-description-filled": () => import('./icons/IconFileDescriptionFilled.ts'),
  "file-diff-filled": () => import('./icons/IconFileDiffFilled.ts'),
  "file-digit-filled": () => import('./icons/IconFileDigitFilled.ts'),
  "file-dollar-filled": () => import('./icons/IconFileDollarFilled.ts'),
  "file-dots-filled": () => import('./icons/IconFileDotsFilled.ts'),
  "file-download-filled": () => import('./icons/IconFileDownloadFilled.ts'),
  "file-euro-filled": () => import('./icons/IconFileEuroFilled.ts'),
  "file-function-filled": () => import('./icons/IconFileFunctionFilled.ts'),
  "file-horizontal-filled": () => import('./icons/IconFileHorizontalFilled.ts'),
  "file-info-filled": () => import('./icons/IconFileInfoFilled.ts'),
  "file-invoice-filled": () => import('./icons/IconFileInvoiceFilled.ts'),
  "file-lambda-filled": () => import('./icons/IconFileLambdaFilled.ts'),
  "file-minus-filled": () => import('./icons/IconFileMinusFilled.ts'),
  "file-music-filled": () => import('./icons/IconFileMusicFilled.ts'),
  "file-neutral-filled": () => import('./icons/IconFileNeutralFilled.ts'),
  "file-pencil-filled": () => import('./icons/IconFilePencilFilled.ts'),
  "file-percent-filled": () => import('./icons/IconFilePercentFilled.ts'),
  "file-phone-filled": () => import('./icons/IconFilePhoneFilled.ts'),
  "file-power-filled": () => import('./icons/IconFilePowerFilled.ts'),
  "file-rss-filled": () => import('./icons/IconFileRssFilled.ts'),
  "file-sad-filled": () => import('./icons/IconFileSadFilled.ts'),
  "file-scissors-filled": () => import('./icons/IconFileScissorsFilled.ts'),
  "file-settings-filled": () => import('./icons/IconFileSettingsFilled.ts'),
  "file-signal-filled": () => import('./icons/IconFileSignalFilled.ts'),
  "file-smile-filled": () => import('./icons/IconFileSmileFilled.ts'),
  "file-star-filled": () => import('./icons/IconFileStarFilled.ts'),
  "file-text-filled": () => import('./icons/IconFileTextFilled.ts'),
  "file-time-filled": () => import('./icons/IconFileTimeFilled.ts'),
  "file-typography-filled": () => import('./icons/IconFileTypographyFilled.ts'),
  "file-unknown-filled": () => import('./icons/IconFileUnknownFilled.ts'),
  "file-upload-filled": () => import('./icons/IconFileUploadFilled.ts'),
  "file-vector-filled": () => import('./icons/IconFileVectorFilled.ts'),
  "file-x-filled": () => import('./icons/IconFileXFilled.ts'),
  "file-filled": () => import('./icons/IconFileFilled.ts'),
  "files-filled": () => import('./icons/IconFilesFilled.ts'),
  "filter-filled": () => import('./icons/IconFilterFilled.ts'),
  "filters-filled": () => import('./icons/IconFiltersFilled.ts'),
  "fish-bone-filled": () => import('./icons/IconFishBoneFilled.ts'),
  "flag-2-filled": () => import('./icons/IconFlag2Filled.ts'),
  "flag-3-filled": () => import('./icons/IconFlag3Filled.ts'),
  "flag-filled": () => import('./icons/IconFlagFilled.ts'),
  "flame-filled": () => import('./icons/IconFlameFilled.ts'),
  "flare-filled": () => import('./icons/IconFlareFilled.ts'),
  "flask-2-filled": () => import('./icons/IconFlask2Filled.ts'),
  "flask-filled": () => import('./icons/IconFlaskFilled.ts'),
  "flower-filled": () => import('./icons/IconFlowerFilled.ts'),
  "folder-open-filled": () => import('./icons/IconFolderOpenFilled.ts'),
  "folder-filled": () => import('./icons/IconFolderFilled.ts'),
  "folders-filled": () => import('./icons/IconFoldersFilled.ts'),
  "forbid-2-filled": () => import('./icons/IconForbid2Filled.ts'),
  "forbid-filled": () => import('./icons/IconForbidFilled.ts'),
  "fountain-filled": () => import('./icons/IconFountainFilled.ts'),
  "function-filled": () => import('./icons/IconFunctionFilled.ts'),
  "garden-cart-filled": () => import('./icons/IconGardenCartFilled.ts'),
  "gas-station-filled": () => import('./icons/IconGasStationFilled.ts'),
  "gauge-filled": () => import('./icons/IconGaugeFilled.ts'),
  "ghost-2-filled": () => import('./icons/IconGhost2Filled.ts'),
  "ghost-3-filled": () => import('./icons/IconGhost3Filled.ts'),
  "ghost-filled": () => import('./icons/IconGhostFilled.ts'),
  "gift-card-filled": () => import('./icons/IconGiftCardFilled.ts'),
  "gift-filled": () => import('./icons/IconGiftFilled.ts'),
  "glass-full-filled": () => import('./icons/IconGlassFullFilled.ts'),
  "glass-filled": () => import('./icons/IconGlassFilled.ts'),
  "globe-filled": () => import('./icons/IconGlobeFilled.ts'),
  "golf-filled": () => import('./icons/IconGolfFilled.ts'),
  "gps-filled": () => import('./icons/IconGpsFilled.ts'),
  "graph-filled": () => import('./icons/IconGraphFilled.ts'),
  "grid-pattern-filled": () => import('./icons/IconGridPatternFilled.ts'),
  "guitar-pick-filled": () => import('./icons/IconGuitarPickFilled.ts'),
  "hanger-2-filled": () => import('./icons/IconHanger2Filled.ts'),
  "headphones-filled": () => import('./icons/IconHeadphonesFilled.ts'),
  "heart-broken-filled": () => import('./icons/IconHeartBrokenFilled.ts'),
  "heart-filled": () => import('./icons/IconHeartFilled.ts'),
  "helicopter-landing-filled": () => import('./icons/IconHelicopterLandingFilled.ts'),
  "helicopter-filled": () => import('./icons/IconHelicopterFilled.ts'),
  "help-circle-filled": () => import('./icons/IconHelpCircleFilled.ts'),
  "help-hexagon-filled": () => import('./icons/IconHelpHexagonFilled.ts'),
  "help-octagon-filled": () => import('./icons/IconHelpOctagonFilled.ts'),
  "help-square-rounded-filled": () => import('./icons/IconHelpSquareRoundedFilled.ts'),
  "help-square-filled": () => import('./icons/IconHelpSquareFilled.ts'),
  "help-triangle-filled": () => import('./icons/IconHelpTriangleFilled.ts'),
  "hexagon-letter-a-filled": () => import('./icons/IconHexagonLetterAFilled.ts'),
  "hexagon-letter-b-filled": () => import('./icons/IconHexagonLetterBFilled.ts'),
  "hexagon-letter-c-filled": () => import('./icons/IconHexagonLetterCFilled.ts'),
  "hexagon-letter-d-filled": () => import('./icons/IconHexagonLetterDFilled.ts'),
  "hexagon-letter-e-filled": () => import('./icons/IconHexagonLetterEFilled.ts'),
  "hexagon-letter-f-filled": () => import('./icons/IconHexagonLetterFFilled.ts'),
  "hexagon-letter-g-filled": () => import('./icons/IconHexagonLetterGFilled.ts'),
  "hexagon-letter-h-filled": () => import('./icons/IconHexagonLetterHFilled.ts'),
  "hexagon-letter-i-filled": () => import('./icons/IconHexagonLetterIFilled.ts'),
  "hexagon-letter-j-filled": () => import('./icons/IconHexagonLetterJFilled.ts'),
  "hexagon-letter-k-filled": () => import('./icons/IconHexagonLetterKFilled.ts'),
  "hexagon-letter-l-filled": () => import('./icons/IconHexagonLetterLFilled.ts'),
  "hexagon-letter-m-filled": () => import('./icons/IconHexagonLetterMFilled.ts'),
  "hexagon-letter-n-filled": () => import('./icons/IconHexagonLetterNFilled.ts'),
  "hexagon-letter-o-filled": () => import('./icons/IconHexagonLetterOFilled.ts'),
  "hexagon-letter-p-filled": () => import('./icons/IconHexagonLetterPFilled.ts'),
  "hexagon-letter-q-filled": () => import('./icons/IconHexagonLetterQFilled.ts'),
  "hexagon-letter-r-filled": () => import('./icons/IconHexagonLetterRFilled.ts'),
  "hexagon-letter-s-filled": () => import('./icons/IconHexagonLetterSFilled.ts'),
  "hexagon-letter-t-filled": () => import('./icons/IconHexagonLetterTFilled.ts'),
  "hexagon-letter-u-filled": () => import('./icons/IconHexagonLetterUFilled.ts'),
  "hexagon-letter-v-filled": () => import('./icons/IconHexagonLetterVFilled.ts'),
  "hexagon-letter-w-filled": () => import('./icons/IconHexagonLetterWFilled.ts'),
  "hexagon-letter-x-filled": () => import('./icons/IconHexagonLetterXFilled.ts'),
  "hexagon-letter-y-filled": () => import('./icons/IconHexagonLetterYFilled.ts'),
  "hexagon-letter-z-filled": () => import('./icons/IconHexagonLetterZFilled.ts'),
  "hexagon-minus-filled": () => import('./icons/IconHexagonMinusFilled.ts'),
  "hexagon-number-0-filled": () => import('./icons/IconHexagonNumber0Filled.ts'),
  "hexagon-number-1-filled": () => import('./icons/IconHexagonNumber1Filled.ts'),
  "hexagon-number-2-filled": () => import('./icons/IconHexagonNumber2Filled.ts'),
  "hexagon-number-3-filled": () => import('./icons/IconHexagonNumber3Filled.ts'),
  "hexagon-number-4-filled": () => import('./icons/IconHexagonNumber4Filled.ts'),
  "hexagon-number-5-filled": () => import('./icons/IconHexagonNumber5Filled.ts'),
  "hexagon-number-6-filled": () => import('./icons/IconHexagonNumber6Filled.ts'),
  "hexagon-number-7-filled": () => import('./icons/IconHexagonNumber7Filled.ts'),
  "hexagon-number-8-filled": () => import('./icons/IconHexagonNumber8Filled.ts'),
  "hexagon-number-9-filled": () => import('./icons/IconHexagonNumber9Filled.ts'),
  "hexagon-plus-filled": () => import('./icons/IconHexagonPlusFilled.ts'),
  "hexagon-filled": () => import('./icons/IconHexagonFilled.ts'),
  "home-filled": () => import('./icons/IconHomeFilled.ts'),
  "hospital-circle-filled": () => import('./icons/IconHospitalCircleFilled.ts'),
  "hourglass-filled": () => import('./icons/IconHourglassFilled.ts'),
  "icons-filled": () => import('./icons/IconIconsFilled.ts'),
  "info-circle-filled": () => import('./icons/IconInfoCircleFilled.ts'),
  "info-hexagon-filled": () => import('./icons/IconInfoHexagonFilled.ts'),
  "info-octagon-filled": () => import('./icons/IconInfoOctagonFilled.ts'),
  "info-square-rounded-filled": () => import('./icons/IconInfoSquareRoundedFilled.ts'),
  "info-square-filled": () => import('./icons/IconInfoSquareFilled.ts'),
  "info-triangle-filled": () => import('./icons/IconInfoTriangleFilled.ts'),
  "inner-shadow-bottom-left-filled": () => import('./icons/IconInnerShadowBottomLeftFilled.ts'),
  "inner-shadow-bottom-right-filled": () => import('./icons/IconInnerShadowBottomRightFilled.ts'),
  "inner-shadow-bottom-filled": () => import('./icons/IconInnerShadowBottomFilled.ts'),
  "inner-shadow-left-filled": () => import('./icons/IconInnerShadowLeftFilled.ts'),
  "inner-shadow-right-filled": () => import('./icons/IconInnerShadowRightFilled.ts'),
  "inner-shadow-top-left-filled": () => import('./icons/IconInnerShadowTopLeftFilled.ts'),
  "inner-shadow-top-right-filled": () => import('./icons/IconInnerShadowTopRightFilled.ts'),
  "inner-shadow-top-filled": () => import('./icons/IconInnerShadowTopFilled.ts'),
  "ironing-1-filled": () => import('./icons/IconIroning1Filled.ts'),
  "ironing-2-filled": () => import('./icons/IconIroning2Filled.ts'),
  "ironing-3-filled": () => import('./icons/IconIroning3Filled.ts'),
  "ironing-steam-filled": () => import('./icons/IconIroningSteamFilled.ts'),
  "ironing-filled": () => import('./icons/IconIroningFilled.ts'),
  "jetpack-filled": () => import('./icons/IconJetpackFilled.ts'),
  "jewish-star-filled": () => import('./icons/IconJewishStarFilled.ts'),
  "key-filled": () => import('./icons/IconKeyFilled.ts'),
  "keyboard-filled": () => import('./icons/IconKeyboardFilled.ts'),
  "keyframe-align-center-filled": () => import('./icons/IconKeyframeAlignCenterFilled.ts'),
  "keyframe-align-horizontal-filled": () => import('./icons/IconKeyframeAlignHorizontalFilled.ts'),
  "keyframe-align-vertical-filled": () => import('./icons/IconKeyframeAlignVerticalFilled.ts'),
  "keyframe-filled": () => import('./icons/IconKeyframeFilled.ts'),
  "keyframes-filled": () => import('./icons/IconKeyframesFilled.ts'),
  "label-important-filled": () => import('./icons/IconLabelImportantFilled.ts'),
  "label-filled": () => import('./icons/IconLabelFilled.ts'),
  "lasso-polygon-filled": () => import('./icons/IconLassoPolygonFilled.ts'),
  "laurel-wreath-1-filled": () => import('./icons/IconLaurelWreath1Filled.ts'),
  "laurel-wreath-2-filled": () => import('./icons/IconLaurelWreath2Filled.ts'),
  "laurel-wreath-3-filled": () => import('./icons/IconLaurelWreath3Filled.ts'),
  "laurel-wreath-filled": () => import('./icons/IconLaurelWreathFilled.ts'),
  "layout-2-filled": () => import('./icons/IconLayout2Filled.ts'),
  "layout-align-bottom-filled": () => import('./icons/IconLayoutAlignBottomFilled.ts'),
  "layout-align-center-filled": () => import('./icons/IconLayoutAlignCenterFilled.ts'),
  "layout-align-left-filled": () => import('./icons/IconLayoutAlignLeftFilled.ts'),
  "layout-align-middle-filled": () => import('./icons/IconLayoutAlignMiddleFilled.ts'),
  "layout-align-right-filled": () => import('./icons/IconLayoutAlignRightFilled.ts'),
  "layout-align-top-filled": () => import('./icons/IconLayoutAlignTopFilled.ts'),
  "layout-board-split-filled": () => import('./icons/IconLayoutBoardSplitFilled.ts'),
  "layout-board-filled": () => import('./icons/IconLayoutBoardFilled.ts'),
  "layout-bottombar-collapse-filled": () => import('./icons/IconLayoutBottombarCollapseFilled.ts'),
  "layout-bottombar-expand-filled": () => import('./icons/IconLayoutBottombarExpandFilled.ts'),
  "layout-bottombar-filled": () => import('./icons/IconLayoutBottombarFilled.ts'),
  "layout-cards-filled": () => import('./icons/IconLayoutCardsFilled.ts'),
  "layout-dashboard-filled": () => import('./icons/IconLayoutDashboardFilled.ts'),
  "layout-distribute-horizontal-filled": () => import('./icons/IconLayoutDistributeHorizontalFilled.ts'),
  "layout-distribute-vertical-filled": () => import('./icons/IconLayoutDistributeVerticalFilled.ts'),
  "layout-grid-filled": () => import('./icons/IconLayoutGridFilled.ts'),
  "layout-kanban-filled": () => import('./icons/IconLayoutKanbanFilled.ts'),
  "layout-list-filled": () => import('./icons/IconLayoutListFilled.ts'),
  "layout-navbar-collapse-filled": () => import('./icons/IconLayoutNavbarCollapseFilled.ts'),
  "layout-navbar-expand-filled": () => import('./icons/IconLayoutNavbarExpandFilled.ts'),
  "layout-navbar-filled": () => import('./icons/IconLayoutNavbarFilled.ts'),
  "layout-sidebar-left-collapse-filled": () => import('./icons/IconLayoutSidebarLeftCollapseFilled.ts'),
  "layout-sidebar-left-expand-filled": () => import('./icons/IconLayoutSidebarLeftExpandFilled.ts'),
  "layout-sidebar-right-collapse-filled": () => import('./icons/IconLayoutSidebarRightCollapseFilled.ts'),
  "layout-sidebar-right-expand-filled": () => import('./icons/IconLayoutSidebarRightExpandFilled.ts'),
  "layout-sidebar-right-filled": () => import('./icons/IconLayoutSidebarRightFilled.ts'),
  "layout-sidebar-filled": () => import('./icons/IconLayoutSidebarFilled.ts'),
  "layout-filled": () => import('./icons/IconLayoutFilled.ts'),
  "leaf-filled": () => import('./icons/IconLeafFilled.ts'),
  "lego-filled": () => import('./icons/IconLegoFilled.ts'),
  "lemon-2-filled": () => import('./icons/IconLemon2Filled.ts'),
  "library-plus-filled": () => import('./icons/IconLibraryPlusFilled.ts'),
  "library-filled": () => import('./icons/IconLibraryFilled.ts'),
  "lifebuoy-filled": () => import('./icons/IconLifebuoyFilled.ts'),
  "live-photo-filled": () => import('./icons/IconLivePhotoFilled.ts'),
  "live-view-filled": () => import('./icons/IconLiveViewFilled.ts'),
  "location-filled": () => import('./icons/IconLocationFilled.ts'),
  "lock-square-rounded-filled": () => import('./icons/IconLockSquareRoundedFilled.ts'),
  "lock-filled": () => import('./icons/IconLockFilled.ts'),
  "lungs-filled": () => import('./icons/IconLungsFilled.ts'),
  "macro-filled": () => import('./icons/IconMacroFilled.ts'),
  "magnet-filled": () => import('./icons/IconMagnetFilled.ts'),
  "mail-opened-filled": () => import('./icons/IconMailOpenedFilled.ts'),
  "mail-filled": () => import('./icons/IconMailFilled.ts'),
  "man-filled": () => import('./icons/IconManFilled.ts'),
  "manual-gearbox-filled": () => import('./icons/IconManualGearboxFilled.ts'),
  "map-pin-filled": () => import('./icons/IconMapPinFilled.ts'),
  "medical-cross-filled": () => import('./icons/IconMedicalCrossFilled.ts'),
  "meeple-filled": () => import('./icons/IconMeepleFilled.ts'),
  "melon-filled": () => import('./icons/IconMelonFilled.ts'),
  "message-2-filled": () => import('./icons/IconMessage2Filled.ts'),
  "message-chatbot-filled": () => import('./icons/IconMessageChatbotFilled.ts'),
  "message-circle-filled": () => import('./icons/IconMessageCircleFilled.ts'),
  "message-report-filled": () => import('./icons/IconMessageReportFilled.ts'),
  "message-filled": () => import('./icons/IconMessageFilled.ts'),
  "meteor-filled": () => import('./icons/IconMeteorFilled.ts'),
  "michelin-star-filled": () => import('./icons/IconMichelinStarFilled.ts'),
  "mickey-filled": () => import('./icons/IconMickeyFilled.ts'),
  "microphone-filled": () => import('./icons/IconMicrophoneFilled.ts'),
  "microscope-filled": () => import('./icons/IconMicroscopeFilled.ts'),
  "microwave-filled": () => import('./icons/IconMicrowaveFilled.ts'),
  "military-rank-filled": () => import('./icons/IconMilitaryRankFilled.ts'),
  "milk-filled": () => import('./icons/IconMilkFilled.ts'),
  "mood-angry-filled": () => import('./icons/IconMoodAngryFilled.ts'),
  "mood-confuzed-filled": () => import('./icons/IconMoodConfuzedFilled.ts'),
  "mood-crazy-happy-filled": () => import('./icons/IconMoodCrazyHappyFilled.ts'),
  "mood-empty-filled": () => import('./icons/IconMoodEmptyFilled.ts'),
  "mood-happy-filled": () => import('./icons/IconMoodHappyFilled.ts'),
  "mood-kid-filled": () => import('./icons/IconMoodKidFilled.ts'),
  "mood-neutral-filled": () => import('./icons/IconMoodNeutralFilled.ts'),
  "mood-sad-filled": () => import('./icons/IconMoodSadFilled.ts'),
  "mood-smile-filled": () => import('./icons/IconMoodSmileFilled.ts'),
  "mood-wrrr-filled": () => import('./icons/IconMoodWrrrFilled.ts'),
  "moon-filled": () => import('./icons/IconMoonFilled.ts'),
  "motorbike-filled": () => import('./icons/IconMotorbikeFilled.ts'),
  "mountain-filled": () => import('./icons/IconMountainFilled.ts'),
  "mouse-filled": () => import('./icons/IconMouseFilled.ts'),
  "mug-filled": () => import('./icons/IconMugFilled.ts'),
  "mushroom-filled": () => import('./icons/IconMushroomFilled.ts'),
  "navigation-filled": () => import('./icons/IconNavigationFilled.ts'),
  "nurse-filled": () => import('./icons/IconNurseFilled.ts'),
  "octagon-minus-filled": () => import('./icons/IconOctagonMinusFilled.ts'),
  "octagon-plus-filled": () => import('./icons/IconOctagonPlusFilled.ts'),
  "octagon-filled": () => import('./icons/IconOctagonFilled.ts'),
  "oval-vertical-filled": () => import('./icons/IconOvalVerticalFilled.ts'),
  "oval-filled": () => import('./icons/IconOvalFilled.ts'),
  "pacman-filled": () => import('./icons/IconPacmanFilled.ts'),
  "paint-filled": () => import('./icons/IconPaintFilled.ts'),
  "palette-filled": () => import('./icons/IconPaletteFilled.ts'),
  "panorama-horizontal-filled": () => import('./icons/IconPanoramaHorizontalFilled.ts'),
  "panorama-vertical-filled": () => import('./icons/IconPanoramaVerticalFilled.ts'),
  "parking-circle-filled": () => import('./icons/IconParkingCircleFilled.ts'),
  "paw-filled": () => import('./icons/IconPawFilled.ts'),
  "pennant-2-filled": () => import('./icons/IconPennant2Filled.ts'),
  "pennant-filled": () => import('./icons/IconPennantFilled.ts'),
  "pentagon-filled": () => import('./icons/IconPentagonFilled.ts'),
  "phone-call-filled": () => import('./icons/IconPhoneCallFilled.ts'),
  "phone-calling-filled": () => import('./icons/IconPhoneCallingFilled.ts'),
  "phone-check-filled": () => import('./icons/IconPhoneCheckFilled.ts'),
  "phone-x-filled": () => import('./icons/IconPhoneXFilled.ts'),
  "phone-filled": () => import('./icons/IconPhoneFilled.ts'),
  "photo-filled": () => import('./icons/IconPhotoFilled.ts'),
  "picture-in-picture-top-filled": () => import('./icons/IconPictureInPictureTopFilled.ts'),
  "picture-in-picture-filled": () => import('./icons/IconPictureInPictureFilled.ts'),
  "pig-filled": () => import('./icons/IconPigFilled.ts'),
  "pill-filled": () => import('./icons/IconPillFilled.ts'),
  "pin-filled": () => import('./icons/IconPinFilled.ts'),
  "pinned-filled": () => import('./icons/IconPinnedFilled.ts'),
  "pizza-filled": () => import('./icons/IconPizzaFilled.ts'),
  "plane-arrival-filled": () => import('./icons/IconPlaneArrivalFilled.ts'),
  "plane-departure-filled": () => import('./icons/IconPlaneDepartureFilled.ts'),
  "plane-tilt-filled": () => import('./icons/IconPlaneTiltFilled.ts'),
  "plane-filled": () => import('./icons/IconPlaneFilled.ts'),
  "play-card-1-filled": () => import('./icons/IconPlayCard1Filled.ts'),
  "play-card-10-filled": () => import('./icons/IconPlayCard10Filled.ts'),
  "play-card-2-filled": () => import('./icons/IconPlayCard2Filled.ts'),
  "play-card-3-filled": () => import('./icons/IconPlayCard3Filled.ts'),
  "play-card-4-filled": () => import('./icons/IconPlayCard4Filled.ts'),
  "play-card-5-filled": () => import('./icons/IconPlayCard5Filled.ts'),
  "play-card-6-filled": () => import('./icons/IconPlayCard6Filled.ts'),
  "play-card-7-filled": () => import('./icons/IconPlayCard7Filled.ts'),
  "play-card-8-filled": () => import('./icons/IconPlayCard8Filled.ts'),
  "play-card-9-filled": () => import('./icons/IconPlayCard9Filled.ts'),
  "play-card-a-filled": () => import('./icons/IconPlayCardAFilled.ts'),
  "play-card-j-filled": () => import('./icons/IconPlayCardJFilled.ts'),
  "play-card-k-filled": () => import('./icons/IconPlayCardKFilled.ts'),
  "play-card-q-filled": () => import('./icons/IconPlayCardQFilled.ts'),
  "play-card-star-filled": () => import('./icons/IconPlayCardStarFilled.ts'),
  "play-card-filled": () => import('./icons/IconPlayCardFilled.ts'),
  "player-eject-filled": () => import('./icons/IconPlayerEjectFilled.ts'),
  "player-pause-filled": () => import('./icons/IconPlayerPauseFilled.ts'),
  "player-play-filled": () => import('./icons/IconPlayerPlayFilled.ts'),
  "player-record-filled": () => import('./icons/IconPlayerRecordFilled.ts'),
  "player-skip-back-filled": () => import('./icons/IconPlayerSkipBackFilled.ts'),
  "player-skip-forward-filled": () => import('./icons/IconPlayerSkipForwardFilled.ts'),
  "player-stop-filled": () => import('./icons/IconPlayerStopFilled.ts'),
  "player-track-next-filled": () => import('./icons/IconPlayerTrackNextFilled.ts'),
  "player-track-prev-filled": () => import('./icons/IconPlayerTrackPrevFilled.ts'),
  "playlist-filled": () => import('./icons/IconPlaylistFilled.ts'),
  "point-filled": () => import('./icons/IconPointFilled.ts'),
  "pointer-filled": () => import('./icons/IconPointerFilled.ts'),
  "polaroid-filled": () => import('./icons/IconPolaroidFilled.ts'),
  "poo-filled": () => import('./icons/IconPooFilled.ts'),
  "presentation-analytics-filled": () => import('./icons/IconPresentationAnalyticsFilled.ts'),
  "presentation-filled": () => import('./icons/IconPresentationFilled.ts'),
  "puzzle-filled": () => import('./icons/IconPuzzleFilled.ts'),
  "quote-filled": () => import('./icons/IconQuoteFilled.ts'),
  "radar-filled": () => import('./icons/IconRadarFilled.ts'),
  "radioactive-filled": () => import('./icons/IconRadioactiveFilled.ts'),
  "receipt-dollar-filled": () => import('./icons/IconReceiptDollarFilled.ts'),
  "receipt-euro-filled": () => import('./icons/IconReceiptEuroFilled.ts'),
  "receipt-pound-filled": () => import('./icons/IconReceiptPoundFilled.ts'),
  "receipt-rupee-filled": () => import('./icons/IconReceiptRupeeFilled.ts'),
  "receipt-yen-filled": () => import('./icons/IconReceiptYenFilled.ts'),
  "receipt-yuan-filled": () => import('./icons/IconReceiptYuanFilled.ts'),
  "receipt-filled": () => import('./icons/IconReceiptFilled.ts'),
  "rectangle-vertical-filled": () => import('./icons/IconRectangleVerticalFilled.ts'),
  "rectangle-filled": () => import('./icons/IconRectangleFilled.ts'),
  "registered-filled": () => import('./icons/IconRegisteredFilled.ts'),
  "relation-many-to-many-filled": () => import('./icons/IconRelationManyToManyFilled.ts'),
  "relation-one-to-many-filled": () => import('./icons/IconRelationOneToManyFilled.ts'),
  "relation-one-to-one-filled": () => import('./icons/IconRelationOneToOneFilled.ts'),
  "replace-filled": () => import('./icons/IconReplaceFilled.ts'),
  "report-analytics-filled": () => import('./icons/IconReportAnalyticsFilled.ts'),
  "report-money-filled": () => import('./icons/IconReportMoneyFilled.ts'),
  "rollercoaster-filled": () => import('./icons/IconRollercoasterFilled.ts'),
  "rosette-discount-check-filled": () => import('./icons/IconRosetteDiscountCheckFilled.ts'),
  "rosette-discount-filled": () => import('./icons/IconRosetteDiscountFilled.ts'),
  "rosette-filled": () => import('./icons/IconRosetteFilled.ts'),
  "salad-filled": () => import('./icons/IconSaladFilled.ts'),
  "satellite-filled": () => import('./icons/IconSatelliteFilled.ts'),
  "scuba-diving-tank-filled": () => import('./icons/IconScubaDivingTankFilled.ts'),
  "section-filled": () => import('./icons/IconSectionFilled.ts'),
  "seedling-filled": () => import('./icons/IconSeedlingFilled.ts'),
  "settings-filled": () => import('./icons/IconSettingsFilled.ts'),
  "shield-check-filled": () => import('./icons/IconShieldCheckFilled.ts'),
  "shield-checkered-filled": () => import('./icons/IconShieldCheckeredFilled.ts'),
  "shield-half-filled": () => import('./icons/IconShieldHalfFilled.ts'),
  "shield-lock-filled": () => import('./icons/IconShieldLockFilled.ts'),
  "shield-filled": () => import('./icons/IconShieldFilled.ts'),
  "shirt-filled": () => import('./icons/IconShirtFilled.ts'),
  "shopping-cart-filled": () => import('./icons/IconShoppingCartFilled.ts'),
  "sign-left-filled": () => import('./icons/IconSignLeftFilled.ts'),
  "sign-right-filled": () => import('./icons/IconSignRightFilled.ts'),
  "sitemap-filled": () => import('./icons/IconSitemapFilled.ts'),
  "sort-ascending-2-filled": () => import('./icons/IconSortAscending2Filled.ts'),
  "sort-ascending-shapes-filled": () => import('./icons/IconSortAscendingShapesFilled.ts'),
  "sort-descending-2-filled": () => import('./icons/IconSortDescending2Filled.ts'),
  "sort-descending-shapes-filled": () => import('./icons/IconSortDescendingShapesFilled.ts'),
  "soup-filled": () => import('./icons/IconSoupFilled.ts'),
  "spade-filled": () => import('./icons/IconSpadeFilled.ts'),
  "sparkles-2-filled": () => import('./icons/IconSparkles2Filled.ts'),
  "sparkles-filled": () => import('./icons/IconSparklesFilled.ts'),
  "speedboat-filled": () => import('./icons/IconSpeedboatFilled.ts'),
  "spider-filled": () => import('./icons/IconSpiderFilled.ts'),
  "square-arrow-down-filled": () => import('./icons/IconSquareArrowDownFilled.ts'),
  "square-arrow-left-filled": () => import('./icons/IconSquareArrowLeftFilled.ts'),
  "square-arrow-right-filled": () => import('./icons/IconSquareArrowRightFilled.ts'),
  "square-arrow-up-filled": () => import('./icons/IconSquareArrowUpFilled.ts'),
  "square-asterisk-filled": () => import('./icons/IconSquareAsteriskFilled.ts'),
  "square-check-filled": () => import('./icons/IconSquareCheckFilled.ts'),
  "square-chevron-down-filled": () => import('./icons/IconSquareChevronDownFilled.ts'),
  "square-chevron-left-filled": () => import('./icons/IconSquareChevronLeftFilled.ts'),
  "square-chevron-right-filled": () => import('./icons/IconSquareChevronRightFilled.ts'),
  "square-chevron-up-filled": () => import('./icons/IconSquareChevronUpFilled.ts'),
  "square-chevrons-down-filled": () => import('./icons/IconSquareChevronsDownFilled.ts'),
  "square-chevrons-left-filled": () => import('./icons/IconSquareChevronsLeftFilled.ts'),
  "square-chevrons-right-filled": () => import('./icons/IconSquareChevronsRightFilled.ts'),
  "square-chevrons-up-filled": () => import('./icons/IconSquareChevronsUpFilled.ts'),
  "square-dot-filled": () => import('./icons/IconSquareDotFilled.ts'),
  "square-f0-filled": () => import('./icons/IconSquareF0Filled.ts'),
  "square-f1-filled": () => import('./icons/IconSquareF1Filled.ts'),
  "square-f2-filled": () => import('./icons/IconSquareF2Filled.ts'),
  "square-f3-filled": () => import('./icons/IconSquareF3Filled.ts'),
  "square-f4-filled": () => import('./icons/IconSquareF4Filled.ts'),
  "square-f5-filled": () => import('./icons/IconSquareF5Filled.ts'),
  "square-f6-filled": () => import('./icons/IconSquareF6Filled.ts'),
  "square-f7-filled": () => import('./icons/IconSquareF7Filled.ts'),
  "square-f8-filled": () => import('./icons/IconSquareF8Filled.ts'),
  "square-f9-filled": () => import('./icons/IconSquareF9Filled.ts'),
  "square-letter-a-filled": () => import('./icons/IconSquareLetterAFilled.ts'),
  "square-letter-b-filled": () => import('./icons/IconSquareLetterBFilled.ts'),
  "square-letter-c-filled": () => import('./icons/IconSquareLetterCFilled.ts'),
  "square-letter-d-filled": () => import('./icons/IconSquareLetterDFilled.ts'),
  "square-letter-e-filled": () => import('./icons/IconSquareLetterEFilled.ts'),
  "square-letter-f-filled": () => import('./icons/IconSquareLetterFFilled.ts'),
  "square-letter-g-filled": () => import('./icons/IconSquareLetterGFilled.ts'),
  "square-letter-h-filled": () => import('./icons/IconSquareLetterHFilled.ts'),
  "square-letter-i-filled": () => import('./icons/IconSquareLetterIFilled.ts'),
  "square-letter-j-filled": () => import('./icons/IconSquareLetterJFilled.ts'),
  "square-letter-k-filled": () => import('./icons/IconSquareLetterKFilled.ts'),
  "square-letter-l-filled": () => import('./icons/IconSquareLetterLFilled.ts'),
  "square-letter-m-filled": () => import('./icons/IconSquareLetterMFilled.ts'),
  "square-letter-n-filled": () => import('./icons/IconSquareLetterNFilled.ts'),
  "square-letter-o-filled": () => import('./icons/IconSquareLetterOFilled.ts'),
  "square-letter-p-filled": () => import('./icons/IconSquareLetterPFilled.ts'),
  "square-letter-q-filled": () => import('./icons/IconSquareLetterQFilled.ts'),
  "square-letter-r-filled": () => import('./icons/IconSquareLetterRFilled.ts'),
  "square-letter-s-filled": () => import('./icons/IconSquareLetterSFilled.ts'),
  "square-letter-t-filled": () => import('./icons/IconSquareLetterTFilled.ts'),
  "square-letter-u-filled": () => import('./icons/IconSquareLetterUFilled.ts'),
  "square-letter-v-filled": () => import('./icons/IconSquareLetterVFilled.ts'),
  "square-letter-w-filled": () => import('./icons/IconSquareLetterWFilled.ts'),
  "square-letter-x-filled": () => import('./icons/IconSquareLetterXFilled.ts'),
  "square-letter-y-filled": () => import('./icons/IconSquareLetterYFilled.ts'),
  "square-letter-z-filled": () => import('./icons/IconSquareLetterZFilled.ts'),
  "square-minus-filled": () => import('./icons/IconSquareMinusFilled.ts'),
  "square-number-0-filled": () => import('./icons/IconSquareNumber0Filled.ts'),
  "square-number-1-filled": () => import('./icons/IconSquareNumber1Filled.ts'),
  "square-number-2-filled": () => import('./icons/IconSquareNumber2Filled.ts'),
  "square-number-3-filled": () => import('./icons/IconSquareNumber3Filled.ts'),
  "square-number-4-filled": () => import('./icons/IconSquareNumber4Filled.ts'),
  "square-number-5-filled": () => import('./icons/IconSquareNumber5Filled.ts'),
  "square-number-6-filled": () => import('./icons/IconSquareNumber6Filled.ts'),
  "square-number-7-filled": () => import('./icons/IconSquareNumber7Filled.ts'),
  "square-number-8-filled": () => import('./icons/IconSquareNumber8Filled.ts'),
  "square-number-9-filled": () => import('./icons/IconSquareNumber9Filled.ts'),
  "square-rotated-filled": () => import('./icons/IconSquareRotatedFilled.ts'),
  "square-rounded-arrow-down-filled": () => import('./icons/IconSquareRoundedArrowDownFilled.ts'),
  "square-rounded-arrow-left-filled": () => import('./icons/IconSquareRoundedArrowLeftFilled.ts'),
  "square-rounded-arrow-right-filled": () => import('./icons/IconSquareRoundedArrowRightFilled.ts'),
  "square-rounded-arrow-up-filled": () => import('./icons/IconSquareRoundedArrowUpFilled.ts'),
  "square-rounded-check-filled": () => import('./icons/IconSquareRoundedCheckFilled.ts'),
  "square-rounded-chevron-down-filled": () => import('./icons/IconSquareRoundedChevronDownFilled.ts'),
  "square-rounded-chevron-left-filled": () => import('./icons/IconSquareRoundedChevronLeftFilled.ts'),
  "square-rounded-chevron-right-filled": () => import('./icons/IconSquareRoundedChevronRightFilled.ts'),
  "square-rounded-chevron-up-filled": () => import('./icons/IconSquareRoundedChevronUpFilled.ts'),
  "square-rounded-chevrons-down-filled": () => import('./icons/IconSquareRoundedChevronsDownFilled.ts'),
  "square-rounded-chevrons-left-filled": () => import('./icons/IconSquareRoundedChevronsLeftFilled.ts'),
  "square-rounded-chevrons-right-filled": () => import('./icons/IconSquareRoundedChevronsRightFilled.ts'),
  "square-rounded-chevrons-up-filled": () => import('./icons/IconSquareRoundedChevronsUpFilled.ts'),
  "square-rounded-letter-a-filled": () => import('./icons/IconSquareRoundedLetterAFilled.ts'),
  "square-rounded-letter-b-filled": () => import('./icons/IconSquareRoundedLetterBFilled.ts'),
  "square-rounded-letter-c-filled": () => import('./icons/IconSquareRoundedLetterCFilled.ts'),
  "square-rounded-letter-d-filled": () => import('./icons/IconSquareRoundedLetterDFilled.ts'),
  "square-rounded-letter-e-filled": () => import('./icons/IconSquareRoundedLetterEFilled.ts'),
  "square-rounded-letter-f-filled": () => import('./icons/IconSquareRoundedLetterFFilled.ts'),
  "square-rounded-letter-g-filled": () => import('./icons/IconSquareRoundedLetterGFilled.ts'),
  "square-rounded-letter-h-filled": () => import('./icons/IconSquareRoundedLetterHFilled.ts'),
  "square-rounded-letter-i-filled": () => import('./icons/IconSquareRoundedLetterIFilled.ts'),
  "square-rounded-letter-j-filled": () => import('./icons/IconSquareRoundedLetterJFilled.ts'),
  "square-rounded-letter-k-filled": () => import('./icons/IconSquareRoundedLetterKFilled.ts'),
  "square-rounded-letter-l-filled": () => import('./icons/IconSquareRoundedLetterLFilled.ts'),
  "square-rounded-letter-m-filled": () => import('./icons/IconSquareRoundedLetterMFilled.ts'),
  "square-rounded-letter-n-filled": () => import('./icons/IconSquareRoundedLetterNFilled.ts'),
  "square-rounded-letter-o-filled": () => import('./icons/IconSquareRoundedLetterOFilled.ts'),
  "square-rounded-letter-p-filled": () => import('./icons/IconSquareRoundedLetterPFilled.ts'),
  "square-rounded-letter-q-filled": () => import('./icons/IconSquareRoundedLetterQFilled.ts'),
  "square-rounded-letter-r-filled": () => import('./icons/IconSquareRoundedLetterRFilled.ts'),
  "square-rounded-letter-s-filled": () => import('./icons/IconSquareRoundedLetterSFilled.ts'),
  "square-rounded-letter-t-filled": () => import('./icons/IconSquareRoundedLetterTFilled.ts'),
  "square-rounded-letter-u-filled": () => import('./icons/IconSquareRoundedLetterUFilled.ts'),
  "square-rounded-letter-v-filled": () => import('./icons/IconSquareRoundedLetterVFilled.ts'),
  "square-rounded-letter-w-filled": () => import('./icons/IconSquareRoundedLetterWFilled.ts'),
  "square-rounded-letter-x-filled": () => import('./icons/IconSquareRoundedLetterXFilled.ts'),
  "square-rounded-letter-y-filled": () => import('./icons/IconSquareRoundedLetterYFilled.ts'),
  "square-rounded-letter-z-filled": () => import('./icons/IconSquareRoundedLetterZFilled.ts'),
  "square-rounded-minus-filled": () => import('./icons/IconSquareRoundedMinusFilled.ts'),
  "square-rounded-number-0-filled": () => import('./icons/IconSquareRoundedNumber0Filled.ts'),
  "square-rounded-number-1-filled": () => import('./icons/IconSquareRoundedNumber1Filled.ts'),
  "square-rounded-number-2-filled": () => import('./icons/IconSquareRoundedNumber2Filled.ts'),
  "square-rounded-number-3-filled": () => import('./icons/IconSquareRoundedNumber3Filled.ts'),
  "square-rounded-number-4-filled": () => import('./icons/IconSquareRoundedNumber4Filled.ts'),
  "square-rounded-number-5-filled": () => import('./icons/IconSquareRoundedNumber5Filled.ts'),
  "square-rounded-number-6-filled": () => import('./icons/IconSquareRoundedNumber6Filled.ts'),
  "square-rounded-number-7-filled": () => import('./icons/IconSquareRoundedNumber7Filled.ts'),
  "square-rounded-number-8-filled": () => import('./icons/IconSquareRoundedNumber8Filled.ts'),
  "square-rounded-number-9-filled": () => import('./icons/IconSquareRoundedNumber9Filled.ts'),
  "square-rounded-plus-filled": () => import('./icons/IconSquareRoundedPlusFilled.ts'),
  "square-rounded-x-filled": () => import('./icons/IconSquareRoundedXFilled.ts'),
  "square-rounded-filled": () => import('./icons/IconSquareRoundedFilled.ts'),
  "square-x-filled": () => import('./icons/IconSquareXFilled.ts'),
  "square-filled": () => import('./icons/IconSquareFilled.ts'),
  "squares-filled": () => import('./icons/IconSquaresFilled.ts'),
  "stack-2-filled": () => import('./icons/IconStack2Filled.ts'),
  "stack-3-filled": () => import('./icons/IconStack3Filled.ts'),
  "stack-filled": () => import('./icons/IconStackFilled.ts'),
  "star-half-filled": () => import('./icons/IconStarHalfFilled.ts'),
  "star-filled": () => import('./icons/IconStarFilled.ts'),
  "stars-filled": () => import('./icons/IconStarsFilled.ts'),
  "steering-wheel-filled": () => import('./icons/IconSteeringWheelFilled.ts'),
  "sun-high-filled": () => import('./icons/IconSunHighFilled.ts'),
  "sun-low-filled": () => import('./icons/IconSunLowFilled.ts'),
  "sun-filled": () => import('./icons/IconSunFilled.ts'),
  "sunglasses-filled": () => import('./icons/IconSunglassesFilled.ts'),
  "sunrise-filled": () => import('./icons/IconSunriseFilled.ts'),
  "sunset-2-filled": () => import('./icons/IconSunset2Filled.ts'),
  "sunset-filled": () => import('./icons/IconSunsetFilled.ts'),
  "swipe-down-filled": () => import('./icons/IconSwipeDownFilled.ts'),
  "swipe-left-filled": () => import('./icons/IconSwipeLeftFilled.ts'),
  "swipe-right-filled": () => import('./icons/IconSwipeRightFilled.ts'),
  "swipe-up-filled": () => import('./icons/IconSwipeUpFilled.ts'),
  "table-filled": () => import('./icons/IconTableFilled.ts'),
  "tag-filled": () => import('./icons/IconTagFilled.ts'),
  "tags-filled": () => import('./icons/IconTagsFilled.ts'),
  "temperature-minus-filled": () => import('./icons/IconTemperatureMinusFilled.ts'),
  "temperature-plus-filled": () => import('./icons/IconTemperaturePlusFilled.ts'),
  "template-filled": () => import('./icons/IconTemplateFilled.ts'),
  "test-pipe-2-filled": () => import('./icons/IconTestPipe2Filled.ts'),
  "thumb-down-filled": () => import('./icons/IconThumbDownFilled.ts'),
  "thumb-up-filled": () => import('./icons/IconThumbUpFilled.ts'),
  "tilt-shift-filled": () => import('./icons/IconTiltShiftFilled.ts'),
  "timeline-event-filled": () => import('./icons/IconTimelineEventFilled.ts'),
  "toggle-left-filled": () => import('./icons/IconToggleLeftFilled.ts'),
  "toggle-right-filled": () => import('./icons/IconToggleRightFilled.ts'),
  "train-filled": () => import('./icons/IconTrainFilled.ts'),
  "transform-filled": () => import('./icons/IconTransformFilled.ts'),
  "transition-bottom-filled": () => import('./icons/IconTransitionBottomFilled.ts'),
  "transition-left-filled": () => import('./icons/IconTransitionLeftFilled.ts'),
  "transition-right-filled": () => import('./icons/IconTransitionRightFilled.ts'),
  "transition-top-filled": () => import('./icons/IconTransitionTopFilled.ts'),
  "trash-x-filled": () => import('./icons/IconTrashXFilled.ts'),
  "trash-filled": () => import('./icons/IconTrashFilled.ts'),
  "triangle-inverted-filled": () => import('./icons/IconTriangleInvertedFilled.ts'),
  "triangle-square-circle-filled": () => import('./icons/IconTriangleSquareCircleFilled.ts'),
  "triangle-filled": () => import('./icons/IconTriangleFilled.ts'),
  "trolley-filled": () => import('./icons/IconTrolleyFilled.ts'),
  "trophy-filled": () => import('./icons/IconTrophyFilled.ts'),
  "truck-filled": () => import('./icons/IconTruckFilled.ts'),
  "ufo-filled": () => import('./icons/IconUfoFilled.ts'),
  "umbrella-filled": () => import('./icons/IconUmbrellaFilled.ts'),
  "user-filled": () => import('./icons/IconUserFilled.ts'),
  "versions-filled": () => import('./icons/IconVersionsFilled.ts'),
  "video-minus-filled": () => import('./icons/IconVideoMinusFilled.ts'),
  "video-plus-filled": () => import('./icons/IconVideoPlusFilled.ts'),
  "video-filled": () => import('./icons/IconVideoFilled.ts'),
  "windmill-filled": () => import('./icons/IconWindmillFilled.ts'),
  "windsock-filled": () => import('./icons/IconWindsockFilled.ts'),
  "woman-filled": () => import('./icons/IconWomanFilled.ts'),
  "writing-sign-filled": () => import('./icons/IconWritingSignFilled.ts'),
  "writing-filled": () => import('./icons/IconWritingFilled.ts'),
  "xbox-a-filled": () => import('./icons/IconXboxAFilled.ts'),
  "xbox-b-filled": () => import('./icons/IconXboxBFilled.ts'),
  "xbox-x-filled": () => import('./icons/IconXboxXFilled.ts'),
  "xbox-y-filled": () => import('./icons/IconXboxYFilled.ts'),
  "yin-yang-filled": () => import('./icons/IconYinYangFilled.ts'),
  "zeppelin-filled": () => import('./icons/IconZeppelinFilled.ts'),
  "zoom-cancel-filled": () => import('./icons/IconZoomCancelFilled.ts'),
  "zoom-check-filled": () => import('./icons/IconZoomCheckFilled.ts'),
  "zoom-code-filled": () => import('./icons/IconZoomCodeFilled.ts'),
  "zoom-exclamation-filled": () => import('./icons/IconZoomExclamationFilled.ts'),
  "zoom-in-area-filled": () => import('./icons/IconZoomInAreaFilled.ts'),
  "zoom-in-filled": () => import('./icons/IconZoomInFilled.ts'),
  "zoom-money-filled": () => import('./icons/IconZoomMoneyFilled.ts'),
  "zoom-out-area-filled": () => import('./icons/IconZoomOutAreaFilled.ts'),
  "zoom-out-filled": () => import('./icons/IconZoomOutFilled.ts'),
  "zoom-pan-filled": () => import('./icons/IconZoomPanFilled.ts'),
  "zoom-question-filled": () => import('./icons/IconZoomQuestionFilled.ts'),
  "zoom-scan-filled": () => import('./icons/IconZoomScanFilled.ts'),
  "zoom-filled": () => import('./icons/IconZoomFilled.ts')
};

export { dynamicImports as default };
//# sourceMappingURL=dynamic-imports.mjs.map
