import * as react from 'react';
import { ReactSVG, FunctionComponent, ForwardRefExoticComponent, RefAttributes } from 'react';
export { ReactNode } from 'react';

type IconNode = [elementName: keyof ReactSVG, attrs: Record<string, string>][];
interface IconProps extends Partial<Omit<React.ComponentPropsWithoutRef<'svg'>, 'stroke'>> {
    size?: string | number;
    stroke?: string | number;
    title?: string;
}
type Icon = FunctionComponent<IconProps>;
type TablerIcon = ForwardRefExoticComponent<IconProps & RefAttributes<SVGSVGElement>>;

declare const IconAB2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconABOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAB: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAbacusOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAbacus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAbc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAccessPointOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAccessPoint: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAccessibleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAccessible: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconActivityHeartbeat: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconActivity: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAd2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdCircleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAddressBookOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAddressBook: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsAlt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsSpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustments: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAerialLift: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAffiliate: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAi: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAirBalloon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAirConditioningDisabled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAirConditioning: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAirTrafficControl: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlarmAverage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlarmMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlarmOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlarmPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlarmSmoke: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlarmSnooze: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlarm: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlbumOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlbum: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlertCircleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlertCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlertHexagonOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlertHexagon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlertOctagon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlertSmallOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlertSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlertSquareRoundedOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlertSquareRounded: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlertSquare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlertTriangleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlertTriangle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlien: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxBottomCenter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxBottomLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxBottomRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxCenterBottom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxCenterMiddle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxCenterStretch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxCenterTop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxLeftBottom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxLeftMiddle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxLeftStretch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxLeftTop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxRightBottom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxRightMiddle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxRightStretch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxRightTop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxTopCenter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxTopLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxTopRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignCenter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignJustified: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignLeft2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignRight2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlpha: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlphabetArabic: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlphabetBangla: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlphabetCyrillic: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlphabetGreek: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlphabetHebrew: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlphabetKorean: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlphabetLatin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlphabetPolish: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlphabetRunes: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlphabetThai: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAmbulance: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAmpersand: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAnalyzeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAnalyze: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAnchorOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAnchor: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAngle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAnkh: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAntennaBars1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAntennaBars2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAntennaBars3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAntennaBars4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAntennaBars5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAntennaBarsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAntennaOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAntenna: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconApertureOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAperture: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconApiAppOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconApiApp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconApiOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconApi: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAppWindow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconApple: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAppsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconApps: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArcheryArrow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArchiveOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArchive: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArmchair2Off: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArmchair2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArmchairOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArmchair: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowAutofitContent: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowAutofitDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowAutofitHeight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowAutofitLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowAutofitRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowAutofitUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowAutofitWidth: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBackUpDouble: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBackUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBack: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBadgeDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBadgeLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBadgeRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBadgeUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBarBoth: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBarDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBarLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBarRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBarToDownDashed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBarToDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBarToLeftDashed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBarToLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBarToRightDashed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBarToRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBarToUpDashed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBarToUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBarUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBearLeft2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBearLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBearRight2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBearRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigDownLine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigDownLines: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigLeftLine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigLeftLines: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigRightLine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigRightLines: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigUpLine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigUpLines: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBounce: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowCapsule: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowCurveLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowCurveRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowDownBar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowDownCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowDownDashed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowDownFromArc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowDownLeftCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowDownLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowDownRhombus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowDownRightCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowDownRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowDownSquare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowDownTail: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowDownToArc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowElbowLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowElbowRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowFork: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowForwardUpDouble: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowForwardUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowForward: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowGuide: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowIteration: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowLeftBar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowLeftCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowLeftDashed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowLeftFromArc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowLeftRhombus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowLeftRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowLeftSquare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowLeftTail: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowLeftToArc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowLoopLeft2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowLoopLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowLoopRight2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowLoopRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowMergeAltLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowMergeAltRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowMergeBoth: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowMergeLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowMergeRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowMerge: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowMoveDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowMoveLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowMoveRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowMoveUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowNarrowDownDashed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowNarrowDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowNarrowLeftDashed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowNarrowLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowNarrowRightDashed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowNarrowRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowNarrowUpDashed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowNarrowUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRampLeft2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRampLeft3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRampLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRampRight2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRampRight3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRampRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRightBar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRightCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRightDashed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRightFromArc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRightRhombus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRightSquare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRightTail: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRightToArc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRotaryFirstLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRotaryFirstRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRotaryLastLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRotaryLastRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRotaryLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRotaryRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRotaryStraight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRoundaboutLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRoundaboutRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowSharpTurnLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowSharpTurnRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowUpBar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowUpCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowUpDashed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowUpFromArc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowUpLeftCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowUpLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowUpRhombus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowUpRightCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowUpRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowUpSquare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowUpTail: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowUpToArc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowWaveLeftDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowWaveLeftUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowWaveRightDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowWaveRightUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowZigZag: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsCross: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsDiagonal2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsDiagonalMinimize2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsDiagonalMinimize: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsDiagonal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsDiff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsDoubleNeSw: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsDoubleNwSe: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsDoubleSeNw: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsDoubleSwNe: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsDownUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsExchange2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsExchange: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsJoin2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsJoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsLeftDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsLeftRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsMaximize: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsMinimize: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsMoveHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsMoveVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsMove: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsRandom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsRightDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsRightLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsShuffle2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsShuffle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsSort: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsSplit2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsSplit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsTransferDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsTransferUpDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsTransferUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsUpDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsUpLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsUpRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowsVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArtboardOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArtboard: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArticleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArticle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAspectRatioOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAspectRatio: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAssemblyOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAssembly: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAsset: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAsteriskSimple: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAsterisk: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAtOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAtom2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAtomOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAtom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAugmentedReality2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAugmentedRealityOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAugmentedReality: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAuth2fa: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAutomaticGearbox: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAutomation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAvocado: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAwardOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAward: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAxe: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAxisX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAxisY: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBabyBottle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBabyCarriage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBackground: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBackhoe: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBackpackOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBackpack: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBackslash: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBackspace: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadge2k: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadge3d: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadge3k: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadge4k: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadge5k: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadge8k: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeAdOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeAd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeAr: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeCc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeHd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeSd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeTm: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeVo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeVr: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeWc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadge: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgesOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadges: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBaguette: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBallAmericanFootballOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBallAmericanFootball: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBallBaseball: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBallBasketball: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBallBowling: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBallFootballOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBallFootball: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBallTennis: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBallVolleyball: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBalloonOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBalloon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBallpenOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBallpen: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBandageOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBandage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBarbellOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBarbell: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBarcodeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBarcode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBarrelOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBarrel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBarrierBlockOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBarrierBlock: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBaselineDensityLarge: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBaselineDensityMedium: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBaselineDensitySmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBaseline: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketDiscount: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasket: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBat: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBathOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBath: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBattery1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBattery2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBattery3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBattery4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryAutomotive: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryCharging2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryCharging: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryEco: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatterySpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryVertical1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryVertical2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryVertical3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryVertical4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryVerticalCharging2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryVerticalCharging: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryVerticalEco: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryVerticalExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryVerticalOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBattery: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBeachOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBeach: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBedFlat: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBedOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBeerOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBeer: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellRinging2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellRinging: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellSchool: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellZ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBell: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBeta: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBible: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBikeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBike: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBinaryOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBinaryTree2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBinaryTree: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBinary: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBinoculars: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBiohazardOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBiohazard: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBlade: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBleachChlorine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBleachNoChlorine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBleachOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBleach: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBlendMode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBlender: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBlind: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBlob: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBlockquote: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBlocks: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBluetoothConnected: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBluetoothOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBluetoothX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBluetooth: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBlurOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBlur: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBmp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBodyScan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoldOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBold: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoltOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBomb: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoneOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBone: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBongOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBong: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBook2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBookDownload: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBookOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBookUpload: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBook: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBookmarkAi: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBookmarkEdit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBookmarkMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBookmarkOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBookmarkPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBookmarkQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBookmark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBookmarksOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBookmarks: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBooksOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBooks: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderAll: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderBottomPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderBottom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderCornerIos: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderCornerPill: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderCornerRounded: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderCornerSquare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderCorners: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderInner: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderLeftPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderNone: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderOuter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderRadius: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderRightPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderSides: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderStyle2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderStyle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderTopPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderTop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBorderVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBottleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBottle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBounceLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBounceRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBowlChopsticks: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBowlSpoon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBowl: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBowling: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxAlignBottomLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxAlignBottomRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxAlignBottom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxAlignLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxAlignRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxAlignTopLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxAlignTopRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxAlignTop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxMargin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxModel2Off: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxModel2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxModelOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxModel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxMultiple0: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxMultiple1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxMultiple2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxMultiple3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxMultiple4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxMultiple5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxMultiple6: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxMultiple7: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxMultiple8: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxMultiple9: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxMultiple: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxPadding: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBox: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBracesOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBraces: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBracketsAngleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBracketsAngle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBracketsContainEnd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBracketsContainStart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBracketsContain: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBracketsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrackets: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBraille: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrain: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrand4chan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAbstract: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAdobeAfterEffect: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAdobeIllustrator: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAdobeIndesign: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAdobePhotoshop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAdobePremiere: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAdobeXd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAdobe: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAdonisJs: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAirbnb: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAirtable: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAlgolia: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAlipay: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAlpineJs: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAmazon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAmd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAmie: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAmigo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAmongUs: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAndroid: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAngular: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAnsible: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAo3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAppgallery: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAppleArcade: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAppleNews: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandApplePodcast: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandApple: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAppstore: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandArc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAsana: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAstro: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAuth0: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAws: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAzure: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBackbone: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBadoo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBaidu: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBandcamp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBandlab: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBeats: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBebo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBehance: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBilibili: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBinance: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBing: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBitbucket: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBlackberry: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBlender: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBlogger: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBluesky: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBooking: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBootstrap: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBulma: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBumble: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBunpo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCSharp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCake: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCakephp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCampaignmonitor: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCarbon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCashapp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandChrome: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCinema4d: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCitymapper: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCloudflare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCodecov: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCodepen: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCodesandbox: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCohost: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCoinbase: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandComedyCentral: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCoreos: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCouchdb: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCouchsurfing: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCpp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCraft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCrunchbase: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCss3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCtemplar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCucumber: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCupra: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandCypress: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandD3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDatabricks: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDaysCounter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDcos: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDebian: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDeezer: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDeliveroo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDeno: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDenodo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDeviantart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDigg: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDingtalk: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDiscord: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDisney: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDisqus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDjango: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDocker: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDoctrine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDolbyDigital: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDouban: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDribbble: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDropbox: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDrops: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDrupal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandEdge: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandElastic: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandElectronicArts: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandEmber: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandEnvato: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandEtsy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandEvernote: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandFacebook: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandFeedly: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandFigma: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandFilezilla: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandFinder: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandFirebase: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandFirefox: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandFiverr: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandFlickr: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandFlightradar24: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandFlipboard: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandFlutter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandFortnite: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandFoursquare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandFramerMotion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandFramer: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandFunimation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGatsby: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGithubCopilot: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGithub: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGitlab: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGmail: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGolang: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGoogleAnalytics: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGoogleBigQuery: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGoogleDrive: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGoogleFit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGoogleHome: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGoogleMaps: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGoogleOne: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGooglePhotos: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGooglePlay: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGooglePodcasts: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGoogle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGrammarly: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGraphql: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGravatar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGrindr: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGuardian: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGumroad: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandHackerrank: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandHbo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandHeadlessui: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandHexo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandHipchat: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandHtml5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandInertia: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandInstagram: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandIntercom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandItch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandJavascript: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandJuejin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandKakoTalk: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandKbin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandKick: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandKickstarter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandKotlin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandLaravel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandLastfm: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandLeetcode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandLetterboxd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandLine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandLinkedin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandLinktree: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandLinqpad: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandLivewire: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandLoom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMailgun: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMantine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMastercard: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMastodon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMatrix: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMcdonalds: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMedium: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMeetup: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMercedes: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMessenger: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMeta: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMetabrainz: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMinecraft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMiniprogram: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMixpanel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMonday: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMongodb: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMyOppo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMysql: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandNationalGeographic: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandNem: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandNetbeans: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandNeteaseMusic: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandNetflix: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandNexo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandNextcloud: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandNextjs: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandNodejs: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandNordVpn: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandNotion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandNpm: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandNuxt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandNytimes: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandOauth: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandOffice: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandOkRu: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandOnedrive: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandOnlyfans: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandOpenSource: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandOpenai: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandOpenvpn: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandOpera: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPagekit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandParsinta: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPatreon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPaypal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPaypay: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPeanut: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPepsi: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPhp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPicsart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPinterest: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPlanetscale: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPnpm: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPocket: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPolymer: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPowershell: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPrintables: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPrisma: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandProducthunt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPushbullet: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPushover: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPython: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandQq: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandRadixUi: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandReactNative: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandReact: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandReason: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandReddit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandRedhat: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandRedux: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandRevolut: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandRumble: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandRust: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSafari: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSamsungpass: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSass: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSentry: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSharik: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandShazam: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandShopee: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSketch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSkype: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSlack: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSnapchat: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSnapseed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSnowflake: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSocketIo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSolidjs: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSoundcloud: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSpacehey: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSpeedtest: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSpotify: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandStackoverflow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandStackshare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSteam: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandStocktwits: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandStorj: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandStorybook: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandStorytel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandStrava: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandStripe: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSublimeText: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSugarizer: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSupabase: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSuperhuman: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSupernova: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSurfshark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSvelte: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSwift: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSymfony: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTabler: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTabnine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTailwind: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTaobao: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTeams: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTelegram: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTerraform: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTesla: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTether: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandThingiverse: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandThreads: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandThreejs: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTidal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTiktok: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTinder: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTopbuzz: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTorchain: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandToyota: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTrello: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTripadvisor: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTumblr: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTwilio: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTwitch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTwitter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTypescript: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandUber: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandUbuntu: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandUnity: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandUnsplash: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandUpwork: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandValorant: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandVercel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandVimeo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandVinted: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandVisa: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandVisualStudio: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandVite: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandVivaldi: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandVk: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandVlc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandVolkswagen: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandVsco: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandVscode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandVue: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandWalmart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandWaze: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandWebflow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandWechat: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandWeibo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandWhatsapp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandWikipedia: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandWindows: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandWindy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandWish: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandWix: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandWordpress: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandXamarin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandXbox: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandXdeep: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandXing: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandYahoo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandYandex: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandYarn: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandYatse: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandYcombinator: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandYoutubeKids: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandYoutube: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandZalando: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandZapier: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandZeit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandZhihu: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandZoom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandZulip: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandZwift: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBreadOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBread: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBriefcase2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBriefcaseOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBriefcase: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrightness2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrightnessAuto: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrightnessDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrightnessHalf: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrightnessOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrightnessUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrightness: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBroadcastOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBroadcast: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrowserCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrowserMaximize: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrowserMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrowserOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrowserPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrowserShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrowserX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrowser: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrushOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrush: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBubbleMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBubblePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBubbleTea2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBubbleTea: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBubbleText: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBubbleX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBubble: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBucketDroplet: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBucketOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBucket: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBugOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBug: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingAirport: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingArch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingBank: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingBridge2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingBridge: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingBroadcastTower: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingBurjAlArab: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingCarousel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingCastle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingChurch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingCircus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingCommunity: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingCottage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingEstate: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingFactory2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingFactory: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingFortress: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingHospital: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingLighthouse: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingMonument: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingMosque: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingPavilion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingSkyscraper: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingStadium: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingStore: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingTunnel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingWarehouse: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingWindTurbine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuilding: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildings: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBulbOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBulb: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBulldozer: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBurger: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBusOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBusStop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBusinessplan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconButterfly: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCactusOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCactus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCakeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCakeRoll: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCake: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalculatorOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalculator: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarClock: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarDot: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarDue: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarEvent: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarMonth: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarRepeat: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarSad: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarSmile: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarStats: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarTime: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarUser: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarWeek: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraAi: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraBitcoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraMoon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraRotate: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraSelfie: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraSpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCamera: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCamper: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCampfire: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCandle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCandyOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCandy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCane: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCannabis: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCapProjecting: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCapRounded: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCapStraight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCapsuleHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCapsule: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCaptureOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCapture: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCar4wd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarCrane: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarCrash: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarFan1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarFan2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarFan3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarFanAuto: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarFan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarGarage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarSuv: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarTurbine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarambola: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCaravan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCardboardsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCardboards: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCards: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCaretDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCaretLeftRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCaretLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCaretRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCaretUpDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCaretUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarouselHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarouselVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarrotOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarrot: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCashBanknoteEdit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCashBanknoteHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCashBanknoteMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCashBanknoteMoveBack: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCashBanknoteMove: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCashBanknoteOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCashBanknotePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCashBanknote: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCashEdit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCashHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCashMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCashMoveBack: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCashMove: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCashOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCashPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCashRegister: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCash: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCastOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCast: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCat: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCategory2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCategoryMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCategoryPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCategory: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCe: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCellSignal1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCellSignal2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCellSignal3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCellSignal4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCellSignal5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCellSignalOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCell: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCertificate2Off: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCertificate2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCertificateOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCertificate: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChairDirector: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChalkboardOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChalkboardTeacher: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChalkboard: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChargingPile: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartArcs3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartArcs: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartAreaLine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartArea: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartArrowsVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartArrows: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartBarOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartBarPopular: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartBar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartBubble: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartCandle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartCircles: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartCohort: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartColumn: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartCovariate: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartDonut2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartDonut3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartDonut4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartDonut: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartDots2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartDots3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartDots: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartFunnel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartGridDots: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartHistogram: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartInfographic: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartLine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartPie2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartPie3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartPie4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartPieOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartPie: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartPpf: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartRadar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartSankey: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartScatter3d: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartScatter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartTreemap: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCheckbox: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChecklist: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChecks: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCheckupList: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCheese: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChefHatOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChefHat: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCherry: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChessBishop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChessKing: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChessKnight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChessQueen: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChessRook: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChess: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronCompactDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronCompactLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronCompactRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronCompactUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronDownLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronDownRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronLeftPipe: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronRightPipe: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronUpLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronUpRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronsDownLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronsDownRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronsDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronsLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronsRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronsUpLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronsUpRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChevronsUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChisel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChristmasBall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChristmasTreeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChristmasTree: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleArrowDownLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleArrowDownRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleArrowDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleArrowLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleArrowRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleArrowUpLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleArrowUpRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleArrowUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleAsterisk: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleCaretDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleCaretLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleCaretRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleCaretUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleChevronDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleChevronLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleChevronRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleChevronUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleChevronsDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleChevronsLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleChevronsRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleChevronsUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterA: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterB: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterC: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterD: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterE: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterF: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterG: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterH: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterI: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterJ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterK: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterL: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterM: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterN: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterO: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterP: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterQ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterR: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterS: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterT: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterU: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterV: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterW: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterY: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedLetterZ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedNumber0: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedNumber1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedNumber2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedNumber3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedNumber4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedNumber5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedNumber6: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedNumber7: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedNumber8: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedNumber9: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedPercentage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashedX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDashed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDot: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterA: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterB: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterC: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterD: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterE: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterF: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterG: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterH: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterI: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterJ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterK: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterL: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterM: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterN: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterO: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterP: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterQ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterR: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterS: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterT: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterU: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterV: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterW: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterY: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDottedLetterZ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDotted: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleHalf2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleHalfVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleHalf: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleKey: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterA: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterB: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterC: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterD: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterE: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterF: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterG: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterH: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterI: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterJ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterK: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterL: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterM: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterN: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterO: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterP: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterQ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterR: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterS: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterT: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterU: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterV: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterW: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterY: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterZ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleMinus2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber0: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber6: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber7: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber8: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber9: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCirclePercentage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCirclePlus2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCirclePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleRectangleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleRectangle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleSquare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleTriangle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCirclesRelation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircles: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitAmmeter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitBattery: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitBulb: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitCapacitorPolarized: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitCapacitor: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitCellPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitCell: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitChangeover: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitDiodeZener: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitDiode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitGroundDigital: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitGround: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitInductor: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitMotor: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitPushbutton: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitResistor: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitSwitchClosed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitSwitchOpen: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircuitVoltmeter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClearAll: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClearFormatting: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClick: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCliffJumping: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardCopy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardData: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardList: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardSmile: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardText: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardTypography: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboard: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClock12: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClock2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClock24: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockBitcoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockEdit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour10: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour11: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour12: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour6: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour7: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour8: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour9: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockPlay: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockRecord: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockShield: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockStop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClock: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClothesRackOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClothesRack: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudBitcoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudComputing: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudDataConnection: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudDownload: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudFog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudLockOpen: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudLock: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudNetwork: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudRain: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudSnow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudStorm: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudUpload: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloud: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClover2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClover: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClubs: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCodeAsterisk: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCodeCircle2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCodeCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCodeDots: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCodeMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCodeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCodePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCodeVariableMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCodeVariablePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCodeVariable: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoffeeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoffee: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoffin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoinBitcoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoinEuro: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoinMonero: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoinOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoinPound: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoinRupee: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoinTaka: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoinYen: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoinYuan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoins: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconColorFilter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconColorPickerOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconColorPicker: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconColorSwatchOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconColorSwatch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconColumnInsertLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconColumnInsertRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconColumnRemove: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconColumns1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconColumns2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconColumns3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconColumnsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconColumns: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconComet: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCommandOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCommand: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCompassOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCompass: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconComponentsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconComponents: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCone2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconConeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconConePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCone: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconConfettiOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconConfetti: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconConfucius: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCongruentTo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconContainerOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconContainer: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconContract: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconContrast2Off: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconContrast2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconContrastOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconContrast: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCooker: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCookieMan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCookieOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCookie: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCopyCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCopyMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCopyOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCopyPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCopyX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCopy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCopyleftOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCopyleft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCopyrightOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCopyright: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCornerDownLeftDouble: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCornerDownLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCornerDownRightDouble: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCornerDownRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCornerLeftDownDouble: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCornerLeftDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCornerLeftUpDouble: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCornerLeftUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCornerRightDownDouble: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCornerRightDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCornerRightUpDouble: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCornerRightUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCornerUpLeftDouble: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCornerUpLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCornerUpRightDouble: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCornerUpRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCpu2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCpuOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCpu: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCraneOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrane: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCreativeCommonsBy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCreativeCommonsNc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCreativeCommonsNd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCreativeCommonsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCreativeCommonsSa: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCreativeCommonsZero: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCreativeCommons: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCreditCardOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCreditCardPay: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCreditCardRefund: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCreditCard: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCricket: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrop11: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrop169: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrop32: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrop54: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrop75: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCropLandscape: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCropPortrait: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrossOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCross: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrosshair: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrownOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrutchesOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrutches: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrystalBall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCsv: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCube3dSphereOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCube3dSphere: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCubeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCubePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCubeSend: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCubeSpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCubeUnfolded: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCube: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCupOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCup: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurling: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurlyLoop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyAfghani: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyBahraini: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyBaht: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyBitcoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyCent: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyDinar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyDirham: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyDogecoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyDollarAustralian: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyDollarBrunei: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyDollarCanadian: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyDollarGuyanese: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyDollarOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyDollarSingapore: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyDollarZimbabwean: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyDong: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyDram: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyEthereum: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyEuroOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyEuro: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyFlorin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyForint: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyFrank: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyGuarani: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyHryvnia: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyIranianRial: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyKip: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyKroneCzech: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyKroneDanish: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyKroneSwedish: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyLari: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyLeu: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyLira: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyLitecoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyLyd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyManat: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyMonero: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyNaira: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyNano: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyPaanga: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyPeso: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyPoundOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyPound: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyQuetzal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyReal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyRenminbi: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyRipple: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyRiyal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyRubel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyRufiyaa: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyRupeeNepalese: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyRupee: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyShekel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencySolana: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencySom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyTaka: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyTenge: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyTugrik: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyWon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyXrp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyYenOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyYen: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyYuan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrencyZloty: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrency: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrentLocationOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrentLocation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCursorOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCursorText: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCut: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCylinderOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCylinderPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCylinder: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDashboardOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDashboard: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDatabaseCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDatabaseDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDatabaseEdit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDatabaseExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDatabaseExport: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDatabaseHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDatabaseImport: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDatabaseLeak: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDatabaseMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDatabaseOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDatabasePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDatabaseSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDatabaseShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDatabaseSmile: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDatabaseStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDatabaseX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDatabase: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeaf: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDecimal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeer: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDelta: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDentalBroken: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDentalOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDental: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeselect: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDesk: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDetailsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDetails: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceAirpodsCase: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceAirpods: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceAirtag: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceAnalytics: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceAudioTape: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceCameraPhone: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceCctvOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceCctv: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceComputerCameraOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceComputerCamera: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopAnalytics: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceFloppy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceGamepad2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceGamepad3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceGamepad: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceHeartMonitor: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImac: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontalX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpad: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceLandlinePhone: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceLaptopOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceLaptop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileCharging: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileMessage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobilePause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobilePin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobilePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileRotated: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileVibration: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobile: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceNintendoOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceNintendo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceProjector: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceRemote: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceSdCard: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceSim1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceSim2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceSim3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceSim: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceSpeakerOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceSpeaker: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTablet: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTvOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTvOld: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTv: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceUnknown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceUsb: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceVisionPro: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchStats2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchStats: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevices2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesPcOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesPc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevicesX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDevices: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDiaboloOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDiaboloPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDiabolo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDialpadOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDialpad: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDiamondOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDiamond: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDiamonds: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDiaper: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDice1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDice2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDice3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDice4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDice5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDice6: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDice: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDimensions: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDirectionArrows: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDirectionHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDirectionSignOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDirectionSign: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDirection: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDirectionsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDirections: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDisabled2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDisabledOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDisabled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDiscGolf: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDiscOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDisc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDiscountOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDiscount: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDivide: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDna2Off: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDna2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDnaOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDna: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDogBowl: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDoorEnter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDoorExit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDoorOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDoor: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDotsCircleHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDotsDiagonal2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDotsDiagonal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDotsVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDots: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDownloadOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDownload: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDragDrop2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDragDrop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDroneOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDrone: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletHalf2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletHalf: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDroplet: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDroplets: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDualScreen: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDumpling: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEPassport: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEarOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEarScan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEaseInControlPoint: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEaseInOutControlPoints: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEaseInOut: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEaseIn: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEaseOutControlPoint: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEaseOut: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEditCircleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEditCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEditOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEdit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEggCracked: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEggFried: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEggOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEgg: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEggs: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconElevatorOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconElevator: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEmergencyBed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEmpathizeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEmpathize: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEmphasis: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEngineOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEngine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEqualDouble: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEqualNot: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEqual: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEraserOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEraser: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconError404Off: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconError404: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEscalatorDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEscalatorUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEscalator: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExchangeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExchange: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExclamationCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExclamationMarkOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExclamationMark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExplicitOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExplicit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExposure0: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExposureMinus1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExposureMinus2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExposureOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExposurePlus1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExposurePlus2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExposure: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExternalLinkOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExternalLink: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeBitcoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeClosed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeDiscount: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeDotted: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeEdit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyePause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyePin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeSpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeTable: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEye: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeglass2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeglassOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeglass: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFaceIdError: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFaceId: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFaceMaskOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFaceMask: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFavicon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFeatherOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFeather: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFenceOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFence: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFerry: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFidgetSpinner: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFile3d: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileAi: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileAlert: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileAnalytics: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileArrowLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileArrowRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileBarcode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileBitcoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileBroken: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileCertificate: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileChart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileCode2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileCv: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileDatabase: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileDelta: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileDescription: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileDiff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileDigit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileDislike: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileDots: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileDownload: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileEuro: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileExcel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileExport: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileFunction: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileImport: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileInfinity: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileInfo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileInvoice: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileIsr: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileLambda: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileLike: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileMusic: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileNeutral: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileOrientation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilePencil: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilePercent: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilePhone: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilePower: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileReport: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileRss: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileSad: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileScissors: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileSettings: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileShredder: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileSignal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileSmile: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileSpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileSpreadsheet: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileStack: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileSymlink: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTextAi: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTextShield: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTextSpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileText: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTime: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeBmp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeCss: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeCsv: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeDoc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeDocx: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeHtml: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeJpg: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeJs: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeJsx: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypePdf: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypePhp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypePng: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypePpt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeRs: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeSql: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeSvg: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeTs: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeTsx: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeTxt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeVue: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeXls: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeXml: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypeZip: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypography: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileUnknown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileUpload: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileVector: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileWord: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileZip: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFile: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilesOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFiles: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Bolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Cancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Check: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Code: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Cog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Discount: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Dollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Down: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Edit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Exclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Minus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Pause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Pin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Plus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Question: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Search: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Share: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Spark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2Up: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2X: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterDiscount: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterEdit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterSpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilters: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFingerprintOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFingerprintScan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFingerprint: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFireExtinguisher: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFireHydrantOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFireHydrant: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFiretruck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFirstAidKitOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFirstAidKit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFishBone: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFishChristianity: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFishHookOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFishHook: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFishOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFish: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlag2Off: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlag2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlag3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagBitcoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagDiscount: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagSpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlag: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlameOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlame: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlask2Off: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlask2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlaskOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlask: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlipFlops: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlipHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlipVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFloatCenter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFloatLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFloatNone: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFloatRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlowerOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlower: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFocus2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFocusAuto: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFocusCentered: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFocus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFoldDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFoldUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFold: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderOpen: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderRoot: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderSymlink: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolder: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFoldersOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolders: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconForbid2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconForbid: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconForklift: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconForms: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFountainOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFountain: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFrameOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFrame: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFreeRights: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFreezeColumn: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFreezeRowColumn: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFreezeRow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFridgeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFridge: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFriendsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFriends: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFrustumOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFrustumPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFrustum: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFunctionOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFunction: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGalaxy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGardenCartOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGardenCart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGasStationOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGasStation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGaugeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGauge: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGavel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGenderAgender: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGenderAndrogyne: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGenderBigender: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGenderDemiboy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGenderDemigirl: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGenderEpicene: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGenderFemale: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGenderFemme: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGenderGenderfluid: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGenderGenderless: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGenderGenderqueer: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGenderHermaphrodite: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGenderIntergender: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGenderMale: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGenderNeutrois: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGenderThird: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGenderTransgender: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGenderTrasvesti: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGeometry: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGhost2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGhost3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGhostOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGhost: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGif: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGiftCard: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGiftOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGift: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGitBranchDeleted: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGitBranch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGitCherryPick: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGitCommit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGitCompare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGitFork: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGitMerge: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGitPullRequestClosed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGitPullRequestDraft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGitPullRequest: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGizmo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGlassChampagne: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGlassCocktail: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGlassFull: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGlassGin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGlassOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGlass: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGlobeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGlobe: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGoGame: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGolfOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGolf: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGps: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGradienter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGrain: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGraphOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGraph: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGrave2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGrave: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGrid3x3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGrid4x4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGridDots: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGridGoldenratio: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGridPattern: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGridScan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGrillFork: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGrillOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGrillSpatula: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGrill: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGripHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGripVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGrowth: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGuitarPick: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGymnastics: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconH1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconH2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconH3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconH4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconH5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconH6: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHammerOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHammer: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHandClickOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHandClick: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHandFingerDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHandFingerLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHandFingerOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHandFingerRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHandFinger: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHandGrab: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHandLittleFinger: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHandLoveYou: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHandMiddleFinger: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHandMove: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHandOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHandRingFinger: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHandSanitizer: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHandStop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHandThreeFingers: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHandTwoFingers: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHanger2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHangerOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHanger: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHash: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHazeMoon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHaze: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHdr: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeadingOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeading: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeadphonesOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeadphones: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeadsetOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeadset: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHealthRecognition: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartBitcoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartBroken: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartDiscount: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartHandshake: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartRateMonitor: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartSpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartbeat: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHearts: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelicopterLanding: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelicopter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelmetOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelmet: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelpCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelpHexagon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelpOctagon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelpOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelpSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelpSquareRounded: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelpSquare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelpTriangle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHemisphereOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHemispherePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHemisphere: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagon3d: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonAsterisk: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterA: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterB: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterC: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterD: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterE: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterF: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterG: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterH: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterI: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterJ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterK: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterL: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterM: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterN: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterO: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterP: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterQ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterR: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterS: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterT: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterU: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterV: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterW: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterY: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterZ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonMinus2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber0: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber6: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber7: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber8: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber9: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonPlus2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonalPrismOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonalPrismPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonalPrism: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonalPyramidOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonalPyramidPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonalPyramid: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagons: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHierarchy2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHierarchy3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHierarchyOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHierarchy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHighlightOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHighlight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHistoryOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHistoryToggle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHistory: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHome2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeBitcoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeDot: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeEco: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeEdit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeHand: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeInfinity: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeLink: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeMove: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeRibbon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeShield: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeSignal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeSpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeStats: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHome: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHorseToy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHorse: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHorseshoe: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHospitalCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHospital: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHotelService: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHourglassEmpty: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHourglassHigh: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHourglassLow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHourglassOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHourglass: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHours12: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHours24: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHtml: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpConnectOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpConnect: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpDeleteOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpDelete: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpGetOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpGet: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpHeadOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpHead: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpOptionsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpOptions: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpPatchOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpPatch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpPostOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpPost: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpPutOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpPut: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpQueOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpQue: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpTraceOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHttpTrace: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIceCream2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIceCreamOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIceCream: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIceSkating: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIconsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIcons: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIdBadge2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIdBadgeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIdBadge: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIdOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconId: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIkosaedr: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconImageInPicture: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInboxOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInbox: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIndentDecrease: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIndentIncrease: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInfinityOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInfinity: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInfoCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInfoHexagon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInfoOctagon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInfoSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInfoSquareRounded: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInfoSquare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInfoTriangle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInnerShadowBottomLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInnerShadowBottomRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInnerShadowBottom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInnerShadowLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInnerShadowRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInnerShadowTopLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInnerShadowTopRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInnerShadowTop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInputAi: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInputCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInputSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInputSpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInputX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInvoice: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIroning1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIroning2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIroning3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIroningOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIroningSteamOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIroningSteam: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIroning: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIrregularPolyhedronOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIrregularPolyhedronPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIrregularPolyhedron: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconItalic: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconJacket: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconJetpack: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconJewishStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconJoinBevel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconJoinRound: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconJoinStraight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconJoker: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconJpg: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconJson: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconJumpRope: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKarate: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKayak: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKerning: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKeyOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKey: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKeyboardHide: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKeyboardOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKeyboardShow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKeyboard: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKeyframeAlignCenter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKeyframeAlignHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKeyframeAlignVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKeyframe: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKeyframes: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLabelImportant: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLabelOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLabel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLadderOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLadder: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLadle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLambda: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLamp2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLampOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLamp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLane: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLanguageHiragana: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLanguageKatakana: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLanguageOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLanguage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLassoOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLassoPolygon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLasso: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLaurelWreath1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLaurelWreath2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLaurelWreath3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLaurelWreath: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayersDifference: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayersIntersect2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayersIntersect: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayersLinked: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayersOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayersSelectedBottom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayersSelected: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayersSubtract: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayersUnion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayout2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutAlignBottom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutAlignCenter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutAlignLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutAlignMiddle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutAlignRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutAlignTop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutBoardSplit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutBoard: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutBottombarCollapse: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutBottombarExpand: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutBottombarInactive: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutBottombar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutCards: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutCollage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutColumns: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutDashboard: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutDistributeHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutDistributeVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutGridAdd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutGridRemove: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutGrid: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutKanban: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutList: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutNavbarCollapse: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutNavbarExpand: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutNavbarInactive: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutNavbar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutRows: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutSidebarInactive: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutSidebarLeftCollapse: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutSidebarLeftExpand: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutSidebarRightCollapse: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutSidebarRightExpand: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutSidebarRightInactive: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutSidebarRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutSidebar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayout: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLeaf2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLeafOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLeaf: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLegoOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLego: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLemon2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLemon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterASmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterA: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterBSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterB: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterCSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterC: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterCaseLower: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterCaseToggle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterCaseUpper: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterCase: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterDSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterD: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterESmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterE: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterFSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterF: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterGSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterG: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterHSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterH: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterISmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterI: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterJSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterJ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterKSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterK: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterLSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterL: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterMSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterM: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterNSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterN: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterOSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterO: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterPSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterP: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterQSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterQ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterRSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterR: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterSSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterS: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterSpacing: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterTSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterT: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterUSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterU: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterVSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterV: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterWSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterW: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterXSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterYSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterY: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterZSmall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLetterZ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLibraryMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLibraryPhoto: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLibraryPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLibrary: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLicenseOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLicense: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLifebuoyOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLifebuoy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLighter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLineDashed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLineDotted: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLineHeight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLineScan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLinkMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLinkOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLinkPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLink: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconListCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconListDetails: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconListLetters: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconListNumbers: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconListSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconListTree: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconList: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLivePhotoOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLivePhoto: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLiveView: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLoadBalancer: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLoader2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLoader3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLoaderQuarter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLoader: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationBroken: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationDiscount: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockAccessOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockAccess: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockBitcoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockOpen2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockOpenOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockOpen: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockPassword: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockSquareRounded: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockSquare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLock: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLogicAnd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLogicBuffer: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLogicNand: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLogicNor: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLogicNot: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLogicOr: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLogicXnor: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLogicXor: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLogin2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLogin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLogout2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLogout: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLogs: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLollipopOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLollipop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLuggageOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLuggage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLungsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLungs: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMacroOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMacro: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMagnetOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMagnet: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMagnetic: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailAi: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailBitcoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailFast: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailForward: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailOpened: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailSpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMail: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailboxOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailbox: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconManualGearbox: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMap2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapDiscount: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapEast: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapNorth: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPin2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPins: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapRoute: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapSouth: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapWest: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMap: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMarkdownOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMarkdown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMarquee2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMarqueeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMarquee: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMars: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMaskOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMask: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMasksTheaterOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMasksTheater: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMassage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMatchstick: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMath1Divide2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMath1Divide3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathAvg: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathCos: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathCtg: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathEqualGreater: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathEqualLower: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathFunctionOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathFunctionY: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathFunction: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathGreater: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathIntegralX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathIntegral: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathIntegrals: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathLower: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathMaxMin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathMax: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathMin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathNot: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathPiDivide2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathPi: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathSec: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathSin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathSymbols: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathTg: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathXDivide2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathXDivideY2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathXDivideY: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathXFloorDivideY: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathXMinusX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathXMinusY: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathXPlusX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathXPlusY: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathXy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathYMinusY: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMathYPlusY: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMath: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMatrix: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMaximizeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMaximize: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMeatOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMeat: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMedal2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMedal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMedicalCrossCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMedicalCrossOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMedicalCross: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMedicineSyrup: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMeeple: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMelon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMenorah: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMenu2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMenu3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMenu4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMenuDeep: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMenuOrder: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMenu: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Bolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Cancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Check: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Code: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Cog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Dollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Down: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Exclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Heart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Minus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Off: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Pause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Pin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Plus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Question: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Search: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Share: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Star: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Up: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2X: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageChatbot: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCirclePause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCirclePin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCirclePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleUser: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageDots: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageForward: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageLanguage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessagePause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessagePin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessagePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageReply: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageReport: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageUser: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessagesOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessages: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMeteorOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMeteor: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMeterCube: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMeterSquare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMetronome: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMichelinBibGourmand: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMichelinStarGreen: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMichelinStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMickey: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMicrophone2Off: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMicrophone2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMicrophoneOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMicrophone: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMicroscopeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMicroscope: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMicrowaveOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMicrowave: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMilitaryAward: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMilitaryRank: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMilkOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMilk: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMilkshake: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMinimize: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMinusVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMistOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMist: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMobiledataOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMobiledata: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoneybagEdit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoneybagHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoneybagMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoneybagMoveBack: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoneybagMove: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoneybagPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoneybag: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMonkeybar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodAngry: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodAnnoyed2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodAnnoyed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodBitcoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodBoy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodConfuzed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodCrazyHappy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodCry: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodEdit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodEmpty: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodHappy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodKid: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodLookDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodLookLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodLookRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodLookUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodNerd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodNervous: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodNeutral: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodPuzzled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodSad2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodSadDizzy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodSadSquint: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodSad: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodSick: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodSilence: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodSing: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodSmileBeam: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodSmileDizzy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodSmile: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodSpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodSurprised: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodTongueWink2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodTongueWink: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodTongue: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodUnamused: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodWink2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodWink: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodWrrr: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodXd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoon2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoonOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoonStars: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoped: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMotorbike: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMountainOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMountain: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMouse2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMouseOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMouse: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoustache: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMovieOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMovie: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMugOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMug: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMultiplier05x: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMultiplier15x: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMultiplier1x: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMultiplier2x: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMushroomOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMushroom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicDiscount: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusicX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMusic: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationDiscount: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationEast: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationNorth: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationSouth: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationTop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationWest: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNeedleThread: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNeedle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNetworkOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNetwork: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNewSection: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNewsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNews: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNfcOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNfc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNoCopyright: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNoCreativeCommons: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNoDerivatives: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNorthStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNoteOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNote: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNotebookOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNotebook: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNotesOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNotes: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNotificationOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNotification: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber0Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber0: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber1Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber10Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber10: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber100Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber11Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber11: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber12Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber123: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber13Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber14Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber15Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber16Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber17Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber18Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber19Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber2Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber20Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber21Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber22Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber23Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber24Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber25Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber26Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber27Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber28Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber29Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber3Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber30Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber31Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber32Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber33Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber34Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber35Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber36Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber37Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber38Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber39Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber4Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber40Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber41Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber42Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber43Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber44Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber45Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber46Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber47Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber48Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber49Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber5Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber50Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber51Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber52Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber53Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber54Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber55Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber56Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber57Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber58Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber59Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber6Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber6: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber60Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber61Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber62Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber63Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber64Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber65Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber66Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber67Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber68Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber69Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber7Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber7: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber70Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber71Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber72Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber73Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber74Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber75Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber76Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber77Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber78Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber79Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber8Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber8: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber80Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber81Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber82Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber83Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber84Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber85Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber86Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber87Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber88Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber89Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber9Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber9: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber90Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber91Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber92Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber93Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber94Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber95Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber96Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber97Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber98Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber99Small: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumber: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNumbers: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNurse: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNut: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconObjectScan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOctagonMinus2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOctagonMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOctagonOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOctagonPlus2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOctagonPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOctagon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOctahedronOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOctahedronPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOctahedron: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOld: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOlympicsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOlympics: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOm: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOmega: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOption: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOutbound: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOutlet: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOvalVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOval: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOverline: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPackageExport: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPackageImport: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPackageOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPackage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPackages: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPacman: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPageBreak: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPaintOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPaint: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPaletteOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPalette: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPanoramaHorizontalOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPanoramaHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPanoramaVerticalOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPanoramaVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPaperBagOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPaperBag: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPaperclip: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconParachuteOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconParachute: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconParenthesesOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconParentheses: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconParkingCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconParkingOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconParking: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPasswordFingerprint: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPasswordMobilePhone: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPasswordUser: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPassword: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPawOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPaw: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPaywall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPdf: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPeace: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilDiscount: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencilX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPencil: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPennant2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPennantOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPennant: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPentagonMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPentagonNumber0: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPentagonNumber1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPentagonNumber2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPentagonNumber3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPentagonNumber4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPentagonNumber5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPentagonNumber6: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPentagonNumber7: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPentagonNumber8: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPentagonNumber9: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPentagonOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPentagonPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPentagonX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPentagon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPentagram: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPepperOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPepper: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPercentage0: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPercentage10: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPercentage100: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPercentage20: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPercentage25: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPercentage30: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPercentage33: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPercentage40: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPercentage50: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPercentage60: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPercentage66: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPercentage70: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPercentage75: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPercentage80: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPercentage90: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPercentage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPerfume: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPerspectiveOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPerspective: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhoneCall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhoneCalling: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhoneCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhoneDone: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhoneEnd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhoneIncoming: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhoneOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhoneOutgoing: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhonePause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhonePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhoneRinging: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhoneSpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhoneX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhone: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoAi: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoBitcoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoCircleMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoCirclePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoEdit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoHexagon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoPentagon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoScan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoSensor2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoSensor3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoSensor: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoShield: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoSpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoSquareRounded: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoVideo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhoto: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhysotherapist: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPiano: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPick: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPicnicTable: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPictureInPictureOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPictureInPictureOn: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPictureInPictureTop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPictureInPicture: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPigMoney: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPigOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPig: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPilcrowLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPilcrowRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPilcrow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPillOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPill: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPills: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPinEnd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPinInvoke: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPingPong: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPinnedOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPinned: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPizzaOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPizza: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaceholder: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaneArrival: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaneDeparture: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaneInflight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaneOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaneTilt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlane: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlanetOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlanet: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlant2Off: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlant2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlantOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlant: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayBasketball: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard10: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard6: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard7: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard8: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard9: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCardA: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCardJ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCardK: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCardOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCardQ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCardStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayFootball: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayHandball: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayVolleyball: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayerEject: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayerPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayerPlay: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayerRecord: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayerSkipBack: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayerSkipForward: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayerStop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayerTrackNext: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayerTrackPrev: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaylistAdd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaylistOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaylistX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaylist: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaystationCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaystationSquare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaystationTriangle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaystationX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlugConnectedX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlugConnected: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlugOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlugX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlug: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlusEqual: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlusMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPng: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPodiumOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPodium: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPoint: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointer: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPokeballOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPokeball: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPokerChip: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPolaroid: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPolygonOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPolygon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPoo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPoolOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPool: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPower: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPray: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPremiumRights: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPrescription: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPresentationAnalytics: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPresentationOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPresentation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPrinterOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPrinter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPrismLight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPrismOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPrismPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPrism: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPrison: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconProgressAlert: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconProgressBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconProgressCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconProgressDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconProgressHelp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconProgressX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconProgress: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPrompt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconProng: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPropellerOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPropeller: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconProtocol: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPumpkinScary: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPuzzle2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPuzzleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPuzzle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPyramidOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPyramidPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPyramid: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconQrcodeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconQrcode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconQuestionMark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconQuoteOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconQuote: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconQuotes: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRadar2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRadarOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRadar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRadioOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRadio: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRadioactiveOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRadioactive: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRadiusBottomLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRadiusBottomRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRadiusTopLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRadiusTopRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRainbowOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRainbow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRating12Plus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRating14Plus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRating16Plus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRating18Plus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRating21Plus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRazorElectric: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRazor: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceipt2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceiptBitcoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceiptDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceiptEuro: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceiptOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceiptPound: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceiptRefund: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceiptRupee: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceiptTax: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceiptYen: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceiptYuan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceipt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRecharging: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRecordMailOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRecordMail: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRectangleRoundedBottom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRectangleRoundedTop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRectangleVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRectangle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRectangularPrismOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRectangularPrismPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRectangularPrism: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRecycleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRecycle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRefreshAlert: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRefreshDot: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRefreshOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRefresh: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRegexOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRegex: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRegistered: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRelationManyToMany: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRelationOneToMany: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRelationOneToOne: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReload: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReorder: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRepeatOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRepeatOnce: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRepeat: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReplaceOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReplaceUser: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReplace: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReportAnalytics: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReportMedical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReportMoney: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReportOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReportSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReport: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReservedLine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconResize: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRestore: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRewindBackward10: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRewindBackward15: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRewindBackward20: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRewindBackward30: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRewindBackward40: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRewindBackward5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRewindBackward50: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRewindBackward60: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRewindForward10: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRewindForward15: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRewindForward20: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRewindForward30: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRewindForward40: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRewindForward5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRewindForward50: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRewindForward60: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRibbonHealth: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRings: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRippleDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRippleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRippleUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRipple: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRoadOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRoadSign: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRoad: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRobotFace: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRobotOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRobot: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRocketOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRocket: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRollerSkating: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRollercoasterOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRollercoaster: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosetteAsterisk: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosetteDiscountCheckOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosetteDiscountCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosetteDiscountOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosetteDiscount: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosetteNumber0: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosetteNumber1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosetteNumber2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosetteNumber3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosetteNumber4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosetteNumber5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosetteNumber6: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosetteNumber7: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosetteNumber8: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosetteNumber9: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosette: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRotate2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRotate360: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRotate3d: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRotateClockwise2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRotateClockwise: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRotateDot: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRotateRectangle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRotate: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRoute2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRouteAltLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRouteAltRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRouteOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRouteScan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRouteSquare2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRouteSquare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRouteX2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRouteX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRoute: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRouterOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRouter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRowInsertBottom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRowInsertTop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRowRemove: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRss: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRubberStampOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRubberStamp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRuler2Off: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRuler2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRuler3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRulerMeasure2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRulerMeasure: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRulerOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRuler: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRun: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRvTruck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSTurnDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSTurnLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSTurnRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSTurnUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSailboat2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSailboatOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSailboat: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSalad: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSalt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSandbox: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSatelliteOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSatellite: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSausage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScaleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScaleOutlineOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScaleOutline: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScale: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScanEye: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScanPosition: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSchemaOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSchema: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSchoolBell: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSchoolOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSchool: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScissorsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScissors: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScooterElectric: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScooter: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScoreboard: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScreenShareOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScreenShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScreenshot: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScribbleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScribble: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScriptMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScriptPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScriptX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScript: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScubaDivingTank: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScubaDiving: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScubaMaskOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScubaMask: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSdk: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSearchOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSectionSign: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSection: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSeedlingOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSeedling: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSelectAll: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSelect: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSelector: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSend2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSendOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSend: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSeo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSeparatorHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSeparatorVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSeparator: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconServer2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconServerBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconServerCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconServerOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconServerSpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconServer: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconServicemark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettings2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsAi: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsAutomation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsSpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettings: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShadowOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShadow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShape2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShape3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShapeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShape: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShare2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShare3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShareOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShareplay: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldCheckered: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldChevron: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldHalf: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldLock: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShield: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShipOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShip: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShirtOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShirtSport: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShirt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoe: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingBagCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingBagDiscount: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingBagEdit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingBagExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingBagHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingBagMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingBagPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingBagSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingBagX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingBag: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartCopy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartDiscount: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShovelPitchforks: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShovel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShredder: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSignLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSignRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSignal2g: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSignal3g: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSignal4gPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSignal4g: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSignal5g: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSignal6g: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSignalE: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSignalG: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSignalHPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSignalH: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSignalLte: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSignatureOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSignature: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSitemapOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSitemap: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSkateboardOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSkateboard: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSkateboarding: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSkewX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSkewY: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSkiJumping: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSkull: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSlash: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSlashes: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSleigh: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSlice: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSlideshow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSmartHomeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSmartHome: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSmokingNo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSmoking: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSnowboarding: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSnowflakeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSnowflake: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSnowman: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSoccerField: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSocialOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSocial: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSock: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSofaOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSofa: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSolarElectricity: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSolarPanel2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSolarPanel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSort09: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSort90: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSortAZ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSortAscending2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSortAscendingLetters: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSortAscendingNumbers: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSortAscendingShapes: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSortAscendingSmallBig: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSortAscending: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSortDescending2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSortDescendingLetters: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSortDescendingNumbers: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSortDescendingShapes: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSortDescendingSmallBig: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSortDescending: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSortZA: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSos: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSoupOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSoup: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSourceCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSpaceOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSpace: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSpaces: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSpacingHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSpacingVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSpade: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSparkles2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSparkles: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSpeakerphone: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSpeedboat: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSphereOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSpherePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSphere: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSpider: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSpiralOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSpiral: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSportBillard: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSpray: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSpyOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSpy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSql: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareArrowDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareArrowLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareArrowRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareArrowUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareAsterisk: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareChevronDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareChevronLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareChevronRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareChevronUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareChevronsDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareChevronsLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareChevronsRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareChevronsUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareDashed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareDot: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF0: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF6: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF7: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF8: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF9: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareForbid2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareForbid: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareHalf: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareKey: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterA: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterB: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterC: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterD: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterE: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterF: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterG: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterH: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterI: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterJ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterK: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterL: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterM: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterN: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterO: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterP: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterQ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterR: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterS: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterT: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterU: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterV: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterW: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterY: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterZ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareMinus2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber0: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber6: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber7: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber8: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber9: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquarePercentage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquarePlus2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquarePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoot2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoot: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRotatedAsterisk: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRotatedForbid2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRotatedForbid: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRotatedOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRotated: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedArrowDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedArrowLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedArrowRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedArrowUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedChevronDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedChevronLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedChevronRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedChevronUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedChevronsDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedChevronsLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedChevronsRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedChevronsUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterA: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterB: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterC: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterD: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterE: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterF: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterG: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterH: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterI: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterJ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterK: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterL: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterM: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterN: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterO: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterP: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterQ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterR: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterS: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterT: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterU: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterV: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterW: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterY: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterZ: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedMinus2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber0: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber6: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber7: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber8: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber9: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedPercentage: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedPlus2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRounded: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareToggleHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareToggle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquaresDiagonal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquaresSelected: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquares: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStack2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStack3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStackBack: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStackBackward: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStackForward: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStackFront: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStackMiddle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStackPop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStackPush: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStack: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStairsDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStairsUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStairs: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStarHalf: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStarOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStarsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStars: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStatusChange: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSteam: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSteeringWheelOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSteeringWheel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStepInto: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStepOut: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStereoGlasses: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStethoscopeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStethoscope: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSticker2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSticker: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStopwatch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStormOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStorm: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStretching2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStretching: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStrikethrough: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSubmarine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSubscript: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSubtask: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSubtitlesAi: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSubtitlesEdit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSubtitlesOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSubtitles: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSumOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSum: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSunElectricity: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSunHigh: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSunLow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSunMoon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSunOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSunWind: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSun: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSunglasses: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSunrise: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSunset2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSunset: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSuperscript: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSvg: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSwimming: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSwipeDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSwipeLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSwipeRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSwipeUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSwipe: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSwitch2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSwitch3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSwitchHorizontal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSwitchVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSwitch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSwordOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSword: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSwords: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTableAlias: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTableColumn: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTableDashed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTableDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTableExport: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTableHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTableImport: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTableMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTableOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTableOptions: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTablePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTableRow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTableShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTableShortcut: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTableSpark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTable: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTagMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTagOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTagPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTagStarred: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTag: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTagsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTags: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTallymark1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTallymark2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTallymark3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTallymark4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTallymarks: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTank: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTargetArrow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTargetOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTarget: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTaxEuro: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTaxPound: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTax: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTeapot: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTelescopeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTelescope: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTemperatureCelsius: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTemperatureFahrenheit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTemperatureMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTemperatureOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTemperaturePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTemperatureSnow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTemperatureSun: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTemperature: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTemplateOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTemplate: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTentOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTent: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTerminal2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTerminal: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTestPipe2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTestPipeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTestPipe: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTex: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTextCaption: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTextColor: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTextDecrease: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTextDirectionLtr: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTextDirectionRtl: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTextGrammar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTextIncrease: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTextOrientation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTextPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTextRecognition: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTextResize: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTextScan2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTextSize: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTextSpellcheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTextWrapColumn: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTextWrapDisabled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTextWrap: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTexture: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTheater: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconThermometer: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconThumbDownOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconThumbDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconThumbUpOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconThumbUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTicTac: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTicketOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTicket: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTie: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTilde: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTiltShiftOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTiltShift: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTimeDuration0: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTimeDuration10: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTimeDuration15: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTimeDuration30: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTimeDuration45: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTimeDuration5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTimeDuration60: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTimeDuration90: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTimeDurationOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTimelineEventExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTimelineEventMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTimelineEventPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTimelineEventText: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTimelineEventX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTimelineEvent: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTimeline: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTimezone: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTipJarEuro: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTipJarPound: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTipJar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTir: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconToggleLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconToggleRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconToiletPaperOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconToiletPaper: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconToml: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTool: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconToolsKitchen2Off: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconToolsKitchen2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconToolsKitchen3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconToolsKitchenOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconToolsKitchen: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconToolsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTools: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTooltip: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTopologyBus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTopologyComplex: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTopologyFullHierarchy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTopologyFull: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTopologyRing2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTopologyRing3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTopologyRing: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTopologyStar2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTopologyStar3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTopologyStarRing2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTopologyStarRing3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTopologyStarRing: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTopologyStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTorii: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTornado: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTournament: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTowerOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTower: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrack: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTractor: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrademark: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrafficConeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrafficCone: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrafficLightsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrafficLights: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrain: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransactionBitcoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransactionDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransactionEuro: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransactionPound: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransactionRupee: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransactionYen: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransactionYuan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransferIn: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransferOut: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransferVertical: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransfer: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransformPointBottomLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransformPointBottomRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransformPointTopLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransformPointTopRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransformPoint: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransform: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransitionBottom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransitionLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransitionRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransitionTop: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrashOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrashX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrash: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTreadmill: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTree: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrees: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrekking: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrendingDown2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrendingDown3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrendingDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrendingUp2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrendingUp3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrendingUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTriangleInverted: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTriangleMinus2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTriangleMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTriangleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrianglePlus2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrianglePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTriangleSquareCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTriangle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTriangles: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrident: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrolley: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrophyOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrophy: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrowel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTruckDelivery: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTruckLoading: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTruckOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTruckReturn: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTruck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTxt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTypeface: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTypographyOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTypography: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUTurnLeft: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUTurnRight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUfoOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUfo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUhd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUmbrella2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUmbrellaClosed2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUmbrellaClosed: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUmbrellaOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUmbrella: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUnderline: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUniverse: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUnlink: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUpload: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUrgent: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUsb: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserBitcoin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserEdit: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserHexagon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserPentagon: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserScan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserScreen: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserShield: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserSquareRounded: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserSquare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUser: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUsersGroup: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUsersMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUsersPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUsers: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUvIndex: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUxCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVaccineBottleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVaccineBottle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVaccineOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVaccine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVacuumCleaner: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVariableMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVariableOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVariablePlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVariable: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVectorBezier2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVectorBezierArc: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVectorBezierCircle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVectorBezier: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVectorOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVectorSpline: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVectorTriangleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVectorTriangle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVector: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVenus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVersionsOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVersions: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVideoMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVideoOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVideoPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVideo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconView360Arrow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconView360Number: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconView360Off: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconView360: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconViewfinderOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconViewfinder: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconViewportNarrow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconViewportShort: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconViewportTall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconViewportWide: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVinyl: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVipOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVip: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVirusOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVirusSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVirus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVocabularyOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVocabulary: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVolcano: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVolume2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVolume3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVolume4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVolumeOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVolume: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVs: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWalk: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWallOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWalletOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWallet: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWallpaperOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWallpaper: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWandOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWand: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashDry1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashDry2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashDry3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashDryA: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashDryDip: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashDryF: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashDryFlat: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashDryHang: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashDryOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashDryP: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashDryShade: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashDryW: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashDry: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashDrycleanOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashDryclean: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashEco: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashGentle: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashHand: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashMachine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashPress: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashTemperature1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashTemperature2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashTemperature3: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashTemperature4: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashTemperature5: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashTemperature6: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashTumbleDry: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWashTumbleOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWash: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWaterpolo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWaveSawTool: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWaveSine: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWaveSquare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWavesElectricity: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWebhookOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWebhook: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWeight: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWheatOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWheat: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWheel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWheelchairOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWheelchair: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWhirl: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWhisk: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWifi0: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWifi1: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWifi2: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWifiOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWifi: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWindElectricity: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWindOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWind: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWindmillOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWindmill: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWindowMaximize: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWindowMinimize: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWindowOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWindow: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWindsock: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWiperWash: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWiper: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWoman: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWood: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldBolt: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldCog: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldDollar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldDown: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldDownload: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldHeart: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldLatitude: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldLongitude: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldMinus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldPause: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldPin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldPlus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldSearch: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldShare: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldStar: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldUp: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldUpload: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldWww: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorldX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWorld: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWreckingBall: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWritingOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWritingSignOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWritingSign: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWriting: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconXPowerY: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconXboxA: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconXboxB: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconXboxX: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconXboxY: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconXd: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconXxx: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconYinYang: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconYoga: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZeppelinOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZeppelin: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZip: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZodiacAquarius: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZodiacAries: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZodiacCancer: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZodiacCapricorn: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZodiacGemini: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZodiacLeo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZodiacLibra: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZodiacPisces: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZodiacSagittarius: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZodiacScorpio: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZodiacTaurus: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZodiacVirgo: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomCancel: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomCheck: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomCode: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomExclamation: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomInArea: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomIn: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomMoney: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomOutArea: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomOut: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomPan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomQuestion: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomReplace: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomReset: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomScan: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoom: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZzzOff: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZzz: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAccessibleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdCircleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAdjustmentsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAerialLiftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAffiliateFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAirBalloonFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlarmMinusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlarmPlusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlarmSnoozeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlarmFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlertCircleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlertHexagonFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlertOctagonFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlertSquareRoundedFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlertSquareFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlertTriangleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlienFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxBottomCenterFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxBottomLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxBottomRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxCenterMiddleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxLeftBottomFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxLeftMiddleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxLeftTopFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxRightBottomFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxRightMiddleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxRightTopFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxTopCenterFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxTopLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAlignBoxTopRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAnalyzeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAppWindowFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAppleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAppsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArchiveFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowAutofitContentFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowAutofitDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowAutofitHeightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowAutofitLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowAutofitRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowAutofitUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowAutofitWidthFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBadgeDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBadgeLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBadgeRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBadgeUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigDownLineFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigDownLinesFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigLeftLineFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigLeftLinesFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigRightLineFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigRightLinesFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigUpLineFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigUpLinesFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowBigUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowDownCircleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowDownRhombusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowDownSquareFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowGuideFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowLeftCircleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowLeftRhombusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowLeftSquareFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowMoveDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowMoveLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowMoveRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowMoveUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRightCircleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRightRhombusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowRightSquareFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowUpCircleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowUpRhombusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArrowUpSquareFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArtboardFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconArticleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAspectRatioFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAssemblyFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAssetFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAtom2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAutomaticGearboxFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconAwardFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBabyCarriageFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBackspaceFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadge3dFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadge4kFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadge8kFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeAdFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeArFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeCcFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeHdFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeSdFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeTmFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeVoFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeVrFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeWcFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBadgesFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBallBowlingFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBalloonFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBallpenFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBandageFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBarbellFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBarrierBlockFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBasketFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBathFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBattery1Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBattery2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBattery3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBattery4Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryAutomotiveFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryVertical1Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryVertical2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryVertical3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryVertical4Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryVerticalFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBatteryFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBedFlatFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBedFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBeerFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellMinusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellPlusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellRinging2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellRingingFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellXFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellZFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBellFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBikeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBinaryTree2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBinaryTreeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBinocularsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBiohazardFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBladeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBlenderFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBlobFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoltFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBombFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoneFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBongFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBookFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBookmarkFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBookmarksFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoomFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBottleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBounceLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBounceRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBowFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBowlChopsticksFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBowlSpoonFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBowlFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxAlignBottomLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxAlignBottomRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxAlignBottomFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxAlignLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxAlignRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxAlignTopLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxAlignTopRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxAlignTopFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBoxMultipleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAngularFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandAppleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandBitbucketFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDiscordFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandDribbbleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandFacebookFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGithubFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandGoogleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandInstagramFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandKickFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandLinkedinFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandMessengerFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandOpenSourceFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandOperaFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPatreonFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPaypalFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandPinterestFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSketchFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSnapchatFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSpotifyFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandSteamFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandStripeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTablerFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTiktokFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTinderFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTumblrFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandTwitterFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandVercelFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandVimeoFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandWeiboFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandWhatsappFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandWindowsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandXFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrandYoutubeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBreadFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBriefcase2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBriefcaseFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrightnessAutoFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrightnessDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrightnessUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBrightnessFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBubbleTextFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBubbleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBugFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingBridge2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBuildingBroadcastTowerFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBulbFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconBusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconButterflyFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCactusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalculatorFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarEventFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarMonthFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarWeekFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCalendarFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCameraFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCampfireFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCandleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCannabisFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCapsuleHorizontalFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCapsuleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCaptureFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCar4wdFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarCraneFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarFanFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarSuvFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarambolaFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCaravanFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCardboardsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCardsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCaretDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCaretLeftRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCaretLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCaretRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCaretUpDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCaretUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarouselHorizontalFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCarouselVerticalFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCashBanknoteFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCategoryFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChargingPileFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartAreaLineFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartAreaFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartBubbleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartCandleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartDonutFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartDots2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartDots3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartDotsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartFunnelFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartGridDotsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartPie2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartPie3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartPie4Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChartPieFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChefHatFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCherryFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChessBishopFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChessKingFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChessKnightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChessQueenFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChessRookFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChessFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconChristmasTreeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleArrowDownLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleArrowDownRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleArrowDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleArrowLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleArrowRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleArrowUpLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleArrowUpRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleArrowUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleCaretDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleCaretLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleCaretRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleCaretUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleCheckFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleChevronDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleChevronLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleChevronRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleChevronUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleChevronsDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleChevronsLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleChevronsRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleChevronsUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleDotFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleKeyFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterAFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterBFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterCFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterDFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterEFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterFFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterGFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterHFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterIFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterJFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterKFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterLFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterMFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterNFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterOFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterPFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterQFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterRFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterSFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterTFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterUFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterVFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterWFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterXFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterYFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleLetterZFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber0Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber1Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber4Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber5Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber6Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber7Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber8Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleNumber9Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCirclePercentageFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCirclePlusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleRectangleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleXFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCircleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCirclesFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardCheckFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardDataFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardListFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardPlusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardSmileFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardTextFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardTypographyFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardXFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClipboardFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour1Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour10Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour11Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour12Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour4Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour5Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour6Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour7Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour8Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockHour9Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClockFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudComputingFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudDataConnectionFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloudFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCloverFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconClubsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCodeCircle2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCodeCircleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoinBitcoinFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoinEuroFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoinMoneroFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoinPoundFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoinRupeeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoinTakaFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoinYenFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoinYuanFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCoinFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconColumns1Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconColumns2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconColumns3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCompassFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCone2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconConeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconConfettiFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconContainerFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconContrast2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconContrastFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCookieManFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCookieFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCopyCheckFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCopyMinusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCopyPlusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCopyXFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCopyleftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCopyrightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCreditCardFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrop11Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrop169Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrop32Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrop54Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrop75Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCropLandscapeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCropPortraitFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrossFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCrownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconCurrentLocationFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDashboardFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceCctvFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceDesktopFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceGamepad3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceGamepadFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceHeartMonitorFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceImacFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceIpadFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceMobileFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceRemoteFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceSpeakerFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTabletFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTvOldFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceTvFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceUnknownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceUsbFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceVisionProFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDeviceWatchFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDialpadFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDiamondFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDiamondsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDice1Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDice2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDice3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDice4Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDice5Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDice6Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDiceFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDirectionArrowsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDirectionSignFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDirectionsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDiscFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDiscountFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropCircleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletHalf2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletHalfFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDropletsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDualScreenFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconDumplingFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEaseInControlPointFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEaseInOutControlPointsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEaseOutControlPointFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEggCrackedFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEggFriedFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEggFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconElevatorFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEngineFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEscalatorDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEscalatorUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEscalatorFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExchangeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExclamationCircleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExplicitFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconExposureFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeTableFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeglass2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconEyeglassFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFaceMaskFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFaviconFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFeatherFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFenceFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFerryFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFidgetSpinnerFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileAnalyticsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileCheckFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileCode2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileCodeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileCvFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileDeltaFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileDescriptionFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileDiffFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileDigitFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileDollarFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileDotsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileDownloadFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileEuroFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileFunctionFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileHorizontalFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileInfoFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileInvoiceFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileLambdaFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileMinusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileMusicFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileNeutralFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilePencilFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilePercentFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilePhoneFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilePowerFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileRssFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileSadFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileScissorsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileSettingsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileSignalFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileSmileFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileStarFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTextFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTimeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileTypographyFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileUnknownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileUploadFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileVectorFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileXFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFileFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilesFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFilterFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFiltersFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFishBoneFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlag2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlag3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlagFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlameFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlareFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlask2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlaskFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFlowerFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderOpenFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFolderFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFoldersFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconForbid2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconForbidFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFountainFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconFunctionFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGardenCartFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGasStationFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGaugeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGhost2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGhost3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGhostFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGiftCardFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGiftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGlassFullFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGlassFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGlobeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGolfFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGpsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGraphFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGridPatternFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconGuitarPickFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHanger2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeadphonesFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartBrokenFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHeartFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelicopterLandingFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelicopterFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelpCircleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelpHexagonFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelpOctagonFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelpSquareRoundedFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelpSquareFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHelpTriangleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterAFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterBFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterCFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterDFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterEFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterFFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterGFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterHFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterIFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterJFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterKFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterLFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterMFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterNFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterOFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterPFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterQFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterRFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterSFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterTFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterUFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterVFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterWFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterXFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterYFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonLetterZFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonMinusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber0Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber1Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber4Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber5Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber6Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber7Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber8Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonNumber9Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonPlusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHexagonFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHomeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHospitalCircleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconHourglassFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIconsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInfoCircleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInfoHexagonFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInfoOctagonFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInfoSquareRoundedFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInfoSquareFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInfoTriangleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInnerShadowBottomLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInnerShadowBottomRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInnerShadowBottomFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInnerShadowLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInnerShadowRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInnerShadowTopLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInnerShadowTopRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconInnerShadowTopFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIroning1Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIroning2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIroning3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIroningSteamFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconIroningFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconJetpackFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconJewishStarFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKeyFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKeyboardFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKeyframeAlignCenterFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKeyframeAlignHorizontalFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKeyframeAlignVerticalFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKeyframeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconKeyframesFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLabelImportantFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLabelFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLassoPolygonFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLaurelWreath1Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLaurelWreath2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLaurelWreath3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLaurelWreathFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayout2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutAlignBottomFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutAlignCenterFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutAlignLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutAlignMiddleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutAlignRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutAlignTopFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutBoardSplitFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutBoardFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutBottombarCollapseFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutBottombarExpandFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutBottombarFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutCardsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutDashboardFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutDistributeHorizontalFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutDistributeVerticalFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutGridFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutKanbanFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutListFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutNavbarCollapseFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutNavbarExpandFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutNavbarFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutSidebarLeftCollapseFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutSidebarLeftExpandFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutSidebarRightCollapseFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutSidebarRightExpandFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutSidebarRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutSidebarFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLayoutFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLeafFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLegoFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLemon2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLibraryPlusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLibraryFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLifebuoyFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLivePhotoFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLiveViewFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLocationFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockSquareRoundedFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLockFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconLungsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMacroFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMagnetFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailOpenedFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMailFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconManFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconManualGearboxFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMapPinFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMedicalCrossFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMeepleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMelonFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessage2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageChatbotFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageCircleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageReportFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMessageFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMeteorFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMichelinStarFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMickeyFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMicrophoneFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMicroscopeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMicrowaveFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMilitaryRankFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMilkFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodAngryFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodConfuzedFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodCrazyHappyFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodEmptyFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodHappyFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodKidFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodNeutralFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodSadFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodSmileFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoodWrrrFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMoonFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMotorbikeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMountainFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMouseFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMugFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconMushroomFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNavigationFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconNurseFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOctagonMinusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOctagonPlusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOctagonFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOvalVerticalFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconOvalFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPacmanFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPaintFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPaletteFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPanoramaHorizontalFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPanoramaVerticalFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconParkingCircleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPawFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPennant2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPennantFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPentagonFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhoneCallFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhoneCallingFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhoneCheckFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhoneXFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhoneFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPhotoFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPictureInPictureTopFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPictureInPictureFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPigFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPillFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPinFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPinnedFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPizzaFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaneArrivalFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaneDepartureFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaneTiltFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaneFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard1Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard10Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard4Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard5Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard6Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard7Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard8Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCard9Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCardAFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCardJFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCardKFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCardQFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCardStarFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayCardFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayerEjectFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayerPauseFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayerPlayFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayerRecordFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayerSkipBackFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayerSkipForwardFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayerStopFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayerTrackNextFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlayerTrackPrevFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPlaylistFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPointerFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPolaroidFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPooFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPresentationAnalyticsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPresentationFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconPuzzleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconQuoteFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRadarFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRadioactiveFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceiptDollarFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceiptEuroFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceiptPoundFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceiptRupeeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceiptYenFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceiptYuanFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReceiptFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRectangleVerticalFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRectangleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRegisteredFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRelationManyToManyFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRelationOneToManyFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRelationOneToOneFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReplaceFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReportAnalyticsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconReportMoneyFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRollercoasterFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosetteDiscountCheckFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosetteDiscountFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconRosetteFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSaladFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSatelliteFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconScubaDivingTankFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSectionFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSeedlingFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSettingsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldCheckFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldCheckeredFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldHalfFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldLockFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShieldFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShirtFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconShoppingCartFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSignLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSignRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSitemapFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSortAscending2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSortAscendingShapesFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSortDescending2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSortDescendingShapesFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSoupFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSpadeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSparkles2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSparklesFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSpeedboatFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSpiderFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareArrowDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareArrowLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareArrowRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareArrowUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareAsteriskFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareCheckFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareChevronDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareChevronLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareChevronRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareChevronUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareChevronsDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareChevronsLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareChevronsRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareChevronsUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareDotFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF0Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF1Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF4Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF5Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF6Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF7Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF8Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareF9Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterAFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterBFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterCFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterDFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterEFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterFFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterGFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterHFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterIFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterJFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterKFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterLFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterMFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterNFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterOFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterPFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterQFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterRFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterSFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterTFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterUFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterVFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterWFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterXFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterYFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareLetterZFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareMinusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber0Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber1Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber4Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber5Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber6Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber7Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber8Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareNumber9Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRotatedFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedArrowDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedArrowLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedArrowRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedArrowUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedCheckFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedChevronDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedChevronLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedChevronRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedChevronUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedChevronsDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedChevronsLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedChevronsRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedChevronsUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterAFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterBFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterCFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterDFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterEFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterFFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterGFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterHFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterIFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterJFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterKFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterLFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterMFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterNFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterOFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterPFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterQFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterRFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterSFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterTFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterUFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterVFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterWFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterXFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterYFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedLetterZFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedMinusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber0Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber1Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber4Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber5Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber6Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber7Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber8Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedNumber9Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedPlusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedXFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareRoundedFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareXFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquareFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSquaresFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStack2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStack3Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStackFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStarHalfFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStarFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconStarsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSteeringWheelFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSunHighFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSunLowFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSunFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSunglassesFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSunriseFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSunset2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSunsetFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSwipeDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSwipeLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSwipeRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconSwipeUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTableFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTagFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTagsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTemperatureMinusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTemperaturePlusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTemplateFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTestPipe2Filled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconThumbDownFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconThumbUpFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTiltShiftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTimelineEventFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconToggleLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconToggleRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrainFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransformFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransitionBottomFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransitionLeftFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransitionRightFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTransitionTopFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrashXFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrashFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTriangleInvertedFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTriangleSquareCircleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTriangleFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrolleyFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTrophyFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconTruckFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUfoFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUmbrellaFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconUserFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVersionsFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVideoMinusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVideoPlusFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconVideoFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWindmillFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWindsockFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWomanFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWritingSignFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconWritingFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconXboxAFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconXboxBFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconXboxXFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconXboxYFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconYinYangFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZeppelinFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomCancelFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomCheckFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomCodeFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomExclamationFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomInAreaFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomInFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomMoneyFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomOutAreaFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomOutFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomPanFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomQuestionFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomScanFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const IconZoomFilled: react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

declare const index_IconAB: typeof IconAB;
declare const index_IconAB2: typeof IconAB2;
declare const index_IconABOff: typeof IconABOff;
declare const index_IconAbacus: typeof IconAbacus;
declare const index_IconAbacusOff: typeof IconAbacusOff;
declare const index_IconAbc: typeof IconAbc;
declare const index_IconAccessPoint: typeof IconAccessPoint;
declare const index_IconAccessPointOff: typeof IconAccessPointOff;
declare const index_IconAccessible: typeof IconAccessible;
declare const index_IconAccessibleFilled: typeof IconAccessibleFilled;
declare const index_IconAccessibleOff: typeof IconAccessibleOff;
declare const index_IconActivity: typeof IconActivity;
declare const index_IconActivityHeartbeat: typeof IconActivityHeartbeat;
declare const index_IconAd: typeof IconAd;
declare const index_IconAd2: typeof IconAd2;
declare const index_IconAdCircle: typeof IconAdCircle;
declare const index_IconAdCircleFilled: typeof IconAdCircleFilled;
declare const index_IconAdCircleOff: typeof IconAdCircleOff;
declare const index_IconAdFilled: typeof IconAdFilled;
declare const index_IconAdOff: typeof IconAdOff;
declare const index_IconAddressBook: typeof IconAddressBook;
declare const index_IconAddressBookOff: typeof IconAddressBookOff;
declare const index_IconAdjustments: typeof IconAdjustments;
declare const index_IconAdjustmentsAlt: typeof IconAdjustmentsAlt;
declare const index_IconAdjustmentsBolt: typeof IconAdjustmentsBolt;
declare const index_IconAdjustmentsCancel: typeof IconAdjustmentsCancel;
declare const index_IconAdjustmentsCheck: typeof IconAdjustmentsCheck;
declare const index_IconAdjustmentsCode: typeof IconAdjustmentsCode;
declare const index_IconAdjustmentsCog: typeof IconAdjustmentsCog;
declare const index_IconAdjustmentsDollar: typeof IconAdjustmentsDollar;
declare const index_IconAdjustmentsDown: typeof IconAdjustmentsDown;
declare const index_IconAdjustmentsExclamation: typeof IconAdjustmentsExclamation;
declare const index_IconAdjustmentsFilled: typeof IconAdjustmentsFilled;
declare const index_IconAdjustmentsHeart: typeof IconAdjustmentsHeart;
declare const index_IconAdjustmentsHorizontal: typeof IconAdjustmentsHorizontal;
declare const index_IconAdjustmentsMinus: typeof IconAdjustmentsMinus;
declare const index_IconAdjustmentsOff: typeof IconAdjustmentsOff;
declare const index_IconAdjustmentsPause: typeof IconAdjustmentsPause;
declare const index_IconAdjustmentsPin: typeof IconAdjustmentsPin;
declare const index_IconAdjustmentsPlus: typeof IconAdjustmentsPlus;
declare const index_IconAdjustmentsQuestion: typeof IconAdjustmentsQuestion;
declare const index_IconAdjustmentsSearch: typeof IconAdjustmentsSearch;
declare const index_IconAdjustmentsShare: typeof IconAdjustmentsShare;
declare const index_IconAdjustmentsSpark: typeof IconAdjustmentsSpark;
declare const index_IconAdjustmentsStar: typeof IconAdjustmentsStar;
declare const index_IconAdjustmentsUp: typeof IconAdjustmentsUp;
declare const index_IconAdjustmentsX: typeof IconAdjustmentsX;
declare const index_IconAerialLift: typeof IconAerialLift;
declare const index_IconAerialLiftFilled: typeof IconAerialLiftFilled;
declare const index_IconAffiliate: typeof IconAffiliate;
declare const index_IconAffiliateFilled: typeof IconAffiliateFilled;
declare const index_IconAi: typeof IconAi;
declare const index_IconAirBalloon: typeof IconAirBalloon;
declare const index_IconAirBalloonFilled: typeof IconAirBalloonFilled;
declare const index_IconAirConditioning: typeof IconAirConditioning;
declare const index_IconAirConditioningDisabled: typeof IconAirConditioningDisabled;
declare const index_IconAirTrafficControl: typeof IconAirTrafficControl;
declare const index_IconAlarm: typeof IconAlarm;
declare const index_IconAlarmAverage: typeof IconAlarmAverage;
declare const index_IconAlarmFilled: typeof IconAlarmFilled;
declare const index_IconAlarmMinus: typeof IconAlarmMinus;
declare const index_IconAlarmMinusFilled: typeof IconAlarmMinusFilled;
declare const index_IconAlarmOff: typeof IconAlarmOff;
declare const index_IconAlarmPlus: typeof IconAlarmPlus;
declare const index_IconAlarmPlusFilled: typeof IconAlarmPlusFilled;
declare const index_IconAlarmSmoke: typeof IconAlarmSmoke;
declare const index_IconAlarmSnooze: typeof IconAlarmSnooze;
declare const index_IconAlarmSnoozeFilled: typeof IconAlarmSnoozeFilled;
declare const index_IconAlbum: typeof IconAlbum;
declare const index_IconAlbumOff: typeof IconAlbumOff;
declare const index_IconAlertCircle: typeof IconAlertCircle;
declare const index_IconAlertCircleFilled: typeof IconAlertCircleFilled;
declare const index_IconAlertCircleOff: typeof IconAlertCircleOff;
declare const index_IconAlertHexagon: typeof IconAlertHexagon;
declare const index_IconAlertHexagonFilled: typeof IconAlertHexagonFilled;
declare const index_IconAlertHexagonOff: typeof IconAlertHexagonOff;
declare const index_IconAlertOctagon: typeof IconAlertOctagon;
declare const index_IconAlertOctagonFilled: typeof IconAlertOctagonFilled;
declare const index_IconAlertSmall: typeof IconAlertSmall;
declare const index_IconAlertSmallOff: typeof IconAlertSmallOff;
declare const index_IconAlertSquare: typeof IconAlertSquare;
declare const index_IconAlertSquareFilled: typeof IconAlertSquareFilled;
declare const index_IconAlertSquareRounded: typeof IconAlertSquareRounded;
declare const index_IconAlertSquareRoundedFilled: typeof IconAlertSquareRoundedFilled;
declare const index_IconAlertSquareRoundedOff: typeof IconAlertSquareRoundedOff;
declare const index_IconAlertTriangle: typeof IconAlertTriangle;
declare const index_IconAlertTriangleFilled: typeof IconAlertTriangleFilled;
declare const index_IconAlertTriangleOff: typeof IconAlertTriangleOff;
declare const index_IconAlien: typeof IconAlien;
declare const index_IconAlienFilled: typeof IconAlienFilled;
declare const index_IconAlignBoxBottomCenter: typeof IconAlignBoxBottomCenter;
declare const index_IconAlignBoxBottomCenterFilled: typeof IconAlignBoxBottomCenterFilled;
declare const index_IconAlignBoxBottomLeft: typeof IconAlignBoxBottomLeft;
declare const index_IconAlignBoxBottomLeftFilled: typeof IconAlignBoxBottomLeftFilled;
declare const index_IconAlignBoxBottomRight: typeof IconAlignBoxBottomRight;
declare const index_IconAlignBoxBottomRightFilled: typeof IconAlignBoxBottomRightFilled;
declare const index_IconAlignBoxCenterBottom: typeof IconAlignBoxCenterBottom;
declare const index_IconAlignBoxCenterMiddle: typeof IconAlignBoxCenterMiddle;
declare const index_IconAlignBoxCenterMiddleFilled: typeof IconAlignBoxCenterMiddleFilled;
declare const index_IconAlignBoxCenterStretch: typeof IconAlignBoxCenterStretch;
declare const index_IconAlignBoxCenterTop: typeof IconAlignBoxCenterTop;
declare const index_IconAlignBoxLeftBottom: typeof IconAlignBoxLeftBottom;
declare const index_IconAlignBoxLeftBottomFilled: typeof IconAlignBoxLeftBottomFilled;
declare const index_IconAlignBoxLeftMiddle: typeof IconAlignBoxLeftMiddle;
declare const index_IconAlignBoxLeftMiddleFilled: typeof IconAlignBoxLeftMiddleFilled;
declare const index_IconAlignBoxLeftStretch: typeof IconAlignBoxLeftStretch;
declare const index_IconAlignBoxLeftTop: typeof IconAlignBoxLeftTop;
declare const index_IconAlignBoxLeftTopFilled: typeof IconAlignBoxLeftTopFilled;
declare const index_IconAlignBoxRightBottom: typeof IconAlignBoxRightBottom;
declare const index_IconAlignBoxRightBottomFilled: typeof IconAlignBoxRightBottomFilled;
declare const index_IconAlignBoxRightMiddle: typeof IconAlignBoxRightMiddle;
declare const index_IconAlignBoxRightMiddleFilled: typeof IconAlignBoxRightMiddleFilled;
declare const index_IconAlignBoxRightStretch: typeof IconAlignBoxRightStretch;
declare const index_IconAlignBoxRightTop: typeof IconAlignBoxRightTop;
declare const index_IconAlignBoxRightTopFilled: typeof IconAlignBoxRightTopFilled;
declare const index_IconAlignBoxTopCenter: typeof IconAlignBoxTopCenter;
declare const index_IconAlignBoxTopCenterFilled: typeof IconAlignBoxTopCenterFilled;
declare const index_IconAlignBoxTopLeft: typeof IconAlignBoxTopLeft;
declare const index_IconAlignBoxTopLeftFilled: typeof IconAlignBoxTopLeftFilled;
declare const index_IconAlignBoxTopRight: typeof IconAlignBoxTopRight;
declare const index_IconAlignBoxTopRightFilled: typeof IconAlignBoxTopRightFilled;
declare const index_IconAlignCenter: typeof IconAlignCenter;
declare const index_IconAlignJustified: typeof IconAlignJustified;
declare const index_IconAlignLeft: typeof IconAlignLeft;
declare const index_IconAlignLeft2: typeof IconAlignLeft2;
declare const index_IconAlignRight: typeof IconAlignRight;
declare const index_IconAlignRight2: typeof IconAlignRight2;
declare const index_IconAlpha: typeof IconAlpha;
declare const index_IconAlphabetArabic: typeof IconAlphabetArabic;
declare const index_IconAlphabetBangla: typeof IconAlphabetBangla;
declare const index_IconAlphabetCyrillic: typeof IconAlphabetCyrillic;
declare const index_IconAlphabetGreek: typeof IconAlphabetGreek;
declare const index_IconAlphabetHebrew: typeof IconAlphabetHebrew;
declare const index_IconAlphabetKorean: typeof IconAlphabetKorean;
declare const index_IconAlphabetLatin: typeof IconAlphabetLatin;
declare const index_IconAlphabetPolish: typeof IconAlphabetPolish;
declare const index_IconAlphabetRunes: typeof IconAlphabetRunes;
declare const index_IconAlphabetThai: typeof IconAlphabetThai;
declare const index_IconAlt: typeof IconAlt;
declare const index_IconAmbulance: typeof IconAmbulance;
declare const index_IconAmpersand: typeof IconAmpersand;
declare const index_IconAnalyze: typeof IconAnalyze;
declare const index_IconAnalyzeFilled: typeof IconAnalyzeFilled;
declare const index_IconAnalyzeOff: typeof IconAnalyzeOff;
declare const index_IconAnchor: typeof IconAnchor;
declare const index_IconAnchorOff: typeof IconAnchorOff;
declare const index_IconAngle: typeof IconAngle;
declare const index_IconAnkh: typeof IconAnkh;
declare const index_IconAntenna: typeof IconAntenna;
declare const index_IconAntennaBars1: typeof IconAntennaBars1;
declare const index_IconAntennaBars2: typeof IconAntennaBars2;
declare const index_IconAntennaBars3: typeof IconAntennaBars3;
declare const index_IconAntennaBars4: typeof IconAntennaBars4;
declare const index_IconAntennaBars5: typeof IconAntennaBars5;
declare const index_IconAntennaBarsOff: typeof IconAntennaBarsOff;
declare const index_IconAntennaOff: typeof IconAntennaOff;
declare const index_IconAperture: typeof IconAperture;
declare const index_IconApertureOff: typeof IconApertureOff;
declare const index_IconApi: typeof IconApi;
declare const index_IconApiApp: typeof IconApiApp;
declare const index_IconApiAppOff: typeof IconApiAppOff;
declare const index_IconApiOff: typeof IconApiOff;
declare const index_IconAppWindow: typeof IconAppWindow;
declare const index_IconAppWindowFilled: typeof IconAppWindowFilled;
declare const index_IconApple: typeof IconApple;
declare const index_IconAppleFilled: typeof IconAppleFilled;
declare const index_IconApps: typeof IconApps;
declare const index_IconAppsFilled: typeof IconAppsFilled;
declare const index_IconAppsOff: typeof IconAppsOff;
declare const index_IconArcheryArrow: typeof IconArcheryArrow;
declare const index_IconArchive: typeof IconArchive;
declare const index_IconArchiveFilled: typeof IconArchiveFilled;
declare const index_IconArchiveOff: typeof IconArchiveOff;
declare const index_IconArmchair: typeof IconArmchair;
declare const index_IconArmchair2: typeof IconArmchair2;
declare const index_IconArmchair2Off: typeof IconArmchair2Off;
declare const index_IconArmchairOff: typeof IconArmchairOff;
declare const index_IconArrowAutofitContent: typeof IconArrowAutofitContent;
declare const index_IconArrowAutofitContentFilled: typeof IconArrowAutofitContentFilled;
declare const index_IconArrowAutofitDown: typeof IconArrowAutofitDown;
declare const index_IconArrowAutofitDownFilled: typeof IconArrowAutofitDownFilled;
declare const index_IconArrowAutofitHeight: typeof IconArrowAutofitHeight;
declare const index_IconArrowAutofitHeightFilled: typeof IconArrowAutofitHeightFilled;
declare const index_IconArrowAutofitLeft: typeof IconArrowAutofitLeft;
declare const index_IconArrowAutofitLeftFilled: typeof IconArrowAutofitLeftFilled;
declare const index_IconArrowAutofitRight: typeof IconArrowAutofitRight;
declare const index_IconArrowAutofitRightFilled: typeof IconArrowAutofitRightFilled;
declare const index_IconArrowAutofitUp: typeof IconArrowAutofitUp;
declare const index_IconArrowAutofitUpFilled: typeof IconArrowAutofitUpFilled;
declare const index_IconArrowAutofitWidth: typeof IconArrowAutofitWidth;
declare const index_IconArrowAutofitWidthFilled: typeof IconArrowAutofitWidthFilled;
declare const index_IconArrowBack: typeof IconArrowBack;
declare const index_IconArrowBackUp: typeof IconArrowBackUp;
declare const index_IconArrowBackUpDouble: typeof IconArrowBackUpDouble;
declare const index_IconArrowBadgeDown: typeof IconArrowBadgeDown;
declare const index_IconArrowBadgeDownFilled: typeof IconArrowBadgeDownFilled;
declare const index_IconArrowBadgeLeft: typeof IconArrowBadgeLeft;
declare const index_IconArrowBadgeLeftFilled: typeof IconArrowBadgeLeftFilled;
declare const index_IconArrowBadgeRight: typeof IconArrowBadgeRight;
declare const index_IconArrowBadgeRightFilled: typeof IconArrowBadgeRightFilled;
declare const index_IconArrowBadgeUp: typeof IconArrowBadgeUp;
declare const index_IconArrowBadgeUpFilled: typeof IconArrowBadgeUpFilled;
declare const index_IconArrowBarBoth: typeof IconArrowBarBoth;
declare const index_IconArrowBarDown: typeof IconArrowBarDown;
declare const index_IconArrowBarLeft: typeof IconArrowBarLeft;
declare const index_IconArrowBarRight: typeof IconArrowBarRight;
declare const index_IconArrowBarToDown: typeof IconArrowBarToDown;
declare const index_IconArrowBarToDownDashed: typeof IconArrowBarToDownDashed;
declare const index_IconArrowBarToLeft: typeof IconArrowBarToLeft;
declare const index_IconArrowBarToLeftDashed: typeof IconArrowBarToLeftDashed;
declare const index_IconArrowBarToRight: typeof IconArrowBarToRight;
declare const index_IconArrowBarToRightDashed: typeof IconArrowBarToRightDashed;
declare const index_IconArrowBarToUp: typeof IconArrowBarToUp;
declare const index_IconArrowBarToUpDashed: typeof IconArrowBarToUpDashed;
declare const index_IconArrowBarUp: typeof IconArrowBarUp;
declare const index_IconArrowBearLeft: typeof IconArrowBearLeft;
declare const index_IconArrowBearLeft2: typeof IconArrowBearLeft2;
declare const index_IconArrowBearRight: typeof IconArrowBearRight;
declare const index_IconArrowBearRight2: typeof IconArrowBearRight2;
declare const index_IconArrowBigDown: typeof IconArrowBigDown;
declare const index_IconArrowBigDownFilled: typeof IconArrowBigDownFilled;
declare const index_IconArrowBigDownLine: typeof IconArrowBigDownLine;
declare const index_IconArrowBigDownLineFilled: typeof IconArrowBigDownLineFilled;
declare const index_IconArrowBigDownLines: typeof IconArrowBigDownLines;
declare const index_IconArrowBigDownLinesFilled: typeof IconArrowBigDownLinesFilled;
declare const index_IconArrowBigLeft: typeof IconArrowBigLeft;
declare const index_IconArrowBigLeftFilled: typeof IconArrowBigLeftFilled;
declare const index_IconArrowBigLeftLine: typeof IconArrowBigLeftLine;
declare const index_IconArrowBigLeftLineFilled: typeof IconArrowBigLeftLineFilled;
declare const index_IconArrowBigLeftLines: typeof IconArrowBigLeftLines;
declare const index_IconArrowBigLeftLinesFilled: typeof IconArrowBigLeftLinesFilled;
declare const index_IconArrowBigRight: typeof IconArrowBigRight;
declare const index_IconArrowBigRightFilled: typeof IconArrowBigRightFilled;
declare const index_IconArrowBigRightLine: typeof IconArrowBigRightLine;
declare const index_IconArrowBigRightLineFilled: typeof IconArrowBigRightLineFilled;
declare const index_IconArrowBigRightLines: typeof IconArrowBigRightLines;
declare const index_IconArrowBigRightLinesFilled: typeof IconArrowBigRightLinesFilled;
declare const index_IconArrowBigUp: typeof IconArrowBigUp;
declare const index_IconArrowBigUpFilled: typeof IconArrowBigUpFilled;
declare const index_IconArrowBigUpLine: typeof IconArrowBigUpLine;
declare const index_IconArrowBigUpLineFilled: typeof IconArrowBigUpLineFilled;
declare const index_IconArrowBigUpLines: typeof IconArrowBigUpLines;
declare const index_IconArrowBigUpLinesFilled: typeof IconArrowBigUpLinesFilled;
declare const index_IconArrowBounce: typeof IconArrowBounce;
declare const index_IconArrowCapsule: typeof IconArrowCapsule;
declare const index_IconArrowCurveLeft: typeof IconArrowCurveLeft;
declare const index_IconArrowCurveRight: typeof IconArrowCurveRight;
declare const index_IconArrowDown: typeof IconArrowDown;
declare const index_IconArrowDownBar: typeof IconArrowDownBar;
declare const index_IconArrowDownCircle: typeof IconArrowDownCircle;
declare const index_IconArrowDownCircleFilled: typeof IconArrowDownCircleFilled;
declare const index_IconArrowDownDashed: typeof IconArrowDownDashed;
declare const index_IconArrowDownFromArc: typeof IconArrowDownFromArc;
declare const index_IconArrowDownLeft: typeof IconArrowDownLeft;
declare const index_IconArrowDownLeftCircle: typeof IconArrowDownLeftCircle;
declare const index_IconArrowDownRhombus: typeof IconArrowDownRhombus;
declare const index_IconArrowDownRhombusFilled: typeof IconArrowDownRhombusFilled;
declare const index_IconArrowDownRight: typeof IconArrowDownRight;
declare const index_IconArrowDownRightCircle: typeof IconArrowDownRightCircle;
declare const index_IconArrowDownSquare: typeof IconArrowDownSquare;
declare const index_IconArrowDownSquareFilled: typeof IconArrowDownSquareFilled;
declare const index_IconArrowDownTail: typeof IconArrowDownTail;
declare const index_IconArrowDownToArc: typeof IconArrowDownToArc;
declare const index_IconArrowElbowLeft: typeof IconArrowElbowLeft;
declare const index_IconArrowElbowRight: typeof IconArrowElbowRight;
declare const index_IconArrowFork: typeof IconArrowFork;
declare const index_IconArrowForward: typeof IconArrowForward;
declare const index_IconArrowForwardUp: typeof IconArrowForwardUp;
declare const index_IconArrowForwardUpDouble: typeof IconArrowForwardUpDouble;
declare const index_IconArrowGuide: typeof IconArrowGuide;
declare const index_IconArrowGuideFilled: typeof IconArrowGuideFilled;
declare const index_IconArrowIteration: typeof IconArrowIteration;
declare const index_IconArrowLeft: typeof IconArrowLeft;
declare const index_IconArrowLeftBar: typeof IconArrowLeftBar;
declare const index_IconArrowLeftCircle: typeof IconArrowLeftCircle;
declare const index_IconArrowLeftCircleFilled: typeof IconArrowLeftCircleFilled;
declare const index_IconArrowLeftDashed: typeof IconArrowLeftDashed;
declare const index_IconArrowLeftFromArc: typeof IconArrowLeftFromArc;
declare const index_IconArrowLeftRhombus: typeof IconArrowLeftRhombus;
declare const index_IconArrowLeftRhombusFilled: typeof IconArrowLeftRhombusFilled;
declare const index_IconArrowLeftRight: typeof IconArrowLeftRight;
declare const index_IconArrowLeftSquare: typeof IconArrowLeftSquare;
declare const index_IconArrowLeftSquareFilled: typeof IconArrowLeftSquareFilled;
declare const index_IconArrowLeftTail: typeof IconArrowLeftTail;
declare const index_IconArrowLeftToArc: typeof IconArrowLeftToArc;
declare const index_IconArrowLoopLeft: typeof IconArrowLoopLeft;
declare const index_IconArrowLoopLeft2: typeof IconArrowLoopLeft2;
declare const index_IconArrowLoopRight: typeof IconArrowLoopRight;
declare const index_IconArrowLoopRight2: typeof IconArrowLoopRight2;
declare const index_IconArrowMerge: typeof IconArrowMerge;
declare const index_IconArrowMergeAltLeft: typeof IconArrowMergeAltLeft;
declare const index_IconArrowMergeAltRight: typeof IconArrowMergeAltRight;
declare const index_IconArrowMergeBoth: typeof IconArrowMergeBoth;
declare const index_IconArrowMergeLeft: typeof IconArrowMergeLeft;
declare const index_IconArrowMergeRight: typeof IconArrowMergeRight;
declare const index_IconArrowMoveDown: typeof IconArrowMoveDown;
declare const index_IconArrowMoveDownFilled: typeof IconArrowMoveDownFilled;
declare const index_IconArrowMoveLeft: typeof IconArrowMoveLeft;
declare const index_IconArrowMoveLeftFilled: typeof IconArrowMoveLeftFilled;
declare const index_IconArrowMoveRight: typeof IconArrowMoveRight;
declare const index_IconArrowMoveRightFilled: typeof IconArrowMoveRightFilled;
declare const index_IconArrowMoveUp: typeof IconArrowMoveUp;
declare const index_IconArrowMoveUpFilled: typeof IconArrowMoveUpFilled;
declare const index_IconArrowNarrowDown: typeof IconArrowNarrowDown;
declare const index_IconArrowNarrowDownDashed: typeof IconArrowNarrowDownDashed;
declare const index_IconArrowNarrowLeft: typeof IconArrowNarrowLeft;
declare const index_IconArrowNarrowLeftDashed: typeof IconArrowNarrowLeftDashed;
declare const index_IconArrowNarrowRight: typeof IconArrowNarrowRight;
declare const index_IconArrowNarrowRightDashed: typeof IconArrowNarrowRightDashed;
declare const index_IconArrowNarrowUp: typeof IconArrowNarrowUp;
declare const index_IconArrowNarrowUpDashed: typeof IconArrowNarrowUpDashed;
declare const index_IconArrowRampLeft: typeof IconArrowRampLeft;
declare const index_IconArrowRampLeft2: typeof IconArrowRampLeft2;
declare const index_IconArrowRampLeft3: typeof IconArrowRampLeft3;
declare const index_IconArrowRampRight: typeof IconArrowRampRight;
declare const index_IconArrowRampRight2: typeof IconArrowRampRight2;
declare const index_IconArrowRampRight3: typeof IconArrowRampRight3;
declare const index_IconArrowRight: typeof IconArrowRight;
declare const index_IconArrowRightBar: typeof IconArrowRightBar;
declare const index_IconArrowRightCircle: typeof IconArrowRightCircle;
declare const index_IconArrowRightCircleFilled: typeof IconArrowRightCircleFilled;
declare const index_IconArrowRightDashed: typeof IconArrowRightDashed;
declare const index_IconArrowRightFromArc: typeof IconArrowRightFromArc;
declare const index_IconArrowRightRhombus: typeof IconArrowRightRhombus;
declare const index_IconArrowRightRhombusFilled: typeof IconArrowRightRhombusFilled;
declare const index_IconArrowRightSquare: typeof IconArrowRightSquare;
declare const index_IconArrowRightSquareFilled: typeof IconArrowRightSquareFilled;
declare const index_IconArrowRightTail: typeof IconArrowRightTail;
declare const index_IconArrowRightToArc: typeof IconArrowRightToArc;
declare const index_IconArrowRotaryFirstLeft: typeof IconArrowRotaryFirstLeft;
declare const index_IconArrowRotaryFirstRight: typeof IconArrowRotaryFirstRight;
declare const index_IconArrowRotaryLastLeft: typeof IconArrowRotaryLastLeft;
declare const index_IconArrowRotaryLastRight: typeof IconArrowRotaryLastRight;
declare const index_IconArrowRotaryLeft: typeof IconArrowRotaryLeft;
declare const index_IconArrowRotaryRight: typeof IconArrowRotaryRight;
declare const index_IconArrowRotaryStraight: typeof IconArrowRotaryStraight;
declare const index_IconArrowRoundaboutLeft: typeof IconArrowRoundaboutLeft;
declare const index_IconArrowRoundaboutRight: typeof IconArrowRoundaboutRight;
declare const index_IconArrowSharpTurnLeft: typeof IconArrowSharpTurnLeft;
declare const index_IconArrowSharpTurnRight: typeof IconArrowSharpTurnRight;
declare const index_IconArrowUp: typeof IconArrowUp;
declare const index_IconArrowUpBar: typeof IconArrowUpBar;
declare const index_IconArrowUpCircle: typeof IconArrowUpCircle;
declare const index_IconArrowUpCircleFilled: typeof IconArrowUpCircleFilled;
declare const index_IconArrowUpDashed: typeof IconArrowUpDashed;
declare const index_IconArrowUpFromArc: typeof IconArrowUpFromArc;
declare const index_IconArrowUpLeft: typeof IconArrowUpLeft;
declare const index_IconArrowUpLeftCircle: typeof IconArrowUpLeftCircle;
declare const index_IconArrowUpRhombus: typeof IconArrowUpRhombus;
declare const index_IconArrowUpRhombusFilled: typeof IconArrowUpRhombusFilled;
declare const index_IconArrowUpRight: typeof IconArrowUpRight;
declare const index_IconArrowUpRightCircle: typeof IconArrowUpRightCircle;
declare const index_IconArrowUpSquare: typeof IconArrowUpSquare;
declare const index_IconArrowUpSquareFilled: typeof IconArrowUpSquareFilled;
declare const index_IconArrowUpTail: typeof IconArrowUpTail;
declare const index_IconArrowUpToArc: typeof IconArrowUpToArc;
declare const index_IconArrowWaveLeftDown: typeof IconArrowWaveLeftDown;
declare const index_IconArrowWaveLeftUp: typeof IconArrowWaveLeftUp;
declare const index_IconArrowWaveRightDown: typeof IconArrowWaveRightDown;
declare const index_IconArrowWaveRightUp: typeof IconArrowWaveRightUp;
declare const index_IconArrowZigZag: typeof IconArrowZigZag;
declare const index_IconArrowsCross: typeof IconArrowsCross;
declare const index_IconArrowsDiagonal: typeof IconArrowsDiagonal;
declare const index_IconArrowsDiagonal2: typeof IconArrowsDiagonal2;
declare const index_IconArrowsDiagonalMinimize: typeof IconArrowsDiagonalMinimize;
declare const index_IconArrowsDiagonalMinimize2: typeof IconArrowsDiagonalMinimize2;
declare const index_IconArrowsDiff: typeof IconArrowsDiff;
declare const index_IconArrowsDoubleNeSw: typeof IconArrowsDoubleNeSw;
declare const index_IconArrowsDoubleNwSe: typeof IconArrowsDoubleNwSe;
declare const index_IconArrowsDoubleSeNw: typeof IconArrowsDoubleSeNw;
declare const index_IconArrowsDoubleSwNe: typeof IconArrowsDoubleSwNe;
declare const index_IconArrowsDown: typeof IconArrowsDown;
declare const index_IconArrowsDownUp: typeof IconArrowsDownUp;
declare const index_IconArrowsExchange: typeof IconArrowsExchange;
declare const index_IconArrowsExchange2: typeof IconArrowsExchange2;
declare const index_IconArrowsHorizontal: typeof IconArrowsHorizontal;
declare const index_IconArrowsJoin: typeof IconArrowsJoin;
declare const index_IconArrowsJoin2: typeof IconArrowsJoin2;
declare const index_IconArrowsLeft: typeof IconArrowsLeft;
declare const index_IconArrowsLeftDown: typeof IconArrowsLeftDown;
declare const index_IconArrowsLeftRight: typeof IconArrowsLeftRight;
declare const index_IconArrowsMaximize: typeof IconArrowsMaximize;
declare const index_IconArrowsMinimize: typeof IconArrowsMinimize;
declare const index_IconArrowsMove: typeof IconArrowsMove;
declare const index_IconArrowsMoveHorizontal: typeof IconArrowsMoveHorizontal;
declare const index_IconArrowsMoveVertical: typeof IconArrowsMoveVertical;
declare const index_IconArrowsRandom: typeof IconArrowsRandom;
declare const index_IconArrowsRight: typeof IconArrowsRight;
declare const index_IconArrowsRightDown: typeof IconArrowsRightDown;
declare const index_IconArrowsRightLeft: typeof IconArrowsRightLeft;
declare const index_IconArrowsShuffle: typeof IconArrowsShuffle;
declare const index_IconArrowsShuffle2: typeof IconArrowsShuffle2;
declare const index_IconArrowsSort: typeof IconArrowsSort;
declare const index_IconArrowsSplit: typeof IconArrowsSplit;
declare const index_IconArrowsSplit2: typeof IconArrowsSplit2;
declare const index_IconArrowsTransferDown: typeof IconArrowsTransferDown;
declare const index_IconArrowsTransferUp: typeof IconArrowsTransferUp;
declare const index_IconArrowsTransferUpDown: typeof IconArrowsTransferUpDown;
declare const index_IconArrowsUp: typeof IconArrowsUp;
declare const index_IconArrowsUpDown: typeof IconArrowsUpDown;
declare const index_IconArrowsUpLeft: typeof IconArrowsUpLeft;
declare const index_IconArrowsUpRight: typeof IconArrowsUpRight;
declare const index_IconArrowsVertical: typeof IconArrowsVertical;
declare const index_IconArtboard: typeof IconArtboard;
declare const index_IconArtboardFilled: typeof IconArtboardFilled;
declare const index_IconArtboardOff: typeof IconArtboardOff;
declare const index_IconArticle: typeof IconArticle;
declare const index_IconArticleFilled: typeof IconArticleFilled;
declare const index_IconArticleOff: typeof IconArticleOff;
declare const index_IconAspectRatio: typeof IconAspectRatio;
declare const index_IconAspectRatioFilled: typeof IconAspectRatioFilled;
declare const index_IconAspectRatioOff: typeof IconAspectRatioOff;
declare const index_IconAssembly: typeof IconAssembly;
declare const index_IconAssemblyFilled: typeof IconAssemblyFilled;
declare const index_IconAssemblyOff: typeof IconAssemblyOff;
declare const index_IconAsset: typeof IconAsset;
declare const index_IconAssetFilled: typeof IconAssetFilled;
declare const index_IconAsterisk: typeof IconAsterisk;
declare const index_IconAsteriskSimple: typeof IconAsteriskSimple;
declare const index_IconAt: typeof IconAt;
declare const index_IconAtOff: typeof IconAtOff;
declare const index_IconAtom: typeof IconAtom;
declare const index_IconAtom2: typeof IconAtom2;
declare const index_IconAtom2Filled: typeof IconAtom2Filled;
declare const index_IconAtomOff: typeof IconAtomOff;
declare const index_IconAugmentedReality: typeof IconAugmentedReality;
declare const index_IconAugmentedReality2: typeof IconAugmentedReality2;
declare const index_IconAugmentedRealityOff: typeof IconAugmentedRealityOff;
declare const index_IconAuth2fa: typeof IconAuth2fa;
declare const index_IconAutomaticGearbox: typeof IconAutomaticGearbox;
declare const index_IconAutomaticGearboxFilled: typeof IconAutomaticGearboxFilled;
declare const index_IconAutomation: typeof IconAutomation;
declare const index_IconAvocado: typeof IconAvocado;
declare const index_IconAward: typeof IconAward;
declare const index_IconAwardFilled: typeof IconAwardFilled;
declare const index_IconAwardOff: typeof IconAwardOff;
declare const index_IconAxe: typeof IconAxe;
declare const index_IconAxisX: typeof IconAxisX;
declare const index_IconAxisY: typeof IconAxisY;
declare const index_IconBabyBottle: typeof IconBabyBottle;
declare const index_IconBabyCarriage: typeof IconBabyCarriage;
declare const index_IconBabyCarriageFilled: typeof IconBabyCarriageFilled;
declare const index_IconBackground: typeof IconBackground;
declare const index_IconBackhoe: typeof IconBackhoe;
declare const index_IconBackpack: typeof IconBackpack;
declare const index_IconBackpackOff: typeof IconBackpackOff;
declare const index_IconBackslash: typeof IconBackslash;
declare const index_IconBackspace: typeof IconBackspace;
declare const index_IconBackspaceFilled: typeof IconBackspaceFilled;
declare const index_IconBadge: typeof IconBadge;
declare const index_IconBadge2k: typeof IconBadge2k;
declare const index_IconBadge3d: typeof IconBadge3d;
declare const index_IconBadge3dFilled: typeof IconBadge3dFilled;
declare const index_IconBadge3k: typeof IconBadge3k;
declare const index_IconBadge4k: typeof IconBadge4k;
declare const index_IconBadge4kFilled: typeof IconBadge4kFilled;
declare const index_IconBadge5k: typeof IconBadge5k;
declare const index_IconBadge8k: typeof IconBadge8k;
declare const index_IconBadge8kFilled: typeof IconBadge8kFilled;
declare const index_IconBadgeAd: typeof IconBadgeAd;
declare const index_IconBadgeAdFilled: typeof IconBadgeAdFilled;
declare const index_IconBadgeAdOff: typeof IconBadgeAdOff;
declare const index_IconBadgeAr: typeof IconBadgeAr;
declare const index_IconBadgeArFilled: typeof IconBadgeArFilled;
declare const index_IconBadgeCc: typeof IconBadgeCc;
declare const index_IconBadgeCcFilled: typeof IconBadgeCcFilled;
declare const index_IconBadgeFilled: typeof IconBadgeFilled;
declare const index_IconBadgeHd: typeof IconBadgeHd;
declare const index_IconBadgeHdFilled: typeof IconBadgeHdFilled;
declare const index_IconBadgeOff: typeof IconBadgeOff;
declare const index_IconBadgeSd: typeof IconBadgeSd;
declare const index_IconBadgeSdFilled: typeof IconBadgeSdFilled;
declare const index_IconBadgeTm: typeof IconBadgeTm;
declare const index_IconBadgeTmFilled: typeof IconBadgeTmFilled;
declare const index_IconBadgeVo: typeof IconBadgeVo;
declare const index_IconBadgeVoFilled: typeof IconBadgeVoFilled;
declare const index_IconBadgeVr: typeof IconBadgeVr;
declare const index_IconBadgeVrFilled: typeof IconBadgeVrFilled;
declare const index_IconBadgeWc: typeof IconBadgeWc;
declare const index_IconBadgeWcFilled: typeof IconBadgeWcFilled;
declare const index_IconBadges: typeof IconBadges;
declare const index_IconBadgesFilled: typeof IconBadgesFilled;
declare const index_IconBadgesOff: typeof IconBadgesOff;
declare const index_IconBaguette: typeof IconBaguette;
declare const index_IconBallAmericanFootball: typeof IconBallAmericanFootball;
declare const index_IconBallAmericanFootballOff: typeof IconBallAmericanFootballOff;
declare const index_IconBallBaseball: typeof IconBallBaseball;
declare const index_IconBallBasketball: typeof IconBallBasketball;
declare const index_IconBallBowling: typeof IconBallBowling;
declare const index_IconBallBowlingFilled: typeof IconBallBowlingFilled;
declare const index_IconBallFootball: typeof IconBallFootball;
declare const index_IconBallFootballOff: typeof IconBallFootballOff;
declare const index_IconBallTennis: typeof IconBallTennis;
declare const index_IconBallVolleyball: typeof IconBallVolleyball;
declare const index_IconBalloon: typeof IconBalloon;
declare const index_IconBalloonFilled: typeof IconBalloonFilled;
declare const index_IconBalloonOff: typeof IconBalloonOff;
declare const index_IconBallpen: typeof IconBallpen;
declare const index_IconBallpenFilled: typeof IconBallpenFilled;
declare const index_IconBallpenOff: typeof IconBallpenOff;
declare const index_IconBan: typeof IconBan;
declare const index_IconBandage: typeof IconBandage;
declare const index_IconBandageFilled: typeof IconBandageFilled;
declare const index_IconBandageOff: typeof IconBandageOff;
declare const index_IconBarbell: typeof IconBarbell;
declare const index_IconBarbellFilled: typeof IconBarbellFilled;
declare const index_IconBarbellOff: typeof IconBarbellOff;
declare const index_IconBarcode: typeof IconBarcode;
declare const index_IconBarcodeOff: typeof IconBarcodeOff;
declare const index_IconBarrel: typeof IconBarrel;
declare const index_IconBarrelOff: typeof IconBarrelOff;
declare const index_IconBarrierBlock: typeof IconBarrierBlock;
declare const index_IconBarrierBlockFilled: typeof IconBarrierBlockFilled;
declare const index_IconBarrierBlockOff: typeof IconBarrierBlockOff;
declare const index_IconBaseline: typeof IconBaseline;
declare const index_IconBaselineDensityLarge: typeof IconBaselineDensityLarge;
declare const index_IconBaselineDensityMedium: typeof IconBaselineDensityMedium;
declare const index_IconBaselineDensitySmall: typeof IconBaselineDensitySmall;
declare const index_IconBasket: typeof IconBasket;
declare const index_IconBasketBolt: typeof IconBasketBolt;
declare const index_IconBasketCancel: typeof IconBasketCancel;
declare const index_IconBasketCheck: typeof IconBasketCheck;
declare const index_IconBasketCode: typeof IconBasketCode;
declare const index_IconBasketCog: typeof IconBasketCog;
declare const index_IconBasketDiscount: typeof IconBasketDiscount;
declare const index_IconBasketDollar: typeof IconBasketDollar;
declare const index_IconBasketDown: typeof IconBasketDown;
declare const index_IconBasketExclamation: typeof IconBasketExclamation;
declare const index_IconBasketFilled: typeof IconBasketFilled;
declare const index_IconBasketHeart: typeof IconBasketHeart;
declare const index_IconBasketMinus: typeof IconBasketMinus;
declare const index_IconBasketOff: typeof IconBasketOff;
declare const index_IconBasketPause: typeof IconBasketPause;
declare const index_IconBasketPin: typeof IconBasketPin;
declare const index_IconBasketPlus: typeof IconBasketPlus;
declare const index_IconBasketQuestion: typeof IconBasketQuestion;
declare const index_IconBasketSearch: typeof IconBasketSearch;
declare const index_IconBasketShare: typeof IconBasketShare;
declare const index_IconBasketStar: typeof IconBasketStar;
declare const index_IconBasketUp: typeof IconBasketUp;
declare const index_IconBasketX: typeof IconBasketX;
declare const index_IconBat: typeof IconBat;
declare const index_IconBath: typeof IconBath;
declare const index_IconBathFilled: typeof IconBathFilled;
declare const index_IconBathOff: typeof IconBathOff;
declare const index_IconBattery: typeof IconBattery;
declare const index_IconBattery1: typeof IconBattery1;
declare const index_IconBattery1Filled: typeof IconBattery1Filled;
declare const index_IconBattery2: typeof IconBattery2;
declare const index_IconBattery2Filled: typeof IconBattery2Filled;
declare const index_IconBattery3: typeof IconBattery3;
declare const index_IconBattery3Filled: typeof IconBattery3Filled;
declare const index_IconBattery4: typeof IconBattery4;
declare const index_IconBattery4Filled: typeof IconBattery4Filled;
declare const index_IconBatteryAutomotive: typeof IconBatteryAutomotive;
declare const index_IconBatteryAutomotiveFilled: typeof IconBatteryAutomotiveFilled;
declare const index_IconBatteryCharging: typeof IconBatteryCharging;
declare const index_IconBatteryCharging2: typeof IconBatteryCharging2;
declare const index_IconBatteryEco: typeof IconBatteryEco;
declare const index_IconBatteryExclamation: typeof IconBatteryExclamation;
declare const index_IconBatteryFilled: typeof IconBatteryFilled;
declare const index_IconBatteryOff: typeof IconBatteryOff;
declare const index_IconBatterySpark: typeof IconBatterySpark;
declare const index_IconBatteryVertical: typeof IconBatteryVertical;
declare const index_IconBatteryVertical1: typeof IconBatteryVertical1;
declare const index_IconBatteryVertical1Filled: typeof IconBatteryVertical1Filled;
declare const index_IconBatteryVertical2: typeof IconBatteryVertical2;
declare const index_IconBatteryVertical2Filled: typeof IconBatteryVertical2Filled;
declare const index_IconBatteryVertical3: typeof IconBatteryVertical3;
declare const index_IconBatteryVertical3Filled: typeof IconBatteryVertical3Filled;
declare const index_IconBatteryVertical4: typeof IconBatteryVertical4;
declare const index_IconBatteryVertical4Filled: typeof IconBatteryVertical4Filled;
declare const index_IconBatteryVerticalCharging: typeof IconBatteryVerticalCharging;
declare const index_IconBatteryVerticalCharging2: typeof IconBatteryVerticalCharging2;
declare const index_IconBatteryVerticalEco: typeof IconBatteryVerticalEco;
declare const index_IconBatteryVerticalExclamation: typeof IconBatteryVerticalExclamation;
declare const index_IconBatteryVerticalFilled: typeof IconBatteryVerticalFilled;
declare const index_IconBatteryVerticalOff: typeof IconBatteryVerticalOff;
declare const index_IconBeach: typeof IconBeach;
declare const index_IconBeachOff: typeof IconBeachOff;
declare const index_IconBed: typeof IconBed;
declare const index_IconBedFilled: typeof IconBedFilled;
declare const index_IconBedFlat: typeof IconBedFlat;
declare const index_IconBedFlatFilled: typeof IconBedFlatFilled;
declare const index_IconBedOff: typeof IconBedOff;
declare const index_IconBeer: typeof IconBeer;
declare const index_IconBeerFilled: typeof IconBeerFilled;
declare const index_IconBeerOff: typeof IconBeerOff;
declare const index_IconBell: typeof IconBell;
declare const index_IconBellBolt: typeof IconBellBolt;
declare const index_IconBellCancel: typeof IconBellCancel;
declare const index_IconBellCheck: typeof IconBellCheck;
declare const index_IconBellCode: typeof IconBellCode;
declare const index_IconBellCog: typeof IconBellCog;
declare const index_IconBellDollar: typeof IconBellDollar;
declare const index_IconBellDown: typeof IconBellDown;
declare const index_IconBellExclamation: typeof IconBellExclamation;
declare const index_IconBellFilled: typeof IconBellFilled;
declare const index_IconBellHeart: typeof IconBellHeart;
declare const index_IconBellMinus: typeof IconBellMinus;
declare const index_IconBellMinusFilled: typeof IconBellMinusFilled;
declare const index_IconBellOff: typeof IconBellOff;
declare const index_IconBellPause: typeof IconBellPause;
declare const index_IconBellPin: typeof IconBellPin;
declare const index_IconBellPlus: typeof IconBellPlus;
declare const index_IconBellPlusFilled: typeof IconBellPlusFilled;
declare const index_IconBellQuestion: typeof IconBellQuestion;
declare const index_IconBellRinging: typeof IconBellRinging;
declare const index_IconBellRinging2: typeof IconBellRinging2;
declare const index_IconBellRinging2Filled: typeof IconBellRinging2Filled;
declare const index_IconBellRingingFilled: typeof IconBellRingingFilled;
declare const index_IconBellSchool: typeof IconBellSchool;
declare const index_IconBellSearch: typeof IconBellSearch;
declare const index_IconBellShare: typeof IconBellShare;
declare const index_IconBellStar: typeof IconBellStar;
declare const index_IconBellUp: typeof IconBellUp;
declare const index_IconBellX: typeof IconBellX;
declare const index_IconBellXFilled: typeof IconBellXFilled;
declare const index_IconBellZ: typeof IconBellZ;
declare const index_IconBellZFilled: typeof IconBellZFilled;
declare const index_IconBeta: typeof IconBeta;
declare const index_IconBible: typeof IconBible;
declare const index_IconBike: typeof IconBike;
declare const index_IconBikeFilled: typeof IconBikeFilled;
declare const index_IconBikeOff: typeof IconBikeOff;
declare const index_IconBinary: typeof IconBinary;
declare const index_IconBinaryOff: typeof IconBinaryOff;
declare const index_IconBinaryTree: typeof IconBinaryTree;
declare const index_IconBinaryTree2: typeof IconBinaryTree2;
declare const index_IconBinaryTree2Filled: typeof IconBinaryTree2Filled;
declare const index_IconBinaryTreeFilled: typeof IconBinaryTreeFilled;
declare const index_IconBinoculars: typeof IconBinoculars;
declare const index_IconBinocularsFilled: typeof IconBinocularsFilled;
declare const index_IconBiohazard: typeof IconBiohazard;
declare const index_IconBiohazardFilled: typeof IconBiohazardFilled;
declare const index_IconBiohazardOff: typeof IconBiohazardOff;
declare const index_IconBlade: typeof IconBlade;
declare const index_IconBladeFilled: typeof IconBladeFilled;
declare const index_IconBleach: typeof IconBleach;
declare const index_IconBleachChlorine: typeof IconBleachChlorine;
declare const index_IconBleachNoChlorine: typeof IconBleachNoChlorine;
declare const index_IconBleachOff: typeof IconBleachOff;
declare const index_IconBlendMode: typeof IconBlendMode;
declare const index_IconBlender: typeof IconBlender;
declare const index_IconBlenderFilled: typeof IconBlenderFilled;
declare const index_IconBlind: typeof IconBlind;
declare const index_IconBlob: typeof IconBlob;
declare const index_IconBlobFilled: typeof IconBlobFilled;
declare const index_IconBlockquote: typeof IconBlockquote;
declare const index_IconBlocks: typeof IconBlocks;
declare const index_IconBluetooth: typeof IconBluetooth;
declare const index_IconBluetoothConnected: typeof IconBluetoothConnected;
declare const index_IconBluetoothOff: typeof IconBluetoothOff;
declare const index_IconBluetoothX: typeof IconBluetoothX;
declare const index_IconBlur: typeof IconBlur;
declare const index_IconBlurOff: typeof IconBlurOff;
declare const index_IconBmp: typeof IconBmp;
declare const index_IconBodyScan: typeof IconBodyScan;
declare const index_IconBold: typeof IconBold;
declare const index_IconBoldOff: typeof IconBoldOff;
declare const index_IconBolt: typeof IconBolt;
declare const index_IconBoltFilled: typeof IconBoltFilled;
declare const index_IconBoltOff: typeof IconBoltOff;
declare const index_IconBomb: typeof IconBomb;
declare const index_IconBombFilled: typeof IconBombFilled;
declare const index_IconBone: typeof IconBone;
declare const index_IconBoneFilled: typeof IconBoneFilled;
declare const index_IconBoneOff: typeof IconBoneOff;
declare const index_IconBong: typeof IconBong;
declare const index_IconBongFilled: typeof IconBongFilled;
declare const index_IconBongOff: typeof IconBongOff;
declare const index_IconBook: typeof IconBook;
declare const index_IconBook2: typeof IconBook2;
declare const index_IconBookDownload: typeof IconBookDownload;
declare const index_IconBookFilled: typeof IconBookFilled;
declare const index_IconBookOff: typeof IconBookOff;
declare const index_IconBookUpload: typeof IconBookUpload;
declare const index_IconBookmark: typeof IconBookmark;
declare const index_IconBookmarkAi: typeof IconBookmarkAi;
declare const index_IconBookmarkEdit: typeof IconBookmarkEdit;
declare const index_IconBookmarkFilled: typeof IconBookmarkFilled;
declare const index_IconBookmarkMinus: typeof IconBookmarkMinus;
declare const index_IconBookmarkOff: typeof IconBookmarkOff;
declare const index_IconBookmarkPlus: typeof IconBookmarkPlus;
declare const index_IconBookmarkQuestion: typeof IconBookmarkQuestion;
declare const index_IconBookmarks: typeof IconBookmarks;
declare const index_IconBookmarksFilled: typeof IconBookmarksFilled;
declare const index_IconBookmarksOff: typeof IconBookmarksOff;
declare const index_IconBooks: typeof IconBooks;
declare const index_IconBooksOff: typeof IconBooksOff;
declare const index_IconBoom: typeof IconBoom;
declare const index_IconBoomFilled: typeof IconBoomFilled;
declare const index_IconBorderAll: typeof IconBorderAll;
declare const index_IconBorderBottom: typeof IconBorderBottom;
declare const index_IconBorderBottomPlus: typeof IconBorderBottomPlus;
declare const index_IconBorderCornerIos: typeof IconBorderCornerIos;
declare const index_IconBorderCornerPill: typeof IconBorderCornerPill;
declare const index_IconBorderCornerRounded: typeof IconBorderCornerRounded;
declare const index_IconBorderCornerSquare: typeof IconBorderCornerSquare;
declare const index_IconBorderCorners: typeof IconBorderCorners;
declare const index_IconBorderHorizontal: typeof IconBorderHorizontal;
declare const index_IconBorderInner: typeof IconBorderInner;
declare const index_IconBorderLeft: typeof IconBorderLeft;
declare const index_IconBorderLeftPlus: typeof IconBorderLeftPlus;
declare const index_IconBorderNone: typeof IconBorderNone;
declare const index_IconBorderOuter: typeof IconBorderOuter;
declare const index_IconBorderRadius: typeof IconBorderRadius;
declare const index_IconBorderRight: typeof IconBorderRight;
declare const index_IconBorderRightPlus: typeof IconBorderRightPlus;
declare const index_IconBorderSides: typeof IconBorderSides;
declare const index_IconBorderStyle: typeof IconBorderStyle;
declare const index_IconBorderStyle2: typeof IconBorderStyle2;
declare const index_IconBorderTop: typeof IconBorderTop;
declare const index_IconBorderTopPlus: typeof IconBorderTopPlus;
declare const index_IconBorderVertical: typeof IconBorderVertical;
declare const index_IconBottle: typeof IconBottle;
declare const index_IconBottleFilled: typeof IconBottleFilled;
declare const index_IconBottleOff: typeof IconBottleOff;
declare const index_IconBounceLeft: typeof IconBounceLeft;
declare const index_IconBounceLeftFilled: typeof IconBounceLeftFilled;
declare const index_IconBounceRight: typeof IconBounceRight;
declare const index_IconBounceRightFilled: typeof IconBounceRightFilled;
declare const index_IconBow: typeof IconBow;
declare const index_IconBowFilled: typeof IconBowFilled;
declare const index_IconBowl: typeof IconBowl;
declare const index_IconBowlChopsticks: typeof IconBowlChopsticks;
declare const index_IconBowlChopsticksFilled: typeof IconBowlChopsticksFilled;
declare const index_IconBowlFilled: typeof IconBowlFilled;
declare const index_IconBowlSpoon: typeof IconBowlSpoon;
declare const index_IconBowlSpoonFilled: typeof IconBowlSpoonFilled;
declare const index_IconBowling: typeof IconBowling;
declare const index_IconBox: typeof IconBox;
declare const index_IconBoxAlignBottom: typeof IconBoxAlignBottom;
declare const index_IconBoxAlignBottomFilled: typeof IconBoxAlignBottomFilled;
declare const index_IconBoxAlignBottomLeft: typeof IconBoxAlignBottomLeft;
declare const index_IconBoxAlignBottomLeftFilled: typeof IconBoxAlignBottomLeftFilled;
declare const index_IconBoxAlignBottomRight: typeof IconBoxAlignBottomRight;
declare const index_IconBoxAlignBottomRightFilled: typeof IconBoxAlignBottomRightFilled;
declare const index_IconBoxAlignLeft: typeof IconBoxAlignLeft;
declare const index_IconBoxAlignLeftFilled: typeof IconBoxAlignLeftFilled;
declare const index_IconBoxAlignRight: typeof IconBoxAlignRight;
declare const index_IconBoxAlignRightFilled: typeof IconBoxAlignRightFilled;
declare const index_IconBoxAlignTop: typeof IconBoxAlignTop;
declare const index_IconBoxAlignTopFilled: typeof IconBoxAlignTopFilled;
declare const index_IconBoxAlignTopLeft: typeof IconBoxAlignTopLeft;
declare const index_IconBoxAlignTopLeftFilled: typeof IconBoxAlignTopLeftFilled;
declare const index_IconBoxAlignTopRight: typeof IconBoxAlignTopRight;
declare const index_IconBoxAlignTopRightFilled: typeof IconBoxAlignTopRightFilled;
declare const index_IconBoxMargin: typeof IconBoxMargin;
declare const index_IconBoxModel: typeof IconBoxModel;
declare const index_IconBoxModel2: typeof IconBoxModel2;
declare const index_IconBoxModel2Off: typeof IconBoxModel2Off;
declare const index_IconBoxModelOff: typeof IconBoxModelOff;
declare const index_IconBoxMultiple: typeof IconBoxMultiple;
declare const index_IconBoxMultiple0: typeof IconBoxMultiple0;
declare const index_IconBoxMultiple1: typeof IconBoxMultiple1;
declare const index_IconBoxMultiple2: typeof IconBoxMultiple2;
declare const index_IconBoxMultiple3: typeof IconBoxMultiple3;
declare const index_IconBoxMultiple4: typeof IconBoxMultiple4;
declare const index_IconBoxMultiple5: typeof IconBoxMultiple5;
declare const index_IconBoxMultiple6: typeof IconBoxMultiple6;
declare const index_IconBoxMultiple7: typeof IconBoxMultiple7;
declare const index_IconBoxMultiple8: typeof IconBoxMultiple8;
declare const index_IconBoxMultiple9: typeof IconBoxMultiple9;
declare const index_IconBoxMultipleFilled: typeof IconBoxMultipleFilled;
declare const index_IconBoxOff: typeof IconBoxOff;
declare const index_IconBoxPadding: typeof IconBoxPadding;
declare const index_IconBraces: typeof IconBraces;
declare const index_IconBracesOff: typeof IconBracesOff;
declare const index_IconBrackets: typeof IconBrackets;
declare const index_IconBracketsAngle: typeof IconBracketsAngle;
declare const index_IconBracketsAngleOff: typeof IconBracketsAngleOff;
declare const index_IconBracketsContain: typeof IconBracketsContain;
declare const index_IconBracketsContainEnd: typeof IconBracketsContainEnd;
declare const index_IconBracketsContainStart: typeof IconBracketsContainStart;
declare const index_IconBracketsOff: typeof IconBracketsOff;
declare const index_IconBraille: typeof IconBraille;
declare const index_IconBrain: typeof IconBrain;
declare const index_IconBrand4chan: typeof IconBrand4chan;
declare const index_IconBrandAbstract: typeof IconBrandAbstract;
declare const index_IconBrandAdobe: typeof IconBrandAdobe;
declare const index_IconBrandAdobeAfterEffect: typeof IconBrandAdobeAfterEffect;
declare const index_IconBrandAdobeIllustrator: typeof IconBrandAdobeIllustrator;
declare const index_IconBrandAdobeIndesign: typeof IconBrandAdobeIndesign;
declare const index_IconBrandAdobePhotoshop: typeof IconBrandAdobePhotoshop;
declare const index_IconBrandAdobePremiere: typeof IconBrandAdobePremiere;
declare const index_IconBrandAdobeXd: typeof IconBrandAdobeXd;
declare const index_IconBrandAdonisJs: typeof IconBrandAdonisJs;
declare const index_IconBrandAirbnb: typeof IconBrandAirbnb;
declare const index_IconBrandAirtable: typeof IconBrandAirtable;
declare const index_IconBrandAlgolia: typeof IconBrandAlgolia;
declare const index_IconBrandAlipay: typeof IconBrandAlipay;
declare const index_IconBrandAlpineJs: typeof IconBrandAlpineJs;
declare const index_IconBrandAmazon: typeof IconBrandAmazon;
declare const index_IconBrandAmd: typeof IconBrandAmd;
declare const index_IconBrandAmie: typeof IconBrandAmie;
declare const index_IconBrandAmigo: typeof IconBrandAmigo;
declare const index_IconBrandAmongUs: typeof IconBrandAmongUs;
declare const index_IconBrandAndroid: typeof IconBrandAndroid;
declare const index_IconBrandAngular: typeof IconBrandAngular;
declare const index_IconBrandAngularFilled: typeof IconBrandAngularFilled;
declare const index_IconBrandAnsible: typeof IconBrandAnsible;
declare const index_IconBrandAo3: typeof IconBrandAo3;
declare const index_IconBrandAppgallery: typeof IconBrandAppgallery;
declare const index_IconBrandApple: typeof IconBrandApple;
declare const index_IconBrandAppleArcade: typeof IconBrandAppleArcade;
declare const index_IconBrandAppleFilled: typeof IconBrandAppleFilled;
declare const index_IconBrandAppleNews: typeof IconBrandAppleNews;
declare const index_IconBrandApplePodcast: typeof IconBrandApplePodcast;
declare const index_IconBrandAppstore: typeof IconBrandAppstore;
declare const index_IconBrandArc: typeof IconBrandArc;
declare const index_IconBrandAsana: typeof IconBrandAsana;
declare const index_IconBrandAstro: typeof IconBrandAstro;
declare const index_IconBrandAuth0: typeof IconBrandAuth0;
declare const index_IconBrandAws: typeof IconBrandAws;
declare const index_IconBrandAzure: typeof IconBrandAzure;
declare const index_IconBrandBackbone: typeof IconBrandBackbone;
declare const index_IconBrandBadoo: typeof IconBrandBadoo;
declare const index_IconBrandBaidu: typeof IconBrandBaidu;
declare const index_IconBrandBandcamp: typeof IconBrandBandcamp;
declare const index_IconBrandBandlab: typeof IconBrandBandlab;
declare const index_IconBrandBeats: typeof IconBrandBeats;
declare const index_IconBrandBebo: typeof IconBrandBebo;
declare const index_IconBrandBehance: typeof IconBrandBehance;
declare const index_IconBrandBilibili: typeof IconBrandBilibili;
declare const index_IconBrandBinance: typeof IconBrandBinance;
declare const index_IconBrandBing: typeof IconBrandBing;
declare const index_IconBrandBitbucket: typeof IconBrandBitbucket;
declare const index_IconBrandBitbucketFilled: typeof IconBrandBitbucketFilled;
declare const index_IconBrandBlackberry: typeof IconBrandBlackberry;
declare const index_IconBrandBlender: typeof IconBrandBlender;
declare const index_IconBrandBlogger: typeof IconBrandBlogger;
declare const index_IconBrandBluesky: typeof IconBrandBluesky;
declare const index_IconBrandBooking: typeof IconBrandBooking;
declare const index_IconBrandBootstrap: typeof IconBrandBootstrap;
declare const index_IconBrandBulma: typeof IconBrandBulma;
declare const index_IconBrandBumble: typeof IconBrandBumble;
declare const index_IconBrandBunpo: typeof IconBrandBunpo;
declare const index_IconBrandCSharp: typeof IconBrandCSharp;
declare const index_IconBrandCake: typeof IconBrandCake;
declare const index_IconBrandCakephp: typeof IconBrandCakephp;
declare const index_IconBrandCampaignmonitor: typeof IconBrandCampaignmonitor;
declare const index_IconBrandCarbon: typeof IconBrandCarbon;
declare const index_IconBrandCashapp: typeof IconBrandCashapp;
declare const index_IconBrandChrome: typeof IconBrandChrome;
declare const index_IconBrandCinema4d: typeof IconBrandCinema4d;
declare const index_IconBrandCitymapper: typeof IconBrandCitymapper;
declare const index_IconBrandCloudflare: typeof IconBrandCloudflare;
declare const index_IconBrandCodecov: typeof IconBrandCodecov;
declare const index_IconBrandCodepen: typeof IconBrandCodepen;
declare const index_IconBrandCodesandbox: typeof IconBrandCodesandbox;
declare const index_IconBrandCohost: typeof IconBrandCohost;
declare const index_IconBrandCoinbase: typeof IconBrandCoinbase;
declare const index_IconBrandComedyCentral: typeof IconBrandComedyCentral;
declare const index_IconBrandCoreos: typeof IconBrandCoreos;
declare const index_IconBrandCouchdb: typeof IconBrandCouchdb;
declare const index_IconBrandCouchsurfing: typeof IconBrandCouchsurfing;
declare const index_IconBrandCpp: typeof IconBrandCpp;
declare const index_IconBrandCraft: typeof IconBrandCraft;
declare const index_IconBrandCrunchbase: typeof IconBrandCrunchbase;
declare const index_IconBrandCss3: typeof IconBrandCss3;
declare const index_IconBrandCtemplar: typeof IconBrandCtemplar;
declare const index_IconBrandCucumber: typeof IconBrandCucumber;
declare const index_IconBrandCupra: typeof IconBrandCupra;
declare const index_IconBrandCypress: typeof IconBrandCypress;
declare const index_IconBrandD3: typeof IconBrandD3;
declare const index_IconBrandDatabricks: typeof IconBrandDatabricks;
declare const index_IconBrandDaysCounter: typeof IconBrandDaysCounter;
declare const index_IconBrandDcos: typeof IconBrandDcos;
declare const index_IconBrandDebian: typeof IconBrandDebian;
declare const index_IconBrandDeezer: typeof IconBrandDeezer;
declare const index_IconBrandDeliveroo: typeof IconBrandDeliveroo;
declare const index_IconBrandDeno: typeof IconBrandDeno;
declare const index_IconBrandDenodo: typeof IconBrandDenodo;
declare const index_IconBrandDeviantart: typeof IconBrandDeviantart;
declare const index_IconBrandDigg: typeof IconBrandDigg;
declare const index_IconBrandDingtalk: typeof IconBrandDingtalk;
declare const index_IconBrandDiscord: typeof IconBrandDiscord;
declare const index_IconBrandDiscordFilled: typeof IconBrandDiscordFilled;
declare const index_IconBrandDisney: typeof IconBrandDisney;
declare const index_IconBrandDisqus: typeof IconBrandDisqus;
declare const index_IconBrandDjango: typeof IconBrandDjango;
declare const index_IconBrandDocker: typeof IconBrandDocker;
declare const index_IconBrandDoctrine: typeof IconBrandDoctrine;
declare const index_IconBrandDolbyDigital: typeof IconBrandDolbyDigital;
declare const index_IconBrandDouban: typeof IconBrandDouban;
declare const index_IconBrandDribbble: typeof IconBrandDribbble;
declare const index_IconBrandDribbbleFilled: typeof IconBrandDribbbleFilled;
declare const index_IconBrandDropbox: typeof IconBrandDropbox;
declare const index_IconBrandDrops: typeof IconBrandDrops;
declare const index_IconBrandDrupal: typeof IconBrandDrupal;
declare const index_IconBrandEdge: typeof IconBrandEdge;
declare const index_IconBrandElastic: typeof IconBrandElastic;
declare const index_IconBrandElectronicArts: typeof IconBrandElectronicArts;
declare const index_IconBrandEmber: typeof IconBrandEmber;
declare const index_IconBrandEnvato: typeof IconBrandEnvato;
declare const index_IconBrandEtsy: typeof IconBrandEtsy;
declare const index_IconBrandEvernote: typeof IconBrandEvernote;
declare const index_IconBrandFacebook: typeof IconBrandFacebook;
declare const index_IconBrandFacebookFilled: typeof IconBrandFacebookFilled;
declare const index_IconBrandFeedly: typeof IconBrandFeedly;
declare const index_IconBrandFigma: typeof IconBrandFigma;
declare const index_IconBrandFilezilla: typeof IconBrandFilezilla;
declare const index_IconBrandFinder: typeof IconBrandFinder;
declare const index_IconBrandFirebase: typeof IconBrandFirebase;
declare const index_IconBrandFirefox: typeof IconBrandFirefox;
declare const index_IconBrandFiverr: typeof IconBrandFiverr;
declare const index_IconBrandFlickr: typeof IconBrandFlickr;
declare const index_IconBrandFlightradar24: typeof IconBrandFlightradar24;
declare const index_IconBrandFlipboard: typeof IconBrandFlipboard;
declare const index_IconBrandFlutter: typeof IconBrandFlutter;
declare const index_IconBrandFortnite: typeof IconBrandFortnite;
declare const index_IconBrandFoursquare: typeof IconBrandFoursquare;
declare const index_IconBrandFramer: typeof IconBrandFramer;
declare const index_IconBrandFramerMotion: typeof IconBrandFramerMotion;
declare const index_IconBrandFunimation: typeof IconBrandFunimation;
declare const index_IconBrandGatsby: typeof IconBrandGatsby;
declare const index_IconBrandGit: typeof IconBrandGit;
declare const index_IconBrandGithub: typeof IconBrandGithub;
declare const index_IconBrandGithubCopilot: typeof IconBrandGithubCopilot;
declare const index_IconBrandGithubFilled: typeof IconBrandGithubFilled;
declare const index_IconBrandGitlab: typeof IconBrandGitlab;
declare const index_IconBrandGmail: typeof IconBrandGmail;
declare const index_IconBrandGolang: typeof IconBrandGolang;
declare const index_IconBrandGoogle: typeof IconBrandGoogle;
declare const index_IconBrandGoogleAnalytics: typeof IconBrandGoogleAnalytics;
declare const index_IconBrandGoogleBigQuery: typeof IconBrandGoogleBigQuery;
declare const index_IconBrandGoogleDrive: typeof IconBrandGoogleDrive;
declare const index_IconBrandGoogleFilled: typeof IconBrandGoogleFilled;
declare const index_IconBrandGoogleFit: typeof IconBrandGoogleFit;
declare const index_IconBrandGoogleHome: typeof IconBrandGoogleHome;
declare const index_IconBrandGoogleMaps: typeof IconBrandGoogleMaps;
declare const index_IconBrandGoogleOne: typeof IconBrandGoogleOne;
declare const index_IconBrandGooglePhotos: typeof IconBrandGooglePhotos;
declare const index_IconBrandGooglePlay: typeof IconBrandGooglePlay;
declare const index_IconBrandGooglePodcasts: typeof IconBrandGooglePodcasts;
declare const index_IconBrandGrammarly: typeof IconBrandGrammarly;
declare const index_IconBrandGraphql: typeof IconBrandGraphql;
declare const index_IconBrandGravatar: typeof IconBrandGravatar;
declare const index_IconBrandGrindr: typeof IconBrandGrindr;
declare const index_IconBrandGuardian: typeof IconBrandGuardian;
declare const index_IconBrandGumroad: typeof IconBrandGumroad;
declare const index_IconBrandHackerrank: typeof IconBrandHackerrank;
declare const index_IconBrandHbo: typeof IconBrandHbo;
declare const index_IconBrandHeadlessui: typeof IconBrandHeadlessui;
declare const index_IconBrandHexo: typeof IconBrandHexo;
declare const index_IconBrandHipchat: typeof IconBrandHipchat;
declare const index_IconBrandHtml5: typeof IconBrandHtml5;
declare const index_IconBrandInertia: typeof IconBrandInertia;
declare const index_IconBrandInstagram: typeof IconBrandInstagram;
declare const index_IconBrandInstagramFilled: typeof IconBrandInstagramFilled;
declare const index_IconBrandIntercom: typeof IconBrandIntercom;
declare const index_IconBrandItch: typeof IconBrandItch;
declare const index_IconBrandJavascript: typeof IconBrandJavascript;
declare const index_IconBrandJuejin: typeof IconBrandJuejin;
declare const index_IconBrandKakoTalk: typeof IconBrandKakoTalk;
declare const index_IconBrandKbin: typeof IconBrandKbin;
declare const index_IconBrandKick: typeof IconBrandKick;
declare const index_IconBrandKickFilled: typeof IconBrandKickFilled;
declare const index_IconBrandKickstarter: typeof IconBrandKickstarter;
declare const index_IconBrandKotlin: typeof IconBrandKotlin;
declare const index_IconBrandLaravel: typeof IconBrandLaravel;
declare const index_IconBrandLastfm: typeof IconBrandLastfm;
declare const index_IconBrandLeetcode: typeof IconBrandLeetcode;
declare const index_IconBrandLetterboxd: typeof IconBrandLetterboxd;
declare const index_IconBrandLine: typeof IconBrandLine;
declare const index_IconBrandLinkedin: typeof IconBrandLinkedin;
declare const index_IconBrandLinkedinFilled: typeof IconBrandLinkedinFilled;
declare const index_IconBrandLinktree: typeof IconBrandLinktree;
declare const index_IconBrandLinqpad: typeof IconBrandLinqpad;
declare const index_IconBrandLivewire: typeof IconBrandLivewire;
declare const index_IconBrandLoom: typeof IconBrandLoom;
declare const index_IconBrandMailgun: typeof IconBrandMailgun;
declare const index_IconBrandMantine: typeof IconBrandMantine;
declare const index_IconBrandMastercard: typeof IconBrandMastercard;
declare const index_IconBrandMastodon: typeof IconBrandMastodon;
declare const index_IconBrandMatrix: typeof IconBrandMatrix;
declare const index_IconBrandMcdonalds: typeof IconBrandMcdonalds;
declare const index_IconBrandMedium: typeof IconBrandMedium;
declare const index_IconBrandMeetup: typeof IconBrandMeetup;
declare const index_IconBrandMercedes: typeof IconBrandMercedes;
declare const index_IconBrandMessenger: typeof IconBrandMessenger;
declare const index_IconBrandMessengerFilled: typeof IconBrandMessengerFilled;
declare const index_IconBrandMeta: typeof IconBrandMeta;
declare const index_IconBrandMetabrainz: typeof IconBrandMetabrainz;
declare const index_IconBrandMinecraft: typeof IconBrandMinecraft;
declare const index_IconBrandMiniprogram: typeof IconBrandMiniprogram;
declare const index_IconBrandMixpanel: typeof IconBrandMixpanel;
declare const index_IconBrandMonday: typeof IconBrandMonday;
declare const index_IconBrandMongodb: typeof IconBrandMongodb;
declare const index_IconBrandMyOppo: typeof IconBrandMyOppo;
declare const index_IconBrandMysql: typeof IconBrandMysql;
declare const index_IconBrandNationalGeographic: typeof IconBrandNationalGeographic;
declare const index_IconBrandNem: typeof IconBrandNem;
declare const index_IconBrandNetbeans: typeof IconBrandNetbeans;
declare const index_IconBrandNeteaseMusic: typeof IconBrandNeteaseMusic;
declare const index_IconBrandNetflix: typeof IconBrandNetflix;
declare const index_IconBrandNexo: typeof IconBrandNexo;
declare const index_IconBrandNextcloud: typeof IconBrandNextcloud;
declare const index_IconBrandNextjs: typeof IconBrandNextjs;
declare const index_IconBrandNodejs: typeof IconBrandNodejs;
declare const index_IconBrandNordVpn: typeof IconBrandNordVpn;
declare const index_IconBrandNotion: typeof IconBrandNotion;
declare const index_IconBrandNpm: typeof IconBrandNpm;
declare const index_IconBrandNuxt: typeof IconBrandNuxt;
declare const index_IconBrandNytimes: typeof IconBrandNytimes;
declare const index_IconBrandOauth: typeof IconBrandOauth;
declare const index_IconBrandOffice: typeof IconBrandOffice;
declare const index_IconBrandOkRu: typeof IconBrandOkRu;
declare const index_IconBrandOnedrive: typeof IconBrandOnedrive;
declare const index_IconBrandOnlyfans: typeof IconBrandOnlyfans;
declare const index_IconBrandOpenSource: typeof IconBrandOpenSource;
declare const index_IconBrandOpenSourceFilled: typeof IconBrandOpenSourceFilled;
declare const index_IconBrandOpenai: typeof IconBrandOpenai;
declare const index_IconBrandOpenvpn: typeof IconBrandOpenvpn;
declare const index_IconBrandOpera: typeof IconBrandOpera;
declare const index_IconBrandOperaFilled: typeof IconBrandOperaFilled;
declare const index_IconBrandPagekit: typeof IconBrandPagekit;
declare const index_IconBrandParsinta: typeof IconBrandParsinta;
declare const index_IconBrandPatreon: typeof IconBrandPatreon;
declare const index_IconBrandPatreonFilled: typeof IconBrandPatreonFilled;
declare const index_IconBrandPaypal: typeof IconBrandPaypal;
declare const index_IconBrandPaypalFilled: typeof IconBrandPaypalFilled;
declare const index_IconBrandPaypay: typeof IconBrandPaypay;
declare const index_IconBrandPeanut: typeof IconBrandPeanut;
declare const index_IconBrandPepsi: typeof IconBrandPepsi;
declare const index_IconBrandPhp: typeof IconBrandPhp;
declare const index_IconBrandPicsart: typeof IconBrandPicsart;
declare const index_IconBrandPinterest: typeof IconBrandPinterest;
declare const index_IconBrandPinterestFilled: typeof IconBrandPinterestFilled;
declare const index_IconBrandPlanetscale: typeof IconBrandPlanetscale;
declare const index_IconBrandPnpm: typeof IconBrandPnpm;
declare const index_IconBrandPocket: typeof IconBrandPocket;
declare const index_IconBrandPolymer: typeof IconBrandPolymer;
declare const index_IconBrandPowershell: typeof IconBrandPowershell;
declare const index_IconBrandPrintables: typeof IconBrandPrintables;
declare const index_IconBrandPrisma: typeof IconBrandPrisma;
declare const index_IconBrandProducthunt: typeof IconBrandProducthunt;
declare const index_IconBrandPushbullet: typeof IconBrandPushbullet;
declare const index_IconBrandPushover: typeof IconBrandPushover;
declare const index_IconBrandPython: typeof IconBrandPython;
declare const index_IconBrandQq: typeof IconBrandQq;
declare const index_IconBrandRadixUi: typeof IconBrandRadixUi;
declare const index_IconBrandReact: typeof IconBrandReact;
declare const index_IconBrandReactNative: typeof IconBrandReactNative;
declare const index_IconBrandReason: typeof IconBrandReason;
declare const index_IconBrandReddit: typeof IconBrandReddit;
declare const index_IconBrandRedhat: typeof IconBrandRedhat;
declare const index_IconBrandRedux: typeof IconBrandRedux;
declare const index_IconBrandRevolut: typeof IconBrandRevolut;
declare const index_IconBrandRumble: typeof IconBrandRumble;
declare const index_IconBrandRust: typeof IconBrandRust;
declare const index_IconBrandSafari: typeof IconBrandSafari;
declare const index_IconBrandSamsungpass: typeof IconBrandSamsungpass;
declare const index_IconBrandSass: typeof IconBrandSass;
declare const index_IconBrandSentry: typeof IconBrandSentry;
declare const index_IconBrandSharik: typeof IconBrandSharik;
declare const index_IconBrandShazam: typeof IconBrandShazam;
declare const index_IconBrandShopee: typeof IconBrandShopee;
declare const index_IconBrandSketch: typeof IconBrandSketch;
declare const index_IconBrandSketchFilled: typeof IconBrandSketchFilled;
declare const index_IconBrandSkype: typeof IconBrandSkype;
declare const index_IconBrandSlack: typeof IconBrandSlack;
declare const index_IconBrandSnapchat: typeof IconBrandSnapchat;
declare const index_IconBrandSnapchatFilled: typeof IconBrandSnapchatFilled;
declare const index_IconBrandSnapseed: typeof IconBrandSnapseed;
declare const index_IconBrandSnowflake: typeof IconBrandSnowflake;
declare const index_IconBrandSocketIo: typeof IconBrandSocketIo;
declare const index_IconBrandSolidjs: typeof IconBrandSolidjs;
declare const index_IconBrandSoundcloud: typeof IconBrandSoundcloud;
declare const index_IconBrandSpacehey: typeof IconBrandSpacehey;
declare const index_IconBrandSpeedtest: typeof IconBrandSpeedtest;
declare const index_IconBrandSpotify: typeof IconBrandSpotify;
declare const index_IconBrandSpotifyFilled: typeof IconBrandSpotifyFilled;
declare const index_IconBrandStackoverflow: typeof IconBrandStackoverflow;
declare const index_IconBrandStackshare: typeof IconBrandStackshare;
declare const index_IconBrandSteam: typeof IconBrandSteam;
declare const index_IconBrandSteamFilled: typeof IconBrandSteamFilled;
declare const index_IconBrandStocktwits: typeof IconBrandStocktwits;
declare const index_IconBrandStorj: typeof IconBrandStorj;
declare const index_IconBrandStorybook: typeof IconBrandStorybook;
declare const index_IconBrandStorytel: typeof IconBrandStorytel;
declare const index_IconBrandStrava: typeof IconBrandStrava;
declare const index_IconBrandStripe: typeof IconBrandStripe;
declare const index_IconBrandStripeFilled: typeof IconBrandStripeFilled;
declare const index_IconBrandSublimeText: typeof IconBrandSublimeText;
declare const index_IconBrandSugarizer: typeof IconBrandSugarizer;
declare const index_IconBrandSupabase: typeof IconBrandSupabase;
declare const index_IconBrandSuperhuman: typeof IconBrandSuperhuman;
declare const index_IconBrandSupernova: typeof IconBrandSupernova;
declare const index_IconBrandSurfshark: typeof IconBrandSurfshark;
declare const index_IconBrandSvelte: typeof IconBrandSvelte;
declare const index_IconBrandSwift: typeof IconBrandSwift;
declare const index_IconBrandSymfony: typeof IconBrandSymfony;
declare const index_IconBrandTabler: typeof IconBrandTabler;
declare const index_IconBrandTablerFilled: typeof IconBrandTablerFilled;
declare const index_IconBrandTabnine: typeof IconBrandTabnine;
declare const index_IconBrandTailwind: typeof IconBrandTailwind;
declare const index_IconBrandTaobao: typeof IconBrandTaobao;
declare const index_IconBrandTeams: typeof IconBrandTeams;
declare const index_IconBrandTed: typeof IconBrandTed;
declare const index_IconBrandTelegram: typeof IconBrandTelegram;
declare const index_IconBrandTerraform: typeof IconBrandTerraform;
declare const index_IconBrandTesla: typeof IconBrandTesla;
declare const index_IconBrandTether: typeof IconBrandTether;
declare const index_IconBrandThingiverse: typeof IconBrandThingiverse;
declare const index_IconBrandThreads: typeof IconBrandThreads;
declare const index_IconBrandThreejs: typeof IconBrandThreejs;
declare const index_IconBrandTidal: typeof IconBrandTidal;
declare const index_IconBrandTiktok: typeof IconBrandTiktok;
declare const index_IconBrandTiktokFilled: typeof IconBrandTiktokFilled;
declare const index_IconBrandTinder: typeof IconBrandTinder;
declare const index_IconBrandTinderFilled: typeof IconBrandTinderFilled;
declare const index_IconBrandTopbuzz: typeof IconBrandTopbuzz;
declare const index_IconBrandTorchain: typeof IconBrandTorchain;
declare const index_IconBrandToyota: typeof IconBrandToyota;
declare const index_IconBrandTrello: typeof IconBrandTrello;
declare const index_IconBrandTripadvisor: typeof IconBrandTripadvisor;
declare const index_IconBrandTumblr: typeof IconBrandTumblr;
declare const index_IconBrandTumblrFilled: typeof IconBrandTumblrFilled;
declare const index_IconBrandTwilio: typeof IconBrandTwilio;
declare const index_IconBrandTwitch: typeof IconBrandTwitch;
declare const index_IconBrandTwitter: typeof IconBrandTwitter;
declare const index_IconBrandTwitterFilled: typeof IconBrandTwitterFilled;
declare const index_IconBrandTypescript: typeof IconBrandTypescript;
declare const index_IconBrandUber: typeof IconBrandUber;
declare const index_IconBrandUbuntu: typeof IconBrandUbuntu;
declare const index_IconBrandUnity: typeof IconBrandUnity;
declare const index_IconBrandUnsplash: typeof IconBrandUnsplash;
declare const index_IconBrandUpwork: typeof IconBrandUpwork;
declare const index_IconBrandValorant: typeof IconBrandValorant;
declare const index_IconBrandVercel: typeof IconBrandVercel;
declare const index_IconBrandVercelFilled: typeof IconBrandVercelFilled;
declare const index_IconBrandVimeo: typeof IconBrandVimeo;
declare const index_IconBrandVimeoFilled: typeof IconBrandVimeoFilled;
declare const index_IconBrandVinted: typeof IconBrandVinted;
declare const index_IconBrandVisa: typeof IconBrandVisa;
declare const index_IconBrandVisualStudio: typeof IconBrandVisualStudio;
declare const index_IconBrandVite: typeof IconBrandVite;
declare const index_IconBrandVivaldi: typeof IconBrandVivaldi;
declare const index_IconBrandVk: typeof IconBrandVk;
declare const index_IconBrandVlc: typeof IconBrandVlc;
declare const index_IconBrandVolkswagen: typeof IconBrandVolkswagen;
declare const index_IconBrandVsco: typeof IconBrandVsco;
declare const index_IconBrandVscode: typeof IconBrandVscode;
declare const index_IconBrandVue: typeof IconBrandVue;
declare const index_IconBrandWalmart: typeof IconBrandWalmart;
declare const index_IconBrandWaze: typeof IconBrandWaze;
declare const index_IconBrandWebflow: typeof IconBrandWebflow;
declare const index_IconBrandWechat: typeof IconBrandWechat;
declare const index_IconBrandWeibo: typeof IconBrandWeibo;
declare const index_IconBrandWeiboFilled: typeof IconBrandWeiboFilled;
declare const index_IconBrandWhatsapp: typeof IconBrandWhatsapp;
declare const index_IconBrandWhatsappFilled: typeof IconBrandWhatsappFilled;
declare const index_IconBrandWikipedia: typeof IconBrandWikipedia;
declare const index_IconBrandWindows: typeof IconBrandWindows;
declare const index_IconBrandWindowsFilled: typeof IconBrandWindowsFilled;
declare const index_IconBrandWindy: typeof IconBrandWindy;
declare const index_IconBrandWish: typeof IconBrandWish;
declare const index_IconBrandWix: typeof IconBrandWix;
declare const index_IconBrandWordpress: typeof IconBrandWordpress;
declare const index_IconBrandX: typeof IconBrandX;
declare const index_IconBrandXFilled: typeof IconBrandXFilled;
declare const index_IconBrandXamarin: typeof IconBrandXamarin;
declare const index_IconBrandXbox: typeof IconBrandXbox;
declare const index_IconBrandXdeep: typeof IconBrandXdeep;
declare const index_IconBrandXing: typeof IconBrandXing;
declare const index_IconBrandYahoo: typeof IconBrandYahoo;
declare const index_IconBrandYandex: typeof IconBrandYandex;
declare const index_IconBrandYarn: typeof IconBrandYarn;
declare const index_IconBrandYatse: typeof IconBrandYatse;
declare const index_IconBrandYcombinator: typeof IconBrandYcombinator;
declare const index_IconBrandYoutube: typeof IconBrandYoutube;
declare const index_IconBrandYoutubeFilled: typeof IconBrandYoutubeFilled;
declare const index_IconBrandYoutubeKids: typeof IconBrandYoutubeKids;
declare const index_IconBrandZalando: typeof IconBrandZalando;
declare const index_IconBrandZapier: typeof IconBrandZapier;
declare const index_IconBrandZeit: typeof IconBrandZeit;
declare const index_IconBrandZhihu: typeof IconBrandZhihu;
declare const index_IconBrandZoom: typeof IconBrandZoom;
declare const index_IconBrandZulip: typeof IconBrandZulip;
declare const index_IconBrandZwift: typeof IconBrandZwift;
declare const index_IconBread: typeof IconBread;
declare const index_IconBreadFilled: typeof IconBreadFilled;
declare const index_IconBreadOff: typeof IconBreadOff;
declare const index_IconBriefcase: typeof IconBriefcase;
declare const index_IconBriefcase2: typeof IconBriefcase2;
declare const index_IconBriefcase2Filled: typeof IconBriefcase2Filled;
declare const index_IconBriefcaseFilled: typeof IconBriefcaseFilled;
declare const index_IconBriefcaseOff: typeof IconBriefcaseOff;
declare const index_IconBrightness: typeof IconBrightness;
declare const index_IconBrightness2: typeof IconBrightness2;
declare const index_IconBrightnessAuto: typeof IconBrightnessAuto;
declare const index_IconBrightnessAutoFilled: typeof IconBrightnessAutoFilled;
declare const index_IconBrightnessDown: typeof IconBrightnessDown;
declare const index_IconBrightnessDownFilled: typeof IconBrightnessDownFilled;
declare const index_IconBrightnessFilled: typeof IconBrightnessFilled;
declare const index_IconBrightnessHalf: typeof IconBrightnessHalf;
declare const index_IconBrightnessOff: typeof IconBrightnessOff;
declare const index_IconBrightnessUp: typeof IconBrightnessUp;
declare const index_IconBrightnessUpFilled: typeof IconBrightnessUpFilled;
declare const index_IconBroadcast: typeof IconBroadcast;
declare const index_IconBroadcastOff: typeof IconBroadcastOff;
declare const index_IconBrowser: typeof IconBrowser;
declare const index_IconBrowserCheck: typeof IconBrowserCheck;
declare const index_IconBrowserMaximize: typeof IconBrowserMaximize;
declare const index_IconBrowserMinus: typeof IconBrowserMinus;
declare const index_IconBrowserOff: typeof IconBrowserOff;
declare const index_IconBrowserPlus: typeof IconBrowserPlus;
declare const index_IconBrowserShare: typeof IconBrowserShare;
declare const index_IconBrowserX: typeof IconBrowserX;
declare const index_IconBrush: typeof IconBrush;
declare const index_IconBrushOff: typeof IconBrushOff;
declare const index_IconBubble: typeof IconBubble;
declare const index_IconBubbleFilled: typeof IconBubbleFilled;
declare const index_IconBubbleMinus: typeof IconBubbleMinus;
declare const index_IconBubblePlus: typeof IconBubblePlus;
declare const index_IconBubbleTea: typeof IconBubbleTea;
declare const index_IconBubbleTea2: typeof IconBubbleTea2;
declare const index_IconBubbleText: typeof IconBubbleText;
declare const index_IconBubbleTextFilled: typeof IconBubbleTextFilled;
declare const index_IconBubbleX: typeof IconBubbleX;
declare const index_IconBucket: typeof IconBucket;
declare const index_IconBucketDroplet: typeof IconBucketDroplet;
declare const index_IconBucketOff: typeof IconBucketOff;
declare const index_IconBug: typeof IconBug;
declare const index_IconBugFilled: typeof IconBugFilled;
declare const index_IconBugOff: typeof IconBugOff;
declare const index_IconBuilding: typeof IconBuilding;
declare const index_IconBuildingAirport: typeof IconBuildingAirport;
declare const index_IconBuildingArch: typeof IconBuildingArch;
declare const index_IconBuildingBank: typeof IconBuildingBank;
declare const index_IconBuildingBridge: typeof IconBuildingBridge;
declare const index_IconBuildingBridge2: typeof IconBuildingBridge2;
declare const index_IconBuildingBridge2Filled: typeof IconBuildingBridge2Filled;
declare const index_IconBuildingBroadcastTower: typeof IconBuildingBroadcastTower;
declare const index_IconBuildingBroadcastTowerFilled: typeof IconBuildingBroadcastTowerFilled;
declare const index_IconBuildingBurjAlArab: typeof IconBuildingBurjAlArab;
declare const index_IconBuildingCarousel: typeof IconBuildingCarousel;
declare const index_IconBuildingCastle: typeof IconBuildingCastle;
declare const index_IconBuildingChurch: typeof IconBuildingChurch;
declare const index_IconBuildingCircus: typeof IconBuildingCircus;
declare const index_IconBuildingCog: typeof IconBuildingCog;
declare const index_IconBuildingCommunity: typeof IconBuildingCommunity;
declare const index_IconBuildingCottage: typeof IconBuildingCottage;
declare const index_IconBuildingEstate: typeof IconBuildingEstate;
declare const index_IconBuildingFactory: typeof IconBuildingFactory;
declare const index_IconBuildingFactory2: typeof IconBuildingFactory2;
declare const index_IconBuildingFortress: typeof IconBuildingFortress;
declare const index_IconBuildingHospital: typeof IconBuildingHospital;
declare const index_IconBuildingLighthouse: typeof IconBuildingLighthouse;
declare const index_IconBuildingMinus: typeof IconBuildingMinus;
declare const index_IconBuildingMonument: typeof IconBuildingMonument;
declare const index_IconBuildingMosque: typeof IconBuildingMosque;
declare const index_IconBuildingOff: typeof IconBuildingOff;
declare const index_IconBuildingPavilion: typeof IconBuildingPavilion;
declare const index_IconBuildingPlus: typeof IconBuildingPlus;
declare const index_IconBuildingSkyscraper: typeof IconBuildingSkyscraper;
declare const index_IconBuildingStadium: typeof IconBuildingStadium;
declare const index_IconBuildingStore: typeof IconBuildingStore;
declare const index_IconBuildingTunnel: typeof IconBuildingTunnel;
declare const index_IconBuildingWarehouse: typeof IconBuildingWarehouse;
declare const index_IconBuildingWindTurbine: typeof IconBuildingWindTurbine;
declare const index_IconBuildings: typeof IconBuildings;
declare const index_IconBulb: typeof IconBulb;
declare const index_IconBulbFilled: typeof IconBulbFilled;
declare const index_IconBulbOff: typeof IconBulbOff;
declare const index_IconBulldozer: typeof IconBulldozer;
declare const index_IconBurger: typeof IconBurger;
declare const index_IconBus: typeof IconBus;
declare const index_IconBusFilled: typeof IconBusFilled;
declare const index_IconBusOff: typeof IconBusOff;
declare const index_IconBusStop: typeof IconBusStop;
declare const index_IconBusinessplan: typeof IconBusinessplan;
declare const index_IconButterfly: typeof IconButterfly;
declare const index_IconButterflyFilled: typeof IconButterflyFilled;
declare const index_IconCactus: typeof IconCactus;
declare const index_IconCactusFilled: typeof IconCactusFilled;
declare const index_IconCactusOff: typeof IconCactusOff;
declare const index_IconCake: typeof IconCake;
declare const index_IconCakeOff: typeof IconCakeOff;
declare const index_IconCakeRoll: typeof IconCakeRoll;
declare const index_IconCalculator: typeof IconCalculator;
declare const index_IconCalculatorFilled: typeof IconCalculatorFilled;
declare const index_IconCalculatorOff: typeof IconCalculatorOff;
declare const index_IconCalendar: typeof IconCalendar;
declare const index_IconCalendarBolt: typeof IconCalendarBolt;
declare const index_IconCalendarCancel: typeof IconCalendarCancel;
declare const index_IconCalendarCheck: typeof IconCalendarCheck;
declare const index_IconCalendarClock: typeof IconCalendarClock;
declare const index_IconCalendarCode: typeof IconCalendarCode;
declare const index_IconCalendarCog: typeof IconCalendarCog;
declare const index_IconCalendarDollar: typeof IconCalendarDollar;
declare const index_IconCalendarDot: typeof IconCalendarDot;
declare const index_IconCalendarDown: typeof IconCalendarDown;
declare const index_IconCalendarDue: typeof IconCalendarDue;
declare const index_IconCalendarEvent: typeof IconCalendarEvent;
declare const index_IconCalendarEventFilled: typeof IconCalendarEventFilled;
declare const index_IconCalendarExclamation: typeof IconCalendarExclamation;
declare const index_IconCalendarFilled: typeof IconCalendarFilled;
declare const index_IconCalendarHeart: typeof IconCalendarHeart;
declare const index_IconCalendarMinus: typeof IconCalendarMinus;
declare const index_IconCalendarMonth: typeof IconCalendarMonth;
declare const index_IconCalendarMonthFilled: typeof IconCalendarMonthFilled;
declare const index_IconCalendarOff: typeof IconCalendarOff;
declare const index_IconCalendarPause: typeof IconCalendarPause;
declare const index_IconCalendarPin: typeof IconCalendarPin;
declare const index_IconCalendarPlus: typeof IconCalendarPlus;
declare const index_IconCalendarQuestion: typeof IconCalendarQuestion;
declare const index_IconCalendarRepeat: typeof IconCalendarRepeat;
declare const index_IconCalendarSad: typeof IconCalendarSad;
declare const index_IconCalendarSearch: typeof IconCalendarSearch;
declare const index_IconCalendarShare: typeof IconCalendarShare;
declare const index_IconCalendarSmile: typeof IconCalendarSmile;
declare const index_IconCalendarStar: typeof IconCalendarStar;
declare const index_IconCalendarStats: typeof IconCalendarStats;
declare const index_IconCalendarTime: typeof IconCalendarTime;
declare const index_IconCalendarUp: typeof IconCalendarUp;
declare const index_IconCalendarUser: typeof IconCalendarUser;
declare const index_IconCalendarWeek: typeof IconCalendarWeek;
declare const index_IconCalendarWeekFilled: typeof IconCalendarWeekFilled;
declare const index_IconCalendarX: typeof IconCalendarX;
declare const index_IconCamera: typeof IconCamera;
declare const index_IconCameraAi: typeof IconCameraAi;
declare const index_IconCameraBitcoin: typeof IconCameraBitcoin;
declare const index_IconCameraBolt: typeof IconCameraBolt;
declare const index_IconCameraCancel: typeof IconCameraCancel;
declare const index_IconCameraCheck: typeof IconCameraCheck;
declare const index_IconCameraCode: typeof IconCameraCode;
declare const index_IconCameraCog: typeof IconCameraCog;
declare const index_IconCameraDollar: typeof IconCameraDollar;
declare const index_IconCameraDown: typeof IconCameraDown;
declare const index_IconCameraExclamation: typeof IconCameraExclamation;
declare const index_IconCameraFilled: typeof IconCameraFilled;
declare const index_IconCameraHeart: typeof IconCameraHeart;
declare const index_IconCameraMinus: typeof IconCameraMinus;
declare const index_IconCameraMoon: typeof IconCameraMoon;
declare const index_IconCameraOff: typeof IconCameraOff;
declare const index_IconCameraPause: typeof IconCameraPause;
declare const index_IconCameraPin: typeof IconCameraPin;
declare const index_IconCameraPlus: typeof IconCameraPlus;
declare const index_IconCameraQuestion: typeof IconCameraQuestion;
declare const index_IconCameraRotate: typeof IconCameraRotate;
declare const index_IconCameraSearch: typeof IconCameraSearch;
declare const index_IconCameraSelfie: typeof IconCameraSelfie;
declare const index_IconCameraShare: typeof IconCameraShare;
declare const index_IconCameraSpark: typeof IconCameraSpark;
declare const index_IconCameraStar: typeof IconCameraStar;
declare const index_IconCameraUp: typeof IconCameraUp;
declare const index_IconCameraX: typeof IconCameraX;
declare const index_IconCamper: typeof IconCamper;
declare const index_IconCampfire: typeof IconCampfire;
declare const index_IconCampfireFilled: typeof IconCampfireFilled;
declare const index_IconCancel: typeof IconCancel;
declare const index_IconCandle: typeof IconCandle;
declare const index_IconCandleFilled: typeof IconCandleFilled;
declare const index_IconCandy: typeof IconCandy;
declare const index_IconCandyOff: typeof IconCandyOff;
declare const index_IconCane: typeof IconCane;
declare const index_IconCannabis: typeof IconCannabis;
declare const index_IconCannabisFilled: typeof IconCannabisFilled;
declare const index_IconCapProjecting: typeof IconCapProjecting;
declare const index_IconCapRounded: typeof IconCapRounded;
declare const index_IconCapStraight: typeof IconCapStraight;
declare const index_IconCapsule: typeof IconCapsule;
declare const index_IconCapsuleFilled: typeof IconCapsuleFilled;
declare const index_IconCapsuleHorizontal: typeof IconCapsuleHorizontal;
declare const index_IconCapsuleHorizontalFilled: typeof IconCapsuleHorizontalFilled;
declare const index_IconCapture: typeof IconCapture;
declare const index_IconCaptureFilled: typeof IconCaptureFilled;
declare const index_IconCaptureOff: typeof IconCaptureOff;
declare const index_IconCar: typeof IconCar;
declare const index_IconCar4wd: typeof IconCar4wd;
declare const index_IconCar4wdFilled: typeof IconCar4wdFilled;
declare const index_IconCarCrane: typeof IconCarCrane;
declare const index_IconCarCraneFilled: typeof IconCarCraneFilled;
declare const index_IconCarCrash: typeof IconCarCrash;
declare const index_IconCarFan: typeof IconCarFan;
declare const index_IconCarFan1: typeof IconCarFan1;
declare const index_IconCarFan2: typeof IconCarFan2;
declare const index_IconCarFan3: typeof IconCarFan3;
declare const index_IconCarFanAuto: typeof IconCarFanAuto;
declare const index_IconCarFanFilled: typeof IconCarFanFilled;
declare const index_IconCarFilled: typeof IconCarFilled;
declare const index_IconCarGarage: typeof IconCarGarage;
declare const index_IconCarOff: typeof IconCarOff;
declare const index_IconCarSuv: typeof IconCarSuv;
declare const index_IconCarSuvFilled: typeof IconCarSuvFilled;
declare const index_IconCarTurbine: typeof IconCarTurbine;
declare const index_IconCarambola: typeof IconCarambola;
declare const index_IconCarambolaFilled: typeof IconCarambolaFilled;
declare const index_IconCaravan: typeof IconCaravan;
declare const index_IconCaravanFilled: typeof IconCaravanFilled;
declare const index_IconCardboards: typeof IconCardboards;
declare const index_IconCardboardsFilled: typeof IconCardboardsFilled;
declare const index_IconCardboardsOff: typeof IconCardboardsOff;
declare const index_IconCards: typeof IconCards;
declare const index_IconCardsFilled: typeof IconCardsFilled;
declare const index_IconCaretDown: typeof IconCaretDown;
declare const index_IconCaretDownFilled: typeof IconCaretDownFilled;
declare const index_IconCaretLeft: typeof IconCaretLeft;
declare const index_IconCaretLeftFilled: typeof IconCaretLeftFilled;
declare const index_IconCaretLeftRight: typeof IconCaretLeftRight;
declare const index_IconCaretLeftRightFilled: typeof IconCaretLeftRightFilled;
declare const index_IconCaretRight: typeof IconCaretRight;
declare const index_IconCaretRightFilled: typeof IconCaretRightFilled;
declare const index_IconCaretUp: typeof IconCaretUp;
declare const index_IconCaretUpDown: typeof IconCaretUpDown;
declare const index_IconCaretUpDownFilled: typeof IconCaretUpDownFilled;
declare const index_IconCaretUpFilled: typeof IconCaretUpFilled;
declare const index_IconCarouselHorizontal: typeof IconCarouselHorizontal;
declare const index_IconCarouselHorizontalFilled: typeof IconCarouselHorizontalFilled;
declare const index_IconCarouselVertical: typeof IconCarouselVertical;
declare const index_IconCarouselVerticalFilled: typeof IconCarouselVerticalFilled;
declare const index_IconCarrot: typeof IconCarrot;
declare const index_IconCarrotOff: typeof IconCarrotOff;
declare const index_IconCash: typeof IconCash;
declare const index_IconCashBanknote: typeof IconCashBanknote;
declare const index_IconCashBanknoteEdit: typeof IconCashBanknoteEdit;
declare const index_IconCashBanknoteFilled: typeof IconCashBanknoteFilled;
declare const index_IconCashBanknoteHeart: typeof IconCashBanknoteHeart;
declare const index_IconCashBanknoteMinus: typeof IconCashBanknoteMinus;
declare const index_IconCashBanknoteMove: typeof IconCashBanknoteMove;
declare const index_IconCashBanknoteMoveBack: typeof IconCashBanknoteMoveBack;
declare const index_IconCashBanknoteOff: typeof IconCashBanknoteOff;
declare const index_IconCashBanknotePlus: typeof IconCashBanknotePlus;
declare const index_IconCashEdit: typeof IconCashEdit;
declare const index_IconCashHeart: typeof IconCashHeart;
declare const index_IconCashMinus: typeof IconCashMinus;
declare const index_IconCashMove: typeof IconCashMove;
declare const index_IconCashMoveBack: typeof IconCashMoveBack;
declare const index_IconCashOff: typeof IconCashOff;
declare const index_IconCashPlus: typeof IconCashPlus;
declare const index_IconCashRegister: typeof IconCashRegister;
declare const index_IconCast: typeof IconCast;
declare const index_IconCastOff: typeof IconCastOff;
declare const index_IconCat: typeof IconCat;
declare const index_IconCategory: typeof IconCategory;
declare const index_IconCategory2: typeof IconCategory2;
declare const index_IconCategoryFilled: typeof IconCategoryFilled;
declare const index_IconCategoryMinus: typeof IconCategoryMinus;
declare const index_IconCategoryPlus: typeof IconCategoryPlus;
declare const index_IconCe: typeof IconCe;
declare const index_IconCeOff: typeof IconCeOff;
declare const index_IconCell: typeof IconCell;
declare const index_IconCellSignal1: typeof IconCellSignal1;
declare const index_IconCellSignal2: typeof IconCellSignal2;
declare const index_IconCellSignal3: typeof IconCellSignal3;
declare const index_IconCellSignal4: typeof IconCellSignal4;
declare const index_IconCellSignal5: typeof IconCellSignal5;
declare const index_IconCellSignalOff: typeof IconCellSignalOff;
declare const index_IconCertificate: typeof IconCertificate;
declare const index_IconCertificate2: typeof IconCertificate2;
declare const index_IconCertificate2Off: typeof IconCertificate2Off;
declare const index_IconCertificateOff: typeof IconCertificateOff;
declare const index_IconChairDirector: typeof IconChairDirector;
declare const index_IconChalkboard: typeof IconChalkboard;
declare const index_IconChalkboardOff: typeof IconChalkboardOff;
declare const index_IconChalkboardTeacher: typeof IconChalkboardTeacher;
declare const index_IconChargingPile: typeof IconChargingPile;
declare const index_IconChargingPileFilled: typeof IconChargingPileFilled;
declare const index_IconChartArcs: typeof IconChartArcs;
declare const index_IconChartArcs3: typeof IconChartArcs3;
declare const index_IconChartArea: typeof IconChartArea;
declare const index_IconChartAreaFilled: typeof IconChartAreaFilled;
declare const index_IconChartAreaLine: typeof IconChartAreaLine;
declare const index_IconChartAreaLineFilled: typeof IconChartAreaLineFilled;
declare const index_IconChartArrows: typeof IconChartArrows;
declare const index_IconChartArrowsVertical: typeof IconChartArrowsVertical;
declare const index_IconChartBar: typeof IconChartBar;
declare const index_IconChartBarOff: typeof IconChartBarOff;
declare const index_IconChartBarPopular: typeof IconChartBarPopular;
declare const index_IconChartBubble: typeof IconChartBubble;
declare const index_IconChartBubbleFilled: typeof IconChartBubbleFilled;
declare const index_IconChartCandle: typeof IconChartCandle;
declare const index_IconChartCandleFilled: typeof IconChartCandleFilled;
declare const index_IconChartCircles: typeof IconChartCircles;
declare const index_IconChartCohort: typeof IconChartCohort;
declare const index_IconChartColumn: typeof IconChartColumn;
declare const index_IconChartCovariate: typeof IconChartCovariate;
declare const index_IconChartDonut: typeof IconChartDonut;
declare const index_IconChartDonut2: typeof IconChartDonut2;
declare const index_IconChartDonut3: typeof IconChartDonut3;
declare const index_IconChartDonut4: typeof IconChartDonut4;
declare const index_IconChartDonutFilled: typeof IconChartDonutFilled;
declare const index_IconChartDots: typeof IconChartDots;
declare const index_IconChartDots2: typeof IconChartDots2;
declare const index_IconChartDots2Filled: typeof IconChartDots2Filled;
declare const index_IconChartDots3: typeof IconChartDots3;
declare const index_IconChartDots3Filled: typeof IconChartDots3Filled;
declare const index_IconChartDotsFilled: typeof IconChartDotsFilled;
declare const index_IconChartFunnel: typeof IconChartFunnel;
declare const index_IconChartFunnelFilled: typeof IconChartFunnelFilled;
declare const index_IconChartGridDots: typeof IconChartGridDots;
declare const index_IconChartGridDotsFilled: typeof IconChartGridDotsFilled;
declare const index_IconChartHistogram: typeof IconChartHistogram;
declare const index_IconChartInfographic: typeof IconChartInfographic;
declare const index_IconChartLine: typeof IconChartLine;
declare const index_IconChartPie: typeof IconChartPie;
declare const index_IconChartPie2: typeof IconChartPie2;
declare const index_IconChartPie2Filled: typeof IconChartPie2Filled;
declare const index_IconChartPie3: typeof IconChartPie3;
declare const index_IconChartPie3Filled: typeof IconChartPie3Filled;
declare const index_IconChartPie4: typeof IconChartPie4;
declare const index_IconChartPie4Filled: typeof IconChartPie4Filled;
declare const index_IconChartPieFilled: typeof IconChartPieFilled;
declare const index_IconChartPieOff: typeof IconChartPieOff;
declare const index_IconChartPpf: typeof IconChartPpf;
declare const index_IconChartRadar: typeof IconChartRadar;
declare const index_IconChartSankey: typeof IconChartSankey;
declare const index_IconChartScatter: typeof IconChartScatter;
declare const index_IconChartScatter3d: typeof IconChartScatter3d;
declare const index_IconChartTreemap: typeof IconChartTreemap;
declare const index_IconCheck: typeof IconCheck;
declare const index_IconCheckbox: typeof IconCheckbox;
declare const index_IconChecklist: typeof IconChecklist;
declare const index_IconChecks: typeof IconChecks;
declare const index_IconCheckupList: typeof IconCheckupList;
declare const index_IconCheese: typeof IconCheese;
declare const index_IconChefHat: typeof IconChefHat;
declare const index_IconChefHatFilled: typeof IconChefHatFilled;
declare const index_IconChefHatOff: typeof IconChefHatOff;
declare const index_IconCherry: typeof IconCherry;
declare const index_IconCherryFilled: typeof IconCherryFilled;
declare const index_IconChess: typeof IconChess;
declare const index_IconChessBishop: typeof IconChessBishop;
declare const index_IconChessBishopFilled: typeof IconChessBishopFilled;
declare const index_IconChessFilled: typeof IconChessFilled;
declare const index_IconChessKing: typeof IconChessKing;
declare const index_IconChessKingFilled: typeof IconChessKingFilled;
declare const index_IconChessKnight: typeof IconChessKnight;
declare const index_IconChessKnightFilled: typeof IconChessKnightFilled;
declare const index_IconChessQueen: typeof IconChessQueen;
declare const index_IconChessQueenFilled: typeof IconChessQueenFilled;
declare const index_IconChessRook: typeof IconChessRook;
declare const index_IconChessRookFilled: typeof IconChessRookFilled;
declare const index_IconChevronCompactDown: typeof IconChevronCompactDown;
declare const index_IconChevronCompactLeft: typeof IconChevronCompactLeft;
declare const index_IconChevronCompactRight: typeof IconChevronCompactRight;
declare const index_IconChevronCompactUp: typeof IconChevronCompactUp;
declare const index_IconChevronDown: typeof IconChevronDown;
declare const index_IconChevronDownLeft: typeof IconChevronDownLeft;
declare const index_IconChevronDownRight: typeof IconChevronDownRight;
declare const index_IconChevronLeft: typeof IconChevronLeft;
declare const index_IconChevronLeftPipe: typeof IconChevronLeftPipe;
declare const index_IconChevronRight: typeof IconChevronRight;
declare const index_IconChevronRightPipe: typeof IconChevronRightPipe;
declare const index_IconChevronUp: typeof IconChevronUp;
declare const index_IconChevronUpLeft: typeof IconChevronUpLeft;
declare const index_IconChevronUpRight: typeof IconChevronUpRight;
declare const index_IconChevronsDown: typeof IconChevronsDown;
declare const index_IconChevronsDownLeft: typeof IconChevronsDownLeft;
declare const index_IconChevronsDownRight: typeof IconChevronsDownRight;
declare const index_IconChevronsLeft: typeof IconChevronsLeft;
declare const index_IconChevronsRight: typeof IconChevronsRight;
declare const index_IconChevronsUp: typeof IconChevronsUp;
declare const index_IconChevronsUpLeft: typeof IconChevronsUpLeft;
declare const index_IconChevronsUpRight: typeof IconChevronsUpRight;
declare const index_IconChisel: typeof IconChisel;
declare const index_IconChristmasBall: typeof IconChristmasBall;
declare const index_IconChristmasTree: typeof IconChristmasTree;
declare const index_IconChristmasTreeFilled: typeof IconChristmasTreeFilled;
declare const index_IconChristmasTreeOff: typeof IconChristmasTreeOff;
declare const index_IconCircle: typeof IconCircle;
declare const index_IconCircleArrowDown: typeof IconCircleArrowDown;
declare const index_IconCircleArrowDownFilled: typeof IconCircleArrowDownFilled;
declare const index_IconCircleArrowDownLeft: typeof IconCircleArrowDownLeft;
declare const index_IconCircleArrowDownLeftFilled: typeof IconCircleArrowDownLeftFilled;
declare const index_IconCircleArrowDownRight: typeof IconCircleArrowDownRight;
declare const index_IconCircleArrowDownRightFilled: typeof IconCircleArrowDownRightFilled;
declare const index_IconCircleArrowLeft: typeof IconCircleArrowLeft;
declare const index_IconCircleArrowLeftFilled: typeof IconCircleArrowLeftFilled;
declare const index_IconCircleArrowRight: typeof IconCircleArrowRight;
declare const index_IconCircleArrowRightFilled: typeof IconCircleArrowRightFilled;
declare const index_IconCircleArrowUp: typeof IconCircleArrowUp;
declare const index_IconCircleArrowUpFilled: typeof IconCircleArrowUpFilled;
declare const index_IconCircleArrowUpLeft: typeof IconCircleArrowUpLeft;
declare const index_IconCircleArrowUpLeftFilled: typeof IconCircleArrowUpLeftFilled;
declare const index_IconCircleArrowUpRight: typeof IconCircleArrowUpRight;
declare const index_IconCircleArrowUpRightFilled: typeof IconCircleArrowUpRightFilled;
declare const index_IconCircleAsterisk: typeof IconCircleAsterisk;
declare const index_IconCircleCaretDown: typeof IconCircleCaretDown;
declare const index_IconCircleCaretDownFilled: typeof IconCircleCaretDownFilled;
declare const index_IconCircleCaretLeft: typeof IconCircleCaretLeft;
declare const index_IconCircleCaretLeftFilled: typeof IconCircleCaretLeftFilled;
declare const index_IconCircleCaretRight: typeof IconCircleCaretRight;
declare const index_IconCircleCaretRightFilled: typeof IconCircleCaretRightFilled;
declare const index_IconCircleCaretUp: typeof IconCircleCaretUp;
declare const index_IconCircleCaretUpFilled: typeof IconCircleCaretUpFilled;
declare const index_IconCircleCheck: typeof IconCircleCheck;
declare const index_IconCircleCheckFilled: typeof IconCircleCheckFilled;
declare const index_IconCircleChevronDown: typeof IconCircleChevronDown;
declare const index_IconCircleChevronDownFilled: typeof IconCircleChevronDownFilled;
declare const index_IconCircleChevronLeft: typeof IconCircleChevronLeft;
declare const index_IconCircleChevronLeftFilled: typeof IconCircleChevronLeftFilled;
declare const index_IconCircleChevronRight: typeof IconCircleChevronRight;
declare const index_IconCircleChevronRightFilled: typeof IconCircleChevronRightFilled;
declare const index_IconCircleChevronUp: typeof IconCircleChevronUp;
declare const index_IconCircleChevronUpFilled: typeof IconCircleChevronUpFilled;
declare const index_IconCircleChevronsDown: typeof IconCircleChevronsDown;
declare const index_IconCircleChevronsDownFilled: typeof IconCircleChevronsDownFilled;
declare const index_IconCircleChevronsLeft: typeof IconCircleChevronsLeft;
declare const index_IconCircleChevronsLeftFilled: typeof IconCircleChevronsLeftFilled;
declare const index_IconCircleChevronsRight: typeof IconCircleChevronsRight;
declare const index_IconCircleChevronsRightFilled: typeof IconCircleChevronsRightFilled;
declare const index_IconCircleChevronsUp: typeof IconCircleChevronsUp;
declare const index_IconCircleChevronsUpFilled: typeof IconCircleChevronsUpFilled;
declare const index_IconCircleDashed: typeof IconCircleDashed;
declare const index_IconCircleDashedCheck: typeof IconCircleDashedCheck;
declare const index_IconCircleDashedLetterA: typeof IconCircleDashedLetterA;
declare const index_IconCircleDashedLetterB: typeof IconCircleDashedLetterB;
declare const index_IconCircleDashedLetterC: typeof IconCircleDashedLetterC;
declare const index_IconCircleDashedLetterD: typeof IconCircleDashedLetterD;
declare const index_IconCircleDashedLetterE: typeof IconCircleDashedLetterE;
declare const index_IconCircleDashedLetterF: typeof IconCircleDashedLetterF;
declare const index_IconCircleDashedLetterG: typeof IconCircleDashedLetterG;
declare const index_IconCircleDashedLetterH: typeof IconCircleDashedLetterH;
declare const index_IconCircleDashedLetterI: typeof IconCircleDashedLetterI;
declare const index_IconCircleDashedLetterJ: typeof IconCircleDashedLetterJ;
declare const index_IconCircleDashedLetterK: typeof IconCircleDashedLetterK;
declare const index_IconCircleDashedLetterL: typeof IconCircleDashedLetterL;
declare const index_IconCircleDashedLetterM: typeof IconCircleDashedLetterM;
declare const index_IconCircleDashedLetterN: typeof IconCircleDashedLetterN;
declare const index_IconCircleDashedLetterO: typeof IconCircleDashedLetterO;
declare const index_IconCircleDashedLetterP: typeof IconCircleDashedLetterP;
declare const index_IconCircleDashedLetterQ: typeof IconCircleDashedLetterQ;
declare const index_IconCircleDashedLetterR: typeof IconCircleDashedLetterR;
declare const index_IconCircleDashedLetterS: typeof IconCircleDashedLetterS;
declare const index_IconCircleDashedLetterT: typeof IconCircleDashedLetterT;
declare const index_IconCircleDashedLetterU: typeof IconCircleDashedLetterU;
declare const index_IconCircleDashedLetterV: typeof IconCircleDashedLetterV;
declare const index_IconCircleDashedLetterW: typeof IconCircleDashedLetterW;
declare const index_IconCircleDashedLetterX: typeof IconCircleDashedLetterX;
declare const index_IconCircleDashedLetterY: typeof IconCircleDashedLetterY;
declare const index_IconCircleDashedLetterZ: typeof IconCircleDashedLetterZ;
declare const index_IconCircleDashedMinus: typeof IconCircleDashedMinus;
declare const index_IconCircleDashedNumber0: typeof IconCircleDashedNumber0;
declare const index_IconCircleDashedNumber1: typeof IconCircleDashedNumber1;
declare const index_IconCircleDashedNumber2: typeof IconCircleDashedNumber2;
declare const index_IconCircleDashedNumber3: typeof IconCircleDashedNumber3;
declare const index_IconCircleDashedNumber4: typeof IconCircleDashedNumber4;
declare const index_IconCircleDashedNumber5: typeof IconCircleDashedNumber5;
declare const index_IconCircleDashedNumber6: typeof IconCircleDashedNumber6;
declare const index_IconCircleDashedNumber7: typeof IconCircleDashedNumber7;
declare const index_IconCircleDashedNumber8: typeof IconCircleDashedNumber8;
declare const index_IconCircleDashedNumber9: typeof IconCircleDashedNumber9;
declare const index_IconCircleDashedPercentage: typeof IconCircleDashedPercentage;
declare const index_IconCircleDashedPlus: typeof IconCircleDashedPlus;
declare const index_IconCircleDashedX: typeof IconCircleDashedX;
declare const index_IconCircleDot: typeof IconCircleDot;
declare const index_IconCircleDotFilled: typeof IconCircleDotFilled;
declare const index_IconCircleDotted: typeof IconCircleDotted;
declare const index_IconCircleDottedLetterA: typeof IconCircleDottedLetterA;
declare const index_IconCircleDottedLetterB: typeof IconCircleDottedLetterB;
declare const index_IconCircleDottedLetterC: typeof IconCircleDottedLetterC;
declare const index_IconCircleDottedLetterD: typeof IconCircleDottedLetterD;
declare const index_IconCircleDottedLetterE: typeof IconCircleDottedLetterE;
declare const index_IconCircleDottedLetterF: typeof IconCircleDottedLetterF;
declare const index_IconCircleDottedLetterG: typeof IconCircleDottedLetterG;
declare const index_IconCircleDottedLetterH: typeof IconCircleDottedLetterH;
declare const index_IconCircleDottedLetterI: typeof IconCircleDottedLetterI;
declare const index_IconCircleDottedLetterJ: typeof IconCircleDottedLetterJ;
declare const index_IconCircleDottedLetterK: typeof IconCircleDottedLetterK;
declare const index_IconCircleDottedLetterL: typeof IconCircleDottedLetterL;
declare const index_IconCircleDottedLetterM: typeof IconCircleDottedLetterM;
declare const index_IconCircleDottedLetterN: typeof IconCircleDottedLetterN;
declare const index_IconCircleDottedLetterO: typeof IconCircleDottedLetterO;
declare const index_IconCircleDottedLetterP: typeof IconCircleDottedLetterP;
declare const index_IconCircleDottedLetterQ: typeof IconCircleDottedLetterQ;
declare const index_IconCircleDottedLetterR: typeof IconCircleDottedLetterR;
declare const index_IconCircleDottedLetterS: typeof IconCircleDottedLetterS;
declare const index_IconCircleDottedLetterT: typeof IconCircleDottedLetterT;
declare const index_IconCircleDottedLetterU: typeof IconCircleDottedLetterU;
declare const index_IconCircleDottedLetterV: typeof IconCircleDottedLetterV;
declare const index_IconCircleDottedLetterW: typeof IconCircleDottedLetterW;
declare const index_IconCircleDottedLetterX: typeof IconCircleDottedLetterX;
declare const index_IconCircleDottedLetterY: typeof IconCircleDottedLetterY;
declare const index_IconCircleDottedLetterZ: typeof IconCircleDottedLetterZ;
declare const index_IconCircleFilled: typeof IconCircleFilled;
declare const index_IconCircleHalf: typeof IconCircleHalf;
declare const index_IconCircleHalf2: typeof IconCircleHalf2;
declare const index_IconCircleHalfVertical: typeof IconCircleHalfVertical;
declare const index_IconCircleKey: typeof IconCircleKey;
declare const index_IconCircleKeyFilled: typeof IconCircleKeyFilled;
declare const index_IconCircleLetterA: typeof IconCircleLetterA;
declare const index_IconCircleLetterAFilled: typeof IconCircleLetterAFilled;
declare const index_IconCircleLetterB: typeof IconCircleLetterB;
declare const index_IconCircleLetterBFilled: typeof IconCircleLetterBFilled;
declare const index_IconCircleLetterC: typeof IconCircleLetterC;
declare const index_IconCircleLetterCFilled: typeof IconCircleLetterCFilled;
declare const index_IconCircleLetterD: typeof IconCircleLetterD;
declare const index_IconCircleLetterDFilled: typeof IconCircleLetterDFilled;
declare const index_IconCircleLetterE: typeof IconCircleLetterE;
declare const index_IconCircleLetterEFilled: typeof IconCircleLetterEFilled;
declare const index_IconCircleLetterF: typeof IconCircleLetterF;
declare const index_IconCircleLetterFFilled: typeof IconCircleLetterFFilled;
declare const index_IconCircleLetterG: typeof IconCircleLetterG;
declare const index_IconCircleLetterGFilled: typeof IconCircleLetterGFilled;
declare const index_IconCircleLetterH: typeof IconCircleLetterH;
declare const index_IconCircleLetterHFilled: typeof IconCircleLetterHFilled;
declare const index_IconCircleLetterI: typeof IconCircleLetterI;
declare const index_IconCircleLetterIFilled: typeof IconCircleLetterIFilled;
declare const index_IconCircleLetterJ: typeof IconCircleLetterJ;
declare const index_IconCircleLetterJFilled: typeof IconCircleLetterJFilled;
declare const index_IconCircleLetterK: typeof IconCircleLetterK;
declare const index_IconCircleLetterKFilled: typeof IconCircleLetterKFilled;
declare const index_IconCircleLetterL: typeof IconCircleLetterL;
declare const index_IconCircleLetterLFilled: typeof IconCircleLetterLFilled;
declare const index_IconCircleLetterM: typeof IconCircleLetterM;
declare const index_IconCircleLetterMFilled: typeof IconCircleLetterMFilled;
declare const index_IconCircleLetterN: typeof IconCircleLetterN;
declare const index_IconCircleLetterNFilled: typeof IconCircleLetterNFilled;
declare const index_IconCircleLetterO: typeof IconCircleLetterO;
declare const index_IconCircleLetterOFilled: typeof IconCircleLetterOFilled;
declare const index_IconCircleLetterP: typeof IconCircleLetterP;
declare const index_IconCircleLetterPFilled: typeof IconCircleLetterPFilled;
declare const index_IconCircleLetterQ: typeof IconCircleLetterQ;
declare const index_IconCircleLetterQFilled: typeof IconCircleLetterQFilled;
declare const index_IconCircleLetterR: typeof IconCircleLetterR;
declare const index_IconCircleLetterRFilled: typeof IconCircleLetterRFilled;
declare const index_IconCircleLetterS: typeof IconCircleLetterS;
declare const index_IconCircleLetterSFilled: typeof IconCircleLetterSFilled;
declare const index_IconCircleLetterT: typeof IconCircleLetterT;
declare const index_IconCircleLetterTFilled: typeof IconCircleLetterTFilled;
declare const index_IconCircleLetterU: typeof IconCircleLetterU;
declare const index_IconCircleLetterUFilled: typeof IconCircleLetterUFilled;
declare const index_IconCircleLetterV: typeof IconCircleLetterV;
declare const index_IconCircleLetterVFilled: typeof IconCircleLetterVFilled;
declare const index_IconCircleLetterW: typeof IconCircleLetterW;
declare const index_IconCircleLetterWFilled: typeof IconCircleLetterWFilled;
declare const index_IconCircleLetterX: typeof IconCircleLetterX;
declare const index_IconCircleLetterXFilled: typeof IconCircleLetterXFilled;
declare const index_IconCircleLetterY: typeof IconCircleLetterY;
declare const index_IconCircleLetterYFilled: typeof IconCircleLetterYFilled;
declare const index_IconCircleLetterZ: typeof IconCircleLetterZ;
declare const index_IconCircleLetterZFilled: typeof IconCircleLetterZFilled;
declare const index_IconCircleMinus: typeof IconCircleMinus;
declare const index_IconCircleMinus2: typeof IconCircleMinus2;
declare const index_IconCircleNumber0: typeof IconCircleNumber0;
declare const index_IconCircleNumber0Filled: typeof IconCircleNumber0Filled;
declare const index_IconCircleNumber1: typeof IconCircleNumber1;
declare const index_IconCircleNumber1Filled: typeof IconCircleNumber1Filled;
declare const index_IconCircleNumber2: typeof IconCircleNumber2;
declare const index_IconCircleNumber2Filled: typeof IconCircleNumber2Filled;
declare const index_IconCircleNumber3: typeof IconCircleNumber3;
declare const index_IconCircleNumber3Filled: typeof IconCircleNumber3Filled;
declare const index_IconCircleNumber4: typeof IconCircleNumber4;
declare const index_IconCircleNumber4Filled: typeof IconCircleNumber4Filled;
declare const index_IconCircleNumber5: typeof IconCircleNumber5;
declare const index_IconCircleNumber5Filled: typeof IconCircleNumber5Filled;
declare const index_IconCircleNumber6: typeof IconCircleNumber6;
declare const index_IconCircleNumber6Filled: typeof IconCircleNumber6Filled;
declare const index_IconCircleNumber7: typeof IconCircleNumber7;
declare const index_IconCircleNumber7Filled: typeof IconCircleNumber7Filled;
declare const index_IconCircleNumber8: typeof IconCircleNumber8;
declare const index_IconCircleNumber8Filled: typeof IconCircleNumber8Filled;
declare const index_IconCircleNumber9: typeof IconCircleNumber9;
declare const index_IconCircleNumber9Filled: typeof IconCircleNumber9Filled;
declare const index_IconCircleOff: typeof IconCircleOff;
declare const index_IconCirclePercentage: typeof IconCirclePercentage;
declare const index_IconCirclePercentageFilled: typeof IconCirclePercentageFilled;
declare const index_IconCirclePlus: typeof IconCirclePlus;
declare const index_IconCirclePlus2: typeof IconCirclePlus2;
declare const index_IconCirclePlusFilled: typeof IconCirclePlusFilled;
declare const index_IconCircleRectangle: typeof IconCircleRectangle;
declare const index_IconCircleRectangleFilled: typeof IconCircleRectangleFilled;
declare const index_IconCircleRectangleOff: typeof IconCircleRectangleOff;
declare const index_IconCircleSquare: typeof IconCircleSquare;
declare const index_IconCircleTriangle: typeof IconCircleTriangle;
declare const index_IconCircleX: typeof IconCircleX;
declare const index_IconCircleXFilled: typeof IconCircleXFilled;
declare const index_IconCircles: typeof IconCircles;
declare const index_IconCirclesFilled: typeof IconCirclesFilled;
declare const index_IconCirclesRelation: typeof IconCirclesRelation;
declare const index_IconCircuitAmmeter: typeof IconCircuitAmmeter;
declare const index_IconCircuitBattery: typeof IconCircuitBattery;
declare const index_IconCircuitBulb: typeof IconCircuitBulb;
declare const index_IconCircuitCapacitor: typeof IconCircuitCapacitor;
declare const index_IconCircuitCapacitorPolarized: typeof IconCircuitCapacitorPolarized;
declare const index_IconCircuitCell: typeof IconCircuitCell;
declare const index_IconCircuitCellPlus: typeof IconCircuitCellPlus;
declare const index_IconCircuitChangeover: typeof IconCircuitChangeover;
declare const index_IconCircuitDiode: typeof IconCircuitDiode;
declare const index_IconCircuitDiodeZener: typeof IconCircuitDiodeZener;
declare const index_IconCircuitGround: typeof IconCircuitGround;
declare const index_IconCircuitGroundDigital: typeof IconCircuitGroundDigital;
declare const index_IconCircuitInductor: typeof IconCircuitInductor;
declare const index_IconCircuitMotor: typeof IconCircuitMotor;
declare const index_IconCircuitPushbutton: typeof IconCircuitPushbutton;
declare const index_IconCircuitResistor: typeof IconCircuitResistor;
declare const index_IconCircuitSwitchClosed: typeof IconCircuitSwitchClosed;
declare const index_IconCircuitSwitchOpen: typeof IconCircuitSwitchOpen;
declare const index_IconCircuitVoltmeter: typeof IconCircuitVoltmeter;
declare const index_IconClearAll: typeof IconClearAll;
declare const index_IconClearFormatting: typeof IconClearFormatting;
declare const index_IconClick: typeof IconClick;
declare const index_IconCliffJumping: typeof IconCliffJumping;
declare const index_IconClipboard: typeof IconClipboard;
declare const index_IconClipboardCheck: typeof IconClipboardCheck;
declare const index_IconClipboardCheckFilled: typeof IconClipboardCheckFilled;
declare const index_IconClipboardCopy: typeof IconClipboardCopy;
declare const index_IconClipboardData: typeof IconClipboardData;
declare const index_IconClipboardDataFilled: typeof IconClipboardDataFilled;
declare const index_IconClipboardFilled: typeof IconClipboardFilled;
declare const index_IconClipboardHeart: typeof IconClipboardHeart;
declare const index_IconClipboardList: typeof IconClipboardList;
declare const index_IconClipboardListFilled: typeof IconClipboardListFilled;
declare const index_IconClipboardOff: typeof IconClipboardOff;
declare const index_IconClipboardPlus: typeof IconClipboardPlus;
declare const index_IconClipboardPlusFilled: typeof IconClipboardPlusFilled;
declare const index_IconClipboardSearch: typeof IconClipboardSearch;
declare const index_IconClipboardSmile: typeof IconClipboardSmile;
declare const index_IconClipboardSmileFilled: typeof IconClipboardSmileFilled;
declare const index_IconClipboardText: typeof IconClipboardText;
declare const index_IconClipboardTextFilled: typeof IconClipboardTextFilled;
declare const index_IconClipboardTypography: typeof IconClipboardTypography;
declare const index_IconClipboardTypographyFilled: typeof IconClipboardTypographyFilled;
declare const index_IconClipboardX: typeof IconClipboardX;
declare const index_IconClipboardXFilled: typeof IconClipboardXFilled;
declare const index_IconClock: typeof IconClock;
declare const index_IconClock12: typeof IconClock12;
declare const index_IconClock2: typeof IconClock2;
declare const index_IconClock24: typeof IconClock24;
declare const index_IconClockBitcoin: typeof IconClockBitcoin;
declare const index_IconClockBolt: typeof IconClockBolt;
declare const index_IconClockCancel: typeof IconClockCancel;
declare const index_IconClockCheck: typeof IconClockCheck;
declare const index_IconClockCode: typeof IconClockCode;
declare const index_IconClockCog: typeof IconClockCog;
declare const index_IconClockDollar: typeof IconClockDollar;
declare const index_IconClockDown: typeof IconClockDown;
declare const index_IconClockEdit: typeof IconClockEdit;
declare const index_IconClockExclamation: typeof IconClockExclamation;
declare const index_IconClockFilled: typeof IconClockFilled;
declare const index_IconClockHeart: typeof IconClockHeart;
declare const index_IconClockHour1: typeof IconClockHour1;
declare const index_IconClockHour10: typeof IconClockHour10;
declare const index_IconClockHour10Filled: typeof IconClockHour10Filled;
declare const index_IconClockHour11: typeof IconClockHour11;
declare const index_IconClockHour11Filled: typeof IconClockHour11Filled;
declare const index_IconClockHour12: typeof IconClockHour12;
declare const index_IconClockHour12Filled: typeof IconClockHour12Filled;
declare const index_IconClockHour1Filled: typeof IconClockHour1Filled;
declare const index_IconClockHour2: typeof IconClockHour2;
declare const index_IconClockHour2Filled: typeof IconClockHour2Filled;
declare const index_IconClockHour3: typeof IconClockHour3;
declare const index_IconClockHour3Filled: typeof IconClockHour3Filled;
declare const index_IconClockHour4: typeof IconClockHour4;
declare const index_IconClockHour4Filled: typeof IconClockHour4Filled;
declare const index_IconClockHour5: typeof IconClockHour5;
declare const index_IconClockHour5Filled: typeof IconClockHour5Filled;
declare const index_IconClockHour6: typeof IconClockHour6;
declare const index_IconClockHour6Filled: typeof IconClockHour6Filled;
declare const index_IconClockHour7: typeof IconClockHour7;
declare const index_IconClockHour7Filled: typeof IconClockHour7Filled;
declare const index_IconClockHour8: typeof IconClockHour8;
declare const index_IconClockHour8Filled: typeof IconClockHour8Filled;
declare const index_IconClockHour9: typeof IconClockHour9;
declare const index_IconClockHour9Filled: typeof IconClockHour9Filled;
declare const index_IconClockMinus: typeof IconClockMinus;
declare const index_IconClockOff: typeof IconClockOff;
declare const index_IconClockPause: typeof IconClockPause;
declare const index_IconClockPin: typeof IconClockPin;
declare const index_IconClockPlay: typeof IconClockPlay;
declare const index_IconClockPlus: typeof IconClockPlus;
declare const index_IconClockQuestion: typeof IconClockQuestion;
declare const index_IconClockRecord: typeof IconClockRecord;
declare const index_IconClockSearch: typeof IconClockSearch;
declare const index_IconClockShare: typeof IconClockShare;
declare const index_IconClockShield: typeof IconClockShield;
declare const index_IconClockStar: typeof IconClockStar;
declare const index_IconClockStop: typeof IconClockStop;
declare const index_IconClockUp: typeof IconClockUp;
declare const index_IconClockX: typeof IconClockX;
declare const index_IconClothesRack: typeof IconClothesRack;
declare const index_IconClothesRackOff: typeof IconClothesRackOff;
declare const index_IconCloud: typeof IconCloud;
declare const index_IconCloudBitcoin: typeof IconCloudBitcoin;
declare const index_IconCloudBolt: typeof IconCloudBolt;
declare const index_IconCloudCancel: typeof IconCloudCancel;
declare const index_IconCloudCheck: typeof IconCloudCheck;
declare const index_IconCloudCode: typeof IconCloudCode;
declare const index_IconCloudCog: typeof IconCloudCog;
declare const index_IconCloudComputing: typeof IconCloudComputing;
declare const index_IconCloudComputingFilled: typeof IconCloudComputingFilled;
declare const index_IconCloudDataConnection: typeof IconCloudDataConnection;
declare const index_IconCloudDataConnectionFilled: typeof IconCloudDataConnectionFilled;
declare const index_IconCloudDollar: typeof IconCloudDollar;
declare const index_IconCloudDown: typeof IconCloudDown;
declare const index_IconCloudDownload: typeof IconCloudDownload;
declare const index_IconCloudExclamation: typeof IconCloudExclamation;
declare const index_IconCloudFilled: typeof IconCloudFilled;
declare const index_IconCloudFog: typeof IconCloudFog;
declare const index_IconCloudHeart: typeof IconCloudHeart;
declare const index_IconCloudLock: typeof IconCloudLock;
declare const index_IconCloudLockOpen: typeof IconCloudLockOpen;
declare const index_IconCloudMinus: typeof IconCloudMinus;
declare const index_IconCloudNetwork: typeof IconCloudNetwork;
declare const index_IconCloudOff: typeof IconCloudOff;
declare const index_IconCloudPause: typeof IconCloudPause;
declare const index_IconCloudPin: typeof IconCloudPin;
declare const index_IconCloudPlus: typeof IconCloudPlus;
declare const index_IconCloudQuestion: typeof IconCloudQuestion;
declare const index_IconCloudRain: typeof IconCloudRain;
declare const index_IconCloudSearch: typeof IconCloudSearch;
declare const index_IconCloudShare: typeof IconCloudShare;
declare const index_IconCloudSnow: typeof IconCloudSnow;
declare const index_IconCloudStar: typeof IconCloudStar;
declare const index_IconCloudStorm: typeof IconCloudStorm;
declare const index_IconCloudUp: typeof IconCloudUp;
declare const index_IconCloudUpload: typeof IconCloudUpload;
declare const index_IconCloudX: typeof IconCloudX;
declare const index_IconClover: typeof IconClover;
declare const index_IconClover2: typeof IconClover2;
declare const index_IconCloverFilled: typeof IconCloverFilled;
declare const index_IconClubs: typeof IconClubs;
declare const index_IconClubsFilled: typeof IconClubsFilled;
declare const index_IconCode: typeof IconCode;
declare const index_IconCodeAsterisk: typeof IconCodeAsterisk;
declare const index_IconCodeCircle: typeof IconCodeCircle;
declare const index_IconCodeCircle2: typeof IconCodeCircle2;
declare const index_IconCodeCircle2Filled: typeof IconCodeCircle2Filled;
declare const index_IconCodeCircleFilled: typeof IconCodeCircleFilled;
declare const index_IconCodeDots: typeof IconCodeDots;
declare const index_IconCodeMinus: typeof IconCodeMinus;
declare const index_IconCodeOff: typeof IconCodeOff;
declare const index_IconCodePlus: typeof IconCodePlus;
declare const index_IconCodeVariable: typeof IconCodeVariable;
declare const index_IconCodeVariableMinus: typeof IconCodeVariableMinus;
declare const index_IconCodeVariablePlus: typeof IconCodeVariablePlus;
declare const index_IconCoffee: typeof IconCoffee;
declare const index_IconCoffeeOff: typeof IconCoffeeOff;
declare const index_IconCoffin: typeof IconCoffin;
declare const index_IconCoin: typeof IconCoin;
declare const index_IconCoinBitcoin: typeof IconCoinBitcoin;
declare const index_IconCoinBitcoinFilled: typeof IconCoinBitcoinFilled;
declare const index_IconCoinEuro: typeof IconCoinEuro;
declare const index_IconCoinEuroFilled: typeof IconCoinEuroFilled;
declare const index_IconCoinFilled: typeof IconCoinFilled;
declare const index_IconCoinMonero: typeof IconCoinMonero;
declare const index_IconCoinMoneroFilled: typeof IconCoinMoneroFilled;
declare const index_IconCoinOff: typeof IconCoinOff;
declare const index_IconCoinPound: typeof IconCoinPound;
declare const index_IconCoinPoundFilled: typeof IconCoinPoundFilled;
declare const index_IconCoinRupee: typeof IconCoinRupee;
declare const index_IconCoinRupeeFilled: typeof IconCoinRupeeFilled;
declare const index_IconCoinTaka: typeof IconCoinTaka;
declare const index_IconCoinTakaFilled: typeof IconCoinTakaFilled;
declare const index_IconCoinYen: typeof IconCoinYen;
declare const index_IconCoinYenFilled: typeof IconCoinYenFilled;
declare const index_IconCoinYuan: typeof IconCoinYuan;
declare const index_IconCoinYuanFilled: typeof IconCoinYuanFilled;
declare const index_IconCoins: typeof IconCoins;
declare const index_IconColorFilter: typeof IconColorFilter;
declare const index_IconColorPicker: typeof IconColorPicker;
declare const index_IconColorPickerOff: typeof IconColorPickerOff;
declare const index_IconColorSwatch: typeof IconColorSwatch;
declare const index_IconColorSwatchOff: typeof IconColorSwatchOff;
declare const index_IconColumnInsertLeft: typeof IconColumnInsertLeft;
declare const index_IconColumnInsertRight: typeof IconColumnInsertRight;
declare const index_IconColumnRemove: typeof IconColumnRemove;
declare const index_IconColumns: typeof IconColumns;
declare const index_IconColumns1: typeof IconColumns1;
declare const index_IconColumns1Filled: typeof IconColumns1Filled;
declare const index_IconColumns2: typeof IconColumns2;
declare const index_IconColumns2Filled: typeof IconColumns2Filled;
declare const index_IconColumns3: typeof IconColumns3;
declare const index_IconColumns3Filled: typeof IconColumns3Filled;
declare const index_IconColumnsOff: typeof IconColumnsOff;
declare const index_IconComet: typeof IconComet;
declare const index_IconCommand: typeof IconCommand;
declare const index_IconCommandOff: typeof IconCommandOff;
declare const index_IconCompass: typeof IconCompass;
declare const index_IconCompassFilled: typeof IconCompassFilled;
declare const index_IconCompassOff: typeof IconCompassOff;
declare const index_IconComponents: typeof IconComponents;
declare const index_IconComponentsOff: typeof IconComponentsOff;
declare const index_IconCone: typeof IconCone;
declare const index_IconCone2: typeof IconCone2;
declare const index_IconCone2Filled: typeof IconCone2Filled;
declare const index_IconConeFilled: typeof IconConeFilled;
declare const index_IconConeOff: typeof IconConeOff;
declare const index_IconConePlus: typeof IconConePlus;
declare const index_IconConfetti: typeof IconConfetti;
declare const index_IconConfettiFilled: typeof IconConfettiFilled;
declare const index_IconConfettiOff: typeof IconConfettiOff;
declare const index_IconConfucius: typeof IconConfucius;
declare const index_IconCongruentTo: typeof IconCongruentTo;
declare const index_IconContainer: typeof IconContainer;
declare const index_IconContainerFilled: typeof IconContainerFilled;
declare const index_IconContainerOff: typeof IconContainerOff;
declare const index_IconContract: typeof IconContract;
declare const index_IconContrast: typeof IconContrast;
declare const index_IconContrast2: typeof IconContrast2;
declare const index_IconContrast2Filled: typeof IconContrast2Filled;
declare const index_IconContrast2Off: typeof IconContrast2Off;
declare const index_IconContrastFilled: typeof IconContrastFilled;
declare const index_IconContrastOff: typeof IconContrastOff;
declare const index_IconCooker: typeof IconCooker;
declare const index_IconCookie: typeof IconCookie;
declare const index_IconCookieFilled: typeof IconCookieFilled;
declare const index_IconCookieMan: typeof IconCookieMan;
declare const index_IconCookieManFilled: typeof IconCookieManFilled;
declare const index_IconCookieOff: typeof IconCookieOff;
declare const index_IconCopy: typeof IconCopy;
declare const index_IconCopyCheck: typeof IconCopyCheck;
declare const index_IconCopyCheckFilled: typeof IconCopyCheckFilled;
declare const index_IconCopyMinus: typeof IconCopyMinus;
declare const index_IconCopyMinusFilled: typeof IconCopyMinusFilled;
declare const index_IconCopyOff: typeof IconCopyOff;
declare const index_IconCopyPlus: typeof IconCopyPlus;
declare const index_IconCopyPlusFilled: typeof IconCopyPlusFilled;
declare const index_IconCopyX: typeof IconCopyX;
declare const index_IconCopyXFilled: typeof IconCopyXFilled;
declare const index_IconCopyleft: typeof IconCopyleft;
declare const index_IconCopyleftFilled: typeof IconCopyleftFilled;
declare const index_IconCopyleftOff: typeof IconCopyleftOff;
declare const index_IconCopyright: typeof IconCopyright;
declare const index_IconCopyrightFilled: typeof IconCopyrightFilled;
declare const index_IconCopyrightOff: typeof IconCopyrightOff;
declare const index_IconCornerDownLeft: typeof IconCornerDownLeft;
declare const index_IconCornerDownLeftDouble: typeof IconCornerDownLeftDouble;
declare const index_IconCornerDownRight: typeof IconCornerDownRight;
declare const index_IconCornerDownRightDouble: typeof IconCornerDownRightDouble;
declare const index_IconCornerLeftDown: typeof IconCornerLeftDown;
declare const index_IconCornerLeftDownDouble: typeof IconCornerLeftDownDouble;
declare const index_IconCornerLeftUp: typeof IconCornerLeftUp;
declare const index_IconCornerLeftUpDouble: typeof IconCornerLeftUpDouble;
declare const index_IconCornerRightDown: typeof IconCornerRightDown;
declare const index_IconCornerRightDownDouble: typeof IconCornerRightDownDouble;
declare const index_IconCornerRightUp: typeof IconCornerRightUp;
declare const index_IconCornerRightUpDouble: typeof IconCornerRightUpDouble;
declare const index_IconCornerUpLeft: typeof IconCornerUpLeft;
declare const index_IconCornerUpLeftDouble: typeof IconCornerUpLeftDouble;
declare const index_IconCornerUpRight: typeof IconCornerUpRight;
declare const index_IconCornerUpRightDouble: typeof IconCornerUpRightDouble;
declare const index_IconCpu: typeof IconCpu;
declare const index_IconCpu2: typeof IconCpu2;
declare const index_IconCpuOff: typeof IconCpuOff;
declare const index_IconCrane: typeof IconCrane;
declare const index_IconCraneOff: typeof IconCraneOff;
declare const index_IconCreativeCommons: typeof IconCreativeCommons;
declare const index_IconCreativeCommonsBy: typeof IconCreativeCommonsBy;
declare const index_IconCreativeCommonsNc: typeof IconCreativeCommonsNc;
declare const index_IconCreativeCommonsNd: typeof IconCreativeCommonsNd;
declare const index_IconCreativeCommonsOff: typeof IconCreativeCommonsOff;
declare const index_IconCreativeCommonsSa: typeof IconCreativeCommonsSa;
declare const index_IconCreativeCommonsZero: typeof IconCreativeCommonsZero;
declare const index_IconCreditCard: typeof IconCreditCard;
declare const index_IconCreditCardFilled: typeof IconCreditCardFilled;
declare const index_IconCreditCardOff: typeof IconCreditCardOff;
declare const index_IconCreditCardPay: typeof IconCreditCardPay;
declare const index_IconCreditCardRefund: typeof IconCreditCardRefund;
declare const index_IconCricket: typeof IconCricket;
declare const index_IconCrop: typeof IconCrop;
declare const index_IconCrop11: typeof IconCrop11;
declare const index_IconCrop11Filled: typeof IconCrop11Filled;
declare const index_IconCrop169: typeof IconCrop169;
declare const index_IconCrop169Filled: typeof IconCrop169Filled;
declare const index_IconCrop32: typeof IconCrop32;
declare const index_IconCrop32Filled: typeof IconCrop32Filled;
declare const index_IconCrop54: typeof IconCrop54;
declare const index_IconCrop54Filled: typeof IconCrop54Filled;
declare const index_IconCrop75: typeof IconCrop75;
declare const index_IconCrop75Filled: typeof IconCrop75Filled;
declare const index_IconCropLandscape: typeof IconCropLandscape;
declare const index_IconCropLandscapeFilled: typeof IconCropLandscapeFilled;
declare const index_IconCropPortrait: typeof IconCropPortrait;
declare const index_IconCropPortraitFilled: typeof IconCropPortraitFilled;
declare const index_IconCross: typeof IconCross;
declare const index_IconCrossFilled: typeof IconCrossFilled;
declare const index_IconCrossOff: typeof IconCrossOff;
declare const index_IconCrosshair: typeof IconCrosshair;
declare const index_IconCrown: typeof IconCrown;
declare const index_IconCrownFilled: typeof IconCrownFilled;
declare const index_IconCrownOff: typeof IconCrownOff;
declare const index_IconCrutches: typeof IconCrutches;
declare const index_IconCrutchesOff: typeof IconCrutchesOff;
declare const index_IconCrystalBall: typeof IconCrystalBall;
declare const index_IconCsv: typeof IconCsv;
declare const index_IconCube: typeof IconCube;
declare const index_IconCube3dSphere: typeof IconCube3dSphere;
declare const index_IconCube3dSphereOff: typeof IconCube3dSphereOff;
declare const index_IconCubeOff: typeof IconCubeOff;
declare const index_IconCubePlus: typeof IconCubePlus;
declare const index_IconCubeSend: typeof IconCubeSend;
declare const index_IconCubeSpark: typeof IconCubeSpark;
declare const index_IconCubeUnfolded: typeof IconCubeUnfolded;
declare const index_IconCup: typeof IconCup;
declare const index_IconCupOff: typeof IconCupOff;
declare const index_IconCurling: typeof IconCurling;
declare const index_IconCurlyLoop: typeof IconCurlyLoop;
declare const index_IconCurrency: typeof IconCurrency;
declare const index_IconCurrencyAfghani: typeof IconCurrencyAfghani;
declare const index_IconCurrencyBahraini: typeof IconCurrencyBahraini;
declare const index_IconCurrencyBaht: typeof IconCurrencyBaht;
declare const index_IconCurrencyBitcoin: typeof IconCurrencyBitcoin;
declare const index_IconCurrencyCent: typeof IconCurrencyCent;
declare const index_IconCurrencyDinar: typeof IconCurrencyDinar;
declare const index_IconCurrencyDirham: typeof IconCurrencyDirham;
declare const index_IconCurrencyDogecoin: typeof IconCurrencyDogecoin;
declare const index_IconCurrencyDollar: typeof IconCurrencyDollar;
declare const index_IconCurrencyDollarAustralian: typeof IconCurrencyDollarAustralian;
declare const index_IconCurrencyDollarBrunei: typeof IconCurrencyDollarBrunei;
declare const index_IconCurrencyDollarCanadian: typeof IconCurrencyDollarCanadian;
declare const index_IconCurrencyDollarGuyanese: typeof IconCurrencyDollarGuyanese;
declare const index_IconCurrencyDollarOff: typeof IconCurrencyDollarOff;
declare const index_IconCurrencyDollarSingapore: typeof IconCurrencyDollarSingapore;
declare const index_IconCurrencyDollarZimbabwean: typeof IconCurrencyDollarZimbabwean;
declare const index_IconCurrencyDong: typeof IconCurrencyDong;
declare const index_IconCurrencyDram: typeof IconCurrencyDram;
declare const index_IconCurrencyEthereum: typeof IconCurrencyEthereum;
declare const index_IconCurrencyEuro: typeof IconCurrencyEuro;
declare const index_IconCurrencyEuroOff: typeof IconCurrencyEuroOff;
declare const index_IconCurrencyFlorin: typeof IconCurrencyFlorin;
declare const index_IconCurrencyForint: typeof IconCurrencyForint;
declare const index_IconCurrencyFrank: typeof IconCurrencyFrank;
declare const index_IconCurrencyGuarani: typeof IconCurrencyGuarani;
declare const index_IconCurrencyHryvnia: typeof IconCurrencyHryvnia;
declare const index_IconCurrencyIranianRial: typeof IconCurrencyIranianRial;
declare const index_IconCurrencyKip: typeof IconCurrencyKip;
declare const index_IconCurrencyKroneCzech: typeof IconCurrencyKroneCzech;
declare const index_IconCurrencyKroneDanish: typeof IconCurrencyKroneDanish;
declare const index_IconCurrencyKroneSwedish: typeof IconCurrencyKroneSwedish;
declare const index_IconCurrencyLari: typeof IconCurrencyLari;
declare const index_IconCurrencyLeu: typeof IconCurrencyLeu;
declare const index_IconCurrencyLira: typeof IconCurrencyLira;
declare const index_IconCurrencyLitecoin: typeof IconCurrencyLitecoin;
declare const index_IconCurrencyLyd: typeof IconCurrencyLyd;
declare const index_IconCurrencyManat: typeof IconCurrencyManat;
declare const index_IconCurrencyMonero: typeof IconCurrencyMonero;
declare const index_IconCurrencyNaira: typeof IconCurrencyNaira;
declare const index_IconCurrencyNano: typeof IconCurrencyNano;
declare const index_IconCurrencyOff: typeof IconCurrencyOff;
declare const index_IconCurrencyPaanga: typeof IconCurrencyPaanga;
declare const index_IconCurrencyPeso: typeof IconCurrencyPeso;
declare const index_IconCurrencyPound: typeof IconCurrencyPound;
declare const index_IconCurrencyPoundOff: typeof IconCurrencyPoundOff;
declare const index_IconCurrencyQuetzal: typeof IconCurrencyQuetzal;
declare const index_IconCurrencyReal: typeof IconCurrencyReal;
declare const index_IconCurrencyRenminbi: typeof IconCurrencyRenminbi;
declare const index_IconCurrencyRipple: typeof IconCurrencyRipple;
declare const index_IconCurrencyRiyal: typeof IconCurrencyRiyal;
declare const index_IconCurrencyRubel: typeof IconCurrencyRubel;
declare const index_IconCurrencyRufiyaa: typeof IconCurrencyRufiyaa;
declare const index_IconCurrencyRupee: typeof IconCurrencyRupee;
declare const index_IconCurrencyRupeeNepalese: typeof IconCurrencyRupeeNepalese;
declare const index_IconCurrencyShekel: typeof IconCurrencyShekel;
declare const index_IconCurrencySolana: typeof IconCurrencySolana;
declare const index_IconCurrencySom: typeof IconCurrencySom;
declare const index_IconCurrencyTaka: typeof IconCurrencyTaka;
declare const index_IconCurrencyTenge: typeof IconCurrencyTenge;
declare const index_IconCurrencyTugrik: typeof IconCurrencyTugrik;
declare const index_IconCurrencyWon: typeof IconCurrencyWon;
declare const index_IconCurrencyXrp: typeof IconCurrencyXrp;
declare const index_IconCurrencyYen: typeof IconCurrencyYen;
declare const index_IconCurrencyYenOff: typeof IconCurrencyYenOff;
declare const index_IconCurrencyYuan: typeof IconCurrencyYuan;
declare const index_IconCurrencyZloty: typeof IconCurrencyZloty;
declare const index_IconCurrentLocation: typeof IconCurrentLocation;
declare const index_IconCurrentLocationFilled: typeof IconCurrentLocationFilled;
declare const index_IconCurrentLocationOff: typeof IconCurrentLocationOff;
declare const index_IconCursorOff: typeof IconCursorOff;
declare const index_IconCursorText: typeof IconCursorText;
declare const index_IconCut: typeof IconCut;
declare const index_IconCylinder: typeof IconCylinder;
declare const index_IconCylinderOff: typeof IconCylinderOff;
declare const index_IconCylinderPlus: typeof IconCylinderPlus;
declare const index_IconDashboard: typeof IconDashboard;
declare const index_IconDashboardFilled: typeof IconDashboardFilled;
declare const index_IconDashboardOff: typeof IconDashboardOff;
declare const index_IconDatabase: typeof IconDatabase;
declare const index_IconDatabaseCog: typeof IconDatabaseCog;
declare const index_IconDatabaseDollar: typeof IconDatabaseDollar;
declare const index_IconDatabaseEdit: typeof IconDatabaseEdit;
declare const index_IconDatabaseExclamation: typeof IconDatabaseExclamation;
declare const index_IconDatabaseExport: typeof IconDatabaseExport;
declare const index_IconDatabaseHeart: typeof IconDatabaseHeart;
declare const index_IconDatabaseImport: typeof IconDatabaseImport;
declare const index_IconDatabaseLeak: typeof IconDatabaseLeak;
declare const index_IconDatabaseMinus: typeof IconDatabaseMinus;
declare const index_IconDatabaseOff: typeof IconDatabaseOff;
declare const index_IconDatabasePlus: typeof IconDatabasePlus;
declare const index_IconDatabaseSearch: typeof IconDatabaseSearch;
declare const index_IconDatabaseShare: typeof IconDatabaseShare;
declare const index_IconDatabaseSmile: typeof IconDatabaseSmile;
declare const index_IconDatabaseStar: typeof IconDatabaseStar;
declare const index_IconDatabaseX: typeof IconDatabaseX;
declare const index_IconDeaf: typeof IconDeaf;
declare const index_IconDecimal: typeof IconDecimal;
declare const index_IconDeer: typeof IconDeer;
declare const index_IconDelta: typeof IconDelta;
declare const index_IconDental: typeof IconDental;
declare const index_IconDentalBroken: typeof IconDentalBroken;
declare const index_IconDentalOff: typeof IconDentalOff;
declare const index_IconDeselect: typeof IconDeselect;
declare const index_IconDesk: typeof IconDesk;
declare const index_IconDetails: typeof IconDetails;
declare const index_IconDetailsOff: typeof IconDetailsOff;
declare const index_IconDeviceAirpods: typeof IconDeviceAirpods;
declare const index_IconDeviceAirpodsCase: typeof IconDeviceAirpodsCase;
declare const index_IconDeviceAirtag: typeof IconDeviceAirtag;
declare const index_IconDeviceAnalytics: typeof IconDeviceAnalytics;
declare const index_IconDeviceAudioTape: typeof IconDeviceAudioTape;
declare const index_IconDeviceCameraPhone: typeof IconDeviceCameraPhone;
declare const index_IconDeviceCctv: typeof IconDeviceCctv;
declare const index_IconDeviceCctvFilled: typeof IconDeviceCctvFilled;
declare const index_IconDeviceCctvOff: typeof IconDeviceCctvOff;
declare const index_IconDeviceComputerCamera: typeof IconDeviceComputerCamera;
declare const index_IconDeviceComputerCameraOff: typeof IconDeviceComputerCameraOff;
declare const index_IconDeviceDesktop: typeof IconDeviceDesktop;
declare const index_IconDeviceDesktopAnalytics: typeof IconDeviceDesktopAnalytics;
declare const index_IconDeviceDesktopBolt: typeof IconDeviceDesktopBolt;
declare const index_IconDeviceDesktopCancel: typeof IconDeviceDesktopCancel;
declare const index_IconDeviceDesktopCheck: typeof IconDeviceDesktopCheck;
declare const index_IconDeviceDesktopCode: typeof IconDeviceDesktopCode;
declare const index_IconDeviceDesktopCog: typeof IconDeviceDesktopCog;
declare const index_IconDeviceDesktopDollar: typeof IconDeviceDesktopDollar;
declare const index_IconDeviceDesktopDown: typeof IconDeviceDesktopDown;
declare const index_IconDeviceDesktopExclamation: typeof IconDeviceDesktopExclamation;
declare const index_IconDeviceDesktopFilled: typeof IconDeviceDesktopFilled;
declare const index_IconDeviceDesktopHeart: typeof IconDeviceDesktopHeart;
declare const index_IconDeviceDesktopMinus: typeof IconDeviceDesktopMinus;
declare const index_IconDeviceDesktopOff: typeof IconDeviceDesktopOff;
declare const index_IconDeviceDesktopPause: typeof IconDeviceDesktopPause;
declare const index_IconDeviceDesktopPin: typeof IconDeviceDesktopPin;
declare const index_IconDeviceDesktopPlus: typeof IconDeviceDesktopPlus;
declare const index_IconDeviceDesktopQuestion: typeof IconDeviceDesktopQuestion;
declare const index_IconDeviceDesktopSearch: typeof IconDeviceDesktopSearch;
declare const index_IconDeviceDesktopShare: typeof IconDeviceDesktopShare;
declare const index_IconDeviceDesktopStar: typeof IconDeviceDesktopStar;
declare const index_IconDeviceDesktopUp: typeof IconDeviceDesktopUp;
declare const index_IconDeviceDesktopX: typeof IconDeviceDesktopX;
declare const index_IconDeviceFloppy: typeof IconDeviceFloppy;
declare const index_IconDeviceGamepad: typeof IconDeviceGamepad;
declare const index_IconDeviceGamepad2: typeof IconDeviceGamepad2;
declare const index_IconDeviceGamepad3: typeof IconDeviceGamepad3;
declare const index_IconDeviceGamepad3Filled: typeof IconDeviceGamepad3Filled;
declare const index_IconDeviceGamepadFilled: typeof IconDeviceGamepadFilled;
declare const index_IconDeviceHeartMonitor: typeof IconDeviceHeartMonitor;
declare const index_IconDeviceHeartMonitorFilled: typeof IconDeviceHeartMonitorFilled;
declare const index_IconDeviceImac: typeof IconDeviceImac;
declare const index_IconDeviceImacBolt: typeof IconDeviceImacBolt;
declare const index_IconDeviceImacCancel: typeof IconDeviceImacCancel;
declare const index_IconDeviceImacCheck: typeof IconDeviceImacCheck;
declare const index_IconDeviceImacCode: typeof IconDeviceImacCode;
declare const index_IconDeviceImacCog: typeof IconDeviceImacCog;
declare const index_IconDeviceImacDollar: typeof IconDeviceImacDollar;
declare const index_IconDeviceImacDown: typeof IconDeviceImacDown;
declare const index_IconDeviceImacExclamation: typeof IconDeviceImacExclamation;
declare const index_IconDeviceImacFilled: typeof IconDeviceImacFilled;
declare const index_IconDeviceImacHeart: typeof IconDeviceImacHeart;
declare const index_IconDeviceImacMinus: typeof IconDeviceImacMinus;
declare const index_IconDeviceImacOff: typeof IconDeviceImacOff;
declare const index_IconDeviceImacPause: typeof IconDeviceImacPause;
declare const index_IconDeviceImacPin: typeof IconDeviceImacPin;
declare const index_IconDeviceImacPlus: typeof IconDeviceImacPlus;
declare const index_IconDeviceImacQuestion: typeof IconDeviceImacQuestion;
declare const index_IconDeviceImacSearch: typeof IconDeviceImacSearch;
declare const index_IconDeviceImacShare: typeof IconDeviceImacShare;
declare const index_IconDeviceImacStar: typeof IconDeviceImacStar;
declare const index_IconDeviceImacUp: typeof IconDeviceImacUp;
declare const index_IconDeviceImacX: typeof IconDeviceImacX;
declare const index_IconDeviceIpad: typeof IconDeviceIpad;
declare const index_IconDeviceIpadBolt: typeof IconDeviceIpadBolt;
declare const index_IconDeviceIpadCancel: typeof IconDeviceIpadCancel;
declare const index_IconDeviceIpadCheck: typeof IconDeviceIpadCheck;
declare const index_IconDeviceIpadCode: typeof IconDeviceIpadCode;
declare const index_IconDeviceIpadCog: typeof IconDeviceIpadCog;
declare const index_IconDeviceIpadDollar: typeof IconDeviceIpadDollar;
declare const index_IconDeviceIpadDown: typeof IconDeviceIpadDown;
declare const index_IconDeviceIpadExclamation: typeof IconDeviceIpadExclamation;
declare const index_IconDeviceIpadFilled: typeof IconDeviceIpadFilled;
declare const index_IconDeviceIpadHeart: typeof IconDeviceIpadHeart;
declare const index_IconDeviceIpadHorizontal: typeof IconDeviceIpadHorizontal;
declare const index_IconDeviceIpadHorizontalBolt: typeof IconDeviceIpadHorizontalBolt;
declare const index_IconDeviceIpadHorizontalCancel: typeof IconDeviceIpadHorizontalCancel;
declare const index_IconDeviceIpadHorizontalCheck: typeof IconDeviceIpadHorizontalCheck;
declare const index_IconDeviceIpadHorizontalCode: typeof IconDeviceIpadHorizontalCode;
declare const index_IconDeviceIpadHorizontalCog: typeof IconDeviceIpadHorizontalCog;
declare const index_IconDeviceIpadHorizontalDollar: typeof IconDeviceIpadHorizontalDollar;
declare const index_IconDeviceIpadHorizontalDown: typeof IconDeviceIpadHorizontalDown;
declare const index_IconDeviceIpadHorizontalExclamation: typeof IconDeviceIpadHorizontalExclamation;
declare const index_IconDeviceIpadHorizontalHeart: typeof IconDeviceIpadHorizontalHeart;
declare const index_IconDeviceIpadHorizontalMinus: typeof IconDeviceIpadHorizontalMinus;
declare const index_IconDeviceIpadHorizontalOff: typeof IconDeviceIpadHorizontalOff;
declare const index_IconDeviceIpadHorizontalPause: typeof IconDeviceIpadHorizontalPause;
declare const index_IconDeviceIpadHorizontalPin: typeof IconDeviceIpadHorizontalPin;
declare const index_IconDeviceIpadHorizontalPlus: typeof IconDeviceIpadHorizontalPlus;
declare const index_IconDeviceIpadHorizontalQuestion: typeof IconDeviceIpadHorizontalQuestion;
declare const index_IconDeviceIpadHorizontalSearch: typeof IconDeviceIpadHorizontalSearch;
declare const index_IconDeviceIpadHorizontalShare: typeof IconDeviceIpadHorizontalShare;
declare const index_IconDeviceIpadHorizontalStar: typeof IconDeviceIpadHorizontalStar;
declare const index_IconDeviceIpadHorizontalUp: typeof IconDeviceIpadHorizontalUp;
declare const index_IconDeviceIpadHorizontalX: typeof IconDeviceIpadHorizontalX;
declare const index_IconDeviceIpadMinus: typeof IconDeviceIpadMinus;
declare const index_IconDeviceIpadOff: typeof IconDeviceIpadOff;
declare const index_IconDeviceIpadPause: typeof IconDeviceIpadPause;
declare const index_IconDeviceIpadPin: typeof IconDeviceIpadPin;
declare const index_IconDeviceIpadPlus: typeof IconDeviceIpadPlus;
declare const index_IconDeviceIpadQuestion: typeof IconDeviceIpadQuestion;
declare const index_IconDeviceIpadSearch: typeof IconDeviceIpadSearch;
declare const index_IconDeviceIpadShare: typeof IconDeviceIpadShare;
declare const index_IconDeviceIpadStar: typeof IconDeviceIpadStar;
declare const index_IconDeviceIpadUp: typeof IconDeviceIpadUp;
declare const index_IconDeviceIpadX: typeof IconDeviceIpadX;
declare const index_IconDeviceLandlinePhone: typeof IconDeviceLandlinePhone;
declare const index_IconDeviceLaptop: typeof IconDeviceLaptop;
declare const index_IconDeviceLaptopOff: typeof IconDeviceLaptopOff;
declare const index_IconDeviceMobile: typeof IconDeviceMobile;
declare const index_IconDeviceMobileBolt: typeof IconDeviceMobileBolt;
declare const index_IconDeviceMobileCancel: typeof IconDeviceMobileCancel;
declare const index_IconDeviceMobileCharging: typeof IconDeviceMobileCharging;
declare const index_IconDeviceMobileCheck: typeof IconDeviceMobileCheck;
declare const index_IconDeviceMobileCode: typeof IconDeviceMobileCode;
declare const index_IconDeviceMobileCog: typeof IconDeviceMobileCog;
declare const index_IconDeviceMobileDollar: typeof IconDeviceMobileDollar;
declare const index_IconDeviceMobileDown: typeof IconDeviceMobileDown;
declare const index_IconDeviceMobileExclamation: typeof IconDeviceMobileExclamation;
declare const index_IconDeviceMobileFilled: typeof IconDeviceMobileFilled;
declare const index_IconDeviceMobileHeart: typeof IconDeviceMobileHeart;
declare const index_IconDeviceMobileMessage: typeof IconDeviceMobileMessage;
declare const index_IconDeviceMobileMinus: typeof IconDeviceMobileMinus;
declare const index_IconDeviceMobileOff: typeof IconDeviceMobileOff;
declare const index_IconDeviceMobilePause: typeof IconDeviceMobilePause;
declare const index_IconDeviceMobilePin: typeof IconDeviceMobilePin;
declare const index_IconDeviceMobilePlus: typeof IconDeviceMobilePlus;
declare const index_IconDeviceMobileQuestion: typeof IconDeviceMobileQuestion;
declare const index_IconDeviceMobileRotated: typeof IconDeviceMobileRotated;
declare const index_IconDeviceMobileSearch: typeof IconDeviceMobileSearch;
declare const index_IconDeviceMobileShare: typeof IconDeviceMobileShare;
declare const index_IconDeviceMobileStar: typeof IconDeviceMobileStar;
declare const index_IconDeviceMobileUp: typeof IconDeviceMobileUp;
declare const index_IconDeviceMobileVibration: typeof IconDeviceMobileVibration;
declare const index_IconDeviceMobileX: typeof IconDeviceMobileX;
declare const index_IconDeviceNintendo: typeof IconDeviceNintendo;
declare const index_IconDeviceNintendoOff: typeof IconDeviceNintendoOff;
declare const index_IconDeviceProjector: typeof IconDeviceProjector;
declare const index_IconDeviceRemote: typeof IconDeviceRemote;
declare const index_IconDeviceRemoteFilled: typeof IconDeviceRemoteFilled;
declare const index_IconDeviceSdCard: typeof IconDeviceSdCard;
declare const index_IconDeviceSim: typeof IconDeviceSim;
declare const index_IconDeviceSim1: typeof IconDeviceSim1;
declare const index_IconDeviceSim2: typeof IconDeviceSim2;
declare const index_IconDeviceSim3: typeof IconDeviceSim3;
declare const index_IconDeviceSpeaker: typeof IconDeviceSpeaker;
declare const index_IconDeviceSpeakerFilled: typeof IconDeviceSpeakerFilled;
declare const index_IconDeviceSpeakerOff: typeof IconDeviceSpeakerOff;
declare const index_IconDeviceTablet: typeof IconDeviceTablet;
declare const index_IconDeviceTabletBolt: typeof IconDeviceTabletBolt;
declare const index_IconDeviceTabletCancel: typeof IconDeviceTabletCancel;
declare const index_IconDeviceTabletCheck: typeof IconDeviceTabletCheck;
declare const index_IconDeviceTabletCode: typeof IconDeviceTabletCode;
declare const index_IconDeviceTabletCog: typeof IconDeviceTabletCog;
declare const index_IconDeviceTabletDollar: typeof IconDeviceTabletDollar;
declare const index_IconDeviceTabletDown: typeof IconDeviceTabletDown;
declare const index_IconDeviceTabletExclamation: typeof IconDeviceTabletExclamation;
declare const index_IconDeviceTabletFilled: typeof IconDeviceTabletFilled;
declare const index_IconDeviceTabletHeart: typeof IconDeviceTabletHeart;
declare const index_IconDeviceTabletMinus: typeof IconDeviceTabletMinus;
declare const index_IconDeviceTabletOff: typeof IconDeviceTabletOff;
declare const index_IconDeviceTabletPause: typeof IconDeviceTabletPause;
declare const index_IconDeviceTabletPin: typeof IconDeviceTabletPin;
declare const index_IconDeviceTabletPlus: typeof IconDeviceTabletPlus;
declare const index_IconDeviceTabletQuestion: typeof IconDeviceTabletQuestion;
declare const index_IconDeviceTabletSearch: typeof IconDeviceTabletSearch;
declare const index_IconDeviceTabletShare: typeof IconDeviceTabletShare;
declare const index_IconDeviceTabletStar: typeof IconDeviceTabletStar;
declare const index_IconDeviceTabletUp: typeof IconDeviceTabletUp;
declare const index_IconDeviceTabletX: typeof IconDeviceTabletX;
declare const index_IconDeviceTv: typeof IconDeviceTv;
declare const index_IconDeviceTvFilled: typeof IconDeviceTvFilled;
declare const index_IconDeviceTvOff: typeof IconDeviceTvOff;
declare const index_IconDeviceTvOld: typeof IconDeviceTvOld;
declare const index_IconDeviceTvOldFilled: typeof IconDeviceTvOldFilled;
declare const index_IconDeviceUnknown: typeof IconDeviceUnknown;
declare const index_IconDeviceUnknownFilled: typeof IconDeviceUnknownFilled;
declare const index_IconDeviceUsb: typeof IconDeviceUsb;
declare const index_IconDeviceUsbFilled: typeof IconDeviceUsbFilled;
declare const index_IconDeviceVisionPro: typeof IconDeviceVisionPro;
declare const index_IconDeviceVisionProFilled: typeof IconDeviceVisionProFilled;
declare const index_IconDeviceWatch: typeof IconDeviceWatch;
declare const index_IconDeviceWatchBolt: typeof IconDeviceWatchBolt;
declare const index_IconDeviceWatchCancel: typeof IconDeviceWatchCancel;
declare const index_IconDeviceWatchCheck: typeof IconDeviceWatchCheck;
declare const index_IconDeviceWatchCode: typeof IconDeviceWatchCode;
declare const index_IconDeviceWatchCog: typeof IconDeviceWatchCog;
declare const index_IconDeviceWatchDollar: typeof IconDeviceWatchDollar;
declare const index_IconDeviceWatchDown: typeof IconDeviceWatchDown;
declare const index_IconDeviceWatchExclamation: typeof IconDeviceWatchExclamation;
declare const index_IconDeviceWatchFilled: typeof IconDeviceWatchFilled;
declare const index_IconDeviceWatchHeart: typeof IconDeviceWatchHeart;
declare const index_IconDeviceWatchMinus: typeof IconDeviceWatchMinus;
declare const index_IconDeviceWatchOff: typeof IconDeviceWatchOff;
declare const index_IconDeviceWatchPause: typeof IconDeviceWatchPause;
declare const index_IconDeviceWatchPin: typeof IconDeviceWatchPin;
declare const index_IconDeviceWatchPlus: typeof IconDeviceWatchPlus;
declare const index_IconDeviceWatchQuestion: typeof IconDeviceWatchQuestion;
declare const index_IconDeviceWatchSearch: typeof IconDeviceWatchSearch;
declare const index_IconDeviceWatchShare: typeof IconDeviceWatchShare;
declare const index_IconDeviceWatchStar: typeof IconDeviceWatchStar;
declare const index_IconDeviceWatchStats: typeof IconDeviceWatchStats;
declare const index_IconDeviceWatchStats2: typeof IconDeviceWatchStats2;
declare const index_IconDeviceWatchUp: typeof IconDeviceWatchUp;
declare const index_IconDeviceWatchX: typeof IconDeviceWatchX;
declare const index_IconDevices: typeof IconDevices;
declare const index_IconDevices2: typeof IconDevices2;
declare const index_IconDevicesBolt: typeof IconDevicesBolt;
declare const index_IconDevicesCancel: typeof IconDevicesCancel;
declare const index_IconDevicesCheck: typeof IconDevicesCheck;
declare const index_IconDevicesCode: typeof IconDevicesCode;
declare const index_IconDevicesCog: typeof IconDevicesCog;
declare const index_IconDevicesDollar: typeof IconDevicesDollar;
declare const index_IconDevicesDown: typeof IconDevicesDown;
declare const index_IconDevicesExclamation: typeof IconDevicesExclamation;
declare const index_IconDevicesHeart: typeof IconDevicesHeart;
declare const index_IconDevicesMinus: typeof IconDevicesMinus;
declare const index_IconDevicesOff: typeof IconDevicesOff;
declare const index_IconDevicesPause: typeof IconDevicesPause;
declare const index_IconDevicesPc: typeof IconDevicesPc;
declare const index_IconDevicesPcOff: typeof IconDevicesPcOff;
declare const index_IconDevicesPin: typeof IconDevicesPin;
declare const index_IconDevicesPlus: typeof IconDevicesPlus;
declare const index_IconDevicesQuestion: typeof IconDevicesQuestion;
declare const index_IconDevicesSearch: typeof IconDevicesSearch;
declare const index_IconDevicesShare: typeof IconDevicesShare;
declare const index_IconDevicesStar: typeof IconDevicesStar;
declare const index_IconDevicesUp: typeof IconDevicesUp;
declare const index_IconDevicesX: typeof IconDevicesX;
declare const index_IconDiabolo: typeof IconDiabolo;
declare const index_IconDiaboloOff: typeof IconDiaboloOff;
declare const index_IconDiaboloPlus: typeof IconDiaboloPlus;
declare const index_IconDialpad: typeof IconDialpad;
declare const index_IconDialpadFilled: typeof IconDialpadFilled;
declare const index_IconDialpadOff: typeof IconDialpadOff;
declare const index_IconDiamond: typeof IconDiamond;
declare const index_IconDiamondFilled: typeof IconDiamondFilled;
declare const index_IconDiamondOff: typeof IconDiamondOff;
declare const index_IconDiamonds: typeof IconDiamonds;
declare const index_IconDiamondsFilled: typeof IconDiamondsFilled;
declare const index_IconDiaper: typeof IconDiaper;
declare const index_IconDice: typeof IconDice;
declare const index_IconDice1: typeof IconDice1;
declare const index_IconDice1Filled: typeof IconDice1Filled;
declare const index_IconDice2: typeof IconDice2;
declare const index_IconDice2Filled: typeof IconDice2Filled;
declare const index_IconDice3: typeof IconDice3;
declare const index_IconDice3Filled: typeof IconDice3Filled;
declare const index_IconDice4: typeof IconDice4;
declare const index_IconDice4Filled: typeof IconDice4Filled;
declare const index_IconDice5: typeof IconDice5;
declare const index_IconDice5Filled: typeof IconDice5Filled;
declare const index_IconDice6: typeof IconDice6;
declare const index_IconDice6Filled: typeof IconDice6Filled;
declare const index_IconDiceFilled: typeof IconDiceFilled;
declare const index_IconDimensions: typeof IconDimensions;
declare const index_IconDirection: typeof IconDirection;
declare const index_IconDirectionArrows: typeof IconDirectionArrows;
declare const index_IconDirectionArrowsFilled: typeof IconDirectionArrowsFilled;
declare const index_IconDirectionHorizontal: typeof IconDirectionHorizontal;
declare const index_IconDirectionSign: typeof IconDirectionSign;
declare const index_IconDirectionSignFilled: typeof IconDirectionSignFilled;
declare const index_IconDirectionSignOff: typeof IconDirectionSignOff;
declare const index_IconDirections: typeof IconDirections;
declare const index_IconDirectionsFilled: typeof IconDirectionsFilled;
declare const index_IconDirectionsOff: typeof IconDirectionsOff;
declare const index_IconDisabled: typeof IconDisabled;
declare const index_IconDisabled2: typeof IconDisabled2;
declare const index_IconDisabledOff: typeof IconDisabledOff;
declare const index_IconDisc: typeof IconDisc;
declare const index_IconDiscFilled: typeof IconDiscFilled;
declare const index_IconDiscGolf: typeof IconDiscGolf;
declare const index_IconDiscOff: typeof IconDiscOff;
declare const index_IconDiscount: typeof IconDiscount;
declare const index_IconDiscountFilled: typeof IconDiscountFilled;
declare const index_IconDiscountOff: typeof IconDiscountOff;
declare const index_IconDivide: typeof IconDivide;
declare const index_IconDna: typeof IconDna;
declare const index_IconDna2: typeof IconDna2;
declare const index_IconDna2Off: typeof IconDna2Off;
declare const index_IconDnaOff: typeof IconDnaOff;
declare const index_IconDog: typeof IconDog;
declare const index_IconDogBowl: typeof IconDogBowl;
declare const index_IconDoor: typeof IconDoor;
declare const index_IconDoorEnter: typeof IconDoorEnter;
declare const index_IconDoorExit: typeof IconDoorExit;
declare const index_IconDoorOff: typeof IconDoorOff;
declare const index_IconDots: typeof IconDots;
declare const index_IconDotsCircleHorizontal: typeof IconDotsCircleHorizontal;
declare const index_IconDotsDiagonal: typeof IconDotsDiagonal;
declare const index_IconDotsDiagonal2: typeof IconDotsDiagonal2;
declare const index_IconDotsVertical: typeof IconDotsVertical;
declare const index_IconDownload: typeof IconDownload;
declare const index_IconDownloadOff: typeof IconDownloadOff;
declare const index_IconDragDrop: typeof IconDragDrop;
declare const index_IconDragDrop2: typeof IconDragDrop2;
declare const index_IconDrone: typeof IconDrone;
declare const index_IconDroneOff: typeof IconDroneOff;
declare const index_IconDropCircle: typeof IconDropCircle;
declare const index_IconDropCircleFilled: typeof IconDropCircleFilled;
declare const index_IconDroplet: typeof IconDroplet;
declare const index_IconDropletBolt: typeof IconDropletBolt;
declare const index_IconDropletCancel: typeof IconDropletCancel;
declare const index_IconDropletCheck: typeof IconDropletCheck;
declare const index_IconDropletCode: typeof IconDropletCode;
declare const index_IconDropletCog: typeof IconDropletCog;
declare const index_IconDropletDollar: typeof IconDropletDollar;
declare const index_IconDropletDown: typeof IconDropletDown;
declare const index_IconDropletExclamation: typeof IconDropletExclamation;
declare const index_IconDropletFilled: typeof IconDropletFilled;
declare const index_IconDropletHalf: typeof IconDropletHalf;
declare const index_IconDropletHalf2: typeof IconDropletHalf2;
declare const index_IconDropletHalf2Filled: typeof IconDropletHalf2Filled;
declare const index_IconDropletHalfFilled: typeof IconDropletHalfFilled;
declare const index_IconDropletHeart: typeof IconDropletHeart;
declare const index_IconDropletMinus: typeof IconDropletMinus;
declare const index_IconDropletOff: typeof IconDropletOff;
declare const index_IconDropletPause: typeof IconDropletPause;
declare const index_IconDropletPin: typeof IconDropletPin;
declare const index_IconDropletPlus: typeof IconDropletPlus;
declare const index_IconDropletQuestion: typeof IconDropletQuestion;
declare const index_IconDropletSearch: typeof IconDropletSearch;
declare const index_IconDropletShare: typeof IconDropletShare;
declare const index_IconDropletStar: typeof IconDropletStar;
declare const index_IconDropletUp: typeof IconDropletUp;
declare const index_IconDropletX: typeof IconDropletX;
declare const index_IconDroplets: typeof IconDroplets;
declare const index_IconDropletsFilled: typeof IconDropletsFilled;
declare const index_IconDualScreen: typeof IconDualScreen;
declare const index_IconDualScreenFilled: typeof IconDualScreenFilled;
declare const index_IconDumpling: typeof IconDumpling;
declare const index_IconDumplingFilled: typeof IconDumplingFilled;
declare const index_IconEPassport: typeof IconEPassport;
declare const index_IconEar: typeof IconEar;
declare const index_IconEarOff: typeof IconEarOff;
declare const index_IconEarScan: typeof IconEarScan;
declare const index_IconEaseIn: typeof IconEaseIn;
declare const index_IconEaseInControlPoint: typeof IconEaseInControlPoint;
declare const index_IconEaseInControlPointFilled: typeof IconEaseInControlPointFilled;
declare const index_IconEaseInOut: typeof IconEaseInOut;
declare const index_IconEaseInOutControlPoints: typeof IconEaseInOutControlPoints;
declare const index_IconEaseInOutControlPointsFilled: typeof IconEaseInOutControlPointsFilled;
declare const index_IconEaseOut: typeof IconEaseOut;
declare const index_IconEaseOutControlPoint: typeof IconEaseOutControlPoint;
declare const index_IconEaseOutControlPointFilled: typeof IconEaseOutControlPointFilled;
declare const index_IconEdit: typeof IconEdit;
declare const index_IconEditCircle: typeof IconEditCircle;
declare const index_IconEditCircleOff: typeof IconEditCircleOff;
declare const index_IconEditOff: typeof IconEditOff;
declare const index_IconEgg: typeof IconEgg;
declare const index_IconEggCracked: typeof IconEggCracked;
declare const index_IconEggCrackedFilled: typeof IconEggCrackedFilled;
declare const index_IconEggFilled: typeof IconEggFilled;
declare const index_IconEggFried: typeof IconEggFried;
declare const index_IconEggFriedFilled: typeof IconEggFriedFilled;
declare const index_IconEggOff: typeof IconEggOff;
declare const index_IconEggs: typeof IconEggs;
declare const index_IconElevator: typeof IconElevator;
declare const index_IconElevatorFilled: typeof IconElevatorFilled;
declare const index_IconElevatorOff: typeof IconElevatorOff;
declare const index_IconEmergencyBed: typeof IconEmergencyBed;
declare const index_IconEmpathize: typeof IconEmpathize;
declare const index_IconEmpathizeOff: typeof IconEmpathizeOff;
declare const index_IconEmphasis: typeof IconEmphasis;
declare const index_IconEngine: typeof IconEngine;
declare const index_IconEngineFilled: typeof IconEngineFilled;
declare const index_IconEngineOff: typeof IconEngineOff;
declare const index_IconEqual: typeof IconEqual;
declare const index_IconEqualDouble: typeof IconEqualDouble;
declare const index_IconEqualNot: typeof IconEqualNot;
declare const index_IconEraser: typeof IconEraser;
declare const index_IconEraserOff: typeof IconEraserOff;
declare const index_IconError404: typeof IconError404;
declare const index_IconError404Off: typeof IconError404Off;
declare const index_IconEscalator: typeof IconEscalator;
declare const index_IconEscalatorDown: typeof IconEscalatorDown;
declare const index_IconEscalatorDownFilled: typeof IconEscalatorDownFilled;
declare const index_IconEscalatorFilled: typeof IconEscalatorFilled;
declare const index_IconEscalatorUp: typeof IconEscalatorUp;
declare const index_IconEscalatorUpFilled: typeof IconEscalatorUpFilled;
declare const index_IconExchange: typeof IconExchange;
declare const index_IconExchangeFilled: typeof IconExchangeFilled;
declare const index_IconExchangeOff: typeof IconExchangeOff;
declare const index_IconExclamationCircle: typeof IconExclamationCircle;
declare const index_IconExclamationCircleFilled: typeof IconExclamationCircleFilled;
declare const index_IconExclamationMark: typeof IconExclamationMark;
declare const index_IconExclamationMarkOff: typeof IconExclamationMarkOff;
declare const index_IconExplicit: typeof IconExplicit;
declare const index_IconExplicitFilled: typeof IconExplicitFilled;
declare const index_IconExplicitOff: typeof IconExplicitOff;
declare const index_IconExposure: typeof IconExposure;
declare const index_IconExposure0: typeof IconExposure0;
declare const index_IconExposureFilled: typeof IconExposureFilled;
declare const index_IconExposureMinus1: typeof IconExposureMinus1;
declare const index_IconExposureMinus2: typeof IconExposureMinus2;
declare const index_IconExposureOff: typeof IconExposureOff;
declare const index_IconExposurePlus1: typeof IconExposurePlus1;
declare const index_IconExposurePlus2: typeof IconExposurePlus2;
declare const index_IconExternalLink: typeof IconExternalLink;
declare const index_IconExternalLinkOff: typeof IconExternalLinkOff;
declare const index_IconEye: typeof IconEye;
declare const index_IconEyeBitcoin: typeof IconEyeBitcoin;
declare const index_IconEyeBolt: typeof IconEyeBolt;
declare const index_IconEyeCancel: typeof IconEyeCancel;
declare const index_IconEyeCheck: typeof IconEyeCheck;
declare const index_IconEyeClosed: typeof IconEyeClosed;
declare const index_IconEyeCode: typeof IconEyeCode;
declare const index_IconEyeCog: typeof IconEyeCog;
declare const index_IconEyeDiscount: typeof IconEyeDiscount;
declare const index_IconEyeDollar: typeof IconEyeDollar;
declare const index_IconEyeDotted: typeof IconEyeDotted;
declare const index_IconEyeDown: typeof IconEyeDown;
declare const index_IconEyeEdit: typeof IconEyeEdit;
declare const index_IconEyeExclamation: typeof IconEyeExclamation;
declare const index_IconEyeFilled: typeof IconEyeFilled;
declare const index_IconEyeHeart: typeof IconEyeHeart;
declare const index_IconEyeMinus: typeof IconEyeMinus;
declare const index_IconEyeOff: typeof IconEyeOff;
declare const index_IconEyePause: typeof IconEyePause;
declare const index_IconEyePin: typeof IconEyePin;
declare const index_IconEyePlus: typeof IconEyePlus;
declare const index_IconEyeQuestion: typeof IconEyeQuestion;
declare const index_IconEyeSearch: typeof IconEyeSearch;
declare const index_IconEyeShare: typeof IconEyeShare;
declare const index_IconEyeSpark: typeof IconEyeSpark;
declare const index_IconEyeStar: typeof IconEyeStar;
declare const index_IconEyeTable: typeof IconEyeTable;
declare const index_IconEyeTableFilled: typeof IconEyeTableFilled;
declare const index_IconEyeUp: typeof IconEyeUp;
declare const index_IconEyeX: typeof IconEyeX;
declare const index_IconEyeglass: typeof IconEyeglass;
declare const index_IconEyeglass2: typeof IconEyeglass2;
declare const index_IconEyeglass2Filled: typeof IconEyeglass2Filled;
declare const index_IconEyeglassFilled: typeof IconEyeglassFilled;
declare const index_IconEyeglassOff: typeof IconEyeglassOff;
declare const index_IconFaceId: typeof IconFaceId;
declare const index_IconFaceIdError: typeof IconFaceIdError;
declare const index_IconFaceMask: typeof IconFaceMask;
declare const index_IconFaceMaskFilled: typeof IconFaceMaskFilled;
declare const index_IconFaceMaskOff: typeof IconFaceMaskOff;
declare const index_IconFall: typeof IconFall;
declare const index_IconFavicon: typeof IconFavicon;
declare const index_IconFaviconFilled: typeof IconFaviconFilled;
declare const index_IconFeather: typeof IconFeather;
declare const index_IconFeatherFilled: typeof IconFeatherFilled;
declare const index_IconFeatherOff: typeof IconFeatherOff;
declare const index_IconFence: typeof IconFence;
declare const index_IconFenceFilled: typeof IconFenceFilled;
declare const index_IconFenceOff: typeof IconFenceOff;
declare const index_IconFerry: typeof IconFerry;
declare const index_IconFerryFilled: typeof IconFerryFilled;
declare const index_IconFidgetSpinner: typeof IconFidgetSpinner;
declare const index_IconFidgetSpinnerFilled: typeof IconFidgetSpinnerFilled;
declare const index_IconFile: typeof IconFile;
declare const index_IconFile3d: typeof IconFile3d;
declare const index_IconFileAi: typeof IconFileAi;
declare const index_IconFileAlert: typeof IconFileAlert;
declare const index_IconFileAnalytics: typeof IconFileAnalytics;
declare const index_IconFileAnalyticsFilled: typeof IconFileAnalyticsFilled;
declare const index_IconFileArrowLeft: typeof IconFileArrowLeft;
declare const index_IconFileArrowRight: typeof IconFileArrowRight;
declare const index_IconFileBarcode: typeof IconFileBarcode;
declare const index_IconFileBitcoin: typeof IconFileBitcoin;
declare const index_IconFileBroken: typeof IconFileBroken;
declare const index_IconFileCertificate: typeof IconFileCertificate;
declare const index_IconFileChart: typeof IconFileChart;
declare const index_IconFileCheck: typeof IconFileCheck;
declare const index_IconFileCheckFilled: typeof IconFileCheckFilled;
declare const index_IconFileCode: typeof IconFileCode;
declare const index_IconFileCode2: typeof IconFileCode2;
declare const index_IconFileCode2Filled: typeof IconFileCode2Filled;
declare const index_IconFileCodeFilled: typeof IconFileCodeFilled;
declare const index_IconFileCv: typeof IconFileCv;
declare const index_IconFileCvFilled: typeof IconFileCvFilled;
declare const index_IconFileDatabase: typeof IconFileDatabase;
declare const index_IconFileDelta: typeof IconFileDelta;
declare const index_IconFileDeltaFilled: typeof IconFileDeltaFilled;
declare const index_IconFileDescription: typeof IconFileDescription;
declare const index_IconFileDescriptionFilled: typeof IconFileDescriptionFilled;
declare const index_IconFileDiff: typeof IconFileDiff;
declare const index_IconFileDiffFilled: typeof IconFileDiffFilled;
declare const index_IconFileDigit: typeof IconFileDigit;
declare const index_IconFileDigitFilled: typeof IconFileDigitFilled;
declare const index_IconFileDislike: typeof IconFileDislike;
declare const index_IconFileDollar: typeof IconFileDollar;
declare const index_IconFileDollarFilled: typeof IconFileDollarFilled;
declare const index_IconFileDots: typeof IconFileDots;
declare const index_IconFileDotsFilled: typeof IconFileDotsFilled;
declare const index_IconFileDownload: typeof IconFileDownload;
declare const index_IconFileDownloadFilled: typeof IconFileDownloadFilled;
declare const index_IconFileEuro: typeof IconFileEuro;
declare const index_IconFileEuroFilled: typeof IconFileEuroFilled;
declare const index_IconFileExcel: typeof IconFileExcel;
declare const index_IconFileExport: typeof IconFileExport;
declare const index_IconFileFilled: typeof IconFileFilled;
declare const index_IconFileFunction: typeof IconFileFunction;
declare const index_IconFileFunctionFilled: typeof IconFileFunctionFilled;
declare const index_IconFileHorizontal: typeof IconFileHorizontal;
declare const index_IconFileHorizontalFilled: typeof IconFileHorizontalFilled;
declare const index_IconFileImport: typeof IconFileImport;
declare const index_IconFileInfinity: typeof IconFileInfinity;
declare const index_IconFileInfo: typeof IconFileInfo;
declare const index_IconFileInfoFilled: typeof IconFileInfoFilled;
declare const index_IconFileInvoice: typeof IconFileInvoice;
declare const index_IconFileInvoiceFilled: typeof IconFileInvoiceFilled;
declare const index_IconFileIsr: typeof IconFileIsr;
declare const index_IconFileLambda: typeof IconFileLambda;
declare const index_IconFileLambdaFilled: typeof IconFileLambdaFilled;
declare const index_IconFileLike: typeof IconFileLike;
declare const index_IconFileMinus: typeof IconFileMinus;
declare const index_IconFileMinusFilled: typeof IconFileMinusFilled;
declare const index_IconFileMusic: typeof IconFileMusic;
declare const index_IconFileMusicFilled: typeof IconFileMusicFilled;
declare const index_IconFileNeutral: typeof IconFileNeutral;
declare const index_IconFileNeutralFilled: typeof IconFileNeutralFilled;
declare const index_IconFileOff: typeof IconFileOff;
declare const index_IconFileOrientation: typeof IconFileOrientation;
declare const index_IconFilePencil: typeof IconFilePencil;
declare const index_IconFilePencilFilled: typeof IconFilePencilFilled;
declare const index_IconFilePercent: typeof IconFilePercent;
declare const index_IconFilePercentFilled: typeof IconFilePercentFilled;
declare const index_IconFilePhone: typeof IconFilePhone;
declare const index_IconFilePhoneFilled: typeof IconFilePhoneFilled;
declare const index_IconFilePlus: typeof IconFilePlus;
declare const index_IconFilePower: typeof IconFilePower;
declare const index_IconFilePowerFilled: typeof IconFilePowerFilled;
declare const index_IconFileReport: typeof IconFileReport;
declare const index_IconFileRss: typeof IconFileRss;
declare const index_IconFileRssFilled: typeof IconFileRssFilled;
declare const index_IconFileSad: typeof IconFileSad;
declare const index_IconFileSadFilled: typeof IconFileSadFilled;
declare const index_IconFileScissors: typeof IconFileScissors;
declare const index_IconFileScissorsFilled: typeof IconFileScissorsFilled;
declare const index_IconFileSearch: typeof IconFileSearch;
declare const index_IconFileSettings: typeof IconFileSettings;
declare const index_IconFileSettingsFilled: typeof IconFileSettingsFilled;
declare const index_IconFileShredder: typeof IconFileShredder;
declare const index_IconFileSignal: typeof IconFileSignal;
declare const index_IconFileSignalFilled: typeof IconFileSignalFilled;
declare const index_IconFileSmile: typeof IconFileSmile;
declare const index_IconFileSmileFilled: typeof IconFileSmileFilled;
declare const index_IconFileSpark: typeof IconFileSpark;
declare const index_IconFileSpreadsheet: typeof IconFileSpreadsheet;
declare const index_IconFileStack: typeof IconFileStack;
declare const index_IconFileStar: typeof IconFileStar;
declare const index_IconFileStarFilled: typeof IconFileStarFilled;
declare const index_IconFileSymlink: typeof IconFileSymlink;
declare const index_IconFileText: typeof IconFileText;
declare const index_IconFileTextAi: typeof IconFileTextAi;
declare const index_IconFileTextFilled: typeof IconFileTextFilled;
declare const index_IconFileTextShield: typeof IconFileTextShield;
declare const index_IconFileTextSpark: typeof IconFileTextSpark;
declare const index_IconFileTime: typeof IconFileTime;
declare const index_IconFileTimeFilled: typeof IconFileTimeFilled;
declare const index_IconFileTypeBmp: typeof IconFileTypeBmp;
declare const index_IconFileTypeCss: typeof IconFileTypeCss;
declare const index_IconFileTypeCsv: typeof IconFileTypeCsv;
declare const index_IconFileTypeDoc: typeof IconFileTypeDoc;
declare const index_IconFileTypeDocx: typeof IconFileTypeDocx;
declare const index_IconFileTypeHtml: typeof IconFileTypeHtml;
declare const index_IconFileTypeJpg: typeof IconFileTypeJpg;
declare const index_IconFileTypeJs: typeof IconFileTypeJs;
declare const index_IconFileTypeJsx: typeof IconFileTypeJsx;
declare const index_IconFileTypePdf: typeof IconFileTypePdf;
declare const index_IconFileTypePhp: typeof IconFileTypePhp;
declare const index_IconFileTypePng: typeof IconFileTypePng;
declare const index_IconFileTypePpt: typeof IconFileTypePpt;
declare const index_IconFileTypeRs: typeof IconFileTypeRs;
declare const index_IconFileTypeSql: typeof IconFileTypeSql;
declare const index_IconFileTypeSvg: typeof IconFileTypeSvg;
declare const index_IconFileTypeTs: typeof IconFileTypeTs;
declare const index_IconFileTypeTsx: typeof IconFileTypeTsx;
declare const index_IconFileTypeTxt: typeof IconFileTypeTxt;
declare const index_IconFileTypeVue: typeof IconFileTypeVue;
declare const index_IconFileTypeXls: typeof IconFileTypeXls;
declare const index_IconFileTypeXml: typeof IconFileTypeXml;
declare const index_IconFileTypeZip: typeof IconFileTypeZip;
declare const index_IconFileTypography: typeof IconFileTypography;
declare const index_IconFileTypographyFilled: typeof IconFileTypographyFilled;
declare const index_IconFileUnknown: typeof IconFileUnknown;
declare const index_IconFileUnknownFilled: typeof IconFileUnknownFilled;
declare const index_IconFileUpload: typeof IconFileUpload;
declare const index_IconFileUploadFilled: typeof IconFileUploadFilled;
declare const index_IconFileVector: typeof IconFileVector;
declare const index_IconFileVectorFilled: typeof IconFileVectorFilled;
declare const index_IconFileWord: typeof IconFileWord;
declare const index_IconFileX: typeof IconFileX;
declare const index_IconFileXFilled: typeof IconFileXFilled;
declare const index_IconFileZip: typeof IconFileZip;
declare const index_IconFiles: typeof IconFiles;
declare const index_IconFilesFilled: typeof IconFilesFilled;
declare const index_IconFilesOff: typeof IconFilesOff;
declare const index_IconFilter: typeof IconFilter;
declare const index_IconFilter2: typeof IconFilter2;
declare const index_IconFilter2Bolt: typeof IconFilter2Bolt;
declare const index_IconFilter2Cancel: typeof IconFilter2Cancel;
declare const index_IconFilter2Check: typeof IconFilter2Check;
declare const index_IconFilter2Code: typeof IconFilter2Code;
declare const index_IconFilter2Cog: typeof IconFilter2Cog;
declare const index_IconFilter2Discount: typeof IconFilter2Discount;
declare const index_IconFilter2Dollar: typeof IconFilter2Dollar;
declare const index_IconFilter2Down: typeof IconFilter2Down;
declare const index_IconFilter2Edit: typeof IconFilter2Edit;
declare const index_IconFilter2Exclamation: typeof IconFilter2Exclamation;
declare const index_IconFilter2Minus: typeof IconFilter2Minus;
declare const index_IconFilter2Pause: typeof IconFilter2Pause;
declare const index_IconFilter2Pin: typeof IconFilter2Pin;
declare const index_IconFilter2Plus: typeof IconFilter2Plus;
declare const index_IconFilter2Question: typeof IconFilter2Question;
declare const index_IconFilter2Search: typeof IconFilter2Search;
declare const index_IconFilter2Share: typeof IconFilter2Share;
declare const index_IconFilter2Spark: typeof IconFilter2Spark;
declare const index_IconFilter2Up: typeof IconFilter2Up;
declare const index_IconFilter2X: typeof IconFilter2X;
declare const index_IconFilterBolt: typeof IconFilterBolt;
declare const index_IconFilterCancel: typeof IconFilterCancel;
declare const index_IconFilterCheck: typeof IconFilterCheck;
declare const index_IconFilterCode: typeof IconFilterCode;
declare const index_IconFilterCog: typeof IconFilterCog;
declare const index_IconFilterDiscount: typeof IconFilterDiscount;
declare const index_IconFilterDollar: typeof IconFilterDollar;
declare const index_IconFilterDown: typeof IconFilterDown;
declare const index_IconFilterEdit: typeof IconFilterEdit;
declare const index_IconFilterExclamation: typeof IconFilterExclamation;
declare const index_IconFilterFilled: typeof IconFilterFilled;
declare const index_IconFilterHeart: typeof IconFilterHeart;
declare const index_IconFilterMinus: typeof IconFilterMinus;
declare const index_IconFilterOff: typeof IconFilterOff;
declare const index_IconFilterPause: typeof IconFilterPause;
declare const index_IconFilterPin: typeof IconFilterPin;
declare const index_IconFilterPlus: typeof IconFilterPlus;
declare const index_IconFilterQuestion: typeof IconFilterQuestion;
declare const index_IconFilterSearch: typeof IconFilterSearch;
declare const index_IconFilterShare: typeof IconFilterShare;
declare const index_IconFilterSpark: typeof IconFilterSpark;
declare const index_IconFilterStar: typeof IconFilterStar;
declare const index_IconFilterUp: typeof IconFilterUp;
declare const index_IconFilterX: typeof IconFilterX;
declare const index_IconFilters: typeof IconFilters;
declare const index_IconFiltersFilled: typeof IconFiltersFilled;
declare const index_IconFingerprint: typeof IconFingerprint;
declare const index_IconFingerprintOff: typeof IconFingerprintOff;
declare const index_IconFingerprintScan: typeof IconFingerprintScan;
declare const index_IconFireExtinguisher: typeof IconFireExtinguisher;
declare const index_IconFireHydrant: typeof IconFireHydrant;
declare const index_IconFireHydrantOff: typeof IconFireHydrantOff;
declare const index_IconFiretruck: typeof IconFiretruck;
declare const index_IconFirstAidKit: typeof IconFirstAidKit;
declare const index_IconFirstAidKitOff: typeof IconFirstAidKitOff;
declare const index_IconFish: typeof IconFish;
declare const index_IconFishBone: typeof IconFishBone;
declare const index_IconFishBoneFilled: typeof IconFishBoneFilled;
declare const index_IconFishChristianity: typeof IconFishChristianity;
declare const index_IconFishHook: typeof IconFishHook;
declare const index_IconFishHookOff: typeof IconFishHookOff;
declare const index_IconFishOff: typeof IconFishOff;
declare const index_IconFlag: typeof IconFlag;
declare const index_IconFlag2: typeof IconFlag2;
declare const index_IconFlag2Filled: typeof IconFlag2Filled;
declare const index_IconFlag2Off: typeof IconFlag2Off;
declare const index_IconFlag3: typeof IconFlag3;
declare const index_IconFlag3Filled: typeof IconFlag3Filled;
declare const index_IconFlagBitcoin: typeof IconFlagBitcoin;
declare const index_IconFlagBolt: typeof IconFlagBolt;
declare const index_IconFlagCancel: typeof IconFlagCancel;
declare const index_IconFlagCheck: typeof IconFlagCheck;
declare const index_IconFlagCode: typeof IconFlagCode;
declare const index_IconFlagCog: typeof IconFlagCog;
declare const index_IconFlagDiscount: typeof IconFlagDiscount;
declare const index_IconFlagDollar: typeof IconFlagDollar;
declare const index_IconFlagDown: typeof IconFlagDown;
declare const index_IconFlagExclamation: typeof IconFlagExclamation;
declare const index_IconFlagFilled: typeof IconFlagFilled;
declare const index_IconFlagHeart: typeof IconFlagHeart;
declare const index_IconFlagMinus: typeof IconFlagMinus;
declare const index_IconFlagOff: typeof IconFlagOff;
declare const index_IconFlagPause: typeof IconFlagPause;
declare const index_IconFlagPin: typeof IconFlagPin;
declare const index_IconFlagPlus: typeof IconFlagPlus;
declare const index_IconFlagQuestion: typeof IconFlagQuestion;
declare const index_IconFlagSearch: typeof IconFlagSearch;
declare const index_IconFlagShare: typeof IconFlagShare;
declare const index_IconFlagSpark: typeof IconFlagSpark;
declare const index_IconFlagStar: typeof IconFlagStar;
declare const index_IconFlagUp: typeof IconFlagUp;
declare const index_IconFlagX: typeof IconFlagX;
declare const index_IconFlame: typeof IconFlame;
declare const index_IconFlameFilled: typeof IconFlameFilled;
declare const index_IconFlameOff: typeof IconFlameOff;
declare const index_IconFlare: typeof IconFlare;
declare const index_IconFlareFilled: typeof IconFlareFilled;
declare const index_IconFlask: typeof IconFlask;
declare const index_IconFlask2: typeof IconFlask2;
declare const index_IconFlask2Filled: typeof IconFlask2Filled;
declare const index_IconFlask2Off: typeof IconFlask2Off;
declare const index_IconFlaskFilled: typeof IconFlaskFilled;
declare const index_IconFlaskOff: typeof IconFlaskOff;
declare const index_IconFlipFlops: typeof IconFlipFlops;
declare const index_IconFlipHorizontal: typeof IconFlipHorizontal;
declare const index_IconFlipVertical: typeof IconFlipVertical;
declare const index_IconFloatCenter: typeof IconFloatCenter;
declare const index_IconFloatLeft: typeof IconFloatLeft;
declare const index_IconFloatNone: typeof IconFloatNone;
declare const index_IconFloatRight: typeof IconFloatRight;
declare const index_IconFlower: typeof IconFlower;
declare const index_IconFlowerFilled: typeof IconFlowerFilled;
declare const index_IconFlowerOff: typeof IconFlowerOff;
declare const index_IconFocus: typeof IconFocus;
declare const index_IconFocus2: typeof IconFocus2;
declare const index_IconFocusAuto: typeof IconFocusAuto;
declare const index_IconFocusCentered: typeof IconFocusCentered;
declare const index_IconFold: typeof IconFold;
declare const index_IconFoldDown: typeof IconFoldDown;
declare const index_IconFoldUp: typeof IconFoldUp;
declare const index_IconFolder: typeof IconFolder;
declare const index_IconFolderBolt: typeof IconFolderBolt;
declare const index_IconFolderCancel: typeof IconFolderCancel;
declare const index_IconFolderCheck: typeof IconFolderCheck;
declare const index_IconFolderCode: typeof IconFolderCode;
declare const index_IconFolderCog: typeof IconFolderCog;
declare const index_IconFolderDollar: typeof IconFolderDollar;
declare const index_IconFolderDown: typeof IconFolderDown;
declare const index_IconFolderExclamation: typeof IconFolderExclamation;
declare const index_IconFolderFilled: typeof IconFolderFilled;
declare const index_IconFolderHeart: typeof IconFolderHeart;
declare const index_IconFolderMinus: typeof IconFolderMinus;
declare const index_IconFolderOff: typeof IconFolderOff;
declare const index_IconFolderOpen: typeof IconFolderOpen;
declare const index_IconFolderOpenFilled: typeof IconFolderOpenFilled;
declare const index_IconFolderPause: typeof IconFolderPause;
declare const index_IconFolderPin: typeof IconFolderPin;
declare const index_IconFolderPlus: typeof IconFolderPlus;
declare const index_IconFolderQuestion: typeof IconFolderQuestion;
declare const index_IconFolderRoot: typeof IconFolderRoot;
declare const index_IconFolderSearch: typeof IconFolderSearch;
declare const index_IconFolderShare: typeof IconFolderShare;
declare const index_IconFolderStar: typeof IconFolderStar;
declare const index_IconFolderSymlink: typeof IconFolderSymlink;
declare const index_IconFolderUp: typeof IconFolderUp;
declare const index_IconFolderX: typeof IconFolderX;
declare const index_IconFolders: typeof IconFolders;
declare const index_IconFoldersFilled: typeof IconFoldersFilled;
declare const index_IconFoldersOff: typeof IconFoldersOff;
declare const index_IconForbid: typeof IconForbid;
declare const index_IconForbid2: typeof IconForbid2;
declare const index_IconForbid2Filled: typeof IconForbid2Filled;
declare const index_IconForbidFilled: typeof IconForbidFilled;
declare const index_IconForklift: typeof IconForklift;
declare const index_IconForms: typeof IconForms;
declare const index_IconFountain: typeof IconFountain;
declare const index_IconFountainFilled: typeof IconFountainFilled;
declare const index_IconFountainOff: typeof IconFountainOff;
declare const index_IconFrame: typeof IconFrame;
declare const index_IconFrameOff: typeof IconFrameOff;
declare const index_IconFreeRights: typeof IconFreeRights;
declare const index_IconFreezeColumn: typeof IconFreezeColumn;
declare const index_IconFreezeRow: typeof IconFreezeRow;
declare const index_IconFreezeRowColumn: typeof IconFreezeRowColumn;
declare const index_IconFridge: typeof IconFridge;
declare const index_IconFridgeOff: typeof IconFridgeOff;
declare const index_IconFriends: typeof IconFriends;
declare const index_IconFriendsOff: typeof IconFriendsOff;
declare const index_IconFrustum: typeof IconFrustum;
declare const index_IconFrustumOff: typeof IconFrustumOff;
declare const index_IconFrustumPlus: typeof IconFrustumPlus;
declare const index_IconFunction: typeof IconFunction;
declare const index_IconFunctionFilled: typeof IconFunctionFilled;
declare const index_IconFunctionOff: typeof IconFunctionOff;
declare const index_IconGalaxy: typeof IconGalaxy;
declare const index_IconGardenCart: typeof IconGardenCart;
declare const index_IconGardenCartFilled: typeof IconGardenCartFilled;
declare const index_IconGardenCartOff: typeof IconGardenCartOff;
declare const index_IconGasStation: typeof IconGasStation;
declare const index_IconGasStationFilled: typeof IconGasStationFilled;
declare const index_IconGasStationOff: typeof IconGasStationOff;
declare const index_IconGauge: typeof IconGauge;
declare const index_IconGaugeFilled: typeof IconGaugeFilled;
declare const index_IconGaugeOff: typeof IconGaugeOff;
declare const index_IconGavel: typeof IconGavel;
declare const index_IconGenderAgender: typeof IconGenderAgender;
declare const index_IconGenderAndrogyne: typeof IconGenderAndrogyne;
declare const index_IconGenderBigender: typeof IconGenderBigender;
declare const index_IconGenderDemiboy: typeof IconGenderDemiboy;
declare const index_IconGenderDemigirl: typeof IconGenderDemigirl;
declare const index_IconGenderEpicene: typeof IconGenderEpicene;
declare const index_IconGenderFemale: typeof IconGenderFemale;
declare const index_IconGenderFemme: typeof IconGenderFemme;
declare const index_IconGenderGenderfluid: typeof IconGenderGenderfluid;
declare const index_IconGenderGenderless: typeof IconGenderGenderless;
declare const index_IconGenderGenderqueer: typeof IconGenderGenderqueer;
declare const index_IconGenderHermaphrodite: typeof IconGenderHermaphrodite;
declare const index_IconGenderIntergender: typeof IconGenderIntergender;
declare const index_IconGenderMale: typeof IconGenderMale;
declare const index_IconGenderNeutrois: typeof IconGenderNeutrois;
declare const index_IconGenderThird: typeof IconGenderThird;
declare const index_IconGenderTransgender: typeof IconGenderTransgender;
declare const index_IconGenderTrasvesti: typeof IconGenderTrasvesti;
declare const index_IconGeometry: typeof IconGeometry;
declare const index_IconGhost: typeof IconGhost;
declare const index_IconGhost2: typeof IconGhost2;
declare const index_IconGhost2Filled: typeof IconGhost2Filled;
declare const index_IconGhost3: typeof IconGhost3;
declare const index_IconGhost3Filled: typeof IconGhost3Filled;
declare const index_IconGhostFilled: typeof IconGhostFilled;
declare const index_IconGhostOff: typeof IconGhostOff;
declare const index_IconGif: typeof IconGif;
declare const index_IconGift: typeof IconGift;
declare const index_IconGiftCard: typeof IconGiftCard;
declare const index_IconGiftCardFilled: typeof IconGiftCardFilled;
declare const index_IconGiftFilled: typeof IconGiftFilled;
declare const index_IconGiftOff: typeof IconGiftOff;
declare const index_IconGitBranch: typeof IconGitBranch;
declare const index_IconGitBranchDeleted: typeof IconGitBranchDeleted;
declare const index_IconGitCherryPick: typeof IconGitCherryPick;
declare const index_IconGitCommit: typeof IconGitCommit;
declare const index_IconGitCompare: typeof IconGitCompare;
declare const index_IconGitFork: typeof IconGitFork;
declare const index_IconGitMerge: typeof IconGitMerge;
declare const index_IconGitPullRequest: typeof IconGitPullRequest;
declare const index_IconGitPullRequestClosed: typeof IconGitPullRequestClosed;
declare const index_IconGitPullRequestDraft: typeof IconGitPullRequestDraft;
declare const index_IconGizmo: typeof IconGizmo;
declare const index_IconGlass: typeof IconGlass;
declare const index_IconGlassChampagne: typeof IconGlassChampagne;
declare const index_IconGlassCocktail: typeof IconGlassCocktail;
declare const index_IconGlassFilled: typeof IconGlassFilled;
declare const index_IconGlassFull: typeof IconGlassFull;
declare const index_IconGlassFullFilled: typeof IconGlassFullFilled;
declare const index_IconGlassGin: typeof IconGlassGin;
declare const index_IconGlassOff: typeof IconGlassOff;
declare const index_IconGlobe: typeof IconGlobe;
declare const index_IconGlobeFilled: typeof IconGlobeFilled;
declare const index_IconGlobeOff: typeof IconGlobeOff;
declare const index_IconGoGame: typeof IconGoGame;
declare const index_IconGolf: typeof IconGolf;
declare const index_IconGolfFilled: typeof IconGolfFilled;
declare const index_IconGolfOff: typeof IconGolfOff;
declare const index_IconGps: typeof IconGps;
declare const index_IconGpsFilled: typeof IconGpsFilled;
declare const index_IconGradienter: typeof IconGradienter;
declare const index_IconGrain: typeof IconGrain;
declare const index_IconGraph: typeof IconGraph;
declare const index_IconGraphFilled: typeof IconGraphFilled;
declare const index_IconGraphOff: typeof IconGraphOff;
declare const index_IconGrave: typeof IconGrave;
declare const index_IconGrave2: typeof IconGrave2;
declare const index_IconGrid3x3: typeof IconGrid3x3;
declare const index_IconGrid4x4: typeof IconGrid4x4;
declare const index_IconGridDots: typeof IconGridDots;
declare const index_IconGridGoldenratio: typeof IconGridGoldenratio;
declare const index_IconGridPattern: typeof IconGridPattern;
declare const index_IconGridPatternFilled: typeof IconGridPatternFilled;
declare const index_IconGridScan: typeof IconGridScan;
declare const index_IconGrill: typeof IconGrill;
declare const index_IconGrillFork: typeof IconGrillFork;
declare const index_IconGrillOff: typeof IconGrillOff;
declare const index_IconGrillSpatula: typeof IconGrillSpatula;
declare const index_IconGripHorizontal: typeof IconGripHorizontal;
declare const index_IconGripVertical: typeof IconGripVertical;
declare const index_IconGrowth: typeof IconGrowth;
declare const index_IconGuitarPick: typeof IconGuitarPick;
declare const index_IconGuitarPickFilled: typeof IconGuitarPickFilled;
declare const index_IconGymnastics: typeof IconGymnastics;
declare const index_IconH1: typeof IconH1;
declare const index_IconH2: typeof IconH2;
declare const index_IconH3: typeof IconH3;
declare const index_IconH4: typeof IconH4;
declare const index_IconH5: typeof IconH5;
declare const index_IconH6: typeof IconH6;
declare const index_IconHammer: typeof IconHammer;
declare const index_IconHammerOff: typeof IconHammerOff;
declare const index_IconHandClick: typeof IconHandClick;
declare const index_IconHandClickOff: typeof IconHandClickOff;
declare const index_IconHandFinger: typeof IconHandFinger;
declare const index_IconHandFingerDown: typeof IconHandFingerDown;
declare const index_IconHandFingerLeft: typeof IconHandFingerLeft;
declare const index_IconHandFingerOff: typeof IconHandFingerOff;
declare const index_IconHandFingerRight: typeof IconHandFingerRight;
declare const index_IconHandGrab: typeof IconHandGrab;
declare const index_IconHandLittleFinger: typeof IconHandLittleFinger;
declare const index_IconHandLoveYou: typeof IconHandLoveYou;
declare const index_IconHandMiddleFinger: typeof IconHandMiddleFinger;
declare const index_IconHandMove: typeof IconHandMove;
declare const index_IconHandOff: typeof IconHandOff;
declare const index_IconHandRingFinger: typeof IconHandRingFinger;
declare const index_IconHandSanitizer: typeof IconHandSanitizer;
declare const index_IconHandStop: typeof IconHandStop;
declare const index_IconHandThreeFingers: typeof IconHandThreeFingers;
declare const index_IconHandTwoFingers: typeof IconHandTwoFingers;
declare const index_IconHanger: typeof IconHanger;
declare const index_IconHanger2: typeof IconHanger2;
declare const index_IconHanger2Filled: typeof IconHanger2Filled;
declare const index_IconHangerOff: typeof IconHangerOff;
declare const index_IconHash: typeof IconHash;
declare const index_IconHaze: typeof IconHaze;
declare const index_IconHazeMoon: typeof IconHazeMoon;
declare const index_IconHdr: typeof IconHdr;
declare const index_IconHeading: typeof IconHeading;
declare const index_IconHeadingOff: typeof IconHeadingOff;
declare const index_IconHeadphones: typeof IconHeadphones;
declare const index_IconHeadphonesFilled: typeof IconHeadphonesFilled;
declare const index_IconHeadphonesOff: typeof IconHeadphonesOff;
declare const index_IconHeadset: typeof IconHeadset;
declare const index_IconHeadsetOff: typeof IconHeadsetOff;
declare const index_IconHealthRecognition: typeof IconHealthRecognition;
declare const index_IconHeart: typeof IconHeart;
declare const index_IconHeartBitcoin: typeof IconHeartBitcoin;
declare const index_IconHeartBolt: typeof IconHeartBolt;
declare const index_IconHeartBroken: typeof IconHeartBroken;
declare const index_IconHeartBrokenFilled: typeof IconHeartBrokenFilled;
declare const index_IconHeartCancel: typeof IconHeartCancel;
declare const index_IconHeartCheck: typeof IconHeartCheck;
declare const index_IconHeartCode: typeof IconHeartCode;
declare const index_IconHeartCog: typeof IconHeartCog;
declare const index_IconHeartDiscount: typeof IconHeartDiscount;
declare const index_IconHeartDollar: typeof IconHeartDollar;
declare const index_IconHeartDown: typeof IconHeartDown;
declare const index_IconHeartExclamation: typeof IconHeartExclamation;
declare const index_IconHeartFilled: typeof IconHeartFilled;
declare const index_IconHeartHandshake: typeof IconHeartHandshake;
declare const index_IconHeartMinus: typeof IconHeartMinus;
declare const index_IconHeartOff: typeof IconHeartOff;
declare const index_IconHeartPause: typeof IconHeartPause;
declare const index_IconHeartPin: typeof IconHeartPin;
declare const index_IconHeartPlus: typeof IconHeartPlus;
declare const index_IconHeartQuestion: typeof IconHeartQuestion;
declare const index_IconHeartRateMonitor: typeof IconHeartRateMonitor;
declare const index_IconHeartSearch: typeof IconHeartSearch;
declare const index_IconHeartShare: typeof IconHeartShare;
declare const index_IconHeartSpark: typeof IconHeartSpark;
declare const index_IconHeartStar: typeof IconHeartStar;
declare const index_IconHeartUp: typeof IconHeartUp;
declare const index_IconHeartX: typeof IconHeartX;
declare const index_IconHeartbeat: typeof IconHeartbeat;
declare const index_IconHearts: typeof IconHearts;
declare const index_IconHeartsOff: typeof IconHeartsOff;
declare const index_IconHelicopter: typeof IconHelicopter;
declare const index_IconHelicopterFilled: typeof IconHelicopterFilled;
declare const index_IconHelicopterLanding: typeof IconHelicopterLanding;
declare const index_IconHelicopterLandingFilled: typeof IconHelicopterLandingFilled;
declare const index_IconHelmet: typeof IconHelmet;
declare const index_IconHelmetOff: typeof IconHelmetOff;
declare const index_IconHelp: typeof IconHelp;
declare const index_IconHelpCircle: typeof IconHelpCircle;
declare const index_IconHelpCircleFilled: typeof IconHelpCircleFilled;
declare const index_IconHelpHexagon: typeof IconHelpHexagon;
declare const index_IconHelpHexagonFilled: typeof IconHelpHexagonFilled;
declare const index_IconHelpOctagon: typeof IconHelpOctagon;
declare const index_IconHelpOctagonFilled: typeof IconHelpOctagonFilled;
declare const index_IconHelpOff: typeof IconHelpOff;
declare const index_IconHelpSmall: typeof IconHelpSmall;
declare const index_IconHelpSquare: typeof IconHelpSquare;
declare const index_IconHelpSquareFilled: typeof IconHelpSquareFilled;
declare const index_IconHelpSquareRounded: typeof IconHelpSquareRounded;
declare const index_IconHelpSquareRoundedFilled: typeof IconHelpSquareRoundedFilled;
declare const index_IconHelpTriangle: typeof IconHelpTriangle;
declare const index_IconHelpTriangleFilled: typeof IconHelpTriangleFilled;
declare const index_IconHemisphere: typeof IconHemisphere;
declare const index_IconHemisphereOff: typeof IconHemisphereOff;
declare const index_IconHemispherePlus: typeof IconHemispherePlus;
declare const index_IconHexagon: typeof IconHexagon;
declare const index_IconHexagon3d: typeof IconHexagon3d;
declare const index_IconHexagonAsterisk: typeof IconHexagonAsterisk;
declare const index_IconHexagonFilled: typeof IconHexagonFilled;
declare const index_IconHexagonLetterA: typeof IconHexagonLetterA;
declare const index_IconHexagonLetterAFilled: typeof IconHexagonLetterAFilled;
declare const index_IconHexagonLetterB: typeof IconHexagonLetterB;
declare const index_IconHexagonLetterBFilled: typeof IconHexagonLetterBFilled;
declare const index_IconHexagonLetterC: typeof IconHexagonLetterC;
declare const index_IconHexagonLetterCFilled: typeof IconHexagonLetterCFilled;
declare const index_IconHexagonLetterD: typeof IconHexagonLetterD;
declare const index_IconHexagonLetterDFilled: typeof IconHexagonLetterDFilled;
declare const index_IconHexagonLetterE: typeof IconHexagonLetterE;
declare const index_IconHexagonLetterEFilled: typeof IconHexagonLetterEFilled;
declare const index_IconHexagonLetterF: typeof IconHexagonLetterF;
declare const index_IconHexagonLetterFFilled: typeof IconHexagonLetterFFilled;
declare const index_IconHexagonLetterG: typeof IconHexagonLetterG;
declare const index_IconHexagonLetterGFilled: typeof IconHexagonLetterGFilled;
declare const index_IconHexagonLetterH: typeof IconHexagonLetterH;
declare const index_IconHexagonLetterHFilled: typeof IconHexagonLetterHFilled;
declare const index_IconHexagonLetterI: typeof IconHexagonLetterI;
declare const index_IconHexagonLetterIFilled: typeof IconHexagonLetterIFilled;
declare const index_IconHexagonLetterJ: typeof IconHexagonLetterJ;
declare const index_IconHexagonLetterJFilled: typeof IconHexagonLetterJFilled;
declare const index_IconHexagonLetterK: typeof IconHexagonLetterK;
declare const index_IconHexagonLetterKFilled: typeof IconHexagonLetterKFilled;
declare const index_IconHexagonLetterL: typeof IconHexagonLetterL;
declare const index_IconHexagonLetterLFilled: typeof IconHexagonLetterLFilled;
declare const index_IconHexagonLetterM: typeof IconHexagonLetterM;
declare const index_IconHexagonLetterMFilled: typeof IconHexagonLetterMFilled;
declare const index_IconHexagonLetterN: typeof IconHexagonLetterN;
declare const index_IconHexagonLetterNFilled: typeof IconHexagonLetterNFilled;
declare const index_IconHexagonLetterO: typeof IconHexagonLetterO;
declare const index_IconHexagonLetterOFilled: typeof IconHexagonLetterOFilled;
declare const index_IconHexagonLetterP: typeof IconHexagonLetterP;
declare const index_IconHexagonLetterPFilled: typeof IconHexagonLetterPFilled;
declare const index_IconHexagonLetterQ: typeof IconHexagonLetterQ;
declare const index_IconHexagonLetterQFilled: typeof IconHexagonLetterQFilled;
declare const index_IconHexagonLetterR: typeof IconHexagonLetterR;
declare const index_IconHexagonLetterRFilled: typeof IconHexagonLetterRFilled;
declare const index_IconHexagonLetterS: typeof IconHexagonLetterS;
declare const index_IconHexagonLetterSFilled: typeof IconHexagonLetterSFilled;
declare const index_IconHexagonLetterT: typeof IconHexagonLetterT;
declare const index_IconHexagonLetterTFilled: typeof IconHexagonLetterTFilled;
declare const index_IconHexagonLetterU: typeof IconHexagonLetterU;
declare const index_IconHexagonLetterUFilled: typeof IconHexagonLetterUFilled;
declare const index_IconHexagonLetterV: typeof IconHexagonLetterV;
declare const index_IconHexagonLetterVFilled: typeof IconHexagonLetterVFilled;
declare const index_IconHexagonLetterW: typeof IconHexagonLetterW;
declare const index_IconHexagonLetterWFilled: typeof IconHexagonLetterWFilled;
declare const index_IconHexagonLetterX: typeof IconHexagonLetterX;
declare const index_IconHexagonLetterXFilled: typeof IconHexagonLetterXFilled;
declare const index_IconHexagonLetterY: typeof IconHexagonLetterY;
declare const index_IconHexagonLetterYFilled: typeof IconHexagonLetterYFilled;
declare const index_IconHexagonLetterZ: typeof IconHexagonLetterZ;
declare const index_IconHexagonLetterZFilled: typeof IconHexagonLetterZFilled;
declare const index_IconHexagonMinus: typeof IconHexagonMinus;
declare const index_IconHexagonMinus2: typeof IconHexagonMinus2;
declare const index_IconHexagonMinusFilled: typeof IconHexagonMinusFilled;
declare const index_IconHexagonNumber0: typeof IconHexagonNumber0;
declare const index_IconHexagonNumber0Filled: typeof IconHexagonNumber0Filled;
declare const index_IconHexagonNumber1: typeof IconHexagonNumber1;
declare const index_IconHexagonNumber1Filled: typeof IconHexagonNumber1Filled;
declare const index_IconHexagonNumber2: typeof IconHexagonNumber2;
declare const index_IconHexagonNumber2Filled: typeof IconHexagonNumber2Filled;
declare const index_IconHexagonNumber3: typeof IconHexagonNumber3;
declare const index_IconHexagonNumber3Filled: typeof IconHexagonNumber3Filled;
declare const index_IconHexagonNumber4: typeof IconHexagonNumber4;
declare const index_IconHexagonNumber4Filled: typeof IconHexagonNumber4Filled;
declare const index_IconHexagonNumber5: typeof IconHexagonNumber5;
declare const index_IconHexagonNumber5Filled: typeof IconHexagonNumber5Filled;
declare const index_IconHexagonNumber6: typeof IconHexagonNumber6;
declare const index_IconHexagonNumber6Filled: typeof IconHexagonNumber6Filled;
declare const index_IconHexagonNumber7: typeof IconHexagonNumber7;
declare const index_IconHexagonNumber7Filled: typeof IconHexagonNumber7Filled;
declare const index_IconHexagonNumber8: typeof IconHexagonNumber8;
declare const index_IconHexagonNumber8Filled: typeof IconHexagonNumber8Filled;
declare const index_IconHexagonNumber9: typeof IconHexagonNumber9;
declare const index_IconHexagonNumber9Filled: typeof IconHexagonNumber9Filled;
declare const index_IconHexagonOff: typeof IconHexagonOff;
declare const index_IconHexagonPlus: typeof IconHexagonPlus;
declare const index_IconHexagonPlus2: typeof IconHexagonPlus2;
declare const index_IconHexagonPlusFilled: typeof IconHexagonPlusFilled;
declare const index_IconHexagonalPrism: typeof IconHexagonalPrism;
declare const index_IconHexagonalPrismOff: typeof IconHexagonalPrismOff;
declare const index_IconHexagonalPrismPlus: typeof IconHexagonalPrismPlus;
declare const index_IconHexagonalPyramid: typeof IconHexagonalPyramid;
declare const index_IconHexagonalPyramidOff: typeof IconHexagonalPyramidOff;
declare const index_IconHexagonalPyramidPlus: typeof IconHexagonalPyramidPlus;
declare const index_IconHexagons: typeof IconHexagons;
declare const index_IconHexagonsOff: typeof IconHexagonsOff;
declare const index_IconHierarchy: typeof IconHierarchy;
declare const index_IconHierarchy2: typeof IconHierarchy2;
declare const index_IconHierarchy3: typeof IconHierarchy3;
declare const index_IconHierarchyOff: typeof IconHierarchyOff;
declare const index_IconHighlight: typeof IconHighlight;
declare const index_IconHighlightOff: typeof IconHighlightOff;
declare const index_IconHistory: typeof IconHistory;
declare const index_IconHistoryOff: typeof IconHistoryOff;
declare const index_IconHistoryToggle: typeof IconHistoryToggle;
declare const index_IconHome: typeof IconHome;
declare const index_IconHome2: typeof IconHome2;
declare const index_IconHomeBitcoin: typeof IconHomeBitcoin;
declare const index_IconHomeBolt: typeof IconHomeBolt;
declare const index_IconHomeCancel: typeof IconHomeCancel;
declare const index_IconHomeCheck: typeof IconHomeCheck;
declare const index_IconHomeCog: typeof IconHomeCog;
declare const index_IconHomeDollar: typeof IconHomeDollar;
declare const index_IconHomeDot: typeof IconHomeDot;
declare const index_IconHomeDown: typeof IconHomeDown;
declare const index_IconHomeEco: typeof IconHomeEco;
declare const index_IconHomeEdit: typeof IconHomeEdit;
declare const index_IconHomeExclamation: typeof IconHomeExclamation;
declare const index_IconHomeFilled: typeof IconHomeFilled;
declare const index_IconHomeHand: typeof IconHomeHand;
declare const index_IconHomeHeart: typeof IconHomeHeart;
declare const index_IconHomeInfinity: typeof IconHomeInfinity;
declare const index_IconHomeLink: typeof IconHomeLink;
declare const index_IconHomeMinus: typeof IconHomeMinus;
declare const index_IconHomeMove: typeof IconHomeMove;
declare const index_IconHomeOff: typeof IconHomeOff;
declare const index_IconHomePlus: typeof IconHomePlus;
declare const index_IconHomeQuestion: typeof IconHomeQuestion;
declare const index_IconHomeRibbon: typeof IconHomeRibbon;
declare const index_IconHomeSearch: typeof IconHomeSearch;
declare const index_IconHomeShare: typeof IconHomeShare;
declare const index_IconHomeShield: typeof IconHomeShield;
declare const index_IconHomeSignal: typeof IconHomeSignal;
declare const index_IconHomeSpark: typeof IconHomeSpark;
declare const index_IconHomeStar: typeof IconHomeStar;
declare const index_IconHomeStats: typeof IconHomeStats;
declare const index_IconHomeUp: typeof IconHomeUp;
declare const index_IconHomeX: typeof IconHomeX;
declare const index_IconHorse: typeof IconHorse;
declare const index_IconHorseToy: typeof IconHorseToy;
declare const index_IconHorseshoe: typeof IconHorseshoe;
declare const index_IconHospital: typeof IconHospital;
declare const index_IconHospitalCircle: typeof IconHospitalCircle;
declare const index_IconHospitalCircleFilled: typeof IconHospitalCircleFilled;
declare const index_IconHotelService: typeof IconHotelService;
declare const index_IconHourglass: typeof IconHourglass;
declare const index_IconHourglassEmpty: typeof IconHourglassEmpty;
declare const index_IconHourglassFilled: typeof IconHourglassFilled;
declare const index_IconHourglassHigh: typeof IconHourglassHigh;
declare const index_IconHourglassLow: typeof IconHourglassLow;
declare const index_IconHourglassOff: typeof IconHourglassOff;
declare const index_IconHours12: typeof IconHours12;
declare const index_IconHours24: typeof IconHours24;
declare const index_IconHtml: typeof IconHtml;
declare const index_IconHttpConnect: typeof IconHttpConnect;
declare const index_IconHttpConnectOff: typeof IconHttpConnectOff;
declare const index_IconHttpDelete: typeof IconHttpDelete;
declare const index_IconHttpDeleteOff: typeof IconHttpDeleteOff;
declare const index_IconHttpGet: typeof IconHttpGet;
declare const index_IconHttpGetOff: typeof IconHttpGetOff;
declare const index_IconHttpHead: typeof IconHttpHead;
declare const index_IconHttpHeadOff: typeof IconHttpHeadOff;
declare const index_IconHttpOptions: typeof IconHttpOptions;
declare const index_IconHttpOptionsOff: typeof IconHttpOptionsOff;
declare const index_IconHttpPatch: typeof IconHttpPatch;
declare const index_IconHttpPatchOff: typeof IconHttpPatchOff;
declare const index_IconHttpPost: typeof IconHttpPost;
declare const index_IconHttpPostOff: typeof IconHttpPostOff;
declare const index_IconHttpPut: typeof IconHttpPut;
declare const index_IconHttpPutOff: typeof IconHttpPutOff;
declare const index_IconHttpQue: typeof IconHttpQue;
declare const index_IconHttpQueOff: typeof IconHttpQueOff;
declare const index_IconHttpTrace: typeof IconHttpTrace;
declare const index_IconHttpTraceOff: typeof IconHttpTraceOff;
declare const index_IconIceCream: typeof IconIceCream;
declare const index_IconIceCream2: typeof IconIceCream2;
declare const index_IconIceCreamOff: typeof IconIceCreamOff;
declare const index_IconIceSkating: typeof IconIceSkating;
declare const index_IconIcons: typeof IconIcons;
declare const index_IconIconsFilled: typeof IconIconsFilled;
declare const index_IconIconsOff: typeof IconIconsOff;
declare const index_IconId: typeof IconId;
declare const index_IconIdBadge: typeof IconIdBadge;
declare const index_IconIdBadge2: typeof IconIdBadge2;
declare const index_IconIdBadgeOff: typeof IconIdBadgeOff;
declare const index_IconIdOff: typeof IconIdOff;
declare const index_IconIkosaedr: typeof IconIkosaedr;
declare const index_IconImageInPicture: typeof IconImageInPicture;
declare const index_IconInbox: typeof IconInbox;
declare const index_IconInboxOff: typeof IconInboxOff;
declare const index_IconIndentDecrease: typeof IconIndentDecrease;
declare const index_IconIndentIncrease: typeof IconIndentIncrease;
declare const index_IconInfinity: typeof IconInfinity;
declare const index_IconInfinityOff: typeof IconInfinityOff;
declare const index_IconInfoCircle: typeof IconInfoCircle;
declare const index_IconInfoCircleFilled: typeof IconInfoCircleFilled;
declare const index_IconInfoHexagon: typeof IconInfoHexagon;
declare const index_IconInfoHexagonFilled: typeof IconInfoHexagonFilled;
declare const index_IconInfoOctagon: typeof IconInfoOctagon;
declare const index_IconInfoOctagonFilled: typeof IconInfoOctagonFilled;
declare const index_IconInfoSmall: typeof IconInfoSmall;
declare const index_IconInfoSquare: typeof IconInfoSquare;
declare const index_IconInfoSquareFilled: typeof IconInfoSquareFilled;
declare const index_IconInfoSquareRounded: typeof IconInfoSquareRounded;
declare const index_IconInfoSquareRoundedFilled: typeof IconInfoSquareRoundedFilled;
declare const index_IconInfoTriangle: typeof IconInfoTriangle;
declare const index_IconInfoTriangleFilled: typeof IconInfoTriangleFilled;
declare const index_IconInnerShadowBottom: typeof IconInnerShadowBottom;
declare const index_IconInnerShadowBottomFilled: typeof IconInnerShadowBottomFilled;
declare const index_IconInnerShadowBottomLeft: typeof IconInnerShadowBottomLeft;
declare const index_IconInnerShadowBottomLeftFilled: typeof IconInnerShadowBottomLeftFilled;
declare const index_IconInnerShadowBottomRight: typeof IconInnerShadowBottomRight;
declare const index_IconInnerShadowBottomRightFilled: typeof IconInnerShadowBottomRightFilled;
declare const index_IconInnerShadowLeft: typeof IconInnerShadowLeft;
declare const index_IconInnerShadowLeftFilled: typeof IconInnerShadowLeftFilled;
declare const index_IconInnerShadowRight: typeof IconInnerShadowRight;
declare const index_IconInnerShadowRightFilled: typeof IconInnerShadowRightFilled;
declare const index_IconInnerShadowTop: typeof IconInnerShadowTop;
declare const index_IconInnerShadowTopFilled: typeof IconInnerShadowTopFilled;
declare const index_IconInnerShadowTopLeft: typeof IconInnerShadowTopLeft;
declare const index_IconInnerShadowTopLeftFilled: typeof IconInnerShadowTopLeftFilled;
declare const index_IconInnerShadowTopRight: typeof IconInnerShadowTopRight;
declare const index_IconInnerShadowTopRightFilled: typeof IconInnerShadowTopRightFilled;
declare const index_IconInputAi: typeof IconInputAi;
declare const index_IconInputCheck: typeof IconInputCheck;
declare const index_IconInputSearch: typeof IconInputSearch;
declare const index_IconInputSpark: typeof IconInputSpark;
declare const index_IconInputX: typeof IconInputX;
declare const index_IconInvoice: typeof IconInvoice;
declare const index_IconIroning: typeof IconIroning;
declare const index_IconIroning1: typeof IconIroning1;
declare const index_IconIroning1Filled: typeof IconIroning1Filled;
declare const index_IconIroning2: typeof IconIroning2;
declare const index_IconIroning2Filled: typeof IconIroning2Filled;
declare const index_IconIroning3: typeof IconIroning3;
declare const index_IconIroning3Filled: typeof IconIroning3Filled;
declare const index_IconIroningFilled: typeof IconIroningFilled;
declare const index_IconIroningOff: typeof IconIroningOff;
declare const index_IconIroningSteam: typeof IconIroningSteam;
declare const index_IconIroningSteamFilled: typeof IconIroningSteamFilled;
declare const index_IconIroningSteamOff: typeof IconIroningSteamOff;
declare const index_IconIrregularPolyhedron: typeof IconIrregularPolyhedron;
declare const index_IconIrregularPolyhedronOff: typeof IconIrregularPolyhedronOff;
declare const index_IconIrregularPolyhedronPlus: typeof IconIrregularPolyhedronPlus;
declare const index_IconItalic: typeof IconItalic;
declare const index_IconJacket: typeof IconJacket;
declare const index_IconJetpack: typeof IconJetpack;
declare const index_IconJetpackFilled: typeof IconJetpackFilled;
declare const index_IconJewishStar: typeof IconJewishStar;
declare const index_IconJewishStarFilled: typeof IconJewishStarFilled;
declare const index_IconJoinBevel: typeof IconJoinBevel;
declare const index_IconJoinRound: typeof IconJoinRound;
declare const index_IconJoinStraight: typeof IconJoinStraight;
declare const index_IconJoker: typeof IconJoker;
declare const index_IconJpg: typeof IconJpg;
declare const index_IconJson: typeof IconJson;
declare const index_IconJumpRope: typeof IconJumpRope;
declare const index_IconKarate: typeof IconKarate;
declare const index_IconKayak: typeof IconKayak;
declare const index_IconKerning: typeof IconKerning;
declare const index_IconKey: typeof IconKey;
declare const index_IconKeyFilled: typeof IconKeyFilled;
declare const index_IconKeyOff: typeof IconKeyOff;
declare const index_IconKeyboard: typeof IconKeyboard;
declare const index_IconKeyboardFilled: typeof IconKeyboardFilled;
declare const index_IconKeyboardHide: typeof IconKeyboardHide;
declare const index_IconKeyboardOff: typeof IconKeyboardOff;
declare const index_IconKeyboardShow: typeof IconKeyboardShow;
declare const index_IconKeyframe: typeof IconKeyframe;
declare const index_IconKeyframeAlignCenter: typeof IconKeyframeAlignCenter;
declare const index_IconKeyframeAlignCenterFilled: typeof IconKeyframeAlignCenterFilled;
declare const index_IconKeyframeAlignHorizontal: typeof IconKeyframeAlignHorizontal;
declare const index_IconKeyframeAlignHorizontalFilled: typeof IconKeyframeAlignHorizontalFilled;
declare const index_IconKeyframeAlignVertical: typeof IconKeyframeAlignVertical;
declare const index_IconKeyframeAlignVerticalFilled: typeof IconKeyframeAlignVerticalFilled;
declare const index_IconKeyframeFilled: typeof IconKeyframeFilled;
declare const index_IconKeyframes: typeof IconKeyframes;
declare const index_IconKeyframesFilled: typeof IconKeyframesFilled;
declare const index_IconLabel: typeof IconLabel;
declare const index_IconLabelFilled: typeof IconLabelFilled;
declare const index_IconLabelImportant: typeof IconLabelImportant;
declare const index_IconLabelImportantFilled: typeof IconLabelImportantFilled;
declare const index_IconLabelOff: typeof IconLabelOff;
declare const index_IconLadder: typeof IconLadder;
declare const index_IconLadderOff: typeof IconLadderOff;
declare const index_IconLadle: typeof IconLadle;
declare const index_IconLambda: typeof IconLambda;
declare const index_IconLamp: typeof IconLamp;
declare const index_IconLamp2: typeof IconLamp2;
declare const index_IconLampOff: typeof IconLampOff;
declare const index_IconLane: typeof IconLane;
declare const index_IconLanguage: typeof IconLanguage;
declare const index_IconLanguageHiragana: typeof IconLanguageHiragana;
declare const index_IconLanguageKatakana: typeof IconLanguageKatakana;
declare const index_IconLanguageOff: typeof IconLanguageOff;
declare const index_IconLasso: typeof IconLasso;
declare const index_IconLassoOff: typeof IconLassoOff;
declare const index_IconLassoPolygon: typeof IconLassoPolygon;
declare const index_IconLassoPolygonFilled: typeof IconLassoPolygonFilled;
declare const index_IconLaurelWreath: typeof IconLaurelWreath;
declare const index_IconLaurelWreath1: typeof IconLaurelWreath1;
declare const index_IconLaurelWreath1Filled: typeof IconLaurelWreath1Filled;
declare const index_IconLaurelWreath2: typeof IconLaurelWreath2;
declare const index_IconLaurelWreath2Filled: typeof IconLaurelWreath2Filled;
declare const index_IconLaurelWreath3: typeof IconLaurelWreath3;
declare const index_IconLaurelWreath3Filled: typeof IconLaurelWreath3Filled;
declare const index_IconLaurelWreathFilled: typeof IconLaurelWreathFilled;
declare const index_IconLayersDifference: typeof IconLayersDifference;
declare const index_IconLayersIntersect: typeof IconLayersIntersect;
declare const index_IconLayersIntersect2: typeof IconLayersIntersect2;
declare const index_IconLayersLinked: typeof IconLayersLinked;
declare const index_IconLayersOff: typeof IconLayersOff;
declare const index_IconLayersSelected: typeof IconLayersSelected;
declare const index_IconLayersSelectedBottom: typeof IconLayersSelectedBottom;
declare const index_IconLayersSubtract: typeof IconLayersSubtract;
declare const index_IconLayersUnion: typeof IconLayersUnion;
declare const index_IconLayout: typeof IconLayout;
declare const index_IconLayout2: typeof IconLayout2;
declare const index_IconLayout2Filled: typeof IconLayout2Filled;
declare const index_IconLayoutAlignBottom: typeof IconLayoutAlignBottom;
declare const index_IconLayoutAlignBottomFilled: typeof IconLayoutAlignBottomFilled;
declare const index_IconLayoutAlignCenter: typeof IconLayoutAlignCenter;
declare const index_IconLayoutAlignCenterFilled: typeof IconLayoutAlignCenterFilled;
declare const index_IconLayoutAlignLeft: typeof IconLayoutAlignLeft;
declare const index_IconLayoutAlignLeftFilled: typeof IconLayoutAlignLeftFilled;
declare const index_IconLayoutAlignMiddle: typeof IconLayoutAlignMiddle;
declare const index_IconLayoutAlignMiddleFilled: typeof IconLayoutAlignMiddleFilled;
declare const index_IconLayoutAlignRight: typeof IconLayoutAlignRight;
declare const index_IconLayoutAlignRightFilled: typeof IconLayoutAlignRightFilled;
declare const index_IconLayoutAlignTop: typeof IconLayoutAlignTop;
declare const index_IconLayoutAlignTopFilled: typeof IconLayoutAlignTopFilled;
declare const index_IconLayoutBoard: typeof IconLayoutBoard;
declare const index_IconLayoutBoardFilled: typeof IconLayoutBoardFilled;
declare const index_IconLayoutBoardSplit: typeof IconLayoutBoardSplit;
declare const index_IconLayoutBoardSplitFilled: typeof IconLayoutBoardSplitFilled;
declare const index_IconLayoutBottombar: typeof IconLayoutBottombar;
declare const index_IconLayoutBottombarCollapse: typeof IconLayoutBottombarCollapse;
declare const index_IconLayoutBottombarCollapseFilled: typeof IconLayoutBottombarCollapseFilled;
declare const index_IconLayoutBottombarExpand: typeof IconLayoutBottombarExpand;
declare const index_IconLayoutBottombarExpandFilled: typeof IconLayoutBottombarExpandFilled;
declare const index_IconLayoutBottombarFilled: typeof IconLayoutBottombarFilled;
declare const index_IconLayoutBottombarInactive: typeof IconLayoutBottombarInactive;
declare const index_IconLayoutCards: typeof IconLayoutCards;
declare const index_IconLayoutCardsFilled: typeof IconLayoutCardsFilled;
declare const index_IconLayoutCollage: typeof IconLayoutCollage;
declare const index_IconLayoutColumns: typeof IconLayoutColumns;
declare const index_IconLayoutDashboard: typeof IconLayoutDashboard;
declare const index_IconLayoutDashboardFilled: typeof IconLayoutDashboardFilled;
declare const index_IconLayoutDistributeHorizontal: typeof IconLayoutDistributeHorizontal;
declare const index_IconLayoutDistributeHorizontalFilled: typeof IconLayoutDistributeHorizontalFilled;
declare const index_IconLayoutDistributeVertical: typeof IconLayoutDistributeVertical;
declare const index_IconLayoutDistributeVerticalFilled: typeof IconLayoutDistributeVerticalFilled;
declare const index_IconLayoutFilled: typeof IconLayoutFilled;
declare const index_IconLayoutGrid: typeof IconLayoutGrid;
declare const index_IconLayoutGridAdd: typeof IconLayoutGridAdd;
declare const index_IconLayoutGridFilled: typeof IconLayoutGridFilled;
declare const index_IconLayoutGridRemove: typeof IconLayoutGridRemove;
declare const index_IconLayoutKanban: typeof IconLayoutKanban;
declare const index_IconLayoutKanbanFilled: typeof IconLayoutKanbanFilled;
declare const index_IconLayoutList: typeof IconLayoutList;
declare const index_IconLayoutListFilled: typeof IconLayoutListFilled;
declare const index_IconLayoutNavbar: typeof IconLayoutNavbar;
declare const index_IconLayoutNavbarCollapse: typeof IconLayoutNavbarCollapse;
declare const index_IconLayoutNavbarCollapseFilled: typeof IconLayoutNavbarCollapseFilled;
declare const index_IconLayoutNavbarExpand: typeof IconLayoutNavbarExpand;
declare const index_IconLayoutNavbarExpandFilled: typeof IconLayoutNavbarExpandFilled;
declare const index_IconLayoutNavbarFilled: typeof IconLayoutNavbarFilled;
declare const index_IconLayoutNavbarInactive: typeof IconLayoutNavbarInactive;
declare const index_IconLayoutOff: typeof IconLayoutOff;
declare const index_IconLayoutRows: typeof IconLayoutRows;
declare const index_IconLayoutSidebar: typeof IconLayoutSidebar;
declare const index_IconLayoutSidebarFilled: typeof IconLayoutSidebarFilled;
declare const index_IconLayoutSidebarInactive: typeof IconLayoutSidebarInactive;
declare const index_IconLayoutSidebarLeftCollapse: typeof IconLayoutSidebarLeftCollapse;
declare const index_IconLayoutSidebarLeftCollapseFilled: typeof IconLayoutSidebarLeftCollapseFilled;
declare const index_IconLayoutSidebarLeftExpand: typeof IconLayoutSidebarLeftExpand;
declare const index_IconLayoutSidebarLeftExpandFilled: typeof IconLayoutSidebarLeftExpandFilled;
declare const index_IconLayoutSidebarRight: typeof IconLayoutSidebarRight;
declare const index_IconLayoutSidebarRightCollapse: typeof IconLayoutSidebarRightCollapse;
declare const index_IconLayoutSidebarRightCollapseFilled: typeof IconLayoutSidebarRightCollapseFilled;
declare const index_IconLayoutSidebarRightExpand: typeof IconLayoutSidebarRightExpand;
declare const index_IconLayoutSidebarRightExpandFilled: typeof IconLayoutSidebarRightExpandFilled;
declare const index_IconLayoutSidebarRightFilled: typeof IconLayoutSidebarRightFilled;
declare const index_IconLayoutSidebarRightInactive: typeof IconLayoutSidebarRightInactive;
declare const index_IconLeaf: typeof IconLeaf;
declare const index_IconLeaf2: typeof IconLeaf2;
declare const index_IconLeafFilled: typeof IconLeafFilled;
declare const index_IconLeafOff: typeof IconLeafOff;
declare const index_IconLego: typeof IconLego;
declare const index_IconLegoFilled: typeof IconLegoFilled;
declare const index_IconLegoOff: typeof IconLegoOff;
declare const index_IconLemon: typeof IconLemon;
declare const index_IconLemon2: typeof IconLemon2;
declare const index_IconLemon2Filled: typeof IconLemon2Filled;
declare const index_IconLetterA: typeof IconLetterA;
declare const index_IconLetterASmall: typeof IconLetterASmall;
declare const index_IconLetterB: typeof IconLetterB;
declare const index_IconLetterBSmall: typeof IconLetterBSmall;
declare const index_IconLetterC: typeof IconLetterC;
declare const index_IconLetterCSmall: typeof IconLetterCSmall;
declare const index_IconLetterCase: typeof IconLetterCase;
declare const index_IconLetterCaseLower: typeof IconLetterCaseLower;
declare const index_IconLetterCaseToggle: typeof IconLetterCaseToggle;
declare const index_IconLetterCaseUpper: typeof IconLetterCaseUpper;
declare const index_IconLetterD: typeof IconLetterD;
declare const index_IconLetterDSmall: typeof IconLetterDSmall;
declare const index_IconLetterE: typeof IconLetterE;
declare const index_IconLetterESmall: typeof IconLetterESmall;
declare const index_IconLetterF: typeof IconLetterF;
declare const index_IconLetterFSmall: typeof IconLetterFSmall;
declare const index_IconLetterG: typeof IconLetterG;
declare const index_IconLetterGSmall: typeof IconLetterGSmall;
declare const index_IconLetterH: typeof IconLetterH;
declare const index_IconLetterHSmall: typeof IconLetterHSmall;
declare const index_IconLetterI: typeof IconLetterI;
declare const index_IconLetterISmall: typeof IconLetterISmall;
declare const index_IconLetterJ: typeof IconLetterJ;
declare const index_IconLetterJSmall: typeof IconLetterJSmall;
declare const index_IconLetterK: typeof IconLetterK;
declare const index_IconLetterKSmall: typeof IconLetterKSmall;
declare const index_IconLetterL: typeof IconLetterL;
declare const index_IconLetterLSmall: typeof IconLetterLSmall;
declare const index_IconLetterM: typeof IconLetterM;
declare const index_IconLetterMSmall: typeof IconLetterMSmall;
declare const index_IconLetterN: typeof IconLetterN;
declare const index_IconLetterNSmall: typeof IconLetterNSmall;
declare const index_IconLetterO: typeof IconLetterO;
declare const index_IconLetterOSmall: typeof IconLetterOSmall;
declare const index_IconLetterP: typeof IconLetterP;
declare const index_IconLetterPSmall: typeof IconLetterPSmall;
declare const index_IconLetterQ: typeof IconLetterQ;
declare const index_IconLetterQSmall: typeof IconLetterQSmall;
declare const index_IconLetterR: typeof IconLetterR;
declare const index_IconLetterRSmall: typeof IconLetterRSmall;
declare const index_IconLetterS: typeof IconLetterS;
declare const index_IconLetterSSmall: typeof IconLetterSSmall;
declare const index_IconLetterSpacing: typeof IconLetterSpacing;
declare const index_IconLetterT: typeof IconLetterT;
declare const index_IconLetterTSmall: typeof IconLetterTSmall;
declare const index_IconLetterU: typeof IconLetterU;
declare const index_IconLetterUSmall: typeof IconLetterUSmall;
declare const index_IconLetterV: typeof IconLetterV;
declare const index_IconLetterVSmall: typeof IconLetterVSmall;
declare const index_IconLetterW: typeof IconLetterW;
declare const index_IconLetterWSmall: typeof IconLetterWSmall;
declare const index_IconLetterX: typeof IconLetterX;
declare const index_IconLetterXSmall: typeof IconLetterXSmall;
declare const index_IconLetterY: typeof IconLetterY;
declare const index_IconLetterYSmall: typeof IconLetterYSmall;
declare const index_IconLetterZ: typeof IconLetterZ;
declare const index_IconLetterZSmall: typeof IconLetterZSmall;
declare const index_IconLibrary: typeof IconLibrary;
declare const index_IconLibraryFilled: typeof IconLibraryFilled;
declare const index_IconLibraryMinus: typeof IconLibraryMinus;
declare const index_IconLibraryPhoto: typeof IconLibraryPhoto;
declare const index_IconLibraryPlus: typeof IconLibraryPlus;
declare const index_IconLibraryPlusFilled: typeof IconLibraryPlusFilled;
declare const index_IconLicense: typeof IconLicense;
declare const index_IconLicenseOff: typeof IconLicenseOff;
declare const index_IconLifebuoy: typeof IconLifebuoy;
declare const index_IconLifebuoyFilled: typeof IconLifebuoyFilled;
declare const index_IconLifebuoyOff: typeof IconLifebuoyOff;
declare const index_IconLighter: typeof IconLighter;
declare const index_IconLine: typeof IconLine;
declare const index_IconLineDashed: typeof IconLineDashed;
declare const index_IconLineDotted: typeof IconLineDotted;
declare const index_IconLineHeight: typeof IconLineHeight;
declare const index_IconLineScan: typeof IconLineScan;
declare const index_IconLink: typeof IconLink;
declare const index_IconLinkMinus: typeof IconLinkMinus;
declare const index_IconLinkOff: typeof IconLinkOff;
declare const index_IconLinkPlus: typeof IconLinkPlus;
declare const index_IconList: typeof IconList;
declare const index_IconListCheck: typeof IconListCheck;
declare const index_IconListDetails: typeof IconListDetails;
declare const index_IconListLetters: typeof IconListLetters;
declare const index_IconListNumbers: typeof IconListNumbers;
declare const index_IconListSearch: typeof IconListSearch;
declare const index_IconListTree: typeof IconListTree;
declare const index_IconLivePhoto: typeof IconLivePhoto;
declare const index_IconLivePhotoFilled: typeof IconLivePhotoFilled;
declare const index_IconLivePhotoOff: typeof IconLivePhotoOff;
declare const index_IconLiveView: typeof IconLiveView;
declare const index_IconLiveViewFilled: typeof IconLiveViewFilled;
declare const index_IconLoadBalancer: typeof IconLoadBalancer;
declare const index_IconLoader: typeof IconLoader;
declare const index_IconLoader2: typeof IconLoader2;
declare const index_IconLoader3: typeof IconLoader3;
declare const index_IconLoaderQuarter: typeof IconLoaderQuarter;
declare const index_IconLocation: typeof IconLocation;
declare const index_IconLocationBolt: typeof IconLocationBolt;
declare const index_IconLocationBroken: typeof IconLocationBroken;
declare const index_IconLocationCancel: typeof IconLocationCancel;
declare const index_IconLocationCheck: typeof IconLocationCheck;
declare const index_IconLocationCode: typeof IconLocationCode;
declare const index_IconLocationCog: typeof IconLocationCog;
declare const index_IconLocationDiscount: typeof IconLocationDiscount;
declare const index_IconLocationDollar: typeof IconLocationDollar;
declare const index_IconLocationDown: typeof IconLocationDown;
declare const index_IconLocationExclamation: typeof IconLocationExclamation;
declare const index_IconLocationFilled: typeof IconLocationFilled;
declare const index_IconLocationHeart: typeof IconLocationHeart;
declare const index_IconLocationMinus: typeof IconLocationMinus;
declare const index_IconLocationOff: typeof IconLocationOff;
declare const index_IconLocationPause: typeof IconLocationPause;
declare const index_IconLocationPin: typeof IconLocationPin;
declare const index_IconLocationPlus: typeof IconLocationPlus;
declare const index_IconLocationQuestion: typeof IconLocationQuestion;
declare const index_IconLocationSearch: typeof IconLocationSearch;
declare const index_IconLocationShare: typeof IconLocationShare;
declare const index_IconLocationStar: typeof IconLocationStar;
declare const index_IconLocationUp: typeof IconLocationUp;
declare const index_IconLocationX: typeof IconLocationX;
declare const index_IconLock: typeof IconLock;
declare const index_IconLockAccess: typeof IconLockAccess;
declare const index_IconLockAccessOff: typeof IconLockAccessOff;
declare const index_IconLockBitcoin: typeof IconLockBitcoin;
declare const index_IconLockBolt: typeof IconLockBolt;
declare const index_IconLockCancel: typeof IconLockCancel;
declare const index_IconLockCheck: typeof IconLockCheck;
declare const index_IconLockCode: typeof IconLockCode;
declare const index_IconLockCog: typeof IconLockCog;
declare const index_IconLockDollar: typeof IconLockDollar;
declare const index_IconLockDown: typeof IconLockDown;
declare const index_IconLockExclamation: typeof IconLockExclamation;
declare const index_IconLockFilled: typeof IconLockFilled;
declare const index_IconLockHeart: typeof IconLockHeart;
declare const index_IconLockMinus: typeof IconLockMinus;
declare const index_IconLockOff: typeof IconLockOff;
declare const index_IconLockOpen: typeof IconLockOpen;
declare const index_IconLockOpen2: typeof IconLockOpen2;
declare const index_IconLockOpenOff: typeof IconLockOpenOff;
declare const index_IconLockPassword: typeof IconLockPassword;
declare const index_IconLockPause: typeof IconLockPause;
declare const index_IconLockPin: typeof IconLockPin;
declare const index_IconLockPlus: typeof IconLockPlus;
declare const index_IconLockQuestion: typeof IconLockQuestion;
declare const index_IconLockSearch: typeof IconLockSearch;
declare const index_IconLockShare: typeof IconLockShare;
declare const index_IconLockSquare: typeof IconLockSquare;
declare const index_IconLockSquareRounded: typeof IconLockSquareRounded;
declare const index_IconLockSquareRoundedFilled: typeof IconLockSquareRoundedFilled;
declare const index_IconLockStar: typeof IconLockStar;
declare const index_IconLockUp: typeof IconLockUp;
declare const index_IconLockX: typeof IconLockX;
declare const index_IconLogicAnd: typeof IconLogicAnd;
declare const index_IconLogicBuffer: typeof IconLogicBuffer;
declare const index_IconLogicNand: typeof IconLogicNand;
declare const index_IconLogicNor: typeof IconLogicNor;
declare const index_IconLogicNot: typeof IconLogicNot;
declare const index_IconLogicOr: typeof IconLogicOr;
declare const index_IconLogicXnor: typeof IconLogicXnor;
declare const index_IconLogicXor: typeof IconLogicXor;
declare const index_IconLogin: typeof IconLogin;
declare const index_IconLogin2: typeof IconLogin2;
declare const index_IconLogout: typeof IconLogout;
declare const index_IconLogout2: typeof IconLogout2;
declare const index_IconLogs: typeof IconLogs;
declare const index_IconLollipop: typeof IconLollipop;
declare const index_IconLollipopOff: typeof IconLollipopOff;
declare const index_IconLuggage: typeof IconLuggage;
declare const index_IconLuggageOff: typeof IconLuggageOff;
declare const index_IconLungs: typeof IconLungs;
declare const index_IconLungsFilled: typeof IconLungsFilled;
declare const index_IconLungsOff: typeof IconLungsOff;
declare const index_IconMacro: typeof IconMacro;
declare const index_IconMacroFilled: typeof IconMacroFilled;
declare const index_IconMacroOff: typeof IconMacroOff;
declare const index_IconMagnet: typeof IconMagnet;
declare const index_IconMagnetFilled: typeof IconMagnetFilled;
declare const index_IconMagnetOff: typeof IconMagnetOff;
declare const index_IconMagnetic: typeof IconMagnetic;
declare const index_IconMail: typeof IconMail;
declare const index_IconMailAi: typeof IconMailAi;
declare const index_IconMailBitcoin: typeof IconMailBitcoin;
declare const index_IconMailBolt: typeof IconMailBolt;
declare const index_IconMailCancel: typeof IconMailCancel;
declare const index_IconMailCheck: typeof IconMailCheck;
declare const index_IconMailCode: typeof IconMailCode;
declare const index_IconMailCog: typeof IconMailCog;
declare const index_IconMailDollar: typeof IconMailDollar;
declare const index_IconMailDown: typeof IconMailDown;
declare const index_IconMailExclamation: typeof IconMailExclamation;
declare const index_IconMailFast: typeof IconMailFast;
declare const index_IconMailFilled: typeof IconMailFilled;
declare const index_IconMailForward: typeof IconMailForward;
declare const index_IconMailHeart: typeof IconMailHeart;
declare const index_IconMailMinus: typeof IconMailMinus;
declare const index_IconMailOff: typeof IconMailOff;
declare const index_IconMailOpened: typeof IconMailOpened;
declare const index_IconMailOpenedFilled: typeof IconMailOpenedFilled;
declare const index_IconMailPause: typeof IconMailPause;
declare const index_IconMailPin: typeof IconMailPin;
declare const index_IconMailPlus: typeof IconMailPlus;
declare const index_IconMailQuestion: typeof IconMailQuestion;
declare const index_IconMailSearch: typeof IconMailSearch;
declare const index_IconMailShare: typeof IconMailShare;
declare const index_IconMailSpark: typeof IconMailSpark;
declare const index_IconMailStar: typeof IconMailStar;
declare const index_IconMailUp: typeof IconMailUp;
declare const index_IconMailX: typeof IconMailX;
declare const index_IconMailbox: typeof IconMailbox;
declare const index_IconMailboxOff: typeof IconMailboxOff;
declare const index_IconMan: typeof IconMan;
declare const index_IconManFilled: typeof IconManFilled;
declare const index_IconManualGearbox: typeof IconManualGearbox;
declare const index_IconManualGearboxFilled: typeof IconManualGearboxFilled;
declare const index_IconMap: typeof IconMap;
declare const index_IconMap2: typeof IconMap2;
declare const index_IconMapBolt: typeof IconMapBolt;
declare const index_IconMapCancel: typeof IconMapCancel;
declare const index_IconMapCheck: typeof IconMapCheck;
declare const index_IconMapCode: typeof IconMapCode;
declare const index_IconMapCog: typeof IconMapCog;
declare const index_IconMapDiscount: typeof IconMapDiscount;
declare const index_IconMapDollar: typeof IconMapDollar;
declare const index_IconMapDown: typeof IconMapDown;
declare const index_IconMapEast: typeof IconMapEast;
declare const index_IconMapExclamation: typeof IconMapExclamation;
declare const index_IconMapHeart: typeof IconMapHeart;
declare const index_IconMapMinus: typeof IconMapMinus;
declare const index_IconMapNorth: typeof IconMapNorth;
declare const index_IconMapOff: typeof IconMapOff;
declare const index_IconMapPause: typeof IconMapPause;
declare const index_IconMapPin: typeof IconMapPin;
declare const index_IconMapPin2: typeof IconMapPin2;
declare const index_IconMapPinBolt: typeof IconMapPinBolt;
declare const index_IconMapPinCancel: typeof IconMapPinCancel;
declare const index_IconMapPinCheck: typeof IconMapPinCheck;
declare const index_IconMapPinCode: typeof IconMapPinCode;
declare const index_IconMapPinCog: typeof IconMapPinCog;
declare const index_IconMapPinDollar: typeof IconMapPinDollar;
declare const index_IconMapPinDown: typeof IconMapPinDown;
declare const index_IconMapPinExclamation: typeof IconMapPinExclamation;
declare const index_IconMapPinFilled: typeof IconMapPinFilled;
declare const index_IconMapPinHeart: typeof IconMapPinHeart;
declare const index_IconMapPinMinus: typeof IconMapPinMinus;
declare const index_IconMapPinOff: typeof IconMapPinOff;
declare const index_IconMapPinPause: typeof IconMapPinPause;
declare const index_IconMapPinPin: typeof IconMapPinPin;
declare const index_IconMapPinPlus: typeof IconMapPinPlus;
declare const index_IconMapPinQuestion: typeof IconMapPinQuestion;
declare const index_IconMapPinSearch: typeof IconMapPinSearch;
declare const index_IconMapPinShare: typeof IconMapPinShare;
declare const index_IconMapPinStar: typeof IconMapPinStar;
declare const index_IconMapPinUp: typeof IconMapPinUp;
declare const index_IconMapPinX: typeof IconMapPinX;
declare const index_IconMapPins: typeof IconMapPins;
declare const index_IconMapPlus: typeof IconMapPlus;
declare const index_IconMapQuestion: typeof IconMapQuestion;
declare const index_IconMapRoute: typeof IconMapRoute;
declare const index_IconMapSearch: typeof IconMapSearch;
declare const index_IconMapShare: typeof IconMapShare;
declare const index_IconMapSouth: typeof IconMapSouth;
declare const index_IconMapStar: typeof IconMapStar;
declare const index_IconMapUp: typeof IconMapUp;
declare const index_IconMapWest: typeof IconMapWest;
declare const index_IconMapX: typeof IconMapX;
declare const index_IconMarkdown: typeof IconMarkdown;
declare const index_IconMarkdownOff: typeof IconMarkdownOff;
declare const index_IconMarquee: typeof IconMarquee;
declare const index_IconMarquee2: typeof IconMarquee2;
declare const index_IconMarqueeOff: typeof IconMarqueeOff;
declare const index_IconMars: typeof IconMars;
declare const index_IconMask: typeof IconMask;
declare const index_IconMaskOff: typeof IconMaskOff;
declare const index_IconMasksTheater: typeof IconMasksTheater;
declare const index_IconMasksTheaterOff: typeof IconMasksTheaterOff;
declare const index_IconMassage: typeof IconMassage;
declare const index_IconMatchstick: typeof IconMatchstick;
declare const index_IconMath: typeof IconMath;
declare const index_IconMath1Divide2: typeof IconMath1Divide2;
declare const index_IconMath1Divide3: typeof IconMath1Divide3;
declare const index_IconMathAvg: typeof IconMathAvg;
declare const index_IconMathCos: typeof IconMathCos;
declare const index_IconMathCtg: typeof IconMathCtg;
declare const index_IconMathEqualGreater: typeof IconMathEqualGreater;
declare const index_IconMathEqualLower: typeof IconMathEqualLower;
declare const index_IconMathFunction: typeof IconMathFunction;
declare const index_IconMathFunctionOff: typeof IconMathFunctionOff;
declare const index_IconMathFunctionY: typeof IconMathFunctionY;
declare const index_IconMathGreater: typeof IconMathGreater;
declare const index_IconMathIntegral: typeof IconMathIntegral;
declare const index_IconMathIntegralX: typeof IconMathIntegralX;
declare const index_IconMathIntegrals: typeof IconMathIntegrals;
declare const index_IconMathLower: typeof IconMathLower;
declare const index_IconMathMax: typeof IconMathMax;
declare const index_IconMathMaxMin: typeof IconMathMaxMin;
declare const index_IconMathMin: typeof IconMathMin;
declare const index_IconMathNot: typeof IconMathNot;
declare const index_IconMathOff: typeof IconMathOff;
declare const index_IconMathPi: typeof IconMathPi;
declare const index_IconMathPiDivide2: typeof IconMathPiDivide2;
declare const index_IconMathSec: typeof IconMathSec;
declare const index_IconMathSin: typeof IconMathSin;
declare const index_IconMathSymbols: typeof IconMathSymbols;
declare const index_IconMathTg: typeof IconMathTg;
declare const index_IconMathXDivide2: typeof IconMathXDivide2;
declare const index_IconMathXDivideY: typeof IconMathXDivideY;
declare const index_IconMathXDivideY2: typeof IconMathXDivideY2;
declare const index_IconMathXFloorDivideY: typeof IconMathXFloorDivideY;
declare const index_IconMathXMinusX: typeof IconMathXMinusX;
declare const index_IconMathXMinusY: typeof IconMathXMinusY;
declare const index_IconMathXPlusX: typeof IconMathXPlusX;
declare const index_IconMathXPlusY: typeof IconMathXPlusY;
declare const index_IconMathXy: typeof IconMathXy;
declare const index_IconMathYMinusY: typeof IconMathYMinusY;
declare const index_IconMathYPlusY: typeof IconMathYPlusY;
declare const index_IconMatrix: typeof IconMatrix;
declare const index_IconMaximize: typeof IconMaximize;
declare const index_IconMaximizeOff: typeof IconMaximizeOff;
declare const index_IconMeat: typeof IconMeat;
declare const index_IconMeatOff: typeof IconMeatOff;
declare const index_IconMedal: typeof IconMedal;
declare const index_IconMedal2: typeof IconMedal2;
declare const index_IconMedicalCross: typeof IconMedicalCross;
declare const index_IconMedicalCrossCircle: typeof IconMedicalCrossCircle;
declare const index_IconMedicalCrossFilled: typeof IconMedicalCrossFilled;
declare const index_IconMedicalCrossOff: typeof IconMedicalCrossOff;
declare const index_IconMedicineSyrup: typeof IconMedicineSyrup;
declare const index_IconMeeple: typeof IconMeeple;
declare const index_IconMeepleFilled: typeof IconMeepleFilled;
declare const index_IconMelon: typeof IconMelon;
declare const index_IconMelonFilled: typeof IconMelonFilled;
declare const index_IconMenorah: typeof IconMenorah;
declare const index_IconMenu: typeof IconMenu;
declare const index_IconMenu2: typeof IconMenu2;
declare const index_IconMenu3: typeof IconMenu3;
declare const index_IconMenu4: typeof IconMenu4;
declare const index_IconMenuDeep: typeof IconMenuDeep;
declare const index_IconMenuOrder: typeof IconMenuOrder;
declare const index_IconMessage: typeof IconMessage;
declare const index_IconMessage2: typeof IconMessage2;
declare const index_IconMessage2Bolt: typeof IconMessage2Bolt;
declare const index_IconMessage2Cancel: typeof IconMessage2Cancel;
declare const index_IconMessage2Check: typeof IconMessage2Check;
declare const index_IconMessage2Code: typeof IconMessage2Code;
declare const index_IconMessage2Cog: typeof IconMessage2Cog;
declare const index_IconMessage2Dollar: typeof IconMessage2Dollar;
declare const index_IconMessage2Down: typeof IconMessage2Down;
declare const index_IconMessage2Exclamation: typeof IconMessage2Exclamation;
declare const index_IconMessage2Filled: typeof IconMessage2Filled;
declare const index_IconMessage2Heart: typeof IconMessage2Heart;
declare const index_IconMessage2Minus: typeof IconMessage2Minus;
declare const index_IconMessage2Off: typeof IconMessage2Off;
declare const index_IconMessage2Pause: typeof IconMessage2Pause;
declare const index_IconMessage2Pin: typeof IconMessage2Pin;
declare const index_IconMessage2Plus: typeof IconMessage2Plus;
declare const index_IconMessage2Question: typeof IconMessage2Question;
declare const index_IconMessage2Search: typeof IconMessage2Search;
declare const index_IconMessage2Share: typeof IconMessage2Share;
declare const index_IconMessage2Star: typeof IconMessage2Star;
declare const index_IconMessage2Up: typeof IconMessage2Up;
declare const index_IconMessage2X: typeof IconMessage2X;
declare const index_IconMessageBolt: typeof IconMessageBolt;
declare const index_IconMessageCancel: typeof IconMessageCancel;
declare const index_IconMessageChatbot: typeof IconMessageChatbot;
declare const index_IconMessageChatbotFilled: typeof IconMessageChatbotFilled;
declare const index_IconMessageCheck: typeof IconMessageCheck;
declare const index_IconMessageCircle: typeof IconMessageCircle;
declare const index_IconMessageCircleBolt: typeof IconMessageCircleBolt;
declare const index_IconMessageCircleCancel: typeof IconMessageCircleCancel;
declare const index_IconMessageCircleCheck: typeof IconMessageCircleCheck;
declare const index_IconMessageCircleCode: typeof IconMessageCircleCode;
declare const index_IconMessageCircleCog: typeof IconMessageCircleCog;
declare const index_IconMessageCircleDollar: typeof IconMessageCircleDollar;
declare const index_IconMessageCircleDown: typeof IconMessageCircleDown;
declare const index_IconMessageCircleExclamation: typeof IconMessageCircleExclamation;
declare const index_IconMessageCircleFilled: typeof IconMessageCircleFilled;
declare const index_IconMessageCircleHeart: typeof IconMessageCircleHeart;
declare const index_IconMessageCircleMinus: typeof IconMessageCircleMinus;
declare const index_IconMessageCircleOff: typeof IconMessageCircleOff;
declare const index_IconMessageCirclePause: typeof IconMessageCirclePause;
declare const index_IconMessageCirclePin: typeof IconMessageCirclePin;
declare const index_IconMessageCirclePlus: typeof IconMessageCirclePlus;
declare const index_IconMessageCircleQuestion: typeof IconMessageCircleQuestion;
declare const index_IconMessageCircleSearch: typeof IconMessageCircleSearch;
declare const index_IconMessageCircleShare: typeof IconMessageCircleShare;
declare const index_IconMessageCircleStar: typeof IconMessageCircleStar;
declare const index_IconMessageCircleUp: typeof IconMessageCircleUp;
declare const index_IconMessageCircleUser: typeof IconMessageCircleUser;
declare const index_IconMessageCircleX: typeof IconMessageCircleX;
declare const index_IconMessageCode: typeof IconMessageCode;
declare const index_IconMessageCog: typeof IconMessageCog;
declare const index_IconMessageDollar: typeof IconMessageDollar;
declare const index_IconMessageDots: typeof IconMessageDots;
declare const index_IconMessageDown: typeof IconMessageDown;
declare const index_IconMessageExclamation: typeof IconMessageExclamation;
declare const index_IconMessageFilled: typeof IconMessageFilled;
declare const index_IconMessageForward: typeof IconMessageForward;
declare const index_IconMessageHeart: typeof IconMessageHeart;
declare const index_IconMessageLanguage: typeof IconMessageLanguage;
declare const index_IconMessageMinus: typeof IconMessageMinus;
declare const index_IconMessageOff: typeof IconMessageOff;
declare const index_IconMessagePause: typeof IconMessagePause;
declare const index_IconMessagePin: typeof IconMessagePin;
declare const index_IconMessagePlus: typeof IconMessagePlus;
declare const index_IconMessageQuestion: typeof IconMessageQuestion;
declare const index_IconMessageReply: typeof IconMessageReply;
declare const index_IconMessageReport: typeof IconMessageReport;
declare const index_IconMessageReportFilled: typeof IconMessageReportFilled;
declare const index_IconMessageSearch: typeof IconMessageSearch;
declare const index_IconMessageShare: typeof IconMessageShare;
declare const index_IconMessageStar: typeof IconMessageStar;
declare const index_IconMessageUp: typeof IconMessageUp;
declare const index_IconMessageUser: typeof IconMessageUser;
declare const index_IconMessageX: typeof IconMessageX;
declare const index_IconMessages: typeof IconMessages;
declare const index_IconMessagesOff: typeof IconMessagesOff;
declare const index_IconMeteor: typeof IconMeteor;
declare const index_IconMeteorFilled: typeof IconMeteorFilled;
declare const index_IconMeteorOff: typeof IconMeteorOff;
declare const index_IconMeterCube: typeof IconMeterCube;
declare const index_IconMeterSquare: typeof IconMeterSquare;
declare const index_IconMetronome: typeof IconMetronome;
declare const index_IconMichelinBibGourmand: typeof IconMichelinBibGourmand;
declare const index_IconMichelinStar: typeof IconMichelinStar;
declare const index_IconMichelinStarFilled: typeof IconMichelinStarFilled;
declare const index_IconMichelinStarGreen: typeof IconMichelinStarGreen;
declare const index_IconMickey: typeof IconMickey;
declare const index_IconMickeyFilled: typeof IconMickeyFilled;
declare const index_IconMicrophone: typeof IconMicrophone;
declare const index_IconMicrophone2: typeof IconMicrophone2;
declare const index_IconMicrophone2Off: typeof IconMicrophone2Off;
declare const index_IconMicrophoneFilled: typeof IconMicrophoneFilled;
declare const index_IconMicrophoneOff: typeof IconMicrophoneOff;
declare const index_IconMicroscope: typeof IconMicroscope;
declare const index_IconMicroscopeFilled: typeof IconMicroscopeFilled;
declare const index_IconMicroscopeOff: typeof IconMicroscopeOff;
declare const index_IconMicrowave: typeof IconMicrowave;
declare const index_IconMicrowaveFilled: typeof IconMicrowaveFilled;
declare const index_IconMicrowaveOff: typeof IconMicrowaveOff;
declare const index_IconMilitaryAward: typeof IconMilitaryAward;
declare const index_IconMilitaryRank: typeof IconMilitaryRank;
declare const index_IconMilitaryRankFilled: typeof IconMilitaryRankFilled;
declare const index_IconMilk: typeof IconMilk;
declare const index_IconMilkFilled: typeof IconMilkFilled;
declare const index_IconMilkOff: typeof IconMilkOff;
declare const index_IconMilkshake: typeof IconMilkshake;
declare const index_IconMinimize: typeof IconMinimize;
declare const index_IconMinus: typeof IconMinus;
declare const index_IconMinusVertical: typeof IconMinusVertical;
declare const index_IconMist: typeof IconMist;
declare const index_IconMistOff: typeof IconMistOff;
declare const index_IconMobiledata: typeof IconMobiledata;
declare const index_IconMobiledataOff: typeof IconMobiledataOff;
declare const index_IconMoneybag: typeof IconMoneybag;
declare const index_IconMoneybagEdit: typeof IconMoneybagEdit;
declare const index_IconMoneybagHeart: typeof IconMoneybagHeart;
declare const index_IconMoneybagMinus: typeof IconMoneybagMinus;
declare const index_IconMoneybagMove: typeof IconMoneybagMove;
declare const index_IconMoneybagMoveBack: typeof IconMoneybagMoveBack;
declare const index_IconMoneybagPlus: typeof IconMoneybagPlus;
declare const index_IconMonkeybar: typeof IconMonkeybar;
declare const index_IconMoodAngry: typeof IconMoodAngry;
declare const index_IconMoodAngryFilled: typeof IconMoodAngryFilled;
declare const index_IconMoodAnnoyed: typeof IconMoodAnnoyed;
declare const index_IconMoodAnnoyed2: typeof IconMoodAnnoyed2;
declare const index_IconMoodBitcoin: typeof IconMoodBitcoin;
declare const index_IconMoodBoy: typeof IconMoodBoy;
declare const index_IconMoodCheck: typeof IconMoodCheck;
declare const index_IconMoodCog: typeof IconMoodCog;
declare const index_IconMoodConfuzed: typeof IconMoodConfuzed;
declare const index_IconMoodConfuzedFilled: typeof IconMoodConfuzedFilled;
declare const index_IconMoodCrazyHappy: typeof IconMoodCrazyHappy;
declare const index_IconMoodCrazyHappyFilled: typeof IconMoodCrazyHappyFilled;
declare const index_IconMoodCry: typeof IconMoodCry;
declare const index_IconMoodDollar: typeof IconMoodDollar;
declare const index_IconMoodEdit: typeof IconMoodEdit;
declare const index_IconMoodEmpty: typeof IconMoodEmpty;
declare const index_IconMoodEmptyFilled: typeof IconMoodEmptyFilled;
declare const index_IconMoodHappy: typeof IconMoodHappy;
declare const index_IconMoodHappyFilled: typeof IconMoodHappyFilled;
declare const index_IconMoodHeart: typeof IconMoodHeart;
declare const index_IconMoodKid: typeof IconMoodKid;
declare const index_IconMoodKidFilled: typeof IconMoodKidFilled;
declare const index_IconMoodLookDown: typeof IconMoodLookDown;
declare const index_IconMoodLookLeft: typeof IconMoodLookLeft;
declare const index_IconMoodLookRight: typeof IconMoodLookRight;
declare const index_IconMoodLookUp: typeof IconMoodLookUp;
declare const index_IconMoodMinus: typeof IconMoodMinus;
declare const index_IconMoodNerd: typeof IconMoodNerd;
declare const index_IconMoodNervous: typeof IconMoodNervous;
declare const index_IconMoodNeutral: typeof IconMoodNeutral;
declare const index_IconMoodNeutralFilled: typeof IconMoodNeutralFilled;
declare const index_IconMoodOff: typeof IconMoodOff;
declare const index_IconMoodPin: typeof IconMoodPin;
declare const index_IconMoodPlus: typeof IconMoodPlus;
declare const index_IconMoodPuzzled: typeof IconMoodPuzzled;
declare const index_IconMoodSad: typeof IconMoodSad;
declare const index_IconMoodSad2: typeof IconMoodSad2;
declare const index_IconMoodSadDizzy: typeof IconMoodSadDizzy;
declare const index_IconMoodSadFilled: typeof IconMoodSadFilled;
declare const index_IconMoodSadSquint: typeof IconMoodSadSquint;
declare const index_IconMoodSearch: typeof IconMoodSearch;
declare const index_IconMoodShare: typeof IconMoodShare;
declare const index_IconMoodSick: typeof IconMoodSick;
declare const index_IconMoodSilence: typeof IconMoodSilence;
declare const index_IconMoodSing: typeof IconMoodSing;
declare const index_IconMoodSmile: typeof IconMoodSmile;
declare const index_IconMoodSmileBeam: typeof IconMoodSmileBeam;
declare const index_IconMoodSmileDizzy: typeof IconMoodSmileDizzy;
declare const index_IconMoodSmileFilled: typeof IconMoodSmileFilled;
declare const index_IconMoodSpark: typeof IconMoodSpark;
declare const index_IconMoodSurprised: typeof IconMoodSurprised;
declare const index_IconMoodTongue: typeof IconMoodTongue;
declare const index_IconMoodTongueWink: typeof IconMoodTongueWink;
declare const index_IconMoodTongueWink2: typeof IconMoodTongueWink2;
declare const index_IconMoodUnamused: typeof IconMoodUnamused;
declare const index_IconMoodUp: typeof IconMoodUp;
declare const index_IconMoodWink: typeof IconMoodWink;
declare const index_IconMoodWink2: typeof IconMoodWink2;
declare const index_IconMoodWrrr: typeof IconMoodWrrr;
declare const index_IconMoodWrrrFilled: typeof IconMoodWrrrFilled;
declare const index_IconMoodX: typeof IconMoodX;
declare const index_IconMoodXd: typeof IconMoodXd;
declare const index_IconMoon: typeof IconMoon;
declare const index_IconMoon2: typeof IconMoon2;
declare const index_IconMoonFilled: typeof IconMoonFilled;
declare const index_IconMoonOff: typeof IconMoonOff;
declare const index_IconMoonStars: typeof IconMoonStars;
declare const index_IconMoped: typeof IconMoped;
declare const index_IconMotorbike: typeof IconMotorbike;
declare const index_IconMotorbikeFilled: typeof IconMotorbikeFilled;
declare const index_IconMountain: typeof IconMountain;
declare const index_IconMountainFilled: typeof IconMountainFilled;
declare const index_IconMountainOff: typeof IconMountainOff;
declare const index_IconMouse: typeof IconMouse;
declare const index_IconMouse2: typeof IconMouse2;
declare const index_IconMouseFilled: typeof IconMouseFilled;
declare const index_IconMouseOff: typeof IconMouseOff;
declare const index_IconMoustache: typeof IconMoustache;
declare const index_IconMovie: typeof IconMovie;
declare const index_IconMovieOff: typeof IconMovieOff;
declare const index_IconMug: typeof IconMug;
declare const index_IconMugFilled: typeof IconMugFilled;
declare const index_IconMugOff: typeof IconMugOff;
declare const index_IconMultiplier05x: typeof IconMultiplier05x;
declare const index_IconMultiplier15x: typeof IconMultiplier15x;
declare const index_IconMultiplier1x: typeof IconMultiplier1x;
declare const index_IconMultiplier2x: typeof IconMultiplier2x;
declare const index_IconMushroom: typeof IconMushroom;
declare const index_IconMushroomFilled: typeof IconMushroomFilled;
declare const index_IconMushroomOff: typeof IconMushroomOff;
declare const index_IconMusic: typeof IconMusic;
declare const index_IconMusicBolt: typeof IconMusicBolt;
declare const index_IconMusicCancel: typeof IconMusicCancel;
declare const index_IconMusicCheck: typeof IconMusicCheck;
declare const index_IconMusicCode: typeof IconMusicCode;
declare const index_IconMusicCog: typeof IconMusicCog;
declare const index_IconMusicDiscount: typeof IconMusicDiscount;
declare const index_IconMusicDollar: typeof IconMusicDollar;
declare const index_IconMusicDown: typeof IconMusicDown;
declare const index_IconMusicExclamation: typeof IconMusicExclamation;
declare const index_IconMusicHeart: typeof IconMusicHeart;
declare const index_IconMusicMinus: typeof IconMusicMinus;
declare const index_IconMusicOff: typeof IconMusicOff;
declare const index_IconMusicPause: typeof IconMusicPause;
declare const index_IconMusicPin: typeof IconMusicPin;
declare const index_IconMusicPlus: typeof IconMusicPlus;
declare const index_IconMusicQuestion: typeof IconMusicQuestion;
declare const index_IconMusicSearch: typeof IconMusicSearch;
declare const index_IconMusicShare: typeof IconMusicShare;
declare const index_IconMusicStar: typeof IconMusicStar;
declare const index_IconMusicUp: typeof IconMusicUp;
declare const index_IconMusicX: typeof IconMusicX;
declare const index_IconNavigation: typeof IconNavigation;
declare const index_IconNavigationBolt: typeof IconNavigationBolt;
declare const index_IconNavigationCancel: typeof IconNavigationCancel;
declare const index_IconNavigationCheck: typeof IconNavigationCheck;
declare const index_IconNavigationCode: typeof IconNavigationCode;
declare const index_IconNavigationCog: typeof IconNavigationCog;
declare const index_IconNavigationDiscount: typeof IconNavigationDiscount;
declare const index_IconNavigationDollar: typeof IconNavigationDollar;
declare const index_IconNavigationDown: typeof IconNavigationDown;
declare const index_IconNavigationEast: typeof IconNavigationEast;
declare const index_IconNavigationExclamation: typeof IconNavigationExclamation;
declare const index_IconNavigationFilled: typeof IconNavigationFilled;
declare const index_IconNavigationHeart: typeof IconNavigationHeart;
declare const index_IconNavigationMinus: typeof IconNavigationMinus;
declare const index_IconNavigationNorth: typeof IconNavigationNorth;
declare const index_IconNavigationOff: typeof IconNavigationOff;
declare const index_IconNavigationPause: typeof IconNavigationPause;
declare const index_IconNavigationPin: typeof IconNavigationPin;
declare const index_IconNavigationPlus: typeof IconNavigationPlus;
declare const index_IconNavigationQuestion: typeof IconNavigationQuestion;
declare const index_IconNavigationSearch: typeof IconNavigationSearch;
declare const index_IconNavigationShare: typeof IconNavigationShare;
declare const index_IconNavigationSouth: typeof IconNavigationSouth;
declare const index_IconNavigationStar: typeof IconNavigationStar;
declare const index_IconNavigationTop: typeof IconNavigationTop;
declare const index_IconNavigationUp: typeof IconNavigationUp;
declare const index_IconNavigationWest: typeof IconNavigationWest;
declare const index_IconNavigationX: typeof IconNavigationX;
declare const index_IconNeedle: typeof IconNeedle;
declare const index_IconNeedleThread: typeof IconNeedleThread;
declare const index_IconNetwork: typeof IconNetwork;
declare const index_IconNetworkOff: typeof IconNetworkOff;
declare const index_IconNewSection: typeof IconNewSection;
declare const index_IconNews: typeof IconNews;
declare const index_IconNewsOff: typeof IconNewsOff;
declare const index_IconNfc: typeof IconNfc;
declare const index_IconNfcOff: typeof IconNfcOff;
declare const index_IconNoCopyright: typeof IconNoCopyright;
declare const index_IconNoCreativeCommons: typeof IconNoCreativeCommons;
declare const index_IconNoDerivatives: typeof IconNoDerivatives;
declare const index_IconNorthStar: typeof IconNorthStar;
declare const index_IconNote: typeof IconNote;
declare const index_IconNoteOff: typeof IconNoteOff;
declare const index_IconNotebook: typeof IconNotebook;
declare const index_IconNotebookOff: typeof IconNotebookOff;
declare const index_IconNotes: typeof IconNotes;
declare const index_IconNotesOff: typeof IconNotesOff;
declare const index_IconNotification: typeof IconNotification;
declare const index_IconNotificationOff: typeof IconNotificationOff;
declare const index_IconNumber: typeof IconNumber;
declare const index_IconNumber0: typeof IconNumber0;
declare const index_IconNumber0Small: typeof IconNumber0Small;
declare const index_IconNumber1: typeof IconNumber1;
declare const index_IconNumber10: typeof IconNumber10;
declare const index_IconNumber100Small: typeof IconNumber100Small;
declare const index_IconNumber10Small: typeof IconNumber10Small;
declare const index_IconNumber11: typeof IconNumber11;
declare const index_IconNumber11Small: typeof IconNumber11Small;
declare const index_IconNumber123: typeof IconNumber123;
declare const index_IconNumber12Small: typeof IconNumber12Small;
declare const index_IconNumber13Small: typeof IconNumber13Small;
declare const index_IconNumber14Small: typeof IconNumber14Small;
declare const index_IconNumber15Small: typeof IconNumber15Small;
declare const index_IconNumber16Small: typeof IconNumber16Small;
declare const index_IconNumber17Small: typeof IconNumber17Small;
declare const index_IconNumber18Small: typeof IconNumber18Small;
declare const index_IconNumber19Small: typeof IconNumber19Small;
declare const index_IconNumber1Small: typeof IconNumber1Small;
declare const index_IconNumber2: typeof IconNumber2;
declare const index_IconNumber20Small: typeof IconNumber20Small;
declare const index_IconNumber21Small: typeof IconNumber21Small;
declare const index_IconNumber22Small: typeof IconNumber22Small;
declare const index_IconNumber23Small: typeof IconNumber23Small;
declare const index_IconNumber24Small: typeof IconNumber24Small;
declare const index_IconNumber25Small: typeof IconNumber25Small;
declare const index_IconNumber26Small: typeof IconNumber26Small;
declare const index_IconNumber27Small: typeof IconNumber27Small;
declare const index_IconNumber28Small: typeof IconNumber28Small;
declare const index_IconNumber29Small: typeof IconNumber29Small;
declare const index_IconNumber2Small: typeof IconNumber2Small;
declare const index_IconNumber3: typeof IconNumber3;
declare const index_IconNumber30Small: typeof IconNumber30Small;
declare const index_IconNumber31Small: typeof IconNumber31Small;
declare const index_IconNumber32Small: typeof IconNumber32Small;
declare const index_IconNumber33Small: typeof IconNumber33Small;
declare const index_IconNumber34Small: typeof IconNumber34Small;
declare const index_IconNumber35Small: typeof IconNumber35Small;
declare const index_IconNumber36Small: typeof IconNumber36Small;
declare const index_IconNumber37Small: typeof IconNumber37Small;
declare const index_IconNumber38Small: typeof IconNumber38Small;
declare const index_IconNumber39Small: typeof IconNumber39Small;
declare const index_IconNumber3Small: typeof IconNumber3Small;
declare const index_IconNumber4: typeof IconNumber4;
declare const index_IconNumber40Small: typeof IconNumber40Small;
declare const index_IconNumber41Small: typeof IconNumber41Small;
declare const index_IconNumber42Small: typeof IconNumber42Small;
declare const index_IconNumber43Small: typeof IconNumber43Small;
declare const index_IconNumber44Small: typeof IconNumber44Small;
declare const index_IconNumber45Small: typeof IconNumber45Small;
declare const index_IconNumber46Small: typeof IconNumber46Small;
declare const index_IconNumber47Small: typeof IconNumber47Small;
declare const index_IconNumber48Small: typeof IconNumber48Small;
declare const index_IconNumber49Small: typeof IconNumber49Small;
declare const index_IconNumber4Small: typeof IconNumber4Small;
declare const index_IconNumber5: typeof IconNumber5;
declare const index_IconNumber50Small: typeof IconNumber50Small;
declare const index_IconNumber51Small: typeof IconNumber51Small;
declare const index_IconNumber52Small: typeof IconNumber52Small;
declare const index_IconNumber53Small: typeof IconNumber53Small;
declare const index_IconNumber54Small: typeof IconNumber54Small;
declare const index_IconNumber55Small: typeof IconNumber55Small;
declare const index_IconNumber56Small: typeof IconNumber56Small;
declare const index_IconNumber57Small: typeof IconNumber57Small;
declare const index_IconNumber58Small: typeof IconNumber58Small;
declare const index_IconNumber59Small: typeof IconNumber59Small;
declare const index_IconNumber5Small: typeof IconNumber5Small;
declare const index_IconNumber6: typeof IconNumber6;
declare const index_IconNumber60Small: typeof IconNumber60Small;
declare const index_IconNumber61Small: typeof IconNumber61Small;
declare const index_IconNumber62Small: typeof IconNumber62Small;
declare const index_IconNumber63Small: typeof IconNumber63Small;
declare const index_IconNumber64Small: typeof IconNumber64Small;
declare const index_IconNumber65Small: typeof IconNumber65Small;
declare const index_IconNumber66Small: typeof IconNumber66Small;
declare const index_IconNumber67Small: typeof IconNumber67Small;
declare const index_IconNumber68Small: typeof IconNumber68Small;
declare const index_IconNumber69Small: typeof IconNumber69Small;
declare const index_IconNumber6Small: typeof IconNumber6Small;
declare const index_IconNumber7: typeof IconNumber7;
declare const index_IconNumber70Small: typeof IconNumber70Small;
declare const index_IconNumber71Small: typeof IconNumber71Small;
declare const index_IconNumber72Small: typeof IconNumber72Small;
declare const index_IconNumber73Small: typeof IconNumber73Small;
declare const index_IconNumber74Small: typeof IconNumber74Small;
declare const index_IconNumber75Small: typeof IconNumber75Small;
declare const index_IconNumber76Small: typeof IconNumber76Small;
declare const index_IconNumber77Small: typeof IconNumber77Small;
declare const index_IconNumber78Small: typeof IconNumber78Small;
declare const index_IconNumber79Small: typeof IconNumber79Small;
declare const index_IconNumber7Small: typeof IconNumber7Small;
declare const index_IconNumber8: typeof IconNumber8;
declare const index_IconNumber80Small: typeof IconNumber80Small;
declare const index_IconNumber81Small: typeof IconNumber81Small;
declare const index_IconNumber82Small: typeof IconNumber82Small;
declare const index_IconNumber83Small: typeof IconNumber83Small;
declare const index_IconNumber84Small: typeof IconNumber84Small;
declare const index_IconNumber85Small: typeof IconNumber85Small;
declare const index_IconNumber86Small: typeof IconNumber86Small;
declare const index_IconNumber87Small: typeof IconNumber87Small;
declare const index_IconNumber88Small: typeof IconNumber88Small;
declare const index_IconNumber89Small: typeof IconNumber89Small;
declare const index_IconNumber8Small: typeof IconNumber8Small;
declare const index_IconNumber9: typeof IconNumber9;
declare const index_IconNumber90Small: typeof IconNumber90Small;
declare const index_IconNumber91Small: typeof IconNumber91Small;
declare const index_IconNumber92Small: typeof IconNumber92Small;
declare const index_IconNumber93Small: typeof IconNumber93Small;
declare const index_IconNumber94Small: typeof IconNumber94Small;
declare const index_IconNumber95Small: typeof IconNumber95Small;
declare const index_IconNumber96Small: typeof IconNumber96Small;
declare const index_IconNumber97Small: typeof IconNumber97Small;
declare const index_IconNumber98Small: typeof IconNumber98Small;
declare const index_IconNumber99Small: typeof IconNumber99Small;
declare const index_IconNumber9Small: typeof IconNumber9Small;
declare const index_IconNumbers: typeof IconNumbers;
declare const index_IconNurse: typeof IconNurse;
declare const index_IconNurseFilled: typeof IconNurseFilled;
declare const index_IconNut: typeof IconNut;
declare const index_IconObjectScan: typeof IconObjectScan;
declare const index_IconOctagon: typeof IconOctagon;
declare const index_IconOctagonFilled: typeof IconOctagonFilled;
declare const index_IconOctagonMinus: typeof IconOctagonMinus;
declare const index_IconOctagonMinus2: typeof IconOctagonMinus2;
declare const index_IconOctagonMinusFilled: typeof IconOctagonMinusFilled;
declare const index_IconOctagonOff: typeof IconOctagonOff;
declare const index_IconOctagonPlus: typeof IconOctagonPlus;
declare const index_IconOctagonPlus2: typeof IconOctagonPlus2;
declare const index_IconOctagonPlusFilled: typeof IconOctagonPlusFilled;
declare const index_IconOctahedron: typeof IconOctahedron;
declare const index_IconOctahedronOff: typeof IconOctahedronOff;
declare const index_IconOctahedronPlus: typeof IconOctahedronPlus;
declare const index_IconOld: typeof IconOld;
declare const index_IconOlympics: typeof IconOlympics;
declare const index_IconOlympicsOff: typeof IconOlympicsOff;
declare const index_IconOm: typeof IconOm;
declare const index_IconOmega: typeof IconOmega;
declare const index_IconOption: typeof IconOption;
declare const index_IconOutbound: typeof IconOutbound;
declare const index_IconOutlet: typeof IconOutlet;
declare const index_IconOval: typeof IconOval;
declare const index_IconOvalFilled: typeof IconOvalFilled;
declare const index_IconOvalVertical: typeof IconOvalVertical;
declare const index_IconOvalVerticalFilled: typeof IconOvalVerticalFilled;
declare const index_IconOverline: typeof IconOverline;
declare const index_IconPackage: typeof IconPackage;
declare const index_IconPackageExport: typeof IconPackageExport;
declare const index_IconPackageImport: typeof IconPackageImport;
declare const index_IconPackageOff: typeof IconPackageOff;
declare const index_IconPackages: typeof IconPackages;
declare const index_IconPacman: typeof IconPacman;
declare const index_IconPacmanFilled: typeof IconPacmanFilled;
declare const index_IconPageBreak: typeof IconPageBreak;
declare const index_IconPaint: typeof IconPaint;
declare const index_IconPaintFilled: typeof IconPaintFilled;
declare const index_IconPaintOff: typeof IconPaintOff;
declare const index_IconPalette: typeof IconPalette;
declare const index_IconPaletteFilled: typeof IconPaletteFilled;
declare const index_IconPaletteOff: typeof IconPaletteOff;
declare const index_IconPanoramaHorizontal: typeof IconPanoramaHorizontal;
declare const index_IconPanoramaHorizontalFilled: typeof IconPanoramaHorizontalFilled;
declare const index_IconPanoramaHorizontalOff: typeof IconPanoramaHorizontalOff;
declare const index_IconPanoramaVertical: typeof IconPanoramaVertical;
declare const index_IconPanoramaVerticalFilled: typeof IconPanoramaVerticalFilled;
declare const index_IconPanoramaVerticalOff: typeof IconPanoramaVerticalOff;
declare const index_IconPaperBag: typeof IconPaperBag;
declare const index_IconPaperBagOff: typeof IconPaperBagOff;
declare const index_IconPaperclip: typeof IconPaperclip;
declare const index_IconParachute: typeof IconParachute;
declare const index_IconParachuteOff: typeof IconParachuteOff;
declare const index_IconParentheses: typeof IconParentheses;
declare const index_IconParenthesesOff: typeof IconParenthesesOff;
declare const index_IconParking: typeof IconParking;
declare const index_IconParkingCircle: typeof IconParkingCircle;
declare const index_IconParkingCircleFilled: typeof IconParkingCircleFilled;
declare const index_IconParkingOff: typeof IconParkingOff;
declare const index_IconPassword: typeof IconPassword;
declare const index_IconPasswordFingerprint: typeof IconPasswordFingerprint;
declare const index_IconPasswordMobilePhone: typeof IconPasswordMobilePhone;
declare const index_IconPasswordUser: typeof IconPasswordUser;
declare const index_IconPaw: typeof IconPaw;
declare const index_IconPawFilled: typeof IconPawFilled;
declare const index_IconPawOff: typeof IconPawOff;
declare const index_IconPaywall: typeof IconPaywall;
declare const index_IconPdf: typeof IconPdf;
declare const index_IconPeace: typeof IconPeace;
declare const index_IconPencil: typeof IconPencil;
declare const index_IconPencilBolt: typeof IconPencilBolt;
declare const index_IconPencilCancel: typeof IconPencilCancel;
declare const index_IconPencilCheck: typeof IconPencilCheck;
declare const index_IconPencilCode: typeof IconPencilCode;
declare const index_IconPencilCog: typeof IconPencilCog;
declare const index_IconPencilDiscount: typeof IconPencilDiscount;
declare const index_IconPencilDollar: typeof IconPencilDollar;
declare const index_IconPencilDown: typeof IconPencilDown;
declare const index_IconPencilExclamation: typeof IconPencilExclamation;
declare const index_IconPencilHeart: typeof IconPencilHeart;
declare const index_IconPencilMinus: typeof IconPencilMinus;
declare const index_IconPencilOff: typeof IconPencilOff;
declare const index_IconPencilPause: typeof IconPencilPause;
declare const index_IconPencilPin: typeof IconPencilPin;
declare const index_IconPencilPlus: typeof IconPencilPlus;
declare const index_IconPencilQuestion: typeof IconPencilQuestion;
declare const index_IconPencilSearch: typeof IconPencilSearch;
declare const index_IconPencilShare: typeof IconPencilShare;
declare const index_IconPencilStar: typeof IconPencilStar;
declare const index_IconPencilUp: typeof IconPencilUp;
declare const index_IconPencilX: typeof IconPencilX;
declare const index_IconPennant: typeof IconPennant;
declare const index_IconPennant2: typeof IconPennant2;
declare const index_IconPennant2Filled: typeof IconPennant2Filled;
declare const index_IconPennantFilled: typeof IconPennantFilled;
declare const index_IconPennantOff: typeof IconPennantOff;
declare const index_IconPentagon: typeof IconPentagon;
declare const index_IconPentagonFilled: typeof IconPentagonFilled;
declare const index_IconPentagonMinus: typeof IconPentagonMinus;
declare const index_IconPentagonNumber0: typeof IconPentagonNumber0;
declare const index_IconPentagonNumber1: typeof IconPentagonNumber1;
declare const index_IconPentagonNumber2: typeof IconPentagonNumber2;
declare const index_IconPentagonNumber3: typeof IconPentagonNumber3;
declare const index_IconPentagonNumber4: typeof IconPentagonNumber4;
declare const index_IconPentagonNumber5: typeof IconPentagonNumber5;
declare const index_IconPentagonNumber6: typeof IconPentagonNumber6;
declare const index_IconPentagonNumber7: typeof IconPentagonNumber7;
declare const index_IconPentagonNumber8: typeof IconPentagonNumber8;
declare const index_IconPentagonNumber9: typeof IconPentagonNumber9;
declare const index_IconPentagonOff: typeof IconPentagonOff;
declare const index_IconPentagonPlus: typeof IconPentagonPlus;
declare const index_IconPentagonX: typeof IconPentagonX;
declare const index_IconPentagram: typeof IconPentagram;
declare const index_IconPepper: typeof IconPepper;
declare const index_IconPepperOff: typeof IconPepperOff;
declare const index_IconPercentage: typeof IconPercentage;
declare const index_IconPercentage0: typeof IconPercentage0;
declare const index_IconPercentage10: typeof IconPercentage10;
declare const index_IconPercentage100: typeof IconPercentage100;
declare const index_IconPercentage20: typeof IconPercentage20;
declare const index_IconPercentage25: typeof IconPercentage25;
declare const index_IconPercentage30: typeof IconPercentage30;
declare const index_IconPercentage33: typeof IconPercentage33;
declare const index_IconPercentage40: typeof IconPercentage40;
declare const index_IconPercentage50: typeof IconPercentage50;
declare const index_IconPercentage60: typeof IconPercentage60;
declare const index_IconPercentage66: typeof IconPercentage66;
declare const index_IconPercentage70: typeof IconPercentage70;
declare const index_IconPercentage75: typeof IconPercentage75;
declare const index_IconPercentage80: typeof IconPercentage80;
declare const index_IconPercentage90: typeof IconPercentage90;
declare const index_IconPerfume: typeof IconPerfume;
declare const index_IconPerspective: typeof IconPerspective;
declare const index_IconPerspectiveOff: typeof IconPerspectiveOff;
declare const index_IconPhone: typeof IconPhone;
declare const index_IconPhoneCall: typeof IconPhoneCall;
declare const index_IconPhoneCallFilled: typeof IconPhoneCallFilled;
declare const index_IconPhoneCalling: typeof IconPhoneCalling;
declare const index_IconPhoneCallingFilled: typeof IconPhoneCallingFilled;
declare const index_IconPhoneCheck: typeof IconPhoneCheck;
declare const index_IconPhoneCheckFilled: typeof IconPhoneCheckFilled;
declare const index_IconPhoneDone: typeof IconPhoneDone;
declare const index_IconPhoneEnd: typeof IconPhoneEnd;
declare const index_IconPhoneFilled: typeof IconPhoneFilled;
declare const index_IconPhoneIncoming: typeof IconPhoneIncoming;
declare const index_IconPhoneOff: typeof IconPhoneOff;
declare const index_IconPhoneOutgoing: typeof IconPhoneOutgoing;
declare const index_IconPhonePause: typeof IconPhonePause;
declare const index_IconPhonePlus: typeof IconPhonePlus;
declare const index_IconPhoneRinging: typeof IconPhoneRinging;
declare const index_IconPhoneSpark: typeof IconPhoneSpark;
declare const index_IconPhoneX: typeof IconPhoneX;
declare const index_IconPhoneXFilled: typeof IconPhoneXFilled;
declare const index_IconPhoto: typeof IconPhoto;
declare const index_IconPhotoAi: typeof IconPhotoAi;
declare const index_IconPhotoBitcoin: typeof IconPhotoBitcoin;
declare const index_IconPhotoBolt: typeof IconPhotoBolt;
declare const index_IconPhotoCancel: typeof IconPhotoCancel;
declare const index_IconPhotoCheck: typeof IconPhotoCheck;
declare const index_IconPhotoCircle: typeof IconPhotoCircle;
declare const index_IconPhotoCircleMinus: typeof IconPhotoCircleMinus;
declare const index_IconPhotoCirclePlus: typeof IconPhotoCirclePlus;
declare const index_IconPhotoCode: typeof IconPhotoCode;
declare const index_IconPhotoCog: typeof IconPhotoCog;
declare const index_IconPhotoDollar: typeof IconPhotoDollar;
declare const index_IconPhotoDown: typeof IconPhotoDown;
declare const index_IconPhotoEdit: typeof IconPhotoEdit;
declare const index_IconPhotoExclamation: typeof IconPhotoExclamation;
declare const index_IconPhotoFilled: typeof IconPhotoFilled;
declare const index_IconPhotoHeart: typeof IconPhotoHeart;
declare const index_IconPhotoHexagon: typeof IconPhotoHexagon;
declare const index_IconPhotoMinus: typeof IconPhotoMinus;
declare const index_IconPhotoOff: typeof IconPhotoOff;
declare const index_IconPhotoPause: typeof IconPhotoPause;
declare const index_IconPhotoPentagon: typeof IconPhotoPentagon;
declare const index_IconPhotoPin: typeof IconPhotoPin;
declare const index_IconPhotoPlus: typeof IconPhotoPlus;
declare const index_IconPhotoQuestion: typeof IconPhotoQuestion;
declare const index_IconPhotoScan: typeof IconPhotoScan;
declare const index_IconPhotoSearch: typeof IconPhotoSearch;
declare const index_IconPhotoSensor: typeof IconPhotoSensor;
declare const index_IconPhotoSensor2: typeof IconPhotoSensor2;
declare const index_IconPhotoSensor3: typeof IconPhotoSensor3;
declare const index_IconPhotoShare: typeof IconPhotoShare;
declare const index_IconPhotoShield: typeof IconPhotoShield;
declare const index_IconPhotoSpark: typeof IconPhotoSpark;
declare const index_IconPhotoSquareRounded: typeof IconPhotoSquareRounded;
declare const index_IconPhotoStar: typeof IconPhotoStar;
declare const index_IconPhotoUp: typeof IconPhotoUp;
declare const index_IconPhotoVideo: typeof IconPhotoVideo;
declare const index_IconPhotoX: typeof IconPhotoX;
declare const index_IconPhysotherapist: typeof IconPhysotherapist;
declare const index_IconPiano: typeof IconPiano;
declare const index_IconPick: typeof IconPick;
declare const index_IconPicnicTable: typeof IconPicnicTable;
declare const index_IconPictureInPicture: typeof IconPictureInPicture;
declare const index_IconPictureInPictureFilled: typeof IconPictureInPictureFilled;
declare const index_IconPictureInPictureOff: typeof IconPictureInPictureOff;
declare const index_IconPictureInPictureOn: typeof IconPictureInPictureOn;
declare const index_IconPictureInPictureTop: typeof IconPictureInPictureTop;
declare const index_IconPictureInPictureTopFilled: typeof IconPictureInPictureTopFilled;
declare const index_IconPig: typeof IconPig;
declare const index_IconPigFilled: typeof IconPigFilled;
declare const index_IconPigMoney: typeof IconPigMoney;
declare const index_IconPigOff: typeof IconPigOff;
declare const index_IconPilcrow: typeof IconPilcrow;
declare const index_IconPilcrowLeft: typeof IconPilcrowLeft;
declare const index_IconPilcrowRight: typeof IconPilcrowRight;
declare const index_IconPill: typeof IconPill;
declare const index_IconPillFilled: typeof IconPillFilled;
declare const index_IconPillOff: typeof IconPillOff;
declare const index_IconPills: typeof IconPills;
declare const index_IconPin: typeof IconPin;
declare const index_IconPinEnd: typeof IconPinEnd;
declare const index_IconPinFilled: typeof IconPinFilled;
declare const index_IconPinInvoke: typeof IconPinInvoke;
declare const index_IconPingPong: typeof IconPingPong;
declare const index_IconPinned: typeof IconPinned;
declare const index_IconPinnedFilled: typeof IconPinnedFilled;
declare const index_IconPinnedOff: typeof IconPinnedOff;
declare const index_IconPizza: typeof IconPizza;
declare const index_IconPizzaFilled: typeof IconPizzaFilled;
declare const index_IconPizzaOff: typeof IconPizzaOff;
declare const index_IconPlaceholder: typeof IconPlaceholder;
declare const index_IconPlane: typeof IconPlane;
declare const index_IconPlaneArrival: typeof IconPlaneArrival;
declare const index_IconPlaneArrivalFilled: typeof IconPlaneArrivalFilled;
declare const index_IconPlaneDeparture: typeof IconPlaneDeparture;
declare const index_IconPlaneDepartureFilled: typeof IconPlaneDepartureFilled;
declare const index_IconPlaneFilled: typeof IconPlaneFilled;
declare const index_IconPlaneInflight: typeof IconPlaneInflight;
declare const index_IconPlaneOff: typeof IconPlaneOff;
declare const index_IconPlaneTilt: typeof IconPlaneTilt;
declare const index_IconPlaneTiltFilled: typeof IconPlaneTiltFilled;
declare const index_IconPlanet: typeof IconPlanet;
declare const index_IconPlanetOff: typeof IconPlanetOff;
declare const index_IconPlant: typeof IconPlant;
declare const index_IconPlant2: typeof IconPlant2;
declare const index_IconPlant2Off: typeof IconPlant2Off;
declare const index_IconPlantOff: typeof IconPlantOff;
declare const index_IconPlayBasketball: typeof IconPlayBasketball;
declare const index_IconPlayCard: typeof IconPlayCard;
declare const index_IconPlayCard1: typeof IconPlayCard1;
declare const index_IconPlayCard10: typeof IconPlayCard10;
declare const index_IconPlayCard10Filled: typeof IconPlayCard10Filled;
declare const index_IconPlayCard1Filled: typeof IconPlayCard1Filled;
declare const index_IconPlayCard2: typeof IconPlayCard2;
declare const index_IconPlayCard2Filled: typeof IconPlayCard2Filled;
declare const index_IconPlayCard3: typeof IconPlayCard3;
declare const index_IconPlayCard3Filled: typeof IconPlayCard3Filled;
declare const index_IconPlayCard4: typeof IconPlayCard4;
declare const index_IconPlayCard4Filled: typeof IconPlayCard4Filled;
declare const index_IconPlayCard5: typeof IconPlayCard5;
declare const index_IconPlayCard5Filled: typeof IconPlayCard5Filled;
declare const index_IconPlayCard6: typeof IconPlayCard6;
declare const index_IconPlayCard6Filled: typeof IconPlayCard6Filled;
declare const index_IconPlayCard7: typeof IconPlayCard7;
declare const index_IconPlayCard7Filled: typeof IconPlayCard7Filled;
declare const index_IconPlayCard8: typeof IconPlayCard8;
declare const index_IconPlayCard8Filled: typeof IconPlayCard8Filled;
declare const index_IconPlayCard9: typeof IconPlayCard9;
declare const index_IconPlayCard9Filled: typeof IconPlayCard9Filled;
declare const index_IconPlayCardA: typeof IconPlayCardA;
declare const index_IconPlayCardAFilled: typeof IconPlayCardAFilled;
declare const index_IconPlayCardFilled: typeof IconPlayCardFilled;
declare const index_IconPlayCardJ: typeof IconPlayCardJ;
declare const index_IconPlayCardJFilled: typeof IconPlayCardJFilled;
declare const index_IconPlayCardK: typeof IconPlayCardK;
declare const index_IconPlayCardKFilled: typeof IconPlayCardKFilled;
declare const index_IconPlayCardOff: typeof IconPlayCardOff;
declare const index_IconPlayCardQ: typeof IconPlayCardQ;
declare const index_IconPlayCardQFilled: typeof IconPlayCardQFilled;
declare const index_IconPlayCardStar: typeof IconPlayCardStar;
declare const index_IconPlayCardStarFilled: typeof IconPlayCardStarFilled;
declare const index_IconPlayFootball: typeof IconPlayFootball;
declare const index_IconPlayHandball: typeof IconPlayHandball;
declare const index_IconPlayVolleyball: typeof IconPlayVolleyball;
declare const index_IconPlayerEject: typeof IconPlayerEject;
declare const index_IconPlayerEjectFilled: typeof IconPlayerEjectFilled;
declare const index_IconPlayerPause: typeof IconPlayerPause;
declare const index_IconPlayerPauseFilled: typeof IconPlayerPauseFilled;
declare const index_IconPlayerPlay: typeof IconPlayerPlay;
declare const index_IconPlayerPlayFilled: typeof IconPlayerPlayFilled;
declare const index_IconPlayerRecord: typeof IconPlayerRecord;
declare const index_IconPlayerRecordFilled: typeof IconPlayerRecordFilled;
declare const index_IconPlayerSkipBack: typeof IconPlayerSkipBack;
declare const index_IconPlayerSkipBackFilled: typeof IconPlayerSkipBackFilled;
declare const index_IconPlayerSkipForward: typeof IconPlayerSkipForward;
declare const index_IconPlayerSkipForwardFilled: typeof IconPlayerSkipForwardFilled;
declare const index_IconPlayerStop: typeof IconPlayerStop;
declare const index_IconPlayerStopFilled: typeof IconPlayerStopFilled;
declare const index_IconPlayerTrackNext: typeof IconPlayerTrackNext;
declare const index_IconPlayerTrackNextFilled: typeof IconPlayerTrackNextFilled;
declare const index_IconPlayerTrackPrev: typeof IconPlayerTrackPrev;
declare const index_IconPlayerTrackPrevFilled: typeof IconPlayerTrackPrevFilled;
declare const index_IconPlaylist: typeof IconPlaylist;
declare const index_IconPlaylistAdd: typeof IconPlaylistAdd;
declare const index_IconPlaylistFilled: typeof IconPlaylistFilled;
declare const index_IconPlaylistOff: typeof IconPlaylistOff;
declare const index_IconPlaylistX: typeof IconPlaylistX;
declare const index_IconPlaystationCircle: typeof IconPlaystationCircle;
declare const index_IconPlaystationSquare: typeof IconPlaystationSquare;
declare const index_IconPlaystationTriangle: typeof IconPlaystationTriangle;
declare const index_IconPlaystationX: typeof IconPlaystationX;
declare const index_IconPlug: typeof IconPlug;
declare const index_IconPlugConnected: typeof IconPlugConnected;
declare const index_IconPlugConnectedX: typeof IconPlugConnectedX;
declare const index_IconPlugOff: typeof IconPlugOff;
declare const index_IconPlugX: typeof IconPlugX;
declare const index_IconPlus: typeof IconPlus;
declare const index_IconPlusEqual: typeof IconPlusEqual;
declare const index_IconPlusMinus: typeof IconPlusMinus;
declare const index_IconPng: typeof IconPng;
declare const index_IconPodium: typeof IconPodium;
declare const index_IconPodiumOff: typeof IconPodiumOff;
declare const index_IconPoint: typeof IconPoint;
declare const index_IconPointFilled: typeof IconPointFilled;
declare const index_IconPointOff: typeof IconPointOff;
declare const index_IconPointer: typeof IconPointer;
declare const index_IconPointerBolt: typeof IconPointerBolt;
declare const index_IconPointerCancel: typeof IconPointerCancel;
declare const index_IconPointerCheck: typeof IconPointerCheck;
declare const index_IconPointerCode: typeof IconPointerCode;
declare const index_IconPointerCog: typeof IconPointerCog;
declare const index_IconPointerDollar: typeof IconPointerDollar;
declare const index_IconPointerDown: typeof IconPointerDown;
declare const index_IconPointerExclamation: typeof IconPointerExclamation;
declare const index_IconPointerFilled: typeof IconPointerFilled;
declare const index_IconPointerHeart: typeof IconPointerHeart;
declare const index_IconPointerMinus: typeof IconPointerMinus;
declare const index_IconPointerOff: typeof IconPointerOff;
declare const index_IconPointerPause: typeof IconPointerPause;
declare const index_IconPointerPin: typeof IconPointerPin;
declare const index_IconPointerPlus: typeof IconPointerPlus;
declare const index_IconPointerQuestion: typeof IconPointerQuestion;
declare const index_IconPointerSearch: typeof IconPointerSearch;
declare const index_IconPointerShare: typeof IconPointerShare;
declare const index_IconPointerStar: typeof IconPointerStar;
declare const index_IconPointerUp: typeof IconPointerUp;
declare const index_IconPointerX: typeof IconPointerX;
declare const index_IconPokeball: typeof IconPokeball;
declare const index_IconPokeballOff: typeof IconPokeballOff;
declare const index_IconPokerChip: typeof IconPokerChip;
declare const index_IconPolaroid: typeof IconPolaroid;
declare const index_IconPolaroidFilled: typeof IconPolaroidFilled;
declare const index_IconPolygon: typeof IconPolygon;
declare const index_IconPolygonOff: typeof IconPolygonOff;
declare const index_IconPoo: typeof IconPoo;
declare const index_IconPooFilled: typeof IconPooFilled;
declare const index_IconPool: typeof IconPool;
declare const index_IconPoolOff: typeof IconPoolOff;
declare const index_IconPower: typeof IconPower;
declare const index_IconPray: typeof IconPray;
declare const index_IconPremiumRights: typeof IconPremiumRights;
declare const index_IconPrescription: typeof IconPrescription;
declare const index_IconPresentation: typeof IconPresentation;
declare const index_IconPresentationAnalytics: typeof IconPresentationAnalytics;
declare const index_IconPresentationAnalyticsFilled: typeof IconPresentationAnalyticsFilled;
declare const index_IconPresentationFilled: typeof IconPresentationFilled;
declare const index_IconPresentationOff: typeof IconPresentationOff;
declare const index_IconPrinter: typeof IconPrinter;
declare const index_IconPrinterOff: typeof IconPrinterOff;
declare const index_IconPrism: typeof IconPrism;
declare const index_IconPrismLight: typeof IconPrismLight;
declare const index_IconPrismOff: typeof IconPrismOff;
declare const index_IconPrismPlus: typeof IconPrismPlus;
declare const index_IconPrison: typeof IconPrison;
declare const index_IconProgress: typeof IconProgress;
declare const index_IconProgressAlert: typeof IconProgressAlert;
declare const index_IconProgressBolt: typeof IconProgressBolt;
declare const index_IconProgressCheck: typeof IconProgressCheck;
declare const index_IconProgressDown: typeof IconProgressDown;
declare const index_IconProgressHelp: typeof IconProgressHelp;
declare const index_IconProgressX: typeof IconProgressX;
declare const index_IconPrompt: typeof IconPrompt;
declare const index_IconProng: typeof IconProng;
declare const index_IconPropeller: typeof IconPropeller;
declare const index_IconPropellerOff: typeof IconPropellerOff;
declare const index_IconProtocol: typeof IconProtocol;
declare const index_IconPumpkinScary: typeof IconPumpkinScary;
declare const index_IconPuzzle: typeof IconPuzzle;
declare const index_IconPuzzle2: typeof IconPuzzle2;
declare const index_IconPuzzleFilled: typeof IconPuzzleFilled;
declare const index_IconPuzzleOff: typeof IconPuzzleOff;
declare const index_IconPyramid: typeof IconPyramid;
declare const index_IconPyramidOff: typeof IconPyramidOff;
declare const index_IconPyramidPlus: typeof IconPyramidPlus;
declare const index_IconQrcode: typeof IconQrcode;
declare const index_IconQrcodeOff: typeof IconQrcodeOff;
declare const index_IconQuestionMark: typeof IconQuestionMark;
declare const index_IconQuote: typeof IconQuote;
declare const index_IconQuoteFilled: typeof IconQuoteFilled;
declare const index_IconQuoteOff: typeof IconQuoteOff;
declare const index_IconQuotes: typeof IconQuotes;
declare const index_IconRadar: typeof IconRadar;
declare const index_IconRadar2: typeof IconRadar2;
declare const index_IconRadarFilled: typeof IconRadarFilled;
declare const index_IconRadarOff: typeof IconRadarOff;
declare const index_IconRadio: typeof IconRadio;
declare const index_IconRadioOff: typeof IconRadioOff;
declare const index_IconRadioactive: typeof IconRadioactive;
declare const index_IconRadioactiveFilled: typeof IconRadioactiveFilled;
declare const index_IconRadioactiveOff: typeof IconRadioactiveOff;
declare const index_IconRadiusBottomLeft: typeof IconRadiusBottomLeft;
declare const index_IconRadiusBottomRight: typeof IconRadiusBottomRight;
declare const index_IconRadiusTopLeft: typeof IconRadiusTopLeft;
declare const index_IconRadiusTopRight: typeof IconRadiusTopRight;
declare const index_IconRainbow: typeof IconRainbow;
declare const index_IconRainbowOff: typeof IconRainbowOff;
declare const index_IconRating12Plus: typeof IconRating12Plus;
declare const index_IconRating14Plus: typeof IconRating14Plus;
declare const index_IconRating16Plus: typeof IconRating16Plus;
declare const index_IconRating18Plus: typeof IconRating18Plus;
declare const index_IconRating21Plus: typeof IconRating21Plus;
declare const index_IconRazor: typeof IconRazor;
declare const index_IconRazorElectric: typeof IconRazorElectric;
declare const index_IconReceipt: typeof IconReceipt;
declare const index_IconReceipt2: typeof IconReceipt2;
declare const index_IconReceiptBitcoin: typeof IconReceiptBitcoin;
declare const index_IconReceiptDollar: typeof IconReceiptDollar;
declare const index_IconReceiptDollarFilled: typeof IconReceiptDollarFilled;
declare const index_IconReceiptEuro: typeof IconReceiptEuro;
declare const index_IconReceiptEuroFilled: typeof IconReceiptEuroFilled;
declare const index_IconReceiptFilled: typeof IconReceiptFilled;
declare const index_IconReceiptOff: typeof IconReceiptOff;
declare const index_IconReceiptPound: typeof IconReceiptPound;
declare const index_IconReceiptPoundFilled: typeof IconReceiptPoundFilled;
declare const index_IconReceiptRefund: typeof IconReceiptRefund;
declare const index_IconReceiptRupee: typeof IconReceiptRupee;
declare const index_IconReceiptRupeeFilled: typeof IconReceiptRupeeFilled;
declare const index_IconReceiptTax: typeof IconReceiptTax;
declare const index_IconReceiptYen: typeof IconReceiptYen;
declare const index_IconReceiptYenFilled: typeof IconReceiptYenFilled;
declare const index_IconReceiptYuan: typeof IconReceiptYuan;
declare const index_IconReceiptYuanFilled: typeof IconReceiptYuanFilled;
declare const index_IconRecharging: typeof IconRecharging;
declare const index_IconRecordMail: typeof IconRecordMail;
declare const index_IconRecordMailOff: typeof IconRecordMailOff;
declare const index_IconRectangle: typeof IconRectangle;
declare const index_IconRectangleFilled: typeof IconRectangleFilled;
declare const index_IconRectangleRoundedBottom: typeof IconRectangleRoundedBottom;
declare const index_IconRectangleRoundedTop: typeof IconRectangleRoundedTop;
declare const index_IconRectangleVertical: typeof IconRectangleVertical;
declare const index_IconRectangleVerticalFilled: typeof IconRectangleVerticalFilled;
declare const index_IconRectangularPrism: typeof IconRectangularPrism;
declare const index_IconRectangularPrismOff: typeof IconRectangularPrismOff;
declare const index_IconRectangularPrismPlus: typeof IconRectangularPrismPlus;
declare const index_IconRecycle: typeof IconRecycle;
declare const index_IconRecycleOff: typeof IconRecycleOff;
declare const index_IconRefresh: typeof IconRefresh;
declare const index_IconRefreshAlert: typeof IconRefreshAlert;
declare const index_IconRefreshDot: typeof IconRefreshDot;
declare const index_IconRefreshOff: typeof IconRefreshOff;
declare const index_IconRegex: typeof IconRegex;
declare const index_IconRegexOff: typeof IconRegexOff;
declare const index_IconRegistered: typeof IconRegistered;
declare const index_IconRegisteredFilled: typeof IconRegisteredFilled;
declare const index_IconRelationManyToMany: typeof IconRelationManyToMany;
declare const index_IconRelationManyToManyFilled: typeof IconRelationManyToManyFilled;
declare const index_IconRelationOneToMany: typeof IconRelationOneToMany;
declare const index_IconRelationOneToManyFilled: typeof IconRelationOneToManyFilled;
declare const index_IconRelationOneToOne: typeof IconRelationOneToOne;
declare const index_IconRelationOneToOneFilled: typeof IconRelationOneToOneFilled;
declare const index_IconReload: typeof IconReload;
declare const index_IconReorder: typeof IconReorder;
declare const index_IconRepeat: typeof IconRepeat;
declare const index_IconRepeatOff: typeof IconRepeatOff;
declare const index_IconRepeatOnce: typeof IconRepeatOnce;
declare const index_IconReplace: typeof IconReplace;
declare const index_IconReplaceFilled: typeof IconReplaceFilled;
declare const index_IconReplaceOff: typeof IconReplaceOff;
declare const index_IconReplaceUser: typeof IconReplaceUser;
declare const index_IconReport: typeof IconReport;
declare const index_IconReportAnalytics: typeof IconReportAnalytics;
declare const index_IconReportAnalyticsFilled: typeof IconReportAnalyticsFilled;
declare const index_IconReportMedical: typeof IconReportMedical;
declare const index_IconReportMoney: typeof IconReportMoney;
declare const index_IconReportMoneyFilled: typeof IconReportMoneyFilled;
declare const index_IconReportOff: typeof IconReportOff;
declare const index_IconReportSearch: typeof IconReportSearch;
declare const index_IconReservedLine: typeof IconReservedLine;
declare const index_IconResize: typeof IconResize;
declare const index_IconRestore: typeof IconRestore;
declare const index_IconRewindBackward10: typeof IconRewindBackward10;
declare const index_IconRewindBackward15: typeof IconRewindBackward15;
declare const index_IconRewindBackward20: typeof IconRewindBackward20;
declare const index_IconRewindBackward30: typeof IconRewindBackward30;
declare const index_IconRewindBackward40: typeof IconRewindBackward40;
declare const index_IconRewindBackward5: typeof IconRewindBackward5;
declare const index_IconRewindBackward50: typeof IconRewindBackward50;
declare const index_IconRewindBackward60: typeof IconRewindBackward60;
declare const index_IconRewindForward10: typeof IconRewindForward10;
declare const index_IconRewindForward15: typeof IconRewindForward15;
declare const index_IconRewindForward20: typeof IconRewindForward20;
declare const index_IconRewindForward30: typeof IconRewindForward30;
declare const index_IconRewindForward40: typeof IconRewindForward40;
declare const index_IconRewindForward5: typeof IconRewindForward5;
declare const index_IconRewindForward50: typeof IconRewindForward50;
declare const index_IconRewindForward60: typeof IconRewindForward60;
declare const index_IconRibbonHealth: typeof IconRibbonHealth;
declare const index_IconRings: typeof IconRings;
declare const index_IconRipple: typeof IconRipple;
declare const index_IconRippleDown: typeof IconRippleDown;
declare const index_IconRippleOff: typeof IconRippleOff;
declare const index_IconRippleUp: typeof IconRippleUp;
declare const index_IconRoad: typeof IconRoad;
declare const index_IconRoadOff: typeof IconRoadOff;
declare const index_IconRoadSign: typeof IconRoadSign;
declare const index_IconRobot: typeof IconRobot;
declare const index_IconRobotFace: typeof IconRobotFace;
declare const index_IconRobotOff: typeof IconRobotOff;
declare const index_IconRocket: typeof IconRocket;
declare const index_IconRocketOff: typeof IconRocketOff;
declare const index_IconRollerSkating: typeof IconRollerSkating;
declare const index_IconRollercoaster: typeof IconRollercoaster;
declare const index_IconRollercoasterFilled: typeof IconRollercoasterFilled;
declare const index_IconRollercoasterOff: typeof IconRollercoasterOff;
declare const index_IconRosette: typeof IconRosette;
declare const index_IconRosetteAsterisk: typeof IconRosetteAsterisk;
declare const index_IconRosetteDiscount: typeof IconRosetteDiscount;
declare const index_IconRosetteDiscountCheck: typeof IconRosetteDiscountCheck;
declare const index_IconRosetteDiscountCheckFilled: typeof IconRosetteDiscountCheckFilled;
declare const index_IconRosetteDiscountCheckOff: typeof IconRosetteDiscountCheckOff;
declare const index_IconRosetteDiscountFilled: typeof IconRosetteDiscountFilled;
declare const index_IconRosetteDiscountOff: typeof IconRosetteDiscountOff;
declare const index_IconRosetteFilled: typeof IconRosetteFilled;
declare const index_IconRosetteNumber0: typeof IconRosetteNumber0;
declare const index_IconRosetteNumber1: typeof IconRosetteNumber1;
declare const index_IconRosetteNumber2: typeof IconRosetteNumber2;
declare const index_IconRosetteNumber3: typeof IconRosetteNumber3;
declare const index_IconRosetteNumber4: typeof IconRosetteNumber4;
declare const index_IconRosetteNumber5: typeof IconRosetteNumber5;
declare const index_IconRosetteNumber6: typeof IconRosetteNumber6;
declare const index_IconRosetteNumber7: typeof IconRosetteNumber7;
declare const index_IconRosetteNumber8: typeof IconRosetteNumber8;
declare const index_IconRosetteNumber9: typeof IconRosetteNumber9;
declare const index_IconRotate: typeof IconRotate;
declare const index_IconRotate2: typeof IconRotate2;
declare const index_IconRotate360: typeof IconRotate360;
declare const index_IconRotate3d: typeof IconRotate3d;
declare const index_IconRotateClockwise: typeof IconRotateClockwise;
declare const index_IconRotateClockwise2: typeof IconRotateClockwise2;
declare const index_IconRotateDot: typeof IconRotateDot;
declare const index_IconRotateRectangle: typeof IconRotateRectangle;
declare const index_IconRoute: typeof IconRoute;
declare const index_IconRoute2: typeof IconRoute2;
declare const index_IconRouteAltLeft: typeof IconRouteAltLeft;
declare const index_IconRouteAltRight: typeof IconRouteAltRight;
declare const index_IconRouteOff: typeof IconRouteOff;
declare const index_IconRouteScan: typeof IconRouteScan;
declare const index_IconRouteSquare: typeof IconRouteSquare;
declare const index_IconRouteSquare2: typeof IconRouteSquare2;
declare const index_IconRouteX: typeof IconRouteX;
declare const index_IconRouteX2: typeof IconRouteX2;
declare const index_IconRouter: typeof IconRouter;
declare const index_IconRouterOff: typeof IconRouterOff;
declare const index_IconRowInsertBottom: typeof IconRowInsertBottom;
declare const index_IconRowInsertTop: typeof IconRowInsertTop;
declare const index_IconRowRemove: typeof IconRowRemove;
declare const index_IconRss: typeof IconRss;
declare const index_IconRubberStamp: typeof IconRubberStamp;
declare const index_IconRubberStampOff: typeof IconRubberStampOff;
declare const index_IconRuler: typeof IconRuler;
declare const index_IconRuler2: typeof IconRuler2;
declare const index_IconRuler2Off: typeof IconRuler2Off;
declare const index_IconRuler3: typeof IconRuler3;
declare const index_IconRulerMeasure: typeof IconRulerMeasure;
declare const index_IconRulerMeasure2: typeof IconRulerMeasure2;
declare const index_IconRulerOff: typeof IconRulerOff;
declare const index_IconRun: typeof IconRun;
declare const index_IconRvTruck: typeof IconRvTruck;
declare const index_IconSTurnDown: typeof IconSTurnDown;
declare const index_IconSTurnLeft: typeof IconSTurnLeft;
declare const index_IconSTurnRight: typeof IconSTurnRight;
declare const index_IconSTurnUp: typeof IconSTurnUp;
declare const index_IconSailboat: typeof IconSailboat;
declare const index_IconSailboat2: typeof IconSailboat2;
declare const index_IconSailboatOff: typeof IconSailboatOff;
declare const index_IconSalad: typeof IconSalad;
declare const index_IconSaladFilled: typeof IconSaladFilled;
declare const index_IconSalt: typeof IconSalt;
declare const index_IconSandbox: typeof IconSandbox;
declare const index_IconSatellite: typeof IconSatellite;
declare const index_IconSatelliteFilled: typeof IconSatelliteFilled;
declare const index_IconSatelliteOff: typeof IconSatelliteOff;
declare const index_IconSausage: typeof IconSausage;
declare const index_IconScale: typeof IconScale;
declare const index_IconScaleOff: typeof IconScaleOff;
declare const index_IconScaleOutline: typeof IconScaleOutline;
declare const index_IconScaleOutlineOff: typeof IconScaleOutlineOff;
declare const index_IconScan: typeof IconScan;
declare const index_IconScanEye: typeof IconScanEye;
declare const index_IconScanPosition: typeof IconScanPosition;
declare const index_IconSchema: typeof IconSchema;
declare const index_IconSchemaOff: typeof IconSchemaOff;
declare const index_IconSchool: typeof IconSchool;
declare const index_IconSchoolBell: typeof IconSchoolBell;
declare const index_IconSchoolOff: typeof IconSchoolOff;
declare const index_IconScissors: typeof IconScissors;
declare const index_IconScissorsOff: typeof IconScissorsOff;
declare const index_IconScooter: typeof IconScooter;
declare const index_IconScooterElectric: typeof IconScooterElectric;
declare const index_IconScoreboard: typeof IconScoreboard;
declare const index_IconScreenShare: typeof IconScreenShare;
declare const index_IconScreenShareOff: typeof IconScreenShareOff;
declare const index_IconScreenshot: typeof IconScreenshot;
declare const index_IconScribble: typeof IconScribble;
declare const index_IconScribbleOff: typeof IconScribbleOff;
declare const index_IconScript: typeof IconScript;
declare const index_IconScriptMinus: typeof IconScriptMinus;
declare const index_IconScriptPlus: typeof IconScriptPlus;
declare const index_IconScriptX: typeof IconScriptX;
declare const index_IconScubaDiving: typeof IconScubaDiving;
declare const index_IconScubaDivingTank: typeof IconScubaDivingTank;
declare const index_IconScubaDivingTankFilled: typeof IconScubaDivingTankFilled;
declare const index_IconScubaMask: typeof IconScubaMask;
declare const index_IconScubaMaskOff: typeof IconScubaMaskOff;
declare const index_IconSdk: typeof IconSdk;
declare const index_IconSearch: typeof IconSearch;
declare const index_IconSearchOff: typeof IconSearchOff;
declare const index_IconSection: typeof IconSection;
declare const index_IconSectionFilled: typeof IconSectionFilled;
declare const index_IconSectionSign: typeof IconSectionSign;
declare const index_IconSeedling: typeof IconSeedling;
declare const index_IconSeedlingFilled: typeof IconSeedlingFilled;
declare const index_IconSeedlingOff: typeof IconSeedlingOff;
declare const index_IconSelect: typeof IconSelect;
declare const index_IconSelectAll: typeof IconSelectAll;
declare const index_IconSelector: typeof IconSelector;
declare const index_IconSend: typeof IconSend;
declare const index_IconSend2: typeof IconSend2;
declare const index_IconSendOff: typeof IconSendOff;
declare const index_IconSeo: typeof IconSeo;
declare const index_IconSeparator: typeof IconSeparator;
declare const index_IconSeparatorHorizontal: typeof IconSeparatorHorizontal;
declare const index_IconSeparatorVertical: typeof IconSeparatorVertical;
declare const index_IconServer: typeof IconServer;
declare const index_IconServer2: typeof IconServer2;
declare const index_IconServerBolt: typeof IconServerBolt;
declare const index_IconServerCog: typeof IconServerCog;
declare const index_IconServerOff: typeof IconServerOff;
declare const index_IconServerSpark: typeof IconServerSpark;
declare const index_IconServicemark: typeof IconServicemark;
declare const index_IconSettings: typeof IconSettings;
declare const index_IconSettings2: typeof IconSettings2;
declare const index_IconSettingsAi: typeof IconSettingsAi;
declare const index_IconSettingsAutomation: typeof IconSettingsAutomation;
declare const index_IconSettingsBolt: typeof IconSettingsBolt;
declare const index_IconSettingsCancel: typeof IconSettingsCancel;
declare const index_IconSettingsCheck: typeof IconSettingsCheck;
declare const index_IconSettingsCode: typeof IconSettingsCode;
declare const index_IconSettingsCog: typeof IconSettingsCog;
declare const index_IconSettingsDollar: typeof IconSettingsDollar;
declare const index_IconSettingsDown: typeof IconSettingsDown;
declare const index_IconSettingsExclamation: typeof IconSettingsExclamation;
declare const index_IconSettingsFilled: typeof IconSettingsFilled;
declare const index_IconSettingsHeart: typeof IconSettingsHeart;
declare const index_IconSettingsMinus: typeof IconSettingsMinus;
declare const index_IconSettingsOff: typeof IconSettingsOff;
declare const index_IconSettingsPause: typeof IconSettingsPause;
declare const index_IconSettingsPin: typeof IconSettingsPin;
declare const index_IconSettingsPlus: typeof IconSettingsPlus;
declare const index_IconSettingsQuestion: typeof IconSettingsQuestion;
declare const index_IconSettingsSearch: typeof IconSettingsSearch;
declare const index_IconSettingsShare: typeof IconSettingsShare;
declare const index_IconSettingsSpark: typeof IconSettingsSpark;
declare const index_IconSettingsStar: typeof IconSettingsStar;
declare const index_IconSettingsUp: typeof IconSettingsUp;
declare const index_IconSettingsX: typeof IconSettingsX;
declare const index_IconShadow: typeof IconShadow;
declare const index_IconShadowOff: typeof IconShadowOff;
declare const index_IconShape: typeof IconShape;
declare const index_IconShape2: typeof IconShape2;
declare const index_IconShape3: typeof IconShape3;
declare const index_IconShapeOff: typeof IconShapeOff;
declare const index_IconShare: typeof IconShare;
declare const index_IconShare2: typeof IconShare2;
declare const index_IconShare3: typeof IconShare3;
declare const index_IconShareOff: typeof IconShareOff;
declare const index_IconShareplay: typeof IconShareplay;
declare const index_IconShield: typeof IconShield;
declare const index_IconShieldBolt: typeof IconShieldBolt;
declare const index_IconShieldCancel: typeof IconShieldCancel;
declare const index_IconShieldCheck: typeof IconShieldCheck;
declare const index_IconShieldCheckFilled: typeof IconShieldCheckFilled;
declare const index_IconShieldCheckered: typeof IconShieldCheckered;
declare const index_IconShieldCheckeredFilled: typeof IconShieldCheckeredFilled;
declare const index_IconShieldChevron: typeof IconShieldChevron;
declare const index_IconShieldCode: typeof IconShieldCode;
declare const index_IconShieldCog: typeof IconShieldCog;
declare const index_IconShieldDollar: typeof IconShieldDollar;
declare const index_IconShieldDown: typeof IconShieldDown;
declare const index_IconShieldExclamation: typeof IconShieldExclamation;
declare const index_IconShieldFilled: typeof IconShieldFilled;
declare const index_IconShieldHalf: typeof IconShieldHalf;
declare const index_IconShieldHalfFilled: typeof IconShieldHalfFilled;
declare const index_IconShieldHeart: typeof IconShieldHeart;
declare const index_IconShieldLock: typeof IconShieldLock;
declare const index_IconShieldLockFilled: typeof IconShieldLockFilled;
declare const index_IconShieldMinus: typeof IconShieldMinus;
declare const index_IconShieldOff: typeof IconShieldOff;
declare const index_IconShieldPause: typeof IconShieldPause;
declare const index_IconShieldPin: typeof IconShieldPin;
declare const index_IconShieldPlus: typeof IconShieldPlus;
declare const index_IconShieldQuestion: typeof IconShieldQuestion;
declare const index_IconShieldSearch: typeof IconShieldSearch;
declare const index_IconShieldShare: typeof IconShieldShare;
declare const index_IconShieldStar: typeof IconShieldStar;
declare const index_IconShieldUp: typeof IconShieldUp;
declare const index_IconShieldX: typeof IconShieldX;
declare const index_IconShip: typeof IconShip;
declare const index_IconShipOff: typeof IconShipOff;
declare const index_IconShirt: typeof IconShirt;
declare const index_IconShirtFilled: typeof IconShirtFilled;
declare const index_IconShirtOff: typeof IconShirtOff;
declare const index_IconShirtSport: typeof IconShirtSport;
declare const index_IconShoe: typeof IconShoe;
declare const index_IconShoeOff: typeof IconShoeOff;
declare const index_IconShoppingBag: typeof IconShoppingBag;
declare const index_IconShoppingBagCheck: typeof IconShoppingBagCheck;
declare const index_IconShoppingBagDiscount: typeof IconShoppingBagDiscount;
declare const index_IconShoppingBagEdit: typeof IconShoppingBagEdit;
declare const index_IconShoppingBagExclamation: typeof IconShoppingBagExclamation;
declare const index_IconShoppingBagHeart: typeof IconShoppingBagHeart;
declare const index_IconShoppingBagMinus: typeof IconShoppingBagMinus;
declare const index_IconShoppingBagPlus: typeof IconShoppingBagPlus;
declare const index_IconShoppingBagSearch: typeof IconShoppingBagSearch;
declare const index_IconShoppingBagX: typeof IconShoppingBagX;
declare const index_IconShoppingCart: typeof IconShoppingCart;
declare const index_IconShoppingCartBolt: typeof IconShoppingCartBolt;
declare const index_IconShoppingCartCancel: typeof IconShoppingCartCancel;
declare const index_IconShoppingCartCheck: typeof IconShoppingCartCheck;
declare const index_IconShoppingCartCode: typeof IconShoppingCartCode;
declare const index_IconShoppingCartCog: typeof IconShoppingCartCog;
declare const index_IconShoppingCartCopy: typeof IconShoppingCartCopy;
declare const index_IconShoppingCartDiscount: typeof IconShoppingCartDiscount;
declare const index_IconShoppingCartDollar: typeof IconShoppingCartDollar;
declare const index_IconShoppingCartDown: typeof IconShoppingCartDown;
declare const index_IconShoppingCartExclamation: typeof IconShoppingCartExclamation;
declare const index_IconShoppingCartFilled: typeof IconShoppingCartFilled;
declare const index_IconShoppingCartHeart: typeof IconShoppingCartHeart;
declare const index_IconShoppingCartMinus: typeof IconShoppingCartMinus;
declare const index_IconShoppingCartOff: typeof IconShoppingCartOff;
declare const index_IconShoppingCartPause: typeof IconShoppingCartPause;
declare const index_IconShoppingCartPin: typeof IconShoppingCartPin;
declare const index_IconShoppingCartPlus: typeof IconShoppingCartPlus;
declare const index_IconShoppingCartQuestion: typeof IconShoppingCartQuestion;
declare const index_IconShoppingCartSearch: typeof IconShoppingCartSearch;
declare const index_IconShoppingCartShare: typeof IconShoppingCartShare;
declare const index_IconShoppingCartStar: typeof IconShoppingCartStar;
declare const index_IconShoppingCartUp: typeof IconShoppingCartUp;
declare const index_IconShoppingCartX: typeof IconShoppingCartX;
declare const index_IconShovel: typeof IconShovel;
declare const index_IconShovelPitchforks: typeof IconShovelPitchforks;
declare const index_IconShredder: typeof IconShredder;
declare const index_IconSignLeft: typeof IconSignLeft;
declare const index_IconSignLeftFilled: typeof IconSignLeftFilled;
declare const index_IconSignRight: typeof IconSignRight;
declare const index_IconSignRightFilled: typeof IconSignRightFilled;
declare const index_IconSignal2g: typeof IconSignal2g;
declare const index_IconSignal3g: typeof IconSignal3g;
declare const index_IconSignal4g: typeof IconSignal4g;
declare const index_IconSignal4gPlus: typeof IconSignal4gPlus;
declare const index_IconSignal5g: typeof IconSignal5g;
declare const index_IconSignal6g: typeof IconSignal6g;
declare const index_IconSignalE: typeof IconSignalE;
declare const index_IconSignalG: typeof IconSignalG;
declare const index_IconSignalH: typeof IconSignalH;
declare const index_IconSignalHPlus: typeof IconSignalHPlus;
declare const index_IconSignalLte: typeof IconSignalLte;
declare const index_IconSignature: typeof IconSignature;
declare const index_IconSignatureOff: typeof IconSignatureOff;
declare const index_IconSitemap: typeof IconSitemap;
declare const index_IconSitemapFilled: typeof IconSitemapFilled;
declare const index_IconSitemapOff: typeof IconSitemapOff;
declare const index_IconSkateboard: typeof IconSkateboard;
declare const index_IconSkateboardOff: typeof IconSkateboardOff;
declare const index_IconSkateboarding: typeof IconSkateboarding;
declare const index_IconSkewX: typeof IconSkewX;
declare const index_IconSkewY: typeof IconSkewY;
declare const index_IconSkiJumping: typeof IconSkiJumping;
declare const index_IconSkull: typeof IconSkull;
declare const index_IconSlash: typeof IconSlash;
declare const index_IconSlashes: typeof IconSlashes;
declare const index_IconSleigh: typeof IconSleigh;
declare const index_IconSlice: typeof IconSlice;
declare const index_IconSlideshow: typeof IconSlideshow;
declare const index_IconSmartHome: typeof IconSmartHome;
declare const index_IconSmartHomeOff: typeof IconSmartHomeOff;
declare const index_IconSmoking: typeof IconSmoking;
declare const index_IconSmokingNo: typeof IconSmokingNo;
declare const index_IconSnowboarding: typeof IconSnowboarding;
declare const index_IconSnowflake: typeof IconSnowflake;
declare const index_IconSnowflakeOff: typeof IconSnowflakeOff;
declare const index_IconSnowman: typeof IconSnowman;
declare const index_IconSoccerField: typeof IconSoccerField;
declare const index_IconSocial: typeof IconSocial;
declare const index_IconSocialOff: typeof IconSocialOff;
declare const index_IconSock: typeof IconSock;
declare const index_IconSofa: typeof IconSofa;
declare const index_IconSofaOff: typeof IconSofaOff;
declare const index_IconSolarElectricity: typeof IconSolarElectricity;
declare const index_IconSolarPanel: typeof IconSolarPanel;
declare const index_IconSolarPanel2: typeof IconSolarPanel2;
declare const index_IconSort09: typeof IconSort09;
declare const index_IconSort90: typeof IconSort90;
declare const index_IconSortAZ: typeof IconSortAZ;
declare const index_IconSortAscending: typeof IconSortAscending;
declare const index_IconSortAscending2: typeof IconSortAscending2;
declare const index_IconSortAscending2Filled: typeof IconSortAscending2Filled;
declare const index_IconSortAscendingLetters: typeof IconSortAscendingLetters;
declare const index_IconSortAscendingNumbers: typeof IconSortAscendingNumbers;
declare const index_IconSortAscendingShapes: typeof IconSortAscendingShapes;
declare const index_IconSortAscendingShapesFilled: typeof IconSortAscendingShapesFilled;
declare const index_IconSortAscendingSmallBig: typeof IconSortAscendingSmallBig;
declare const index_IconSortDescending: typeof IconSortDescending;
declare const index_IconSortDescending2: typeof IconSortDescending2;
declare const index_IconSortDescending2Filled: typeof IconSortDescending2Filled;
declare const index_IconSortDescendingLetters: typeof IconSortDescendingLetters;
declare const index_IconSortDescendingNumbers: typeof IconSortDescendingNumbers;
declare const index_IconSortDescendingShapes: typeof IconSortDescendingShapes;
declare const index_IconSortDescendingShapesFilled: typeof IconSortDescendingShapesFilled;
declare const index_IconSortDescendingSmallBig: typeof IconSortDescendingSmallBig;
declare const index_IconSortZA: typeof IconSortZA;
declare const index_IconSos: typeof IconSos;
declare const index_IconSoup: typeof IconSoup;
declare const index_IconSoupFilled: typeof IconSoupFilled;
declare const index_IconSoupOff: typeof IconSoupOff;
declare const index_IconSourceCode: typeof IconSourceCode;
declare const index_IconSpace: typeof IconSpace;
declare const index_IconSpaceOff: typeof IconSpaceOff;
declare const index_IconSpaces: typeof IconSpaces;
declare const index_IconSpacingHorizontal: typeof IconSpacingHorizontal;
declare const index_IconSpacingVertical: typeof IconSpacingVertical;
declare const index_IconSpade: typeof IconSpade;
declare const index_IconSpadeFilled: typeof IconSpadeFilled;
declare const index_IconSparkles: typeof IconSparkles;
declare const index_IconSparkles2: typeof IconSparkles2;
declare const index_IconSparkles2Filled: typeof IconSparkles2Filled;
declare const index_IconSparklesFilled: typeof IconSparklesFilled;
declare const index_IconSpeakerphone: typeof IconSpeakerphone;
declare const index_IconSpeedboat: typeof IconSpeedboat;
declare const index_IconSpeedboatFilled: typeof IconSpeedboatFilled;
declare const index_IconSphere: typeof IconSphere;
declare const index_IconSphereOff: typeof IconSphereOff;
declare const index_IconSpherePlus: typeof IconSpherePlus;
declare const index_IconSpider: typeof IconSpider;
declare const index_IconSpiderFilled: typeof IconSpiderFilled;
declare const index_IconSpiral: typeof IconSpiral;
declare const index_IconSpiralOff: typeof IconSpiralOff;
declare const index_IconSportBillard: typeof IconSportBillard;
declare const index_IconSpray: typeof IconSpray;
declare const index_IconSpy: typeof IconSpy;
declare const index_IconSpyOff: typeof IconSpyOff;
declare const index_IconSql: typeof IconSql;
declare const index_IconSquare: typeof IconSquare;
declare const index_IconSquareArrowDown: typeof IconSquareArrowDown;
declare const index_IconSquareArrowDownFilled: typeof IconSquareArrowDownFilled;
declare const index_IconSquareArrowLeft: typeof IconSquareArrowLeft;
declare const index_IconSquareArrowLeftFilled: typeof IconSquareArrowLeftFilled;
declare const index_IconSquareArrowRight: typeof IconSquareArrowRight;
declare const index_IconSquareArrowRightFilled: typeof IconSquareArrowRightFilled;
declare const index_IconSquareArrowUp: typeof IconSquareArrowUp;
declare const index_IconSquareArrowUpFilled: typeof IconSquareArrowUpFilled;
declare const index_IconSquareAsterisk: typeof IconSquareAsterisk;
declare const index_IconSquareAsteriskFilled: typeof IconSquareAsteriskFilled;
declare const index_IconSquareCheck: typeof IconSquareCheck;
declare const index_IconSquareCheckFilled: typeof IconSquareCheckFilled;
declare const index_IconSquareChevronDown: typeof IconSquareChevronDown;
declare const index_IconSquareChevronDownFilled: typeof IconSquareChevronDownFilled;
declare const index_IconSquareChevronLeft: typeof IconSquareChevronLeft;
declare const index_IconSquareChevronLeftFilled: typeof IconSquareChevronLeftFilled;
declare const index_IconSquareChevronRight: typeof IconSquareChevronRight;
declare const index_IconSquareChevronRightFilled: typeof IconSquareChevronRightFilled;
declare const index_IconSquareChevronUp: typeof IconSquareChevronUp;
declare const index_IconSquareChevronUpFilled: typeof IconSquareChevronUpFilled;
declare const index_IconSquareChevronsDown: typeof IconSquareChevronsDown;
declare const index_IconSquareChevronsDownFilled: typeof IconSquareChevronsDownFilled;
declare const index_IconSquareChevronsLeft: typeof IconSquareChevronsLeft;
declare const index_IconSquareChevronsLeftFilled: typeof IconSquareChevronsLeftFilled;
declare const index_IconSquareChevronsRight: typeof IconSquareChevronsRight;
declare const index_IconSquareChevronsRightFilled: typeof IconSquareChevronsRightFilled;
declare const index_IconSquareChevronsUp: typeof IconSquareChevronsUp;
declare const index_IconSquareChevronsUpFilled: typeof IconSquareChevronsUpFilled;
declare const index_IconSquareDashed: typeof IconSquareDashed;
declare const index_IconSquareDot: typeof IconSquareDot;
declare const index_IconSquareDotFilled: typeof IconSquareDotFilled;
declare const index_IconSquareF0: typeof IconSquareF0;
declare const index_IconSquareF0Filled: typeof IconSquareF0Filled;
declare const index_IconSquareF1: typeof IconSquareF1;
declare const index_IconSquareF1Filled: typeof IconSquareF1Filled;
declare const index_IconSquareF2: typeof IconSquareF2;
declare const index_IconSquareF2Filled: typeof IconSquareF2Filled;
declare const index_IconSquareF3: typeof IconSquareF3;
declare const index_IconSquareF3Filled: typeof IconSquareF3Filled;
declare const index_IconSquareF4: typeof IconSquareF4;
declare const index_IconSquareF4Filled: typeof IconSquareF4Filled;
declare const index_IconSquareF5: typeof IconSquareF5;
declare const index_IconSquareF5Filled: typeof IconSquareF5Filled;
declare const index_IconSquareF6: typeof IconSquareF6;
declare const index_IconSquareF6Filled: typeof IconSquareF6Filled;
declare const index_IconSquareF7: typeof IconSquareF7;
declare const index_IconSquareF7Filled: typeof IconSquareF7Filled;
declare const index_IconSquareF8: typeof IconSquareF8;
declare const index_IconSquareF8Filled: typeof IconSquareF8Filled;
declare const index_IconSquareF9: typeof IconSquareF9;
declare const index_IconSquareF9Filled: typeof IconSquareF9Filled;
declare const index_IconSquareFilled: typeof IconSquareFilled;
declare const index_IconSquareForbid: typeof IconSquareForbid;
declare const index_IconSquareForbid2: typeof IconSquareForbid2;
declare const index_IconSquareHalf: typeof IconSquareHalf;
declare const index_IconSquareKey: typeof IconSquareKey;
declare const index_IconSquareLetterA: typeof IconSquareLetterA;
declare const index_IconSquareLetterAFilled: typeof IconSquareLetterAFilled;
declare const index_IconSquareLetterB: typeof IconSquareLetterB;
declare const index_IconSquareLetterBFilled: typeof IconSquareLetterBFilled;
declare const index_IconSquareLetterC: typeof IconSquareLetterC;
declare const index_IconSquareLetterCFilled: typeof IconSquareLetterCFilled;
declare const index_IconSquareLetterD: typeof IconSquareLetterD;
declare const index_IconSquareLetterDFilled: typeof IconSquareLetterDFilled;
declare const index_IconSquareLetterE: typeof IconSquareLetterE;
declare const index_IconSquareLetterEFilled: typeof IconSquareLetterEFilled;
declare const index_IconSquareLetterF: typeof IconSquareLetterF;
declare const index_IconSquareLetterFFilled: typeof IconSquareLetterFFilled;
declare const index_IconSquareLetterG: typeof IconSquareLetterG;
declare const index_IconSquareLetterGFilled: typeof IconSquareLetterGFilled;
declare const index_IconSquareLetterH: typeof IconSquareLetterH;
declare const index_IconSquareLetterHFilled: typeof IconSquareLetterHFilled;
declare const index_IconSquareLetterI: typeof IconSquareLetterI;
declare const index_IconSquareLetterIFilled: typeof IconSquareLetterIFilled;
declare const index_IconSquareLetterJ: typeof IconSquareLetterJ;
declare const index_IconSquareLetterJFilled: typeof IconSquareLetterJFilled;
declare const index_IconSquareLetterK: typeof IconSquareLetterK;
declare const index_IconSquareLetterKFilled: typeof IconSquareLetterKFilled;
declare const index_IconSquareLetterL: typeof IconSquareLetterL;
declare const index_IconSquareLetterLFilled: typeof IconSquareLetterLFilled;
declare const index_IconSquareLetterM: typeof IconSquareLetterM;
declare const index_IconSquareLetterMFilled: typeof IconSquareLetterMFilled;
declare const index_IconSquareLetterN: typeof IconSquareLetterN;
declare const index_IconSquareLetterNFilled: typeof IconSquareLetterNFilled;
declare const index_IconSquareLetterO: typeof IconSquareLetterO;
declare const index_IconSquareLetterOFilled: typeof IconSquareLetterOFilled;
declare const index_IconSquareLetterP: typeof IconSquareLetterP;
declare const index_IconSquareLetterPFilled: typeof IconSquareLetterPFilled;
declare const index_IconSquareLetterQ: typeof IconSquareLetterQ;
declare const index_IconSquareLetterQFilled: typeof IconSquareLetterQFilled;
declare const index_IconSquareLetterR: typeof IconSquareLetterR;
declare const index_IconSquareLetterRFilled: typeof IconSquareLetterRFilled;
declare const index_IconSquareLetterS: typeof IconSquareLetterS;
declare const index_IconSquareLetterSFilled: typeof IconSquareLetterSFilled;
declare const index_IconSquareLetterT: typeof IconSquareLetterT;
declare const index_IconSquareLetterTFilled: typeof IconSquareLetterTFilled;
declare const index_IconSquareLetterU: typeof IconSquareLetterU;
declare const index_IconSquareLetterUFilled: typeof IconSquareLetterUFilled;
declare const index_IconSquareLetterV: typeof IconSquareLetterV;
declare const index_IconSquareLetterVFilled: typeof IconSquareLetterVFilled;
declare const index_IconSquareLetterW: typeof IconSquareLetterW;
declare const index_IconSquareLetterWFilled: typeof IconSquareLetterWFilled;
declare const index_IconSquareLetterX: typeof IconSquareLetterX;
declare const index_IconSquareLetterXFilled: typeof IconSquareLetterXFilled;
declare const index_IconSquareLetterY: typeof IconSquareLetterY;
declare const index_IconSquareLetterYFilled: typeof IconSquareLetterYFilled;
declare const index_IconSquareLetterZ: typeof IconSquareLetterZ;
declare const index_IconSquareLetterZFilled: typeof IconSquareLetterZFilled;
declare const index_IconSquareMinus: typeof IconSquareMinus;
declare const index_IconSquareMinus2: typeof IconSquareMinus2;
declare const index_IconSquareMinusFilled: typeof IconSquareMinusFilled;
declare const index_IconSquareNumber0: typeof IconSquareNumber0;
declare const index_IconSquareNumber0Filled: typeof IconSquareNumber0Filled;
declare const index_IconSquareNumber1: typeof IconSquareNumber1;
declare const index_IconSquareNumber1Filled: typeof IconSquareNumber1Filled;
declare const index_IconSquareNumber2: typeof IconSquareNumber2;
declare const index_IconSquareNumber2Filled: typeof IconSquareNumber2Filled;
declare const index_IconSquareNumber3: typeof IconSquareNumber3;
declare const index_IconSquareNumber3Filled: typeof IconSquareNumber3Filled;
declare const index_IconSquareNumber4: typeof IconSquareNumber4;
declare const index_IconSquareNumber4Filled: typeof IconSquareNumber4Filled;
declare const index_IconSquareNumber5: typeof IconSquareNumber5;
declare const index_IconSquareNumber5Filled: typeof IconSquareNumber5Filled;
declare const index_IconSquareNumber6: typeof IconSquareNumber6;
declare const index_IconSquareNumber6Filled: typeof IconSquareNumber6Filled;
declare const index_IconSquareNumber7: typeof IconSquareNumber7;
declare const index_IconSquareNumber7Filled: typeof IconSquareNumber7Filled;
declare const index_IconSquareNumber8: typeof IconSquareNumber8;
declare const index_IconSquareNumber8Filled: typeof IconSquareNumber8Filled;
declare const index_IconSquareNumber9: typeof IconSquareNumber9;
declare const index_IconSquareNumber9Filled: typeof IconSquareNumber9Filled;
declare const index_IconSquareOff: typeof IconSquareOff;
declare const index_IconSquarePercentage: typeof IconSquarePercentage;
declare const index_IconSquarePlus: typeof IconSquarePlus;
declare const index_IconSquarePlus2: typeof IconSquarePlus2;
declare const index_IconSquareRoot: typeof IconSquareRoot;
declare const index_IconSquareRoot2: typeof IconSquareRoot2;
declare const index_IconSquareRotated: typeof IconSquareRotated;
declare const index_IconSquareRotatedAsterisk: typeof IconSquareRotatedAsterisk;
declare const index_IconSquareRotatedFilled: typeof IconSquareRotatedFilled;
declare const index_IconSquareRotatedForbid: typeof IconSquareRotatedForbid;
declare const index_IconSquareRotatedForbid2: typeof IconSquareRotatedForbid2;
declare const index_IconSquareRotatedOff: typeof IconSquareRotatedOff;
declare const index_IconSquareRounded: typeof IconSquareRounded;
declare const index_IconSquareRoundedArrowDown: typeof IconSquareRoundedArrowDown;
declare const index_IconSquareRoundedArrowDownFilled: typeof IconSquareRoundedArrowDownFilled;
declare const index_IconSquareRoundedArrowLeft: typeof IconSquareRoundedArrowLeft;
declare const index_IconSquareRoundedArrowLeftFilled: typeof IconSquareRoundedArrowLeftFilled;
declare const index_IconSquareRoundedArrowRight: typeof IconSquareRoundedArrowRight;
declare const index_IconSquareRoundedArrowRightFilled: typeof IconSquareRoundedArrowRightFilled;
declare const index_IconSquareRoundedArrowUp: typeof IconSquareRoundedArrowUp;
declare const index_IconSquareRoundedArrowUpFilled: typeof IconSquareRoundedArrowUpFilled;
declare const index_IconSquareRoundedCheck: typeof IconSquareRoundedCheck;
declare const index_IconSquareRoundedCheckFilled: typeof IconSquareRoundedCheckFilled;
declare const index_IconSquareRoundedChevronDown: typeof IconSquareRoundedChevronDown;
declare const index_IconSquareRoundedChevronDownFilled: typeof IconSquareRoundedChevronDownFilled;
declare const index_IconSquareRoundedChevronLeft: typeof IconSquareRoundedChevronLeft;
declare const index_IconSquareRoundedChevronLeftFilled: typeof IconSquareRoundedChevronLeftFilled;
declare const index_IconSquareRoundedChevronRight: typeof IconSquareRoundedChevronRight;
declare const index_IconSquareRoundedChevronRightFilled: typeof IconSquareRoundedChevronRightFilled;
declare const index_IconSquareRoundedChevronUp: typeof IconSquareRoundedChevronUp;
declare const index_IconSquareRoundedChevronUpFilled: typeof IconSquareRoundedChevronUpFilled;
declare const index_IconSquareRoundedChevronsDown: typeof IconSquareRoundedChevronsDown;
declare const index_IconSquareRoundedChevronsDownFilled: typeof IconSquareRoundedChevronsDownFilled;
declare const index_IconSquareRoundedChevronsLeft: typeof IconSquareRoundedChevronsLeft;
declare const index_IconSquareRoundedChevronsLeftFilled: typeof IconSquareRoundedChevronsLeftFilled;
declare const index_IconSquareRoundedChevronsRight: typeof IconSquareRoundedChevronsRight;
declare const index_IconSquareRoundedChevronsRightFilled: typeof IconSquareRoundedChevronsRightFilled;
declare const index_IconSquareRoundedChevronsUp: typeof IconSquareRoundedChevronsUp;
declare const index_IconSquareRoundedChevronsUpFilled: typeof IconSquareRoundedChevronsUpFilled;
declare const index_IconSquareRoundedFilled: typeof IconSquareRoundedFilled;
declare const index_IconSquareRoundedLetterA: typeof IconSquareRoundedLetterA;
declare const index_IconSquareRoundedLetterAFilled: typeof IconSquareRoundedLetterAFilled;
declare const index_IconSquareRoundedLetterB: typeof IconSquareRoundedLetterB;
declare const index_IconSquareRoundedLetterBFilled: typeof IconSquareRoundedLetterBFilled;
declare const index_IconSquareRoundedLetterC: typeof IconSquareRoundedLetterC;
declare const index_IconSquareRoundedLetterCFilled: typeof IconSquareRoundedLetterCFilled;
declare const index_IconSquareRoundedLetterD: typeof IconSquareRoundedLetterD;
declare const index_IconSquareRoundedLetterDFilled: typeof IconSquareRoundedLetterDFilled;
declare const index_IconSquareRoundedLetterE: typeof IconSquareRoundedLetterE;
declare const index_IconSquareRoundedLetterEFilled: typeof IconSquareRoundedLetterEFilled;
declare const index_IconSquareRoundedLetterF: typeof IconSquareRoundedLetterF;
declare const index_IconSquareRoundedLetterFFilled: typeof IconSquareRoundedLetterFFilled;
declare const index_IconSquareRoundedLetterG: typeof IconSquareRoundedLetterG;
declare const index_IconSquareRoundedLetterGFilled: typeof IconSquareRoundedLetterGFilled;
declare const index_IconSquareRoundedLetterH: typeof IconSquareRoundedLetterH;
declare const index_IconSquareRoundedLetterHFilled: typeof IconSquareRoundedLetterHFilled;
declare const index_IconSquareRoundedLetterI: typeof IconSquareRoundedLetterI;
declare const index_IconSquareRoundedLetterIFilled: typeof IconSquareRoundedLetterIFilled;
declare const index_IconSquareRoundedLetterJ: typeof IconSquareRoundedLetterJ;
declare const index_IconSquareRoundedLetterJFilled: typeof IconSquareRoundedLetterJFilled;
declare const index_IconSquareRoundedLetterK: typeof IconSquareRoundedLetterK;
declare const index_IconSquareRoundedLetterKFilled: typeof IconSquareRoundedLetterKFilled;
declare const index_IconSquareRoundedLetterL: typeof IconSquareRoundedLetterL;
declare const index_IconSquareRoundedLetterLFilled: typeof IconSquareRoundedLetterLFilled;
declare const index_IconSquareRoundedLetterM: typeof IconSquareRoundedLetterM;
declare const index_IconSquareRoundedLetterMFilled: typeof IconSquareRoundedLetterMFilled;
declare const index_IconSquareRoundedLetterN: typeof IconSquareRoundedLetterN;
declare const index_IconSquareRoundedLetterNFilled: typeof IconSquareRoundedLetterNFilled;
declare const index_IconSquareRoundedLetterO: typeof IconSquareRoundedLetterO;
declare const index_IconSquareRoundedLetterOFilled: typeof IconSquareRoundedLetterOFilled;
declare const index_IconSquareRoundedLetterP: typeof IconSquareRoundedLetterP;
declare const index_IconSquareRoundedLetterPFilled: typeof IconSquareRoundedLetterPFilled;
declare const index_IconSquareRoundedLetterQ: typeof IconSquareRoundedLetterQ;
declare const index_IconSquareRoundedLetterQFilled: typeof IconSquareRoundedLetterQFilled;
declare const index_IconSquareRoundedLetterR: typeof IconSquareRoundedLetterR;
declare const index_IconSquareRoundedLetterRFilled: typeof IconSquareRoundedLetterRFilled;
declare const index_IconSquareRoundedLetterS: typeof IconSquareRoundedLetterS;
declare const index_IconSquareRoundedLetterSFilled: typeof IconSquareRoundedLetterSFilled;
declare const index_IconSquareRoundedLetterT: typeof IconSquareRoundedLetterT;
declare const index_IconSquareRoundedLetterTFilled: typeof IconSquareRoundedLetterTFilled;
declare const index_IconSquareRoundedLetterU: typeof IconSquareRoundedLetterU;
declare const index_IconSquareRoundedLetterUFilled: typeof IconSquareRoundedLetterUFilled;
declare const index_IconSquareRoundedLetterV: typeof IconSquareRoundedLetterV;
declare const index_IconSquareRoundedLetterVFilled: typeof IconSquareRoundedLetterVFilled;
declare const index_IconSquareRoundedLetterW: typeof IconSquareRoundedLetterW;
declare const index_IconSquareRoundedLetterWFilled: typeof IconSquareRoundedLetterWFilled;
declare const index_IconSquareRoundedLetterX: typeof IconSquareRoundedLetterX;
declare const index_IconSquareRoundedLetterXFilled: typeof IconSquareRoundedLetterXFilled;
declare const index_IconSquareRoundedLetterY: typeof IconSquareRoundedLetterY;
declare const index_IconSquareRoundedLetterYFilled: typeof IconSquareRoundedLetterYFilled;
declare const index_IconSquareRoundedLetterZ: typeof IconSquareRoundedLetterZ;
declare const index_IconSquareRoundedLetterZFilled: typeof IconSquareRoundedLetterZFilled;
declare const index_IconSquareRoundedMinus: typeof IconSquareRoundedMinus;
declare const index_IconSquareRoundedMinus2: typeof IconSquareRoundedMinus2;
declare const index_IconSquareRoundedMinusFilled: typeof IconSquareRoundedMinusFilled;
declare const index_IconSquareRoundedNumber0: typeof IconSquareRoundedNumber0;
declare const index_IconSquareRoundedNumber0Filled: typeof IconSquareRoundedNumber0Filled;
declare const index_IconSquareRoundedNumber1: typeof IconSquareRoundedNumber1;
declare const index_IconSquareRoundedNumber1Filled: typeof IconSquareRoundedNumber1Filled;
declare const index_IconSquareRoundedNumber2: typeof IconSquareRoundedNumber2;
declare const index_IconSquareRoundedNumber2Filled: typeof IconSquareRoundedNumber2Filled;
declare const index_IconSquareRoundedNumber3: typeof IconSquareRoundedNumber3;
declare const index_IconSquareRoundedNumber3Filled: typeof IconSquareRoundedNumber3Filled;
declare const index_IconSquareRoundedNumber4: typeof IconSquareRoundedNumber4;
declare const index_IconSquareRoundedNumber4Filled: typeof IconSquareRoundedNumber4Filled;
declare const index_IconSquareRoundedNumber5: typeof IconSquareRoundedNumber5;
declare const index_IconSquareRoundedNumber5Filled: typeof IconSquareRoundedNumber5Filled;
declare const index_IconSquareRoundedNumber6: typeof IconSquareRoundedNumber6;
declare const index_IconSquareRoundedNumber6Filled: typeof IconSquareRoundedNumber6Filled;
declare const index_IconSquareRoundedNumber7: typeof IconSquareRoundedNumber7;
declare const index_IconSquareRoundedNumber7Filled: typeof IconSquareRoundedNumber7Filled;
declare const index_IconSquareRoundedNumber8: typeof IconSquareRoundedNumber8;
declare const index_IconSquareRoundedNumber8Filled: typeof IconSquareRoundedNumber8Filled;
declare const index_IconSquareRoundedNumber9: typeof IconSquareRoundedNumber9;
declare const index_IconSquareRoundedNumber9Filled: typeof IconSquareRoundedNumber9Filled;
declare const index_IconSquareRoundedPercentage: typeof IconSquareRoundedPercentage;
declare const index_IconSquareRoundedPlus: typeof IconSquareRoundedPlus;
declare const index_IconSquareRoundedPlus2: typeof IconSquareRoundedPlus2;
declare const index_IconSquareRoundedPlusFilled: typeof IconSquareRoundedPlusFilled;
declare const index_IconSquareRoundedX: typeof IconSquareRoundedX;
declare const index_IconSquareRoundedXFilled: typeof IconSquareRoundedXFilled;
declare const index_IconSquareToggle: typeof IconSquareToggle;
declare const index_IconSquareToggleHorizontal: typeof IconSquareToggleHorizontal;
declare const index_IconSquareX: typeof IconSquareX;
declare const index_IconSquareXFilled: typeof IconSquareXFilled;
declare const index_IconSquares: typeof IconSquares;
declare const index_IconSquaresDiagonal: typeof IconSquaresDiagonal;
declare const index_IconSquaresFilled: typeof IconSquaresFilled;
declare const index_IconSquaresSelected: typeof IconSquaresSelected;
declare const index_IconStack: typeof IconStack;
declare const index_IconStack2: typeof IconStack2;
declare const index_IconStack2Filled: typeof IconStack2Filled;
declare const index_IconStack3: typeof IconStack3;
declare const index_IconStack3Filled: typeof IconStack3Filled;
declare const index_IconStackBack: typeof IconStackBack;
declare const index_IconStackBackward: typeof IconStackBackward;
declare const index_IconStackFilled: typeof IconStackFilled;
declare const index_IconStackForward: typeof IconStackForward;
declare const index_IconStackFront: typeof IconStackFront;
declare const index_IconStackMiddle: typeof IconStackMiddle;
declare const index_IconStackPop: typeof IconStackPop;
declare const index_IconStackPush: typeof IconStackPush;
declare const index_IconStairs: typeof IconStairs;
declare const index_IconStairsDown: typeof IconStairsDown;
declare const index_IconStairsUp: typeof IconStairsUp;
declare const index_IconStar: typeof IconStar;
declare const index_IconStarFilled: typeof IconStarFilled;
declare const index_IconStarHalf: typeof IconStarHalf;
declare const index_IconStarHalfFilled: typeof IconStarHalfFilled;
declare const index_IconStarOff: typeof IconStarOff;
declare const index_IconStars: typeof IconStars;
declare const index_IconStarsFilled: typeof IconStarsFilled;
declare const index_IconStarsOff: typeof IconStarsOff;
declare const index_IconStatusChange: typeof IconStatusChange;
declare const index_IconSteam: typeof IconSteam;
declare const index_IconSteeringWheel: typeof IconSteeringWheel;
declare const index_IconSteeringWheelFilled: typeof IconSteeringWheelFilled;
declare const index_IconSteeringWheelOff: typeof IconSteeringWheelOff;
declare const index_IconStepInto: typeof IconStepInto;
declare const index_IconStepOut: typeof IconStepOut;
declare const index_IconStereoGlasses: typeof IconStereoGlasses;
declare const index_IconStethoscope: typeof IconStethoscope;
declare const index_IconStethoscopeOff: typeof IconStethoscopeOff;
declare const index_IconSticker: typeof IconSticker;
declare const index_IconSticker2: typeof IconSticker2;
declare const index_IconStopwatch: typeof IconStopwatch;
declare const index_IconStorm: typeof IconStorm;
declare const index_IconStormOff: typeof IconStormOff;
declare const index_IconStretching: typeof IconStretching;
declare const index_IconStretching2: typeof IconStretching2;
declare const index_IconStrikethrough: typeof IconStrikethrough;
declare const index_IconSubmarine: typeof IconSubmarine;
declare const index_IconSubscript: typeof IconSubscript;
declare const index_IconSubtask: typeof IconSubtask;
declare const index_IconSubtitles: typeof IconSubtitles;
declare const index_IconSubtitlesAi: typeof IconSubtitlesAi;
declare const index_IconSubtitlesEdit: typeof IconSubtitlesEdit;
declare const index_IconSubtitlesOff: typeof IconSubtitlesOff;
declare const index_IconSum: typeof IconSum;
declare const index_IconSumOff: typeof IconSumOff;
declare const index_IconSun: typeof IconSun;
declare const index_IconSunElectricity: typeof IconSunElectricity;
declare const index_IconSunFilled: typeof IconSunFilled;
declare const index_IconSunHigh: typeof IconSunHigh;
declare const index_IconSunHighFilled: typeof IconSunHighFilled;
declare const index_IconSunLow: typeof IconSunLow;
declare const index_IconSunLowFilled: typeof IconSunLowFilled;
declare const index_IconSunMoon: typeof IconSunMoon;
declare const index_IconSunOff: typeof IconSunOff;
declare const index_IconSunWind: typeof IconSunWind;
declare const index_IconSunglasses: typeof IconSunglasses;
declare const index_IconSunglassesFilled: typeof IconSunglassesFilled;
declare const index_IconSunrise: typeof IconSunrise;
declare const index_IconSunriseFilled: typeof IconSunriseFilled;
declare const index_IconSunset: typeof IconSunset;
declare const index_IconSunset2: typeof IconSunset2;
declare const index_IconSunset2Filled: typeof IconSunset2Filled;
declare const index_IconSunsetFilled: typeof IconSunsetFilled;
declare const index_IconSuperscript: typeof IconSuperscript;
declare const index_IconSvg: typeof IconSvg;
declare const index_IconSwimming: typeof IconSwimming;
declare const index_IconSwipe: typeof IconSwipe;
declare const index_IconSwipeDown: typeof IconSwipeDown;
declare const index_IconSwipeDownFilled: typeof IconSwipeDownFilled;
declare const index_IconSwipeLeft: typeof IconSwipeLeft;
declare const index_IconSwipeLeftFilled: typeof IconSwipeLeftFilled;
declare const index_IconSwipeRight: typeof IconSwipeRight;
declare const index_IconSwipeRightFilled: typeof IconSwipeRightFilled;
declare const index_IconSwipeUp: typeof IconSwipeUp;
declare const index_IconSwipeUpFilled: typeof IconSwipeUpFilled;
declare const index_IconSwitch: typeof IconSwitch;
declare const index_IconSwitch2: typeof IconSwitch2;
declare const index_IconSwitch3: typeof IconSwitch3;
declare const index_IconSwitchHorizontal: typeof IconSwitchHorizontal;
declare const index_IconSwitchVertical: typeof IconSwitchVertical;
declare const index_IconSword: typeof IconSword;
declare const index_IconSwordOff: typeof IconSwordOff;
declare const index_IconSwords: typeof IconSwords;
declare const index_IconTable: typeof IconTable;
declare const index_IconTableAlias: typeof IconTableAlias;
declare const index_IconTableColumn: typeof IconTableColumn;
declare const index_IconTableDashed: typeof IconTableDashed;
declare const index_IconTableDown: typeof IconTableDown;
declare const index_IconTableExport: typeof IconTableExport;
declare const index_IconTableFilled: typeof IconTableFilled;
declare const index_IconTableHeart: typeof IconTableHeart;
declare const index_IconTableImport: typeof IconTableImport;
declare const index_IconTableMinus: typeof IconTableMinus;
declare const index_IconTableOff: typeof IconTableOff;
declare const index_IconTableOptions: typeof IconTableOptions;
declare const index_IconTablePlus: typeof IconTablePlus;
declare const index_IconTableRow: typeof IconTableRow;
declare const index_IconTableShare: typeof IconTableShare;
declare const index_IconTableShortcut: typeof IconTableShortcut;
declare const index_IconTableSpark: typeof IconTableSpark;
declare const index_IconTag: typeof IconTag;
declare const index_IconTagFilled: typeof IconTagFilled;
declare const index_IconTagMinus: typeof IconTagMinus;
declare const index_IconTagOff: typeof IconTagOff;
declare const index_IconTagPlus: typeof IconTagPlus;
declare const index_IconTagStarred: typeof IconTagStarred;
declare const index_IconTags: typeof IconTags;
declare const index_IconTagsFilled: typeof IconTagsFilled;
declare const index_IconTagsOff: typeof IconTagsOff;
declare const index_IconTallymark1: typeof IconTallymark1;
declare const index_IconTallymark2: typeof IconTallymark2;
declare const index_IconTallymark3: typeof IconTallymark3;
declare const index_IconTallymark4: typeof IconTallymark4;
declare const index_IconTallymarks: typeof IconTallymarks;
declare const index_IconTank: typeof IconTank;
declare const index_IconTarget: typeof IconTarget;
declare const index_IconTargetArrow: typeof IconTargetArrow;
declare const index_IconTargetOff: typeof IconTargetOff;
declare const index_IconTax: typeof IconTax;
declare const index_IconTaxEuro: typeof IconTaxEuro;
declare const index_IconTaxPound: typeof IconTaxPound;
declare const index_IconTeapot: typeof IconTeapot;
declare const index_IconTelescope: typeof IconTelescope;
declare const index_IconTelescopeOff: typeof IconTelescopeOff;
declare const index_IconTemperature: typeof IconTemperature;
declare const index_IconTemperatureCelsius: typeof IconTemperatureCelsius;
declare const index_IconTemperatureFahrenheit: typeof IconTemperatureFahrenheit;
declare const index_IconTemperatureMinus: typeof IconTemperatureMinus;
declare const index_IconTemperatureMinusFilled: typeof IconTemperatureMinusFilled;
declare const index_IconTemperatureOff: typeof IconTemperatureOff;
declare const index_IconTemperaturePlus: typeof IconTemperaturePlus;
declare const index_IconTemperaturePlusFilled: typeof IconTemperaturePlusFilled;
declare const index_IconTemperatureSnow: typeof IconTemperatureSnow;
declare const index_IconTemperatureSun: typeof IconTemperatureSun;
declare const index_IconTemplate: typeof IconTemplate;
declare const index_IconTemplateFilled: typeof IconTemplateFilled;
declare const index_IconTemplateOff: typeof IconTemplateOff;
declare const index_IconTent: typeof IconTent;
declare const index_IconTentOff: typeof IconTentOff;
declare const index_IconTerminal: typeof IconTerminal;
declare const index_IconTerminal2: typeof IconTerminal2;
declare const index_IconTestPipe: typeof IconTestPipe;
declare const index_IconTestPipe2: typeof IconTestPipe2;
declare const index_IconTestPipe2Filled: typeof IconTestPipe2Filled;
declare const index_IconTestPipeOff: typeof IconTestPipeOff;
declare const index_IconTex: typeof IconTex;
declare const index_IconTextCaption: typeof IconTextCaption;
declare const index_IconTextColor: typeof IconTextColor;
declare const index_IconTextDecrease: typeof IconTextDecrease;
declare const index_IconTextDirectionLtr: typeof IconTextDirectionLtr;
declare const index_IconTextDirectionRtl: typeof IconTextDirectionRtl;
declare const index_IconTextGrammar: typeof IconTextGrammar;
declare const index_IconTextIncrease: typeof IconTextIncrease;
declare const index_IconTextOrientation: typeof IconTextOrientation;
declare const index_IconTextPlus: typeof IconTextPlus;
declare const index_IconTextRecognition: typeof IconTextRecognition;
declare const index_IconTextResize: typeof IconTextResize;
declare const index_IconTextScan2: typeof IconTextScan2;
declare const index_IconTextSize: typeof IconTextSize;
declare const index_IconTextSpellcheck: typeof IconTextSpellcheck;
declare const index_IconTextWrap: typeof IconTextWrap;
declare const index_IconTextWrapColumn: typeof IconTextWrapColumn;
declare const index_IconTextWrapDisabled: typeof IconTextWrapDisabled;
declare const index_IconTexture: typeof IconTexture;
declare const index_IconTheater: typeof IconTheater;
declare const index_IconThermometer: typeof IconThermometer;
declare const index_IconThumbDown: typeof IconThumbDown;
declare const index_IconThumbDownFilled: typeof IconThumbDownFilled;
declare const index_IconThumbDownOff: typeof IconThumbDownOff;
declare const index_IconThumbUp: typeof IconThumbUp;
declare const index_IconThumbUpFilled: typeof IconThumbUpFilled;
declare const index_IconThumbUpOff: typeof IconThumbUpOff;
declare const index_IconTicTac: typeof IconTicTac;
declare const index_IconTicket: typeof IconTicket;
declare const index_IconTicketOff: typeof IconTicketOff;
declare const index_IconTie: typeof IconTie;
declare const index_IconTilde: typeof IconTilde;
declare const index_IconTiltShift: typeof IconTiltShift;
declare const index_IconTiltShiftFilled: typeof IconTiltShiftFilled;
declare const index_IconTiltShiftOff: typeof IconTiltShiftOff;
declare const index_IconTimeDuration0: typeof IconTimeDuration0;
declare const index_IconTimeDuration10: typeof IconTimeDuration10;
declare const index_IconTimeDuration15: typeof IconTimeDuration15;
declare const index_IconTimeDuration30: typeof IconTimeDuration30;
declare const index_IconTimeDuration45: typeof IconTimeDuration45;
declare const index_IconTimeDuration5: typeof IconTimeDuration5;
declare const index_IconTimeDuration60: typeof IconTimeDuration60;
declare const index_IconTimeDuration90: typeof IconTimeDuration90;
declare const index_IconTimeDurationOff: typeof IconTimeDurationOff;
declare const index_IconTimeline: typeof IconTimeline;
declare const index_IconTimelineEvent: typeof IconTimelineEvent;
declare const index_IconTimelineEventExclamation: typeof IconTimelineEventExclamation;
declare const index_IconTimelineEventFilled: typeof IconTimelineEventFilled;
declare const index_IconTimelineEventMinus: typeof IconTimelineEventMinus;
declare const index_IconTimelineEventPlus: typeof IconTimelineEventPlus;
declare const index_IconTimelineEventText: typeof IconTimelineEventText;
declare const index_IconTimelineEventX: typeof IconTimelineEventX;
declare const index_IconTimezone: typeof IconTimezone;
declare const index_IconTipJar: typeof IconTipJar;
declare const index_IconTipJarEuro: typeof IconTipJarEuro;
declare const index_IconTipJarPound: typeof IconTipJarPound;
declare const index_IconTir: typeof IconTir;
declare const index_IconToggleLeft: typeof IconToggleLeft;
declare const index_IconToggleLeftFilled: typeof IconToggleLeftFilled;
declare const index_IconToggleRight: typeof IconToggleRight;
declare const index_IconToggleRightFilled: typeof IconToggleRightFilled;
declare const index_IconToiletPaper: typeof IconToiletPaper;
declare const index_IconToiletPaperOff: typeof IconToiletPaperOff;
declare const index_IconToml: typeof IconToml;
declare const index_IconTool: typeof IconTool;
declare const index_IconTools: typeof IconTools;
declare const index_IconToolsKitchen: typeof IconToolsKitchen;
declare const index_IconToolsKitchen2: typeof IconToolsKitchen2;
declare const index_IconToolsKitchen2Off: typeof IconToolsKitchen2Off;
declare const index_IconToolsKitchen3: typeof IconToolsKitchen3;
declare const index_IconToolsKitchenOff: typeof IconToolsKitchenOff;
declare const index_IconToolsOff: typeof IconToolsOff;
declare const index_IconTooltip: typeof IconTooltip;
declare const index_IconTopologyBus: typeof IconTopologyBus;
declare const index_IconTopologyComplex: typeof IconTopologyComplex;
declare const index_IconTopologyFull: typeof IconTopologyFull;
declare const index_IconTopologyFullHierarchy: typeof IconTopologyFullHierarchy;
declare const index_IconTopologyRing: typeof IconTopologyRing;
declare const index_IconTopologyRing2: typeof IconTopologyRing2;
declare const index_IconTopologyRing3: typeof IconTopologyRing3;
declare const index_IconTopologyStar: typeof IconTopologyStar;
declare const index_IconTopologyStar2: typeof IconTopologyStar2;
declare const index_IconTopologyStar3: typeof IconTopologyStar3;
declare const index_IconTopologyStarRing: typeof IconTopologyStarRing;
declare const index_IconTopologyStarRing2: typeof IconTopologyStarRing2;
declare const index_IconTopologyStarRing3: typeof IconTopologyStarRing3;
declare const index_IconTorii: typeof IconTorii;
declare const index_IconTornado: typeof IconTornado;
declare const index_IconTournament: typeof IconTournament;
declare const index_IconTower: typeof IconTower;
declare const index_IconTowerOff: typeof IconTowerOff;
declare const index_IconTrack: typeof IconTrack;
declare const index_IconTractor: typeof IconTractor;
declare const index_IconTrademark: typeof IconTrademark;
declare const index_IconTrafficCone: typeof IconTrafficCone;
declare const index_IconTrafficConeOff: typeof IconTrafficConeOff;
declare const index_IconTrafficLights: typeof IconTrafficLights;
declare const index_IconTrafficLightsOff: typeof IconTrafficLightsOff;
declare const index_IconTrain: typeof IconTrain;
declare const index_IconTrainFilled: typeof IconTrainFilled;
declare const index_IconTransactionBitcoin: typeof IconTransactionBitcoin;
declare const index_IconTransactionDollar: typeof IconTransactionDollar;
declare const index_IconTransactionEuro: typeof IconTransactionEuro;
declare const index_IconTransactionPound: typeof IconTransactionPound;
declare const index_IconTransactionRupee: typeof IconTransactionRupee;
declare const index_IconTransactionYen: typeof IconTransactionYen;
declare const index_IconTransactionYuan: typeof IconTransactionYuan;
declare const index_IconTransfer: typeof IconTransfer;
declare const index_IconTransferIn: typeof IconTransferIn;
declare const index_IconTransferOut: typeof IconTransferOut;
declare const index_IconTransferVertical: typeof IconTransferVertical;
declare const index_IconTransform: typeof IconTransform;
declare const index_IconTransformFilled: typeof IconTransformFilled;
declare const index_IconTransformPoint: typeof IconTransformPoint;
declare const index_IconTransformPointBottomLeft: typeof IconTransformPointBottomLeft;
declare const index_IconTransformPointBottomRight: typeof IconTransformPointBottomRight;
declare const index_IconTransformPointTopLeft: typeof IconTransformPointTopLeft;
declare const index_IconTransformPointTopRight: typeof IconTransformPointTopRight;
declare const index_IconTransitionBottom: typeof IconTransitionBottom;
declare const index_IconTransitionBottomFilled: typeof IconTransitionBottomFilled;
declare const index_IconTransitionLeft: typeof IconTransitionLeft;
declare const index_IconTransitionLeftFilled: typeof IconTransitionLeftFilled;
declare const index_IconTransitionRight: typeof IconTransitionRight;
declare const index_IconTransitionRightFilled: typeof IconTransitionRightFilled;
declare const index_IconTransitionTop: typeof IconTransitionTop;
declare const index_IconTransitionTopFilled: typeof IconTransitionTopFilled;
declare const index_IconTrash: typeof IconTrash;
declare const index_IconTrashFilled: typeof IconTrashFilled;
declare const index_IconTrashOff: typeof IconTrashOff;
declare const index_IconTrashX: typeof IconTrashX;
declare const index_IconTrashXFilled: typeof IconTrashXFilled;
declare const index_IconTreadmill: typeof IconTreadmill;
declare const index_IconTree: typeof IconTree;
declare const index_IconTrees: typeof IconTrees;
declare const index_IconTrekking: typeof IconTrekking;
declare const index_IconTrendingDown: typeof IconTrendingDown;
declare const index_IconTrendingDown2: typeof IconTrendingDown2;
declare const index_IconTrendingDown3: typeof IconTrendingDown3;
declare const index_IconTrendingUp: typeof IconTrendingUp;
declare const index_IconTrendingUp2: typeof IconTrendingUp2;
declare const index_IconTrendingUp3: typeof IconTrendingUp3;
declare const index_IconTriangle: typeof IconTriangle;
declare const index_IconTriangleFilled: typeof IconTriangleFilled;
declare const index_IconTriangleInverted: typeof IconTriangleInverted;
declare const index_IconTriangleInvertedFilled: typeof IconTriangleInvertedFilled;
declare const index_IconTriangleMinus: typeof IconTriangleMinus;
declare const index_IconTriangleMinus2: typeof IconTriangleMinus2;
declare const index_IconTriangleOff: typeof IconTriangleOff;
declare const index_IconTrianglePlus: typeof IconTrianglePlus;
declare const index_IconTrianglePlus2: typeof IconTrianglePlus2;
declare const index_IconTriangleSquareCircle: typeof IconTriangleSquareCircle;
declare const index_IconTriangleSquareCircleFilled: typeof IconTriangleSquareCircleFilled;
declare const index_IconTriangles: typeof IconTriangles;
declare const index_IconTrident: typeof IconTrident;
declare const index_IconTrolley: typeof IconTrolley;
declare const index_IconTrolleyFilled: typeof IconTrolleyFilled;
declare const index_IconTrophy: typeof IconTrophy;
declare const index_IconTrophyFilled: typeof IconTrophyFilled;
declare const index_IconTrophyOff: typeof IconTrophyOff;
declare const index_IconTrowel: typeof IconTrowel;
declare const index_IconTruck: typeof IconTruck;
declare const index_IconTruckDelivery: typeof IconTruckDelivery;
declare const index_IconTruckFilled: typeof IconTruckFilled;
declare const index_IconTruckLoading: typeof IconTruckLoading;
declare const index_IconTruckOff: typeof IconTruckOff;
declare const index_IconTruckReturn: typeof IconTruckReturn;
declare const index_IconTxt: typeof IconTxt;
declare const index_IconTypeface: typeof IconTypeface;
declare const index_IconTypography: typeof IconTypography;
declare const index_IconTypographyOff: typeof IconTypographyOff;
declare const index_IconUTurnLeft: typeof IconUTurnLeft;
declare const index_IconUTurnRight: typeof IconUTurnRight;
declare const index_IconUfo: typeof IconUfo;
declare const index_IconUfoFilled: typeof IconUfoFilled;
declare const index_IconUfoOff: typeof IconUfoOff;
declare const index_IconUhd: typeof IconUhd;
declare const index_IconUmbrella: typeof IconUmbrella;
declare const index_IconUmbrella2: typeof IconUmbrella2;
declare const index_IconUmbrellaClosed: typeof IconUmbrellaClosed;
declare const index_IconUmbrellaClosed2: typeof IconUmbrellaClosed2;
declare const index_IconUmbrellaFilled: typeof IconUmbrellaFilled;
declare const index_IconUmbrellaOff: typeof IconUmbrellaOff;
declare const index_IconUnderline: typeof IconUnderline;
declare const index_IconUniverse: typeof IconUniverse;
declare const index_IconUnlink: typeof IconUnlink;
declare const index_IconUpload: typeof IconUpload;
declare const index_IconUrgent: typeof IconUrgent;
declare const index_IconUsb: typeof IconUsb;
declare const index_IconUser: typeof IconUser;
declare const index_IconUserBitcoin: typeof IconUserBitcoin;
declare const index_IconUserBolt: typeof IconUserBolt;
declare const index_IconUserCancel: typeof IconUserCancel;
declare const index_IconUserCheck: typeof IconUserCheck;
declare const index_IconUserCircle: typeof IconUserCircle;
declare const index_IconUserCode: typeof IconUserCode;
declare const index_IconUserCog: typeof IconUserCog;
declare const index_IconUserDollar: typeof IconUserDollar;
declare const index_IconUserDown: typeof IconUserDown;
declare const index_IconUserEdit: typeof IconUserEdit;
declare const index_IconUserExclamation: typeof IconUserExclamation;
declare const index_IconUserFilled: typeof IconUserFilled;
declare const index_IconUserHeart: typeof IconUserHeart;
declare const index_IconUserHexagon: typeof IconUserHexagon;
declare const index_IconUserMinus: typeof IconUserMinus;
declare const index_IconUserOff: typeof IconUserOff;
declare const index_IconUserPause: typeof IconUserPause;
declare const index_IconUserPentagon: typeof IconUserPentagon;
declare const index_IconUserPin: typeof IconUserPin;
declare const index_IconUserPlus: typeof IconUserPlus;
declare const index_IconUserQuestion: typeof IconUserQuestion;
declare const index_IconUserScan: typeof IconUserScan;
declare const index_IconUserScreen: typeof IconUserScreen;
declare const index_IconUserSearch: typeof IconUserSearch;
declare const index_IconUserShare: typeof IconUserShare;
declare const index_IconUserShield: typeof IconUserShield;
declare const index_IconUserSquare: typeof IconUserSquare;
declare const index_IconUserSquareRounded: typeof IconUserSquareRounded;
declare const index_IconUserStar: typeof IconUserStar;
declare const index_IconUserUp: typeof IconUserUp;
declare const index_IconUserX: typeof IconUserX;
declare const index_IconUsers: typeof IconUsers;
declare const index_IconUsersGroup: typeof IconUsersGroup;
declare const index_IconUsersMinus: typeof IconUsersMinus;
declare const index_IconUsersPlus: typeof IconUsersPlus;
declare const index_IconUvIndex: typeof IconUvIndex;
declare const index_IconUxCircle: typeof IconUxCircle;
declare const index_IconVaccine: typeof IconVaccine;
declare const index_IconVaccineBottle: typeof IconVaccineBottle;
declare const index_IconVaccineBottleOff: typeof IconVaccineBottleOff;
declare const index_IconVaccineOff: typeof IconVaccineOff;
declare const index_IconVacuumCleaner: typeof IconVacuumCleaner;
declare const index_IconVariable: typeof IconVariable;
declare const index_IconVariableMinus: typeof IconVariableMinus;
declare const index_IconVariableOff: typeof IconVariableOff;
declare const index_IconVariablePlus: typeof IconVariablePlus;
declare const index_IconVector: typeof IconVector;
declare const index_IconVectorBezier: typeof IconVectorBezier;
declare const index_IconVectorBezier2: typeof IconVectorBezier2;
declare const index_IconVectorBezierArc: typeof IconVectorBezierArc;
declare const index_IconVectorBezierCircle: typeof IconVectorBezierCircle;
declare const index_IconVectorOff: typeof IconVectorOff;
declare const index_IconVectorSpline: typeof IconVectorSpline;
declare const index_IconVectorTriangle: typeof IconVectorTriangle;
declare const index_IconVectorTriangleOff: typeof IconVectorTriangleOff;
declare const index_IconVenus: typeof IconVenus;
declare const index_IconVersions: typeof IconVersions;
declare const index_IconVersionsFilled: typeof IconVersionsFilled;
declare const index_IconVersionsOff: typeof IconVersionsOff;
declare const index_IconVideo: typeof IconVideo;
declare const index_IconVideoFilled: typeof IconVideoFilled;
declare const index_IconVideoMinus: typeof IconVideoMinus;
declare const index_IconVideoMinusFilled: typeof IconVideoMinusFilled;
declare const index_IconVideoOff: typeof IconVideoOff;
declare const index_IconVideoPlus: typeof IconVideoPlus;
declare const index_IconVideoPlusFilled: typeof IconVideoPlusFilled;
declare const index_IconView360: typeof IconView360;
declare const index_IconView360Arrow: typeof IconView360Arrow;
declare const index_IconView360Number: typeof IconView360Number;
declare const index_IconView360Off: typeof IconView360Off;
declare const index_IconViewfinder: typeof IconViewfinder;
declare const index_IconViewfinderOff: typeof IconViewfinderOff;
declare const index_IconViewportNarrow: typeof IconViewportNarrow;
declare const index_IconViewportShort: typeof IconViewportShort;
declare const index_IconViewportTall: typeof IconViewportTall;
declare const index_IconViewportWide: typeof IconViewportWide;
declare const index_IconVinyl: typeof IconVinyl;
declare const index_IconVip: typeof IconVip;
declare const index_IconVipOff: typeof IconVipOff;
declare const index_IconVirus: typeof IconVirus;
declare const index_IconVirusOff: typeof IconVirusOff;
declare const index_IconVirusSearch: typeof IconVirusSearch;
declare const index_IconVocabulary: typeof IconVocabulary;
declare const index_IconVocabularyOff: typeof IconVocabularyOff;
declare const index_IconVolcano: typeof IconVolcano;
declare const index_IconVolume: typeof IconVolume;
declare const index_IconVolume2: typeof IconVolume2;
declare const index_IconVolume3: typeof IconVolume3;
declare const index_IconVolume4: typeof IconVolume4;
declare const index_IconVolumeOff: typeof IconVolumeOff;
declare const index_IconVs: typeof IconVs;
declare const index_IconWalk: typeof IconWalk;
declare const index_IconWall: typeof IconWall;
declare const index_IconWallOff: typeof IconWallOff;
declare const index_IconWallet: typeof IconWallet;
declare const index_IconWalletOff: typeof IconWalletOff;
declare const index_IconWallpaper: typeof IconWallpaper;
declare const index_IconWallpaperOff: typeof IconWallpaperOff;
declare const index_IconWand: typeof IconWand;
declare const index_IconWandOff: typeof IconWandOff;
declare const index_IconWash: typeof IconWash;
declare const index_IconWashDry: typeof IconWashDry;
declare const index_IconWashDry1: typeof IconWashDry1;
declare const index_IconWashDry2: typeof IconWashDry2;
declare const index_IconWashDry3: typeof IconWashDry3;
declare const index_IconWashDryA: typeof IconWashDryA;
declare const index_IconWashDryDip: typeof IconWashDryDip;
declare const index_IconWashDryF: typeof IconWashDryF;
declare const index_IconWashDryFlat: typeof IconWashDryFlat;
declare const index_IconWashDryHang: typeof IconWashDryHang;
declare const index_IconWashDryOff: typeof IconWashDryOff;
declare const index_IconWashDryP: typeof IconWashDryP;
declare const index_IconWashDryShade: typeof IconWashDryShade;
declare const index_IconWashDryW: typeof IconWashDryW;
declare const index_IconWashDryclean: typeof IconWashDryclean;
declare const index_IconWashDrycleanOff: typeof IconWashDrycleanOff;
declare const index_IconWashEco: typeof IconWashEco;
declare const index_IconWashGentle: typeof IconWashGentle;
declare const index_IconWashHand: typeof IconWashHand;
declare const index_IconWashMachine: typeof IconWashMachine;
declare const index_IconWashOff: typeof IconWashOff;
declare const index_IconWashPress: typeof IconWashPress;
declare const index_IconWashTemperature1: typeof IconWashTemperature1;
declare const index_IconWashTemperature2: typeof IconWashTemperature2;
declare const index_IconWashTemperature3: typeof IconWashTemperature3;
declare const index_IconWashTemperature4: typeof IconWashTemperature4;
declare const index_IconWashTemperature5: typeof IconWashTemperature5;
declare const index_IconWashTemperature6: typeof IconWashTemperature6;
declare const index_IconWashTumbleDry: typeof IconWashTumbleDry;
declare const index_IconWashTumbleOff: typeof IconWashTumbleOff;
declare const index_IconWaterpolo: typeof IconWaterpolo;
declare const index_IconWaveSawTool: typeof IconWaveSawTool;
declare const index_IconWaveSine: typeof IconWaveSine;
declare const index_IconWaveSquare: typeof IconWaveSquare;
declare const index_IconWavesElectricity: typeof IconWavesElectricity;
declare const index_IconWebhook: typeof IconWebhook;
declare const index_IconWebhookOff: typeof IconWebhookOff;
declare const index_IconWeight: typeof IconWeight;
declare const index_IconWheat: typeof IconWheat;
declare const index_IconWheatOff: typeof IconWheatOff;
declare const index_IconWheel: typeof IconWheel;
declare const index_IconWheelchair: typeof IconWheelchair;
declare const index_IconWheelchairOff: typeof IconWheelchairOff;
declare const index_IconWhirl: typeof IconWhirl;
declare const index_IconWhisk: typeof IconWhisk;
declare const index_IconWifi: typeof IconWifi;
declare const index_IconWifi0: typeof IconWifi0;
declare const index_IconWifi1: typeof IconWifi1;
declare const index_IconWifi2: typeof IconWifi2;
declare const index_IconWifiOff: typeof IconWifiOff;
declare const index_IconWind: typeof IconWind;
declare const index_IconWindElectricity: typeof IconWindElectricity;
declare const index_IconWindOff: typeof IconWindOff;
declare const index_IconWindmill: typeof IconWindmill;
declare const index_IconWindmillFilled: typeof IconWindmillFilled;
declare const index_IconWindmillOff: typeof IconWindmillOff;
declare const index_IconWindow: typeof IconWindow;
declare const index_IconWindowMaximize: typeof IconWindowMaximize;
declare const index_IconWindowMinimize: typeof IconWindowMinimize;
declare const index_IconWindowOff: typeof IconWindowOff;
declare const index_IconWindsock: typeof IconWindsock;
declare const index_IconWindsockFilled: typeof IconWindsockFilled;
declare const index_IconWiper: typeof IconWiper;
declare const index_IconWiperWash: typeof IconWiperWash;
declare const index_IconWoman: typeof IconWoman;
declare const index_IconWomanFilled: typeof IconWomanFilled;
declare const index_IconWood: typeof IconWood;
declare const index_IconWorld: typeof IconWorld;
declare const index_IconWorldBolt: typeof IconWorldBolt;
declare const index_IconWorldCancel: typeof IconWorldCancel;
declare const index_IconWorldCheck: typeof IconWorldCheck;
declare const index_IconWorldCode: typeof IconWorldCode;
declare const index_IconWorldCog: typeof IconWorldCog;
declare const index_IconWorldDollar: typeof IconWorldDollar;
declare const index_IconWorldDown: typeof IconWorldDown;
declare const index_IconWorldDownload: typeof IconWorldDownload;
declare const index_IconWorldExclamation: typeof IconWorldExclamation;
declare const index_IconWorldHeart: typeof IconWorldHeart;
declare const index_IconWorldLatitude: typeof IconWorldLatitude;
declare const index_IconWorldLongitude: typeof IconWorldLongitude;
declare const index_IconWorldMinus: typeof IconWorldMinus;
declare const index_IconWorldOff: typeof IconWorldOff;
declare const index_IconWorldPause: typeof IconWorldPause;
declare const index_IconWorldPin: typeof IconWorldPin;
declare const index_IconWorldPlus: typeof IconWorldPlus;
declare const index_IconWorldQuestion: typeof IconWorldQuestion;
declare const index_IconWorldSearch: typeof IconWorldSearch;
declare const index_IconWorldShare: typeof IconWorldShare;
declare const index_IconWorldStar: typeof IconWorldStar;
declare const index_IconWorldUp: typeof IconWorldUp;
declare const index_IconWorldUpload: typeof IconWorldUpload;
declare const index_IconWorldWww: typeof IconWorldWww;
declare const index_IconWorldX: typeof IconWorldX;
declare const index_IconWreckingBall: typeof IconWreckingBall;
declare const index_IconWriting: typeof IconWriting;
declare const index_IconWritingFilled: typeof IconWritingFilled;
declare const index_IconWritingOff: typeof IconWritingOff;
declare const index_IconWritingSign: typeof IconWritingSign;
declare const index_IconWritingSignFilled: typeof IconWritingSignFilled;
declare const index_IconWritingSignOff: typeof IconWritingSignOff;
declare const index_IconX: typeof IconX;
declare const index_IconXPowerY: typeof IconXPowerY;
declare const index_IconXboxA: typeof IconXboxA;
declare const index_IconXboxAFilled: typeof IconXboxAFilled;
declare const index_IconXboxB: typeof IconXboxB;
declare const index_IconXboxBFilled: typeof IconXboxBFilled;
declare const index_IconXboxX: typeof IconXboxX;
declare const index_IconXboxXFilled: typeof IconXboxXFilled;
declare const index_IconXboxY: typeof IconXboxY;
declare const index_IconXboxYFilled: typeof IconXboxYFilled;
declare const index_IconXd: typeof IconXd;
declare const index_IconXxx: typeof IconXxx;
declare const index_IconYinYang: typeof IconYinYang;
declare const index_IconYinYangFilled: typeof IconYinYangFilled;
declare const index_IconYoga: typeof IconYoga;
declare const index_IconZeppelin: typeof IconZeppelin;
declare const index_IconZeppelinFilled: typeof IconZeppelinFilled;
declare const index_IconZeppelinOff: typeof IconZeppelinOff;
declare const index_IconZip: typeof IconZip;
declare const index_IconZodiacAquarius: typeof IconZodiacAquarius;
declare const index_IconZodiacAries: typeof IconZodiacAries;
declare const index_IconZodiacCancer: typeof IconZodiacCancer;
declare const index_IconZodiacCapricorn: typeof IconZodiacCapricorn;
declare const index_IconZodiacGemini: typeof IconZodiacGemini;
declare const index_IconZodiacLeo: typeof IconZodiacLeo;
declare const index_IconZodiacLibra: typeof IconZodiacLibra;
declare const index_IconZodiacPisces: typeof IconZodiacPisces;
declare const index_IconZodiacSagittarius: typeof IconZodiacSagittarius;
declare const index_IconZodiacScorpio: typeof IconZodiacScorpio;
declare const index_IconZodiacTaurus: typeof IconZodiacTaurus;
declare const index_IconZodiacVirgo: typeof IconZodiacVirgo;
declare const index_IconZoom: typeof IconZoom;
declare const index_IconZoomCancel: typeof IconZoomCancel;
declare const index_IconZoomCancelFilled: typeof IconZoomCancelFilled;
declare const index_IconZoomCheck: typeof IconZoomCheck;
declare const index_IconZoomCheckFilled: typeof IconZoomCheckFilled;
declare const index_IconZoomCode: typeof IconZoomCode;
declare const index_IconZoomCodeFilled: typeof IconZoomCodeFilled;
declare const index_IconZoomExclamation: typeof IconZoomExclamation;
declare const index_IconZoomExclamationFilled: typeof IconZoomExclamationFilled;
declare const index_IconZoomFilled: typeof IconZoomFilled;
declare const index_IconZoomIn: typeof IconZoomIn;
declare const index_IconZoomInArea: typeof IconZoomInArea;
declare const index_IconZoomInAreaFilled: typeof IconZoomInAreaFilled;
declare const index_IconZoomInFilled: typeof IconZoomInFilled;
declare const index_IconZoomMoney: typeof IconZoomMoney;
declare const index_IconZoomMoneyFilled: typeof IconZoomMoneyFilled;
declare const index_IconZoomOut: typeof IconZoomOut;
declare const index_IconZoomOutArea: typeof IconZoomOutArea;
declare const index_IconZoomOutAreaFilled: typeof IconZoomOutAreaFilled;
declare const index_IconZoomOutFilled: typeof IconZoomOutFilled;
declare const index_IconZoomPan: typeof IconZoomPan;
declare const index_IconZoomPanFilled: typeof IconZoomPanFilled;
declare const index_IconZoomQuestion: typeof IconZoomQuestion;
declare const index_IconZoomQuestionFilled: typeof IconZoomQuestionFilled;
declare const index_IconZoomReplace: typeof IconZoomReplace;
declare const index_IconZoomReset: typeof IconZoomReset;
declare const index_IconZoomScan: typeof IconZoomScan;
declare const index_IconZoomScanFilled: typeof IconZoomScanFilled;
declare const index_IconZzz: typeof IconZzz;
declare const index_IconZzzOff: typeof IconZzzOff;
declare namespace index {
  export {
    index_IconAB as IconAB,
    index_IconAB2 as IconAB2,
    index_IconABOff as IconABOff,
    index_IconAbacus as IconAbacus,
    index_IconAbacusOff as IconAbacusOff,
    index_IconAbc as IconAbc,
    index_IconAccessPoint as IconAccessPoint,
    index_IconAccessPointOff as IconAccessPointOff,
    index_IconAccessible as IconAccessible,
    index_IconAccessibleFilled as IconAccessibleFilled,
    index_IconAccessibleOff as IconAccessibleOff,
    index_IconActivity as IconActivity,
    index_IconActivityHeartbeat as IconActivityHeartbeat,
    index_IconAd as IconAd,
    index_IconAd2 as IconAd2,
    index_IconAdCircle as IconAdCircle,
    index_IconAdCircleFilled as IconAdCircleFilled,
    index_IconAdCircleOff as IconAdCircleOff,
    index_IconAdFilled as IconAdFilled,
    index_IconAdOff as IconAdOff,
    index_IconAddressBook as IconAddressBook,
    index_IconAddressBookOff as IconAddressBookOff,
    index_IconAdjustments as IconAdjustments,
    index_IconAdjustmentsAlt as IconAdjustmentsAlt,
    index_IconAdjustmentsBolt as IconAdjustmentsBolt,
    index_IconAdjustmentsCancel as IconAdjustmentsCancel,
    index_IconAdjustmentsCheck as IconAdjustmentsCheck,
    index_IconAdjustmentsCode as IconAdjustmentsCode,
    index_IconAdjustmentsCog as IconAdjustmentsCog,
    index_IconAdjustmentsDollar as IconAdjustmentsDollar,
    index_IconAdjustmentsDown as IconAdjustmentsDown,
    index_IconAdjustmentsExclamation as IconAdjustmentsExclamation,
    index_IconAdjustmentsFilled as IconAdjustmentsFilled,
    index_IconAdjustmentsHeart as IconAdjustmentsHeart,
    index_IconAdjustmentsHorizontal as IconAdjustmentsHorizontal,
    index_IconAdjustmentsMinus as IconAdjustmentsMinus,
    index_IconAdjustmentsOff as IconAdjustmentsOff,
    index_IconAdjustmentsPause as IconAdjustmentsPause,
    index_IconAdjustmentsPin as IconAdjustmentsPin,
    index_IconAdjustmentsPlus as IconAdjustmentsPlus,
    index_IconAdjustmentsQuestion as IconAdjustmentsQuestion,
    index_IconAdjustmentsSearch as IconAdjustmentsSearch,
    index_IconAdjustmentsShare as IconAdjustmentsShare,
    index_IconAdjustmentsSpark as IconAdjustmentsSpark,
    index_IconAdjustmentsStar as IconAdjustmentsStar,
    index_IconAdjustmentsUp as IconAdjustmentsUp,
    index_IconAdjustmentsX as IconAdjustmentsX,
    index_IconAerialLift as IconAerialLift,
    index_IconAerialLiftFilled as IconAerialLiftFilled,
    index_IconAffiliate as IconAffiliate,
    index_IconAffiliateFilled as IconAffiliateFilled,
    index_IconAi as IconAi,
    index_IconAirBalloon as IconAirBalloon,
    index_IconAirBalloonFilled as IconAirBalloonFilled,
    index_IconAirConditioning as IconAirConditioning,
    index_IconAirConditioningDisabled as IconAirConditioningDisabled,
    index_IconAirTrafficControl as IconAirTrafficControl,
    index_IconAlarm as IconAlarm,
    index_IconAlarmAverage as IconAlarmAverage,
    index_IconAlarmFilled as IconAlarmFilled,
    index_IconAlarmMinus as IconAlarmMinus,
    index_IconAlarmMinusFilled as IconAlarmMinusFilled,
    index_IconAlarmOff as IconAlarmOff,
    index_IconAlarmPlus as IconAlarmPlus,
    index_IconAlarmPlusFilled as IconAlarmPlusFilled,
    index_IconAlarmSmoke as IconAlarmSmoke,
    index_IconAlarmSnooze as IconAlarmSnooze,
    index_IconAlarmSnoozeFilled as IconAlarmSnoozeFilled,
    index_IconAlbum as IconAlbum,
    index_IconAlbumOff as IconAlbumOff,
    index_IconAlertCircle as IconAlertCircle,
    index_IconAlertCircleFilled as IconAlertCircleFilled,
    index_IconAlertCircleOff as IconAlertCircleOff,
    index_IconAlertHexagon as IconAlertHexagon,
    index_IconAlertHexagonFilled as IconAlertHexagonFilled,
    index_IconAlertHexagonOff as IconAlertHexagonOff,
    index_IconAlertOctagon as IconAlertOctagon,
    index_IconAlertOctagonFilled as IconAlertOctagonFilled,
    index_IconAlertSmall as IconAlertSmall,
    index_IconAlertSmallOff as IconAlertSmallOff,
    index_IconAlertSquare as IconAlertSquare,
    index_IconAlertSquareFilled as IconAlertSquareFilled,
    index_IconAlertSquareRounded as IconAlertSquareRounded,
    index_IconAlertSquareRoundedFilled as IconAlertSquareRoundedFilled,
    index_IconAlertSquareRoundedOff as IconAlertSquareRoundedOff,
    index_IconAlertTriangle as IconAlertTriangle,
    index_IconAlertTriangleFilled as IconAlertTriangleFilled,
    index_IconAlertTriangleOff as IconAlertTriangleOff,
    index_IconAlien as IconAlien,
    index_IconAlienFilled as IconAlienFilled,
    index_IconAlignBoxBottomCenter as IconAlignBoxBottomCenter,
    index_IconAlignBoxBottomCenterFilled as IconAlignBoxBottomCenterFilled,
    index_IconAlignBoxBottomLeft as IconAlignBoxBottomLeft,
    index_IconAlignBoxBottomLeftFilled as IconAlignBoxBottomLeftFilled,
    index_IconAlignBoxBottomRight as IconAlignBoxBottomRight,
    index_IconAlignBoxBottomRightFilled as IconAlignBoxBottomRightFilled,
    index_IconAlignBoxCenterBottom as IconAlignBoxCenterBottom,
    index_IconAlignBoxCenterMiddle as IconAlignBoxCenterMiddle,
    index_IconAlignBoxCenterMiddleFilled as IconAlignBoxCenterMiddleFilled,
    index_IconAlignBoxCenterStretch as IconAlignBoxCenterStretch,
    index_IconAlignBoxCenterTop as IconAlignBoxCenterTop,
    index_IconAlignBoxLeftBottom as IconAlignBoxLeftBottom,
    index_IconAlignBoxLeftBottomFilled as IconAlignBoxLeftBottomFilled,
    index_IconAlignBoxLeftMiddle as IconAlignBoxLeftMiddle,
    index_IconAlignBoxLeftMiddleFilled as IconAlignBoxLeftMiddleFilled,
    index_IconAlignBoxLeftStretch as IconAlignBoxLeftStretch,
    index_IconAlignBoxLeftTop as IconAlignBoxLeftTop,
    index_IconAlignBoxLeftTopFilled as IconAlignBoxLeftTopFilled,
    index_IconAlignBoxRightBottom as IconAlignBoxRightBottom,
    index_IconAlignBoxRightBottomFilled as IconAlignBoxRightBottomFilled,
    index_IconAlignBoxRightMiddle as IconAlignBoxRightMiddle,
    index_IconAlignBoxRightMiddleFilled as IconAlignBoxRightMiddleFilled,
    index_IconAlignBoxRightStretch as IconAlignBoxRightStretch,
    index_IconAlignBoxRightTop as IconAlignBoxRightTop,
    index_IconAlignBoxRightTopFilled as IconAlignBoxRightTopFilled,
    index_IconAlignBoxTopCenter as IconAlignBoxTopCenter,
    index_IconAlignBoxTopCenterFilled as IconAlignBoxTopCenterFilled,
    index_IconAlignBoxTopLeft as IconAlignBoxTopLeft,
    index_IconAlignBoxTopLeftFilled as IconAlignBoxTopLeftFilled,
    index_IconAlignBoxTopRight as IconAlignBoxTopRight,
    index_IconAlignBoxTopRightFilled as IconAlignBoxTopRightFilled,
    index_IconAlignCenter as IconAlignCenter,
    index_IconAlignJustified as IconAlignJustified,
    index_IconAlignLeft as IconAlignLeft,
    index_IconAlignLeft2 as IconAlignLeft2,
    index_IconAlignRight as IconAlignRight,
    index_IconAlignRight2 as IconAlignRight2,
    index_IconAlpha as IconAlpha,
    index_IconAlphabetArabic as IconAlphabetArabic,
    index_IconAlphabetBangla as IconAlphabetBangla,
    index_IconAlphabetCyrillic as IconAlphabetCyrillic,
    index_IconAlphabetGreek as IconAlphabetGreek,
    index_IconAlphabetHebrew as IconAlphabetHebrew,
    index_IconAlphabetKorean as IconAlphabetKorean,
    index_IconAlphabetLatin as IconAlphabetLatin,
    index_IconAlphabetPolish as IconAlphabetPolish,
    index_IconAlphabetRunes as IconAlphabetRunes,
    index_IconAlphabetThai as IconAlphabetThai,
    index_IconAlt as IconAlt,
    index_IconAmbulance as IconAmbulance,
    index_IconAmpersand as IconAmpersand,
    index_IconAnalyze as IconAnalyze,
    index_IconAnalyzeFilled as IconAnalyzeFilled,
    index_IconAnalyzeOff as IconAnalyzeOff,
    index_IconAnchor as IconAnchor,
    index_IconAnchorOff as IconAnchorOff,
    index_IconAngle as IconAngle,
    index_IconAnkh as IconAnkh,
    index_IconAntenna as IconAntenna,
    index_IconAntennaBars1 as IconAntennaBars1,
    index_IconAntennaBars2 as IconAntennaBars2,
    index_IconAntennaBars3 as IconAntennaBars3,
    index_IconAntennaBars4 as IconAntennaBars4,
    index_IconAntennaBars5 as IconAntennaBars5,
    index_IconAntennaBarsOff as IconAntennaBarsOff,
    index_IconAntennaOff as IconAntennaOff,
    index_IconAperture as IconAperture,
    index_IconApertureOff as IconApertureOff,
    index_IconApi as IconApi,
    index_IconApiApp as IconApiApp,
    index_IconApiAppOff as IconApiAppOff,
    index_IconApiOff as IconApiOff,
    index_IconAppWindow as IconAppWindow,
    index_IconAppWindowFilled as IconAppWindowFilled,
    index_IconApple as IconApple,
    index_IconAppleFilled as IconAppleFilled,
    index_IconApps as IconApps,
    index_IconAppsFilled as IconAppsFilled,
    index_IconAppsOff as IconAppsOff,
    index_IconArcheryArrow as IconArcheryArrow,
    index_IconArchive as IconArchive,
    index_IconArchiveFilled as IconArchiveFilled,
    index_IconArchiveOff as IconArchiveOff,
    index_IconArmchair as IconArmchair,
    index_IconArmchair2 as IconArmchair2,
    index_IconArmchair2Off as IconArmchair2Off,
    index_IconArmchairOff as IconArmchairOff,
    index_IconArrowAutofitContent as IconArrowAutofitContent,
    index_IconArrowAutofitContentFilled as IconArrowAutofitContentFilled,
    index_IconArrowAutofitDown as IconArrowAutofitDown,
    index_IconArrowAutofitDownFilled as IconArrowAutofitDownFilled,
    index_IconArrowAutofitHeight as IconArrowAutofitHeight,
    index_IconArrowAutofitHeightFilled as IconArrowAutofitHeightFilled,
    index_IconArrowAutofitLeft as IconArrowAutofitLeft,
    index_IconArrowAutofitLeftFilled as IconArrowAutofitLeftFilled,
    index_IconArrowAutofitRight as IconArrowAutofitRight,
    index_IconArrowAutofitRightFilled as IconArrowAutofitRightFilled,
    index_IconArrowAutofitUp as IconArrowAutofitUp,
    index_IconArrowAutofitUpFilled as IconArrowAutofitUpFilled,
    index_IconArrowAutofitWidth as IconArrowAutofitWidth,
    index_IconArrowAutofitWidthFilled as IconArrowAutofitWidthFilled,
    index_IconArrowBack as IconArrowBack,
    index_IconArrowBackUp as IconArrowBackUp,
    index_IconArrowBackUpDouble as IconArrowBackUpDouble,
    index_IconArrowBadgeDown as IconArrowBadgeDown,
    index_IconArrowBadgeDownFilled as IconArrowBadgeDownFilled,
    index_IconArrowBadgeLeft as IconArrowBadgeLeft,
    index_IconArrowBadgeLeftFilled as IconArrowBadgeLeftFilled,
    index_IconArrowBadgeRight as IconArrowBadgeRight,
    index_IconArrowBadgeRightFilled as IconArrowBadgeRightFilled,
    index_IconArrowBadgeUp as IconArrowBadgeUp,
    index_IconArrowBadgeUpFilled as IconArrowBadgeUpFilled,
    index_IconArrowBarBoth as IconArrowBarBoth,
    index_IconArrowBarDown as IconArrowBarDown,
    index_IconArrowBarLeft as IconArrowBarLeft,
    index_IconArrowBarRight as IconArrowBarRight,
    index_IconArrowBarToDown as IconArrowBarToDown,
    index_IconArrowBarToDownDashed as IconArrowBarToDownDashed,
    index_IconArrowBarToLeft as IconArrowBarToLeft,
    index_IconArrowBarToLeftDashed as IconArrowBarToLeftDashed,
    index_IconArrowBarToRight as IconArrowBarToRight,
    index_IconArrowBarToRightDashed as IconArrowBarToRightDashed,
    index_IconArrowBarToUp as IconArrowBarToUp,
    index_IconArrowBarToUpDashed as IconArrowBarToUpDashed,
    index_IconArrowBarUp as IconArrowBarUp,
    index_IconArrowBearLeft as IconArrowBearLeft,
    index_IconArrowBearLeft2 as IconArrowBearLeft2,
    index_IconArrowBearRight as IconArrowBearRight,
    index_IconArrowBearRight2 as IconArrowBearRight2,
    index_IconArrowBigDown as IconArrowBigDown,
    index_IconArrowBigDownFilled as IconArrowBigDownFilled,
    index_IconArrowBigDownLine as IconArrowBigDownLine,
    index_IconArrowBigDownLineFilled as IconArrowBigDownLineFilled,
    index_IconArrowBigDownLines as IconArrowBigDownLines,
    index_IconArrowBigDownLinesFilled as IconArrowBigDownLinesFilled,
    index_IconArrowBigLeft as IconArrowBigLeft,
    index_IconArrowBigLeftFilled as IconArrowBigLeftFilled,
    index_IconArrowBigLeftLine as IconArrowBigLeftLine,
    index_IconArrowBigLeftLineFilled as IconArrowBigLeftLineFilled,
    index_IconArrowBigLeftLines as IconArrowBigLeftLines,
    index_IconArrowBigLeftLinesFilled as IconArrowBigLeftLinesFilled,
    index_IconArrowBigRight as IconArrowBigRight,
    index_IconArrowBigRightFilled as IconArrowBigRightFilled,
    index_IconArrowBigRightLine as IconArrowBigRightLine,
    index_IconArrowBigRightLineFilled as IconArrowBigRightLineFilled,
    index_IconArrowBigRightLines as IconArrowBigRightLines,
    index_IconArrowBigRightLinesFilled as IconArrowBigRightLinesFilled,
    index_IconArrowBigUp as IconArrowBigUp,
    index_IconArrowBigUpFilled as IconArrowBigUpFilled,
    index_IconArrowBigUpLine as IconArrowBigUpLine,
    index_IconArrowBigUpLineFilled as IconArrowBigUpLineFilled,
    index_IconArrowBigUpLines as IconArrowBigUpLines,
    index_IconArrowBigUpLinesFilled as IconArrowBigUpLinesFilled,
    index_IconArrowBounce as IconArrowBounce,
    index_IconArrowCapsule as IconArrowCapsule,
    index_IconArrowCurveLeft as IconArrowCurveLeft,
    index_IconArrowCurveRight as IconArrowCurveRight,
    index_IconArrowDown as IconArrowDown,
    index_IconArrowDownBar as IconArrowDownBar,
    index_IconArrowDownCircle as IconArrowDownCircle,
    index_IconArrowDownCircleFilled as IconArrowDownCircleFilled,
    index_IconArrowDownDashed as IconArrowDownDashed,
    index_IconArrowDownFromArc as IconArrowDownFromArc,
    index_IconArrowDownLeft as IconArrowDownLeft,
    index_IconArrowDownLeftCircle as IconArrowDownLeftCircle,
    index_IconArrowDownRhombus as IconArrowDownRhombus,
    index_IconArrowDownRhombusFilled as IconArrowDownRhombusFilled,
    index_IconArrowDownRight as IconArrowDownRight,
    index_IconArrowDownRightCircle as IconArrowDownRightCircle,
    index_IconArrowDownSquare as IconArrowDownSquare,
    index_IconArrowDownSquareFilled as IconArrowDownSquareFilled,
    index_IconArrowDownTail as IconArrowDownTail,
    index_IconArrowDownToArc as IconArrowDownToArc,
    index_IconArrowElbowLeft as IconArrowElbowLeft,
    index_IconArrowElbowRight as IconArrowElbowRight,
    index_IconArrowFork as IconArrowFork,
    index_IconArrowForward as IconArrowForward,
    index_IconArrowForwardUp as IconArrowForwardUp,
    index_IconArrowForwardUpDouble as IconArrowForwardUpDouble,
    index_IconArrowGuide as IconArrowGuide,
    index_IconArrowGuideFilled as IconArrowGuideFilled,
    index_IconArrowIteration as IconArrowIteration,
    index_IconArrowLeft as IconArrowLeft,
    index_IconArrowLeftBar as IconArrowLeftBar,
    index_IconArrowLeftCircle as IconArrowLeftCircle,
    index_IconArrowLeftCircleFilled as IconArrowLeftCircleFilled,
    index_IconArrowLeftDashed as IconArrowLeftDashed,
    index_IconArrowLeftFromArc as IconArrowLeftFromArc,
    index_IconArrowLeftRhombus as IconArrowLeftRhombus,
    index_IconArrowLeftRhombusFilled as IconArrowLeftRhombusFilled,
    index_IconArrowLeftRight as IconArrowLeftRight,
    index_IconArrowLeftSquare as IconArrowLeftSquare,
    index_IconArrowLeftSquareFilled as IconArrowLeftSquareFilled,
    index_IconArrowLeftTail as IconArrowLeftTail,
    index_IconArrowLeftToArc as IconArrowLeftToArc,
    index_IconArrowLoopLeft as IconArrowLoopLeft,
    index_IconArrowLoopLeft2 as IconArrowLoopLeft2,
    index_IconArrowLoopRight as IconArrowLoopRight,
    index_IconArrowLoopRight2 as IconArrowLoopRight2,
    index_IconArrowMerge as IconArrowMerge,
    index_IconArrowMergeAltLeft as IconArrowMergeAltLeft,
    index_IconArrowMergeAltRight as IconArrowMergeAltRight,
    index_IconArrowMergeBoth as IconArrowMergeBoth,
    index_IconArrowMergeLeft as IconArrowMergeLeft,
    index_IconArrowMergeRight as IconArrowMergeRight,
    index_IconArrowMoveDown as IconArrowMoveDown,
    index_IconArrowMoveDownFilled as IconArrowMoveDownFilled,
    index_IconArrowMoveLeft as IconArrowMoveLeft,
    index_IconArrowMoveLeftFilled as IconArrowMoveLeftFilled,
    index_IconArrowMoveRight as IconArrowMoveRight,
    index_IconArrowMoveRightFilled as IconArrowMoveRightFilled,
    index_IconArrowMoveUp as IconArrowMoveUp,
    index_IconArrowMoveUpFilled as IconArrowMoveUpFilled,
    index_IconArrowNarrowDown as IconArrowNarrowDown,
    index_IconArrowNarrowDownDashed as IconArrowNarrowDownDashed,
    index_IconArrowNarrowLeft as IconArrowNarrowLeft,
    index_IconArrowNarrowLeftDashed as IconArrowNarrowLeftDashed,
    index_IconArrowNarrowRight as IconArrowNarrowRight,
    index_IconArrowNarrowRightDashed as IconArrowNarrowRightDashed,
    index_IconArrowNarrowUp as IconArrowNarrowUp,
    index_IconArrowNarrowUpDashed as IconArrowNarrowUpDashed,
    index_IconArrowRampLeft as IconArrowRampLeft,
    index_IconArrowRampLeft2 as IconArrowRampLeft2,
    index_IconArrowRampLeft3 as IconArrowRampLeft3,
    index_IconArrowRampRight as IconArrowRampRight,
    index_IconArrowRampRight2 as IconArrowRampRight2,
    index_IconArrowRampRight3 as IconArrowRampRight3,
    index_IconArrowRight as IconArrowRight,
    index_IconArrowRightBar as IconArrowRightBar,
    index_IconArrowRightCircle as IconArrowRightCircle,
    index_IconArrowRightCircleFilled as IconArrowRightCircleFilled,
    index_IconArrowRightDashed as IconArrowRightDashed,
    index_IconArrowRightFromArc as IconArrowRightFromArc,
    index_IconArrowRightRhombus as IconArrowRightRhombus,
    index_IconArrowRightRhombusFilled as IconArrowRightRhombusFilled,
    index_IconArrowRightSquare as IconArrowRightSquare,
    index_IconArrowRightSquareFilled as IconArrowRightSquareFilled,
    index_IconArrowRightTail as IconArrowRightTail,
    index_IconArrowRightToArc as IconArrowRightToArc,
    index_IconArrowRotaryFirstLeft as IconArrowRotaryFirstLeft,
    index_IconArrowRotaryFirstRight as IconArrowRotaryFirstRight,
    index_IconArrowRotaryLastLeft as IconArrowRotaryLastLeft,
    index_IconArrowRotaryLastRight as IconArrowRotaryLastRight,
    index_IconArrowRotaryLeft as IconArrowRotaryLeft,
    index_IconArrowRotaryRight as IconArrowRotaryRight,
    index_IconArrowRotaryStraight as IconArrowRotaryStraight,
    index_IconArrowRoundaboutLeft as IconArrowRoundaboutLeft,
    index_IconArrowRoundaboutRight as IconArrowRoundaboutRight,
    index_IconArrowSharpTurnLeft as IconArrowSharpTurnLeft,
    index_IconArrowSharpTurnRight as IconArrowSharpTurnRight,
    index_IconArrowUp as IconArrowUp,
    index_IconArrowUpBar as IconArrowUpBar,
    index_IconArrowUpCircle as IconArrowUpCircle,
    index_IconArrowUpCircleFilled as IconArrowUpCircleFilled,
    index_IconArrowUpDashed as IconArrowUpDashed,
    index_IconArrowUpFromArc as IconArrowUpFromArc,
    index_IconArrowUpLeft as IconArrowUpLeft,
    index_IconArrowUpLeftCircle as IconArrowUpLeftCircle,
    index_IconArrowUpRhombus as IconArrowUpRhombus,
    index_IconArrowUpRhombusFilled as IconArrowUpRhombusFilled,
    index_IconArrowUpRight as IconArrowUpRight,
    index_IconArrowUpRightCircle as IconArrowUpRightCircle,
    index_IconArrowUpSquare as IconArrowUpSquare,
    index_IconArrowUpSquareFilled as IconArrowUpSquareFilled,
    index_IconArrowUpTail as IconArrowUpTail,
    index_IconArrowUpToArc as IconArrowUpToArc,
    index_IconArrowWaveLeftDown as IconArrowWaveLeftDown,
    index_IconArrowWaveLeftUp as IconArrowWaveLeftUp,
    index_IconArrowWaveRightDown as IconArrowWaveRightDown,
    index_IconArrowWaveRightUp as IconArrowWaveRightUp,
    index_IconArrowZigZag as IconArrowZigZag,
    index_IconArrowsCross as IconArrowsCross,
    index_IconArrowsDiagonal as IconArrowsDiagonal,
    index_IconArrowsDiagonal2 as IconArrowsDiagonal2,
    index_IconArrowsDiagonalMinimize as IconArrowsDiagonalMinimize,
    index_IconArrowsDiagonalMinimize2 as IconArrowsDiagonalMinimize2,
    index_IconArrowsDiff as IconArrowsDiff,
    index_IconArrowsDoubleNeSw as IconArrowsDoubleNeSw,
    index_IconArrowsDoubleNwSe as IconArrowsDoubleNwSe,
    index_IconArrowsDoubleSeNw as IconArrowsDoubleSeNw,
    index_IconArrowsDoubleSwNe as IconArrowsDoubleSwNe,
    index_IconArrowsDown as IconArrowsDown,
    index_IconArrowsDownUp as IconArrowsDownUp,
    index_IconArrowsExchange as IconArrowsExchange,
    index_IconArrowsExchange2 as IconArrowsExchange2,
    index_IconArrowsHorizontal as IconArrowsHorizontal,
    index_IconArrowsJoin as IconArrowsJoin,
    index_IconArrowsJoin2 as IconArrowsJoin2,
    index_IconArrowsLeft as IconArrowsLeft,
    index_IconArrowsLeftDown as IconArrowsLeftDown,
    index_IconArrowsLeftRight as IconArrowsLeftRight,
    index_IconArrowsMaximize as IconArrowsMaximize,
    index_IconArrowsMinimize as IconArrowsMinimize,
    index_IconArrowsMove as IconArrowsMove,
    index_IconArrowsMoveHorizontal as IconArrowsMoveHorizontal,
    index_IconArrowsMoveVertical as IconArrowsMoveVertical,
    index_IconArrowsRandom as IconArrowsRandom,
    index_IconArrowsRight as IconArrowsRight,
    index_IconArrowsRightDown as IconArrowsRightDown,
    index_IconArrowsRightLeft as IconArrowsRightLeft,
    index_IconArrowsShuffle as IconArrowsShuffle,
    index_IconArrowsShuffle2 as IconArrowsShuffle2,
    index_IconArrowsSort as IconArrowsSort,
    index_IconArrowsSplit as IconArrowsSplit,
    index_IconArrowsSplit2 as IconArrowsSplit2,
    index_IconArrowsTransferDown as IconArrowsTransferDown,
    index_IconArrowsTransferUp as IconArrowsTransferUp,
    index_IconArrowsTransferUpDown as IconArrowsTransferUpDown,
    index_IconArrowsUp as IconArrowsUp,
    index_IconArrowsUpDown as IconArrowsUpDown,
    index_IconArrowsUpLeft as IconArrowsUpLeft,
    index_IconArrowsUpRight as IconArrowsUpRight,
    index_IconArrowsVertical as IconArrowsVertical,
    index_IconArtboard as IconArtboard,
    index_IconArtboardFilled as IconArtboardFilled,
    index_IconArtboardOff as IconArtboardOff,
    index_IconArticle as IconArticle,
    index_IconArticleFilled as IconArticleFilled,
    index_IconArticleOff as IconArticleOff,
    index_IconAspectRatio as IconAspectRatio,
    index_IconAspectRatioFilled as IconAspectRatioFilled,
    index_IconAspectRatioOff as IconAspectRatioOff,
    index_IconAssembly as IconAssembly,
    index_IconAssemblyFilled as IconAssemblyFilled,
    index_IconAssemblyOff as IconAssemblyOff,
    index_IconAsset as IconAsset,
    index_IconAssetFilled as IconAssetFilled,
    index_IconAsterisk as IconAsterisk,
    index_IconAsteriskSimple as IconAsteriskSimple,
    index_IconAt as IconAt,
    index_IconAtOff as IconAtOff,
    index_IconAtom as IconAtom,
    index_IconAtom2 as IconAtom2,
    index_IconAtom2Filled as IconAtom2Filled,
    index_IconAtomOff as IconAtomOff,
    index_IconAugmentedReality as IconAugmentedReality,
    index_IconAugmentedReality2 as IconAugmentedReality2,
    index_IconAugmentedRealityOff as IconAugmentedRealityOff,
    index_IconAuth2fa as IconAuth2fa,
    index_IconAutomaticGearbox as IconAutomaticGearbox,
    index_IconAutomaticGearboxFilled as IconAutomaticGearboxFilled,
    index_IconAutomation as IconAutomation,
    index_IconAvocado as IconAvocado,
    index_IconAward as IconAward,
    index_IconAwardFilled as IconAwardFilled,
    index_IconAwardOff as IconAwardOff,
    index_IconAxe as IconAxe,
    index_IconAxisX as IconAxisX,
    index_IconAxisY as IconAxisY,
    index_IconBabyBottle as IconBabyBottle,
    index_IconBabyCarriage as IconBabyCarriage,
    index_IconBabyCarriageFilled as IconBabyCarriageFilled,
    index_IconBackground as IconBackground,
    index_IconBackhoe as IconBackhoe,
    index_IconBackpack as IconBackpack,
    index_IconBackpackOff as IconBackpackOff,
    index_IconBackslash as IconBackslash,
    index_IconBackspace as IconBackspace,
    index_IconBackspaceFilled as IconBackspaceFilled,
    index_IconBadge as IconBadge,
    index_IconBadge2k as IconBadge2k,
    index_IconBadge3d as IconBadge3d,
    index_IconBadge3dFilled as IconBadge3dFilled,
    index_IconBadge3k as IconBadge3k,
    index_IconBadge4k as IconBadge4k,
    index_IconBadge4kFilled as IconBadge4kFilled,
    index_IconBadge5k as IconBadge5k,
    index_IconBadge8k as IconBadge8k,
    index_IconBadge8kFilled as IconBadge8kFilled,
    index_IconBadgeAd as IconBadgeAd,
    index_IconBadgeAdFilled as IconBadgeAdFilled,
    index_IconBadgeAdOff as IconBadgeAdOff,
    index_IconBadgeAr as IconBadgeAr,
    index_IconBadgeArFilled as IconBadgeArFilled,
    index_IconBadgeCc as IconBadgeCc,
    index_IconBadgeCcFilled as IconBadgeCcFilled,
    index_IconBadgeFilled as IconBadgeFilled,
    index_IconBadgeHd as IconBadgeHd,
    index_IconBadgeHdFilled as IconBadgeHdFilled,
    index_IconBadgeOff as IconBadgeOff,
    index_IconBadgeSd as IconBadgeSd,
    index_IconBadgeSdFilled as IconBadgeSdFilled,
    index_IconBadgeTm as IconBadgeTm,
    index_IconBadgeTmFilled as IconBadgeTmFilled,
    index_IconBadgeVo as IconBadgeVo,
    index_IconBadgeVoFilled as IconBadgeVoFilled,
    index_IconBadgeVr as IconBadgeVr,
    index_IconBadgeVrFilled as IconBadgeVrFilled,
    index_IconBadgeWc as IconBadgeWc,
    index_IconBadgeWcFilled as IconBadgeWcFilled,
    index_IconBadges as IconBadges,
    index_IconBadgesFilled as IconBadgesFilled,
    index_IconBadgesOff as IconBadgesOff,
    index_IconBaguette as IconBaguette,
    index_IconBallAmericanFootball as IconBallAmericanFootball,
    index_IconBallAmericanFootballOff as IconBallAmericanFootballOff,
    index_IconBallBaseball as IconBallBaseball,
    index_IconBallBasketball as IconBallBasketball,
    index_IconBallBowling as IconBallBowling,
    index_IconBallBowlingFilled as IconBallBowlingFilled,
    index_IconBallFootball as IconBallFootball,
    index_IconBallFootballOff as IconBallFootballOff,
    index_IconBallTennis as IconBallTennis,
    index_IconBallVolleyball as IconBallVolleyball,
    index_IconBalloon as IconBalloon,
    index_IconBalloonFilled as IconBalloonFilled,
    index_IconBalloonOff as IconBalloonOff,
    index_IconBallpen as IconBallpen,
    index_IconBallpenFilled as IconBallpenFilled,
    index_IconBallpenOff as IconBallpenOff,
    index_IconBan as IconBan,
    index_IconBandage as IconBandage,
    index_IconBandageFilled as IconBandageFilled,
    index_IconBandageOff as IconBandageOff,
    index_IconBarbell as IconBarbell,
    index_IconBarbellFilled as IconBarbellFilled,
    index_IconBarbellOff as IconBarbellOff,
    index_IconBarcode as IconBarcode,
    index_IconBarcodeOff as IconBarcodeOff,
    index_IconBarrel as IconBarrel,
    index_IconBarrelOff as IconBarrelOff,
    index_IconBarrierBlock as IconBarrierBlock,
    index_IconBarrierBlockFilled as IconBarrierBlockFilled,
    index_IconBarrierBlockOff as IconBarrierBlockOff,
    index_IconBaseline as IconBaseline,
    index_IconBaselineDensityLarge as IconBaselineDensityLarge,
    index_IconBaselineDensityMedium as IconBaselineDensityMedium,
    index_IconBaselineDensitySmall as IconBaselineDensitySmall,
    index_IconBasket as IconBasket,
    index_IconBasketBolt as IconBasketBolt,
    index_IconBasketCancel as IconBasketCancel,
    index_IconBasketCheck as IconBasketCheck,
    index_IconBasketCode as IconBasketCode,
    index_IconBasketCog as IconBasketCog,
    index_IconBasketDiscount as IconBasketDiscount,
    index_IconBasketDollar as IconBasketDollar,
    index_IconBasketDown as IconBasketDown,
    index_IconBasketExclamation as IconBasketExclamation,
    index_IconBasketFilled as IconBasketFilled,
    index_IconBasketHeart as IconBasketHeart,
    index_IconBasketMinus as IconBasketMinus,
    index_IconBasketOff as IconBasketOff,
    index_IconBasketPause as IconBasketPause,
    index_IconBasketPin as IconBasketPin,
    index_IconBasketPlus as IconBasketPlus,
    index_IconBasketQuestion as IconBasketQuestion,
    index_IconBasketSearch as IconBasketSearch,
    index_IconBasketShare as IconBasketShare,
    index_IconBasketStar as IconBasketStar,
    index_IconBasketUp as IconBasketUp,
    index_IconBasketX as IconBasketX,
    index_IconBat as IconBat,
    index_IconBath as IconBath,
    index_IconBathFilled as IconBathFilled,
    index_IconBathOff as IconBathOff,
    index_IconBattery as IconBattery,
    index_IconBattery1 as IconBattery1,
    index_IconBattery1Filled as IconBattery1Filled,
    index_IconBattery2 as IconBattery2,
    index_IconBattery2Filled as IconBattery2Filled,
    index_IconBattery3 as IconBattery3,
    index_IconBattery3Filled as IconBattery3Filled,
    index_IconBattery4 as IconBattery4,
    index_IconBattery4Filled as IconBattery4Filled,
    index_IconBatteryAutomotive as IconBatteryAutomotive,
    index_IconBatteryAutomotiveFilled as IconBatteryAutomotiveFilled,
    index_IconBatteryCharging as IconBatteryCharging,
    index_IconBatteryCharging2 as IconBatteryCharging2,
    index_IconBatteryEco as IconBatteryEco,
    index_IconBatteryExclamation as IconBatteryExclamation,
    index_IconBatteryFilled as IconBatteryFilled,
    index_IconBatteryOff as IconBatteryOff,
    index_IconBatterySpark as IconBatterySpark,
    index_IconBatteryVertical as IconBatteryVertical,
    index_IconBatteryVertical1 as IconBatteryVertical1,
    index_IconBatteryVertical1Filled as IconBatteryVertical1Filled,
    index_IconBatteryVertical2 as IconBatteryVertical2,
    index_IconBatteryVertical2Filled as IconBatteryVertical2Filled,
    index_IconBatteryVertical3 as IconBatteryVertical3,
    index_IconBatteryVertical3Filled as IconBatteryVertical3Filled,
    index_IconBatteryVertical4 as IconBatteryVertical4,
    index_IconBatteryVertical4Filled as IconBatteryVertical4Filled,
    index_IconBatteryVerticalCharging as IconBatteryVerticalCharging,
    index_IconBatteryVerticalCharging2 as IconBatteryVerticalCharging2,
    index_IconBatteryVerticalEco as IconBatteryVerticalEco,
    index_IconBatteryVerticalExclamation as IconBatteryVerticalExclamation,
    index_IconBatteryVerticalFilled as IconBatteryVerticalFilled,
    index_IconBatteryVerticalOff as IconBatteryVerticalOff,
    index_IconBeach as IconBeach,
    index_IconBeachOff as IconBeachOff,
    index_IconBed as IconBed,
    index_IconBedFilled as IconBedFilled,
    index_IconBedFlat as IconBedFlat,
    index_IconBedFlatFilled as IconBedFlatFilled,
    index_IconBedOff as IconBedOff,
    index_IconBeer as IconBeer,
    index_IconBeerFilled as IconBeerFilled,
    index_IconBeerOff as IconBeerOff,
    index_IconBell as IconBell,
    index_IconBellBolt as IconBellBolt,
    index_IconBellCancel as IconBellCancel,
    index_IconBellCheck as IconBellCheck,
    index_IconBellCode as IconBellCode,
    index_IconBellCog as IconBellCog,
    index_IconBellDollar as IconBellDollar,
    index_IconBellDown as IconBellDown,
    index_IconBellExclamation as IconBellExclamation,
    index_IconBellFilled as IconBellFilled,
    index_IconBellHeart as IconBellHeart,
    index_IconBellMinus as IconBellMinus,
    index_IconBellMinusFilled as IconBellMinusFilled,
    index_IconBellOff as IconBellOff,
    index_IconBellPause as IconBellPause,
    index_IconBellPin as IconBellPin,
    index_IconBellPlus as IconBellPlus,
    index_IconBellPlusFilled as IconBellPlusFilled,
    index_IconBellQuestion as IconBellQuestion,
    index_IconBellRinging as IconBellRinging,
    index_IconBellRinging2 as IconBellRinging2,
    index_IconBellRinging2Filled as IconBellRinging2Filled,
    index_IconBellRingingFilled as IconBellRingingFilled,
    index_IconBellSchool as IconBellSchool,
    index_IconBellSearch as IconBellSearch,
    index_IconBellShare as IconBellShare,
    index_IconBellStar as IconBellStar,
    index_IconBellUp as IconBellUp,
    index_IconBellX as IconBellX,
    index_IconBellXFilled as IconBellXFilled,
    index_IconBellZ as IconBellZ,
    index_IconBellZFilled as IconBellZFilled,
    index_IconBeta as IconBeta,
    index_IconBible as IconBible,
    index_IconBike as IconBike,
    index_IconBikeFilled as IconBikeFilled,
    index_IconBikeOff as IconBikeOff,
    index_IconBinary as IconBinary,
    index_IconBinaryOff as IconBinaryOff,
    index_IconBinaryTree as IconBinaryTree,
    index_IconBinaryTree2 as IconBinaryTree2,
    index_IconBinaryTree2Filled as IconBinaryTree2Filled,
    index_IconBinaryTreeFilled as IconBinaryTreeFilled,
    index_IconBinoculars as IconBinoculars,
    index_IconBinocularsFilled as IconBinocularsFilled,
    index_IconBiohazard as IconBiohazard,
    index_IconBiohazardFilled as IconBiohazardFilled,
    index_IconBiohazardOff as IconBiohazardOff,
    index_IconBlade as IconBlade,
    index_IconBladeFilled as IconBladeFilled,
    index_IconBleach as IconBleach,
    index_IconBleachChlorine as IconBleachChlorine,
    index_IconBleachNoChlorine as IconBleachNoChlorine,
    index_IconBleachOff as IconBleachOff,
    index_IconBlendMode as IconBlendMode,
    index_IconBlender as IconBlender,
    index_IconBlenderFilled as IconBlenderFilled,
    index_IconBlind as IconBlind,
    index_IconBlob as IconBlob,
    index_IconBlobFilled as IconBlobFilled,
    index_IconBlockquote as IconBlockquote,
    index_IconBlocks as IconBlocks,
    index_IconBluetooth as IconBluetooth,
    index_IconBluetoothConnected as IconBluetoothConnected,
    index_IconBluetoothOff as IconBluetoothOff,
    index_IconBluetoothX as IconBluetoothX,
    index_IconBlur as IconBlur,
    index_IconBlurOff as IconBlurOff,
    index_IconBmp as IconBmp,
    index_IconBodyScan as IconBodyScan,
    index_IconBold as IconBold,
    index_IconBoldOff as IconBoldOff,
    index_IconBolt as IconBolt,
    index_IconBoltFilled as IconBoltFilled,
    index_IconBoltOff as IconBoltOff,
    index_IconBomb as IconBomb,
    index_IconBombFilled as IconBombFilled,
    index_IconBone as IconBone,
    index_IconBoneFilled as IconBoneFilled,
    index_IconBoneOff as IconBoneOff,
    index_IconBong as IconBong,
    index_IconBongFilled as IconBongFilled,
    index_IconBongOff as IconBongOff,
    index_IconBook as IconBook,
    index_IconBook2 as IconBook2,
    index_IconBookDownload as IconBookDownload,
    index_IconBookFilled as IconBookFilled,
    index_IconBookOff as IconBookOff,
    index_IconBookUpload as IconBookUpload,
    index_IconBookmark as IconBookmark,
    index_IconBookmarkAi as IconBookmarkAi,
    index_IconBookmarkEdit as IconBookmarkEdit,
    index_IconBookmarkFilled as IconBookmarkFilled,
    index_IconBookmarkMinus as IconBookmarkMinus,
    index_IconBookmarkOff as IconBookmarkOff,
    index_IconBookmarkPlus as IconBookmarkPlus,
    index_IconBookmarkQuestion as IconBookmarkQuestion,
    index_IconBookmarks as IconBookmarks,
    index_IconBookmarksFilled as IconBookmarksFilled,
    index_IconBookmarksOff as IconBookmarksOff,
    index_IconBooks as IconBooks,
    index_IconBooksOff as IconBooksOff,
    index_IconBoom as IconBoom,
    index_IconBoomFilled as IconBoomFilled,
    index_IconBorderAll as IconBorderAll,
    index_IconBorderBottom as IconBorderBottom,
    index_IconBorderBottomPlus as IconBorderBottomPlus,
    index_IconBorderCornerIos as IconBorderCornerIos,
    index_IconBorderCornerPill as IconBorderCornerPill,
    index_IconBorderCornerRounded as IconBorderCornerRounded,
    index_IconBorderCornerSquare as IconBorderCornerSquare,
    index_IconBorderCorners as IconBorderCorners,
    index_IconBorderHorizontal as IconBorderHorizontal,
    index_IconBorderInner as IconBorderInner,
    index_IconBorderLeft as IconBorderLeft,
    index_IconBorderLeftPlus as IconBorderLeftPlus,
    index_IconBorderNone as IconBorderNone,
    index_IconBorderOuter as IconBorderOuter,
    index_IconBorderRadius as IconBorderRadius,
    index_IconBorderRight as IconBorderRight,
    index_IconBorderRightPlus as IconBorderRightPlus,
    index_IconBorderSides as IconBorderSides,
    index_IconBorderStyle as IconBorderStyle,
    index_IconBorderStyle2 as IconBorderStyle2,
    index_IconBorderTop as IconBorderTop,
    index_IconBorderTopPlus as IconBorderTopPlus,
    index_IconBorderVertical as IconBorderVertical,
    index_IconBottle as IconBottle,
    index_IconBottleFilled as IconBottleFilled,
    index_IconBottleOff as IconBottleOff,
    index_IconBounceLeft as IconBounceLeft,
    index_IconBounceLeftFilled as IconBounceLeftFilled,
    index_IconBounceRight as IconBounceRight,
    index_IconBounceRightFilled as IconBounceRightFilled,
    index_IconBow as IconBow,
    index_IconBowFilled as IconBowFilled,
    index_IconBowl as IconBowl,
    index_IconBowlChopsticks as IconBowlChopsticks,
    index_IconBowlChopsticksFilled as IconBowlChopsticksFilled,
    index_IconBowlFilled as IconBowlFilled,
    index_IconBowlSpoon as IconBowlSpoon,
    index_IconBowlSpoonFilled as IconBowlSpoonFilled,
    index_IconBowling as IconBowling,
    index_IconBox as IconBox,
    index_IconBoxAlignBottom as IconBoxAlignBottom,
    index_IconBoxAlignBottomFilled as IconBoxAlignBottomFilled,
    index_IconBoxAlignBottomLeft as IconBoxAlignBottomLeft,
    index_IconBoxAlignBottomLeftFilled as IconBoxAlignBottomLeftFilled,
    index_IconBoxAlignBottomRight as IconBoxAlignBottomRight,
    index_IconBoxAlignBottomRightFilled as IconBoxAlignBottomRightFilled,
    index_IconBoxAlignLeft as IconBoxAlignLeft,
    index_IconBoxAlignLeftFilled as IconBoxAlignLeftFilled,
    index_IconBoxAlignRight as IconBoxAlignRight,
    index_IconBoxAlignRightFilled as IconBoxAlignRightFilled,
    index_IconBoxAlignTop as IconBoxAlignTop,
    index_IconBoxAlignTopFilled as IconBoxAlignTopFilled,
    index_IconBoxAlignTopLeft as IconBoxAlignTopLeft,
    index_IconBoxAlignTopLeftFilled as IconBoxAlignTopLeftFilled,
    index_IconBoxAlignTopRight as IconBoxAlignTopRight,
    index_IconBoxAlignTopRightFilled as IconBoxAlignTopRightFilled,
    index_IconBoxMargin as IconBoxMargin,
    index_IconBoxModel as IconBoxModel,
    index_IconBoxModel2 as IconBoxModel2,
    index_IconBoxModel2Off as IconBoxModel2Off,
    index_IconBoxModelOff as IconBoxModelOff,
    index_IconBoxMultiple as IconBoxMultiple,
    index_IconBoxMultiple0 as IconBoxMultiple0,
    index_IconBoxMultiple1 as IconBoxMultiple1,
    index_IconBoxMultiple2 as IconBoxMultiple2,
    index_IconBoxMultiple3 as IconBoxMultiple3,
    index_IconBoxMultiple4 as IconBoxMultiple4,
    index_IconBoxMultiple5 as IconBoxMultiple5,
    index_IconBoxMultiple6 as IconBoxMultiple6,
    index_IconBoxMultiple7 as IconBoxMultiple7,
    index_IconBoxMultiple8 as IconBoxMultiple8,
    index_IconBoxMultiple9 as IconBoxMultiple9,
    index_IconBoxMultipleFilled as IconBoxMultipleFilled,
    index_IconBoxOff as IconBoxOff,
    index_IconBoxPadding as IconBoxPadding,
    index_IconBraces as IconBraces,
    index_IconBracesOff as IconBracesOff,
    index_IconBrackets as IconBrackets,
    index_IconBracketsAngle as IconBracketsAngle,
    index_IconBracketsAngleOff as IconBracketsAngleOff,
    index_IconBracketsContain as IconBracketsContain,
    index_IconBracketsContainEnd as IconBracketsContainEnd,
    index_IconBracketsContainStart as IconBracketsContainStart,
    index_IconBracketsOff as IconBracketsOff,
    index_IconBraille as IconBraille,
    index_IconBrain as IconBrain,
    index_IconBrand4chan as IconBrand4chan,
    index_IconBrandAbstract as IconBrandAbstract,
    index_IconBrandAdobe as IconBrandAdobe,
    index_IconBrandAdobeAfterEffect as IconBrandAdobeAfterEffect,
    index_IconBrandAdobeIllustrator as IconBrandAdobeIllustrator,
    index_IconBrandAdobeIndesign as IconBrandAdobeIndesign,
    index_IconBrandAdobePhotoshop as IconBrandAdobePhotoshop,
    index_IconBrandAdobePremiere as IconBrandAdobePremiere,
    index_IconBrandAdobeXd as IconBrandAdobeXd,
    index_IconBrandAdonisJs as IconBrandAdonisJs,
    index_IconBrandAirbnb as IconBrandAirbnb,
    index_IconBrandAirtable as IconBrandAirtable,
    index_IconBrandAlgolia as IconBrandAlgolia,
    index_IconBrandAlipay as IconBrandAlipay,
    index_IconBrandAlpineJs as IconBrandAlpineJs,
    index_IconBrandAmazon as IconBrandAmazon,
    index_IconBrandAmd as IconBrandAmd,
    index_IconBrandAmie as IconBrandAmie,
    index_IconBrandAmigo as IconBrandAmigo,
    index_IconBrandAmongUs as IconBrandAmongUs,
    index_IconBrandAndroid as IconBrandAndroid,
    index_IconBrandAngular as IconBrandAngular,
    index_IconBrandAngularFilled as IconBrandAngularFilled,
    index_IconBrandAnsible as IconBrandAnsible,
    index_IconBrandAo3 as IconBrandAo3,
    index_IconBrandAppgallery as IconBrandAppgallery,
    index_IconBrandApple as IconBrandApple,
    index_IconBrandAppleArcade as IconBrandAppleArcade,
    index_IconBrandAppleFilled as IconBrandAppleFilled,
    index_IconBrandAppleNews as IconBrandAppleNews,
    index_IconBrandApplePodcast as IconBrandApplePodcast,
    index_IconBrandAppstore as IconBrandAppstore,
    index_IconBrandArc as IconBrandArc,
    index_IconBrandAsana as IconBrandAsana,
    index_IconBrandAstro as IconBrandAstro,
    index_IconBrandAuth0 as IconBrandAuth0,
    index_IconBrandAws as IconBrandAws,
    index_IconBrandAzure as IconBrandAzure,
    index_IconBrandBackbone as IconBrandBackbone,
    index_IconBrandBadoo as IconBrandBadoo,
    index_IconBrandBaidu as IconBrandBaidu,
    index_IconBrandBandcamp as IconBrandBandcamp,
    index_IconBrandBandlab as IconBrandBandlab,
    index_IconBrandBeats as IconBrandBeats,
    index_IconBrandBebo as IconBrandBebo,
    index_IconBrandBehance as IconBrandBehance,
    index_IconBrandBilibili as IconBrandBilibili,
    index_IconBrandBinance as IconBrandBinance,
    index_IconBrandBing as IconBrandBing,
    index_IconBrandBitbucket as IconBrandBitbucket,
    index_IconBrandBitbucketFilled as IconBrandBitbucketFilled,
    index_IconBrandBlackberry as IconBrandBlackberry,
    index_IconBrandBlender as IconBrandBlender,
    index_IconBrandBlogger as IconBrandBlogger,
    index_IconBrandBluesky as IconBrandBluesky,
    index_IconBrandBooking as IconBrandBooking,
    index_IconBrandBootstrap as IconBrandBootstrap,
    index_IconBrandBulma as IconBrandBulma,
    index_IconBrandBumble as IconBrandBumble,
    index_IconBrandBunpo as IconBrandBunpo,
    index_IconBrandCSharp as IconBrandCSharp,
    index_IconBrandCake as IconBrandCake,
    index_IconBrandCakephp as IconBrandCakephp,
    index_IconBrandCampaignmonitor as IconBrandCampaignmonitor,
    index_IconBrandCarbon as IconBrandCarbon,
    index_IconBrandCashapp as IconBrandCashapp,
    index_IconBrandChrome as IconBrandChrome,
    index_IconBrandCinema4d as IconBrandCinema4d,
    index_IconBrandCitymapper as IconBrandCitymapper,
    index_IconBrandCloudflare as IconBrandCloudflare,
    index_IconBrandCodecov as IconBrandCodecov,
    index_IconBrandCodepen as IconBrandCodepen,
    index_IconBrandCodesandbox as IconBrandCodesandbox,
    index_IconBrandCohost as IconBrandCohost,
    index_IconBrandCoinbase as IconBrandCoinbase,
    index_IconBrandComedyCentral as IconBrandComedyCentral,
    index_IconBrandCoreos as IconBrandCoreos,
    index_IconBrandCouchdb as IconBrandCouchdb,
    index_IconBrandCouchsurfing as IconBrandCouchsurfing,
    index_IconBrandCpp as IconBrandCpp,
    index_IconBrandCraft as IconBrandCraft,
    index_IconBrandCrunchbase as IconBrandCrunchbase,
    index_IconBrandCss3 as IconBrandCss3,
    index_IconBrandCtemplar as IconBrandCtemplar,
    index_IconBrandCucumber as IconBrandCucumber,
    index_IconBrandCupra as IconBrandCupra,
    index_IconBrandCypress as IconBrandCypress,
    index_IconBrandD3 as IconBrandD3,
    index_IconBrandDatabricks as IconBrandDatabricks,
    index_IconBrandDaysCounter as IconBrandDaysCounter,
    index_IconBrandDcos as IconBrandDcos,
    index_IconBrandDebian as IconBrandDebian,
    index_IconBrandDeezer as IconBrandDeezer,
    index_IconBrandDeliveroo as IconBrandDeliveroo,
    index_IconBrandDeno as IconBrandDeno,
    index_IconBrandDenodo as IconBrandDenodo,
    index_IconBrandDeviantart as IconBrandDeviantart,
    index_IconBrandDigg as IconBrandDigg,
    index_IconBrandDingtalk as IconBrandDingtalk,
    index_IconBrandDiscord as IconBrandDiscord,
    index_IconBrandDiscordFilled as IconBrandDiscordFilled,
    index_IconBrandDisney as IconBrandDisney,
    index_IconBrandDisqus as IconBrandDisqus,
    index_IconBrandDjango as IconBrandDjango,
    index_IconBrandDocker as IconBrandDocker,
    index_IconBrandDoctrine as IconBrandDoctrine,
    index_IconBrandDolbyDigital as IconBrandDolbyDigital,
    index_IconBrandDouban as IconBrandDouban,
    index_IconBrandDribbble as IconBrandDribbble,
    index_IconBrandDribbbleFilled as IconBrandDribbbleFilled,
    index_IconBrandDropbox as IconBrandDropbox,
    index_IconBrandDrops as IconBrandDrops,
    index_IconBrandDrupal as IconBrandDrupal,
    index_IconBrandEdge as IconBrandEdge,
    index_IconBrandElastic as IconBrandElastic,
    index_IconBrandElectronicArts as IconBrandElectronicArts,
    index_IconBrandEmber as IconBrandEmber,
    index_IconBrandEnvato as IconBrandEnvato,
    index_IconBrandEtsy as IconBrandEtsy,
    index_IconBrandEvernote as IconBrandEvernote,
    index_IconBrandFacebook as IconBrandFacebook,
    index_IconBrandFacebookFilled as IconBrandFacebookFilled,
    index_IconBrandFeedly as IconBrandFeedly,
    index_IconBrandFigma as IconBrandFigma,
    index_IconBrandFilezilla as IconBrandFilezilla,
    index_IconBrandFinder as IconBrandFinder,
    index_IconBrandFirebase as IconBrandFirebase,
    index_IconBrandFirefox as IconBrandFirefox,
    index_IconBrandFiverr as IconBrandFiverr,
    index_IconBrandFlickr as IconBrandFlickr,
    index_IconBrandFlightradar24 as IconBrandFlightradar24,
    index_IconBrandFlipboard as IconBrandFlipboard,
    index_IconBrandFlutter as IconBrandFlutter,
    index_IconBrandFortnite as IconBrandFortnite,
    index_IconBrandFoursquare as IconBrandFoursquare,
    index_IconBrandFramer as IconBrandFramer,
    index_IconBrandFramerMotion as IconBrandFramerMotion,
    index_IconBrandFunimation as IconBrandFunimation,
    index_IconBrandGatsby as IconBrandGatsby,
    index_IconBrandGit as IconBrandGit,
    index_IconBrandGithub as IconBrandGithub,
    index_IconBrandGithubCopilot as IconBrandGithubCopilot,
    index_IconBrandGithubFilled as IconBrandGithubFilled,
    index_IconBrandGitlab as IconBrandGitlab,
    index_IconBrandGmail as IconBrandGmail,
    index_IconBrandGolang as IconBrandGolang,
    index_IconBrandGoogle as IconBrandGoogle,
    index_IconBrandGoogleAnalytics as IconBrandGoogleAnalytics,
    index_IconBrandGoogleBigQuery as IconBrandGoogleBigQuery,
    index_IconBrandGoogleDrive as IconBrandGoogleDrive,
    index_IconBrandGoogleFilled as IconBrandGoogleFilled,
    index_IconBrandGoogleFit as IconBrandGoogleFit,
    index_IconBrandGoogleHome as IconBrandGoogleHome,
    index_IconBrandGoogleMaps as IconBrandGoogleMaps,
    index_IconBrandGoogleOne as IconBrandGoogleOne,
    index_IconBrandGooglePhotos as IconBrandGooglePhotos,
    index_IconBrandGooglePlay as IconBrandGooglePlay,
    index_IconBrandGooglePodcasts as IconBrandGooglePodcasts,
    index_IconBrandGrammarly as IconBrandGrammarly,
    index_IconBrandGraphql as IconBrandGraphql,
    index_IconBrandGravatar as IconBrandGravatar,
    index_IconBrandGrindr as IconBrandGrindr,
    index_IconBrandGuardian as IconBrandGuardian,
    index_IconBrandGumroad as IconBrandGumroad,
    index_IconBrandHackerrank as IconBrandHackerrank,
    index_IconBrandHbo as IconBrandHbo,
    index_IconBrandHeadlessui as IconBrandHeadlessui,
    index_IconBrandHexo as IconBrandHexo,
    index_IconBrandHipchat as IconBrandHipchat,
    index_IconBrandHtml5 as IconBrandHtml5,
    index_IconBrandInertia as IconBrandInertia,
    index_IconBrandInstagram as IconBrandInstagram,
    index_IconBrandInstagramFilled as IconBrandInstagramFilled,
    index_IconBrandIntercom as IconBrandIntercom,
    index_IconBrandItch as IconBrandItch,
    index_IconBrandJavascript as IconBrandJavascript,
    index_IconBrandJuejin as IconBrandJuejin,
    index_IconBrandKakoTalk as IconBrandKakoTalk,
    index_IconBrandKbin as IconBrandKbin,
    index_IconBrandKick as IconBrandKick,
    index_IconBrandKickFilled as IconBrandKickFilled,
    index_IconBrandKickstarter as IconBrandKickstarter,
    index_IconBrandKotlin as IconBrandKotlin,
    index_IconBrandLaravel as IconBrandLaravel,
    index_IconBrandLastfm as IconBrandLastfm,
    index_IconBrandLeetcode as IconBrandLeetcode,
    index_IconBrandLetterboxd as IconBrandLetterboxd,
    index_IconBrandLine as IconBrandLine,
    index_IconBrandLinkedin as IconBrandLinkedin,
    index_IconBrandLinkedinFilled as IconBrandLinkedinFilled,
    index_IconBrandLinktree as IconBrandLinktree,
    index_IconBrandLinqpad as IconBrandLinqpad,
    index_IconBrandLivewire as IconBrandLivewire,
    index_IconBrandLoom as IconBrandLoom,
    index_IconBrandMailgun as IconBrandMailgun,
    index_IconBrandMantine as IconBrandMantine,
    index_IconBrandMastercard as IconBrandMastercard,
    index_IconBrandMastodon as IconBrandMastodon,
    index_IconBrandMatrix as IconBrandMatrix,
    index_IconBrandMcdonalds as IconBrandMcdonalds,
    index_IconBrandMedium as IconBrandMedium,
    index_IconBrandMeetup as IconBrandMeetup,
    index_IconBrandMercedes as IconBrandMercedes,
    index_IconBrandMessenger as IconBrandMessenger,
    index_IconBrandMessengerFilled as IconBrandMessengerFilled,
    index_IconBrandMeta as IconBrandMeta,
    index_IconBrandMetabrainz as IconBrandMetabrainz,
    index_IconBrandMinecraft as IconBrandMinecraft,
    index_IconBrandMiniprogram as IconBrandMiniprogram,
    index_IconBrandMixpanel as IconBrandMixpanel,
    index_IconBrandMonday as IconBrandMonday,
    index_IconBrandMongodb as IconBrandMongodb,
    index_IconBrandMyOppo as IconBrandMyOppo,
    index_IconBrandMysql as IconBrandMysql,
    index_IconBrandNationalGeographic as IconBrandNationalGeographic,
    index_IconBrandNem as IconBrandNem,
    index_IconBrandNetbeans as IconBrandNetbeans,
    index_IconBrandNeteaseMusic as IconBrandNeteaseMusic,
    index_IconBrandNetflix as IconBrandNetflix,
    index_IconBrandNexo as IconBrandNexo,
    index_IconBrandNextcloud as IconBrandNextcloud,
    index_IconBrandNextjs as IconBrandNextjs,
    index_IconBrandNodejs as IconBrandNodejs,
    index_IconBrandNordVpn as IconBrandNordVpn,
    index_IconBrandNotion as IconBrandNotion,
    index_IconBrandNpm as IconBrandNpm,
    index_IconBrandNuxt as IconBrandNuxt,
    index_IconBrandNytimes as IconBrandNytimes,
    index_IconBrandOauth as IconBrandOauth,
    index_IconBrandOffice as IconBrandOffice,
    index_IconBrandOkRu as IconBrandOkRu,
    index_IconBrandOnedrive as IconBrandOnedrive,
    index_IconBrandOnlyfans as IconBrandOnlyfans,
    index_IconBrandOpenSource as IconBrandOpenSource,
    index_IconBrandOpenSourceFilled as IconBrandOpenSourceFilled,
    index_IconBrandOpenai as IconBrandOpenai,
    index_IconBrandOpenvpn as IconBrandOpenvpn,
    index_IconBrandOpera as IconBrandOpera,
    index_IconBrandOperaFilled as IconBrandOperaFilled,
    index_IconBrandPagekit as IconBrandPagekit,
    index_IconBrandParsinta as IconBrandParsinta,
    index_IconBrandPatreon as IconBrandPatreon,
    index_IconBrandPatreonFilled as IconBrandPatreonFilled,
    index_IconBrandPaypal as IconBrandPaypal,
    index_IconBrandPaypalFilled as IconBrandPaypalFilled,
    index_IconBrandPaypay as IconBrandPaypay,
    index_IconBrandPeanut as IconBrandPeanut,
    index_IconBrandPepsi as IconBrandPepsi,
    index_IconBrandPhp as IconBrandPhp,
    index_IconBrandPicsart as IconBrandPicsart,
    index_IconBrandPinterest as IconBrandPinterest,
    index_IconBrandPinterestFilled as IconBrandPinterestFilled,
    index_IconBrandPlanetscale as IconBrandPlanetscale,
    index_IconBrandPnpm as IconBrandPnpm,
    index_IconBrandPocket as IconBrandPocket,
    index_IconBrandPolymer as IconBrandPolymer,
    index_IconBrandPowershell as IconBrandPowershell,
    index_IconBrandPrintables as IconBrandPrintables,
    index_IconBrandPrisma as IconBrandPrisma,
    index_IconBrandProducthunt as IconBrandProducthunt,
    index_IconBrandPushbullet as IconBrandPushbullet,
    index_IconBrandPushover as IconBrandPushover,
    index_IconBrandPython as IconBrandPython,
    index_IconBrandQq as IconBrandQq,
    index_IconBrandRadixUi as IconBrandRadixUi,
    index_IconBrandReact as IconBrandReact,
    index_IconBrandReactNative as IconBrandReactNative,
    index_IconBrandReason as IconBrandReason,
    index_IconBrandReddit as IconBrandReddit,
    index_IconBrandRedhat as IconBrandRedhat,
    index_IconBrandRedux as IconBrandRedux,
    index_IconBrandRevolut as IconBrandRevolut,
    index_IconBrandRumble as IconBrandRumble,
    index_IconBrandRust as IconBrandRust,
    index_IconBrandSafari as IconBrandSafari,
    index_IconBrandSamsungpass as IconBrandSamsungpass,
    index_IconBrandSass as IconBrandSass,
    index_IconBrandSentry as IconBrandSentry,
    index_IconBrandSharik as IconBrandSharik,
    index_IconBrandShazam as IconBrandShazam,
    index_IconBrandShopee as IconBrandShopee,
    index_IconBrandSketch as IconBrandSketch,
    index_IconBrandSketchFilled as IconBrandSketchFilled,
    index_IconBrandSkype as IconBrandSkype,
    index_IconBrandSlack as IconBrandSlack,
    index_IconBrandSnapchat as IconBrandSnapchat,
    index_IconBrandSnapchatFilled as IconBrandSnapchatFilled,
    index_IconBrandSnapseed as IconBrandSnapseed,
    index_IconBrandSnowflake as IconBrandSnowflake,
    index_IconBrandSocketIo as IconBrandSocketIo,
    index_IconBrandSolidjs as IconBrandSolidjs,
    index_IconBrandSoundcloud as IconBrandSoundcloud,
    index_IconBrandSpacehey as IconBrandSpacehey,
    index_IconBrandSpeedtest as IconBrandSpeedtest,
    index_IconBrandSpotify as IconBrandSpotify,
    index_IconBrandSpotifyFilled as IconBrandSpotifyFilled,
    index_IconBrandStackoverflow as IconBrandStackoverflow,
    index_IconBrandStackshare as IconBrandStackshare,
    index_IconBrandSteam as IconBrandSteam,
    index_IconBrandSteamFilled as IconBrandSteamFilled,
    index_IconBrandStocktwits as IconBrandStocktwits,
    index_IconBrandStorj as IconBrandStorj,
    index_IconBrandStorybook as IconBrandStorybook,
    index_IconBrandStorytel as IconBrandStorytel,
    index_IconBrandStrava as IconBrandStrava,
    index_IconBrandStripe as IconBrandStripe,
    index_IconBrandStripeFilled as IconBrandStripeFilled,
    index_IconBrandSublimeText as IconBrandSublimeText,
    index_IconBrandSugarizer as IconBrandSugarizer,
    index_IconBrandSupabase as IconBrandSupabase,
    index_IconBrandSuperhuman as IconBrandSuperhuman,
    index_IconBrandSupernova as IconBrandSupernova,
    index_IconBrandSurfshark as IconBrandSurfshark,
    index_IconBrandSvelte as IconBrandSvelte,
    index_IconBrandSwift as IconBrandSwift,
    index_IconBrandSymfony as IconBrandSymfony,
    index_IconBrandTabler as IconBrandTabler,
    index_IconBrandTablerFilled as IconBrandTablerFilled,
    index_IconBrandTabnine as IconBrandTabnine,
    index_IconBrandTailwind as IconBrandTailwind,
    index_IconBrandTaobao as IconBrandTaobao,
    index_IconBrandTeams as IconBrandTeams,
    index_IconBrandTed as IconBrandTed,
    index_IconBrandTelegram as IconBrandTelegram,
    index_IconBrandTerraform as IconBrandTerraform,
    index_IconBrandTesla as IconBrandTesla,
    index_IconBrandTether as IconBrandTether,
    index_IconBrandThingiverse as IconBrandThingiverse,
    index_IconBrandThreads as IconBrandThreads,
    index_IconBrandThreejs as IconBrandThreejs,
    index_IconBrandTidal as IconBrandTidal,
    index_IconBrandTiktok as IconBrandTiktok,
    index_IconBrandTiktokFilled as IconBrandTiktokFilled,
    index_IconBrandTinder as IconBrandTinder,
    index_IconBrandTinderFilled as IconBrandTinderFilled,
    index_IconBrandTopbuzz as IconBrandTopbuzz,
    index_IconBrandTorchain as IconBrandTorchain,
    index_IconBrandToyota as IconBrandToyota,
    index_IconBrandTrello as IconBrandTrello,
    index_IconBrandTripadvisor as IconBrandTripadvisor,
    index_IconBrandTumblr as IconBrandTumblr,
    index_IconBrandTumblrFilled as IconBrandTumblrFilled,
    index_IconBrandTwilio as IconBrandTwilio,
    index_IconBrandTwitch as IconBrandTwitch,
    index_IconBrandTwitter as IconBrandTwitter,
    index_IconBrandTwitterFilled as IconBrandTwitterFilled,
    index_IconBrandTypescript as IconBrandTypescript,
    index_IconBrandUber as IconBrandUber,
    index_IconBrandUbuntu as IconBrandUbuntu,
    index_IconBrandUnity as IconBrandUnity,
    index_IconBrandUnsplash as IconBrandUnsplash,
    index_IconBrandUpwork as IconBrandUpwork,
    index_IconBrandValorant as IconBrandValorant,
    index_IconBrandVercel as IconBrandVercel,
    index_IconBrandVercelFilled as IconBrandVercelFilled,
    index_IconBrandVimeo as IconBrandVimeo,
    index_IconBrandVimeoFilled as IconBrandVimeoFilled,
    index_IconBrandVinted as IconBrandVinted,
    index_IconBrandVisa as IconBrandVisa,
    index_IconBrandVisualStudio as IconBrandVisualStudio,
    index_IconBrandVite as IconBrandVite,
    index_IconBrandVivaldi as IconBrandVivaldi,
    index_IconBrandVk as IconBrandVk,
    index_IconBrandVlc as IconBrandVlc,
    index_IconBrandVolkswagen as IconBrandVolkswagen,
    index_IconBrandVsco as IconBrandVsco,
    index_IconBrandVscode as IconBrandVscode,
    index_IconBrandVue as IconBrandVue,
    index_IconBrandWalmart as IconBrandWalmart,
    index_IconBrandWaze as IconBrandWaze,
    index_IconBrandWebflow as IconBrandWebflow,
    index_IconBrandWechat as IconBrandWechat,
    index_IconBrandWeibo as IconBrandWeibo,
    index_IconBrandWeiboFilled as IconBrandWeiboFilled,
    index_IconBrandWhatsapp as IconBrandWhatsapp,
    index_IconBrandWhatsappFilled as IconBrandWhatsappFilled,
    index_IconBrandWikipedia as IconBrandWikipedia,
    index_IconBrandWindows as IconBrandWindows,
    index_IconBrandWindowsFilled as IconBrandWindowsFilled,
    index_IconBrandWindy as IconBrandWindy,
    index_IconBrandWish as IconBrandWish,
    index_IconBrandWix as IconBrandWix,
    index_IconBrandWordpress as IconBrandWordpress,
    index_IconBrandX as IconBrandX,
    index_IconBrandXFilled as IconBrandXFilled,
    index_IconBrandXamarin as IconBrandXamarin,
    index_IconBrandXbox as IconBrandXbox,
    index_IconBrandXdeep as IconBrandXdeep,
    index_IconBrandXing as IconBrandXing,
    index_IconBrandYahoo as IconBrandYahoo,
    index_IconBrandYandex as IconBrandYandex,
    index_IconBrandYarn as IconBrandYarn,
    index_IconBrandYatse as IconBrandYatse,
    index_IconBrandYcombinator as IconBrandYcombinator,
    index_IconBrandYoutube as IconBrandYoutube,
    index_IconBrandYoutubeFilled as IconBrandYoutubeFilled,
    index_IconBrandYoutubeKids as IconBrandYoutubeKids,
    index_IconBrandZalando as IconBrandZalando,
    index_IconBrandZapier as IconBrandZapier,
    index_IconBrandZeit as IconBrandZeit,
    index_IconBrandZhihu as IconBrandZhihu,
    index_IconBrandZoom as IconBrandZoom,
    index_IconBrandZulip as IconBrandZulip,
    index_IconBrandZwift as IconBrandZwift,
    index_IconBread as IconBread,
    index_IconBreadFilled as IconBreadFilled,
    index_IconBreadOff as IconBreadOff,
    index_IconBriefcase as IconBriefcase,
    index_IconBriefcase2 as IconBriefcase2,
    index_IconBriefcase2Filled as IconBriefcase2Filled,
    index_IconBriefcaseFilled as IconBriefcaseFilled,
    index_IconBriefcaseOff as IconBriefcaseOff,
    index_IconBrightness as IconBrightness,
    index_IconBrightness2 as IconBrightness2,
    index_IconBrightnessAuto as IconBrightnessAuto,
    index_IconBrightnessAutoFilled as IconBrightnessAutoFilled,
    index_IconBrightnessDown as IconBrightnessDown,
    index_IconBrightnessDownFilled as IconBrightnessDownFilled,
    index_IconBrightnessFilled as IconBrightnessFilled,
    index_IconBrightnessHalf as IconBrightnessHalf,
    index_IconBrightnessOff as IconBrightnessOff,
    index_IconBrightnessUp as IconBrightnessUp,
    index_IconBrightnessUpFilled as IconBrightnessUpFilled,
    index_IconBroadcast as IconBroadcast,
    index_IconBroadcastOff as IconBroadcastOff,
    index_IconBrowser as IconBrowser,
    index_IconBrowserCheck as IconBrowserCheck,
    index_IconBrowserMaximize as IconBrowserMaximize,
    index_IconBrowserMinus as IconBrowserMinus,
    index_IconBrowserOff as IconBrowserOff,
    index_IconBrowserPlus as IconBrowserPlus,
    index_IconBrowserShare as IconBrowserShare,
    index_IconBrowserX as IconBrowserX,
    index_IconBrush as IconBrush,
    index_IconBrushOff as IconBrushOff,
    index_IconBubble as IconBubble,
    index_IconBubbleFilled as IconBubbleFilled,
    index_IconBubbleMinus as IconBubbleMinus,
    index_IconBubblePlus as IconBubblePlus,
    index_IconBubbleTea as IconBubbleTea,
    index_IconBubbleTea2 as IconBubbleTea2,
    index_IconBubbleText as IconBubbleText,
    index_IconBubbleTextFilled as IconBubbleTextFilled,
    index_IconBubbleX as IconBubbleX,
    index_IconBucket as IconBucket,
    index_IconBucketDroplet as IconBucketDroplet,
    index_IconBucketOff as IconBucketOff,
    index_IconBug as IconBug,
    index_IconBugFilled as IconBugFilled,
    index_IconBugOff as IconBugOff,
    index_IconBuilding as IconBuilding,
    index_IconBuildingAirport as IconBuildingAirport,
    index_IconBuildingArch as IconBuildingArch,
    index_IconBuildingBank as IconBuildingBank,
    index_IconBuildingBridge as IconBuildingBridge,
    index_IconBuildingBridge2 as IconBuildingBridge2,
    index_IconBuildingBridge2Filled as IconBuildingBridge2Filled,
    index_IconBuildingBroadcastTower as IconBuildingBroadcastTower,
    index_IconBuildingBroadcastTowerFilled as IconBuildingBroadcastTowerFilled,
    index_IconBuildingBurjAlArab as IconBuildingBurjAlArab,
    index_IconBuildingCarousel as IconBuildingCarousel,
    index_IconBuildingCastle as IconBuildingCastle,
    index_IconBuildingChurch as IconBuildingChurch,
    index_IconBuildingCircus as IconBuildingCircus,
    index_IconBuildingCog as IconBuildingCog,
    index_IconBuildingCommunity as IconBuildingCommunity,
    index_IconBuildingCottage as IconBuildingCottage,
    index_IconBuildingEstate as IconBuildingEstate,
    index_IconBuildingFactory as IconBuildingFactory,
    index_IconBuildingFactory2 as IconBuildingFactory2,
    index_IconBuildingFortress as IconBuildingFortress,
    index_IconBuildingHospital as IconBuildingHospital,
    index_IconBuildingLighthouse as IconBuildingLighthouse,
    index_IconBuildingMinus as IconBuildingMinus,
    index_IconBuildingMonument as IconBuildingMonument,
    index_IconBuildingMosque as IconBuildingMosque,
    index_IconBuildingOff as IconBuildingOff,
    index_IconBuildingPavilion as IconBuildingPavilion,
    index_IconBuildingPlus as IconBuildingPlus,
    index_IconBuildingSkyscraper as IconBuildingSkyscraper,
    index_IconBuildingStadium as IconBuildingStadium,
    index_IconBuildingStore as IconBuildingStore,
    index_IconBuildingTunnel as IconBuildingTunnel,
    index_IconBuildingWarehouse as IconBuildingWarehouse,
    index_IconBuildingWindTurbine as IconBuildingWindTurbine,
    index_IconBuildings as IconBuildings,
    index_IconBulb as IconBulb,
    index_IconBulbFilled as IconBulbFilled,
    index_IconBulbOff as IconBulbOff,
    index_IconBulldozer as IconBulldozer,
    index_IconBurger as IconBurger,
    index_IconBus as IconBus,
    index_IconBusFilled as IconBusFilled,
    index_IconBusOff as IconBusOff,
    index_IconBusStop as IconBusStop,
    index_IconBusinessplan as IconBusinessplan,
    index_IconButterfly as IconButterfly,
    index_IconButterflyFilled as IconButterflyFilled,
    index_IconCactus as IconCactus,
    index_IconCactusFilled as IconCactusFilled,
    index_IconCactusOff as IconCactusOff,
    index_IconCake as IconCake,
    index_IconCakeOff as IconCakeOff,
    index_IconCakeRoll as IconCakeRoll,
    index_IconCalculator as IconCalculator,
    index_IconCalculatorFilled as IconCalculatorFilled,
    index_IconCalculatorOff as IconCalculatorOff,
    index_IconCalendar as IconCalendar,
    index_IconCalendarBolt as IconCalendarBolt,
    index_IconCalendarCancel as IconCalendarCancel,
    index_IconCalendarCheck as IconCalendarCheck,
    index_IconCalendarClock as IconCalendarClock,
    index_IconCalendarCode as IconCalendarCode,
    index_IconCalendarCog as IconCalendarCog,
    index_IconCalendarDollar as IconCalendarDollar,
    index_IconCalendarDot as IconCalendarDot,
    index_IconCalendarDown as IconCalendarDown,
    index_IconCalendarDue as IconCalendarDue,
    index_IconCalendarEvent as IconCalendarEvent,
    index_IconCalendarEventFilled as IconCalendarEventFilled,
    index_IconCalendarExclamation as IconCalendarExclamation,
    index_IconCalendarFilled as IconCalendarFilled,
    index_IconCalendarHeart as IconCalendarHeart,
    index_IconCalendarMinus as IconCalendarMinus,
    index_IconCalendarMonth as IconCalendarMonth,
    index_IconCalendarMonthFilled as IconCalendarMonthFilled,
    index_IconCalendarOff as IconCalendarOff,
    index_IconCalendarPause as IconCalendarPause,
    index_IconCalendarPin as IconCalendarPin,
    index_IconCalendarPlus as IconCalendarPlus,
    index_IconCalendarQuestion as IconCalendarQuestion,
    index_IconCalendarRepeat as IconCalendarRepeat,
    index_IconCalendarSad as IconCalendarSad,
    index_IconCalendarSearch as IconCalendarSearch,
    index_IconCalendarShare as IconCalendarShare,
    index_IconCalendarSmile as IconCalendarSmile,
    index_IconCalendarStar as IconCalendarStar,
    index_IconCalendarStats as IconCalendarStats,
    index_IconCalendarTime as IconCalendarTime,
    index_IconCalendarUp as IconCalendarUp,
    index_IconCalendarUser as IconCalendarUser,
    index_IconCalendarWeek as IconCalendarWeek,
    index_IconCalendarWeekFilled as IconCalendarWeekFilled,
    index_IconCalendarX as IconCalendarX,
    index_IconCamera as IconCamera,
    index_IconCameraAi as IconCameraAi,
    index_IconCameraBitcoin as IconCameraBitcoin,
    index_IconCameraBolt as IconCameraBolt,
    index_IconCameraCancel as IconCameraCancel,
    index_IconCameraCheck as IconCameraCheck,
    index_IconCameraCode as IconCameraCode,
    index_IconCameraCog as IconCameraCog,
    index_IconCameraDollar as IconCameraDollar,
    index_IconCameraDown as IconCameraDown,
    index_IconCameraExclamation as IconCameraExclamation,
    index_IconCameraFilled as IconCameraFilled,
    index_IconCameraHeart as IconCameraHeart,
    index_IconCameraMinus as IconCameraMinus,
    index_IconCameraMoon as IconCameraMoon,
    index_IconCameraOff as IconCameraOff,
    index_IconCameraPause as IconCameraPause,
    index_IconCameraPin as IconCameraPin,
    index_IconCameraPlus as IconCameraPlus,
    index_IconCameraQuestion as IconCameraQuestion,
    index_IconCameraRotate as IconCameraRotate,
    index_IconCameraSearch as IconCameraSearch,
    index_IconCameraSelfie as IconCameraSelfie,
    index_IconCameraShare as IconCameraShare,
    index_IconCameraSpark as IconCameraSpark,
    index_IconCameraStar as IconCameraStar,
    index_IconCameraUp as IconCameraUp,
    index_IconCameraX as IconCameraX,
    index_IconCamper as IconCamper,
    index_IconCampfire as IconCampfire,
    index_IconCampfireFilled as IconCampfireFilled,
    index_IconCancel as IconCancel,
    index_IconCandle as IconCandle,
    index_IconCandleFilled as IconCandleFilled,
    index_IconCandy as IconCandy,
    index_IconCandyOff as IconCandyOff,
    index_IconCane as IconCane,
    index_IconCannabis as IconCannabis,
    index_IconCannabisFilled as IconCannabisFilled,
    index_IconCapProjecting as IconCapProjecting,
    index_IconCapRounded as IconCapRounded,
    index_IconCapStraight as IconCapStraight,
    index_IconCapsule as IconCapsule,
    index_IconCapsuleFilled as IconCapsuleFilled,
    index_IconCapsuleHorizontal as IconCapsuleHorizontal,
    index_IconCapsuleHorizontalFilled as IconCapsuleHorizontalFilled,
    index_IconCapture as IconCapture,
    index_IconCaptureFilled as IconCaptureFilled,
    index_IconCaptureOff as IconCaptureOff,
    index_IconCar as IconCar,
    index_IconCar4wd as IconCar4wd,
    index_IconCar4wdFilled as IconCar4wdFilled,
    index_IconCarCrane as IconCarCrane,
    index_IconCarCraneFilled as IconCarCraneFilled,
    index_IconCarCrash as IconCarCrash,
    index_IconCarFan as IconCarFan,
    index_IconCarFan1 as IconCarFan1,
    index_IconCarFan2 as IconCarFan2,
    index_IconCarFan3 as IconCarFan3,
    index_IconCarFanAuto as IconCarFanAuto,
    index_IconCarFanFilled as IconCarFanFilled,
    index_IconCarFilled as IconCarFilled,
    index_IconCarGarage as IconCarGarage,
    index_IconCarOff as IconCarOff,
    index_IconCarSuv as IconCarSuv,
    index_IconCarSuvFilled as IconCarSuvFilled,
    index_IconCarTurbine as IconCarTurbine,
    index_IconCarambola as IconCarambola,
    index_IconCarambolaFilled as IconCarambolaFilled,
    index_IconCaravan as IconCaravan,
    index_IconCaravanFilled as IconCaravanFilled,
    index_IconCardboards as IconCardboards,
    index_IconCardboardsFilled as IconCardboardsFilled,
    index_IconCardboardsOff as IconCardboardsOff,
    index_IconCards as IconCards,
    index_IconCardsFilled as IconCardsFilled,
    index_IconCaretDown as IconCaretDown,
    index_IconCaretDownFilled as IconCaretDownFilled,
    index_IconCaretLeft as IconCaretLeft,
    index_IconCaretLeftFilled as IconCaretLeftFilled,
    index_IconCaretLeftRight as IconCaretLeftRight,
    index_IconCaretLeftRightFilled as IconCaretLeftRightFilled,
    index_IconCaretRight as IconCaretRight,
    index_IconCaretRightFilled as IconCaretRightFilled,
    index_IconCaretUp as IconCaretUp,
    index_IconCaretUpDown as IconCaretUpDown,
    index_IconCaretUpDownFilled as IconCaretUpDownFilled,
    index_IconCaretUpFilled as IconCaretUpFilled,
    index_IconCarouselHorizontal as IconCarouselHorizontal,
    index_IconCarouselHorizontalFilled as IconCarouselHorizontalFilled,
    index_IconCarouselVertical as IconCarouselVertical,
    index_IconCarouselVerticalFilled as IconCarouselVerticalFilled,
    index_IconCarrot as IconCarrot,
    index_IconCarrotOff as IconCarrotOff,
    index_IconCash as IconCash,
    index_IconCashBanknote as IconCashBanknote,
    index_IconCashBanknoteEdit as IconCashBanknoteEdit,
    index_IconCashBanknoteFilled as IconCashBanknoteFilled,
    index_IconCashBanknoteHeart as IconCashBanknoteHeart,
    index_IconCashBanknoteMinus as IconCashBanknoteMinus,
    index_IconCashBanknoteMove as IconCashBanknoteMove,
    index_IconCashBanknoteMoveBack as IconCashBanknoteMoveBack,
    index_IconCashBanknoteOff as IconCashBanknoteOff,
    index_IconCashBanknotePlus as IconCashBanknotePlus,
    index_IconCashEdit as IconCashEdit,
    index_IconCashHeart as IconCashHeart,
    index_IconCashMinus as IconCashMinus,
    index_IconCashMove as IconCashMove,
    index_IconCashMoveBack as IconCashMoveBack,
    index_IconCashOff as IconCashOff,
    index_IconCashPlus as IconCashPlus,
    index_IconCashRegister as IconCashRegister,
    index_IconCast as IconCast,
    index_IconCastOff as IconCastOff,
    index_IconCat as IconCat,
    index_IconCategory as IconCategory,
    index_IconCategory2 as IconCategory2,
    index_IconCategoryFilled as IconCategoryFilled,
    index_IconCategoryMinus as IconCategoryMinus,
    index_IconCategoryPlus as IconCategoryPlus,
    index_IconCe as IconCe,
    index_IconCeOff as IconCeOff,
    index_IconCell as IconCell,
    index_IconCellSignal1 as IconCellSignal1,
    index_IconCellSignal2 as IconCellSignal2,
    index_IconCellSignal3 as IconCellSignal3,
    index_IconCellSignal4 as IconCellSignal4,
    index_IconCellSignal5 as IconCellSignal5,
    index_IconCellSignalOff as IconCellSignalOff,
    index_IconCertificate as IconCertificate,
    index_IconCertificate2 as IconCertificate2,
    index_IconCertificate2Off as IconCertificate2Off,
    index_IconCertificateOff as IconCertificateOff,
    index_IconChairDirector as IconChairDirector,
    index_IconChalkboard as IconChalkboard,
    index_IconChalkboardOff as IconChalkboardOff,
    index_IconChalkboardTeacher as IconChalkboardTeacher,
    index_IconChargingPile as IconChargingPile,
    index_IconChargingPileFilled as IconChargingPileFilled,
    index_IconChartArcs as IconChartArcs,
    index_IconChartArcs3 as IconChartArcs3,
    index_IconChartArea as IconChartArea,
    index_IconChartAreaFilled as IconChartAreaFilled,
    index_IconChartAreaLine as IconChartAreaLine,
    index_IconChartAreaLineFilled as IconChartAreaLineFilled,
    index_IconChartArrows as IconChartArrows,
    index_IconChartArrowsVertical as IconChartArrowsVertical,
    index_IconChartBar as IconChartBar,
    index_IconChartBarOff as IconChartBarOff,
    index_IconChartBarPopular as IconChartBarPopular,
    index_IconChartBubble as IconChartBubble,
    index_IconChartBubbleFilled as IconChartBubbleFilled,
    index_IconChartCandle as IconChartCandle,
    index_IconChartCandleFilled as IconChartCandleFilled,
    index_IconChartCircles as IconChartCircles,
    index_IconChartCohort as IconChartCohort,
    index_IconChartColumn as IconChartColumn,
    index_IconChartCovariate as IconChartCovariate,
    index_IconChartDonut as IconChartDonut,
    index_IconChartDonut2 as IconChartDonut2,
    index_IconChartDonut3 as IconChartDonut3,
    index_IconChartDonut4 as IconChartDonut4,
    index_IconChartDonutFilled as IconChartDonutFilled,
    index_IconChartDots as IconChartDots,
    index_IconChartDots2 as IconChartDots2,
    index_IconChartDots2Filled as IconChartDots2Filled,
    index_IconChartDots3 as IconChartDots3,
    index_IconChartDots3Filled as IconChartDots3Filled,
    index_IconChartDotsFilled as IconChartDotsFilled,
    index_IconChartFunnel as IconChartFunnel,
    index_IconChartFunnelFilled as IconChartFunnelFilled,
    index_IconChartGridDots as IconChartGridDots,
    index_IconChartGridDotsFilled as IconChartGridDotsFilled,
    index_IconChartHistogram as IconChartHistogram,
    index_IconChartInfographic as IconChartInfographic,
    index_IconChartLine as IconChartLine,
    index_IconChartPie as IconChartPie,
    index_IconChartPie2 as IconChartPie2,
    index_IconChartPie2Filled as IconChartPie2Filled,
    index_IconChartPie3 as IconChartPie3,
    index_IconChartPie3Filled as IconChartPie3Filled,
    index_IconChartPie4 as IconChartPie4,
    index_IconChartPie4Filled as IconChartPie4Filled,
    index_IconChartPieFilled as IconChartPieFilled,
    index_IconChartPieOff as IconChartPieOff,
    index_IconChartPpf as IconChartPpf,
    index_IconChartRadar as IconChartRadar,
    index_IconChartSankey as IconChartSankey,
    index_IconChartScatter as IconChartScatter,
    index_IconChartScatter3d as IconChartScatter3d,
    index_IconChartTreemap as IconChartTreemap,
    index_IconCheck as IconCheck,
    index_IconCheckbox as IconCheckbox,
    index_IconChecklist as IconChecklist,
    index_IconChecks as IconChecks,
    index_IconCheckupList as IconCheckupList,
    index_IconCheese as IconCheese,
    index_IconChefHat as IconChefHat,
    index_IconChefHatFilled as IconChefHatFilled,
    index_IconChefHatOff as IconChefHatOff,
    index_IconCherry as IconCherry,
    index_IconCherryFilled as IconCherryFilled,
    index_IconChess as IconChess,
    index_IconChessBishop as IconChessBishop,
    index_IconChessBishopFilled as IconChessBishopFilled,
    index_IconChessFilled as IconChessFilled,
    index_IconChessKing as IconChessKing,
    index_IconChessKingFilled as IconChessKingFilled,
    index_IconChessKnight as IconChessKnight,
    index_IconChessKnightFilled as IconChessKnightFilled,
    index_IconChessQueen as IconChessQueen,
    index_IconChessQueenFilled as IconChessQueenFilled,
    index_IconChessRook as IconChessRook,
    index_IconChessRookFilled as IconChessRookFilled,
    index_IconChevronCompactDown as IconChevronCompactDown,
    index_IconChevronCompactLeft as IconChevronCompactLeft,
    index_IconChevronCompactRight as IconChevronCompactRight,
    index_IconChevronCompactUp as IconChevronCompactUp,
    index_IconChevronDown as IconChevronDown,
    index_IconChevronDownLeft as IconChevronDownLeft,
    index_IconChevronDownRight as IconChevronDownRight,
    index_IconChevronLeft as IconChevronLeft,
    index_IconChevronLeftPipe as IconChevronLeftPipe,
    index_IconChevronRight as IconChevronRight,
    index_IconChevronRightPipe as IconChevronRightPipe,
    index_IconChevronUp as IconChevronUp,
    index_IconChevronUpLeft as IconChevronUpLeft,
    index_IconChevronUpRight as IconChevronUpRight,
    index_IconChevronsDown as IconChevronsDown,
    index_IconChevronsDownLeft as IconChevronsDownLeft,
    index_IconChevronsDownRight as IconChevronsDownRight,
    index_IconChevronsLeft as IconChevronsLeft,
    index_IconChevronsRight as IconChevronsRight,
    index_IconChevronsUp as IconChevronsUp,
    index_IconChevronsUpLeft as IconChevronsUpLeft,
    index_IconChevronsUpRight as IconChevronsUpRight,
    index_IconChisel as IconChisel,
    index_IconChristmasBall as IconChristmasBall,
    index_IconChristmasTree as IconChristmasTree,
    index_IconChristmasTreeFilled as IconChristmasTreeFilled,
    index_IconChristmasTreeOff as IconChristmasTreeOff,
    index_IconCircle as IconCircle,
    index_IconCircleArrowDown as IconCircleArrowDown,
    index_IconCircleArrowDownFilled as IconCircleArrowDownFilled,
    index_IconCircleArrowDownLeft as IconCircleArrowDownLeft,
    index_IconCircleArrowDownLeftFilled as IconCircleArrowDownLeftFilled,
    index_IconCircleArrowDownRight as IconCircleArrowDownRight,
    index_IconCircleArrowDownRightFilled as IconCircleArrowDownRightFilled,
    index_IconCircleArrowLeft as IconCircleArrowLeft,
    index_IconCircleArrowLeftFilled as IconCircleArrowLeftFilled,
    index_IconCircleArrowRight as IconCircleArrowRight,
    index_IconCircleArrowRightFilled as IconCircleArrowRightFilled,
    index_IconCircleArrowUp as IconCircleArrowUp,
    index_IconCircleArrowUpFilled as IconCircleArrowUpFilled,
    index_IconCircleArrowUpLeft as IconCircleArrowUpLeft,
    index_IconCircleArrowUpLeftFilled as IconCircleArrowUpLeftFilled,
    index_IconCircleArrowUpRight as IconCircleArrowUpRight,
    index_IconCircleArrowUpRightFilled as IconCircleArrowUpRightFilled,
    index_IconCircleAsterisk as IconCircleAsterisk,
    index_IconCircleCaretDown as IconCircleCaretDown,
    index_IconCircleCaretDownFilled as IconCircleCaretDownFilled,
    index_IconCircleCaretLeft as IconCircleCaretLeft,
    index_IconCircleCaretLeftFilled as IconCircleCaretLeftFilled,
    index_IconCircleCaretRight as IconCircleCaretRight,
    index_IconCircleCaretRightFilled as IconCircleCaretRightFilled,
    index_IconCircleCaretUp as IconCircleCaretUp,
    index_IconCircleCaretUpFilled as IconCircleCaretUpFilled,
    index_IconCircleCheck as IconCircleCheck,
    index_IconCircleCheckFilled as IconCircleCheckFilled,
    index_IconCircleChevronDown as IconCircleChevronDown,
    index_IconCircleChevronDownFilled as IconCircleChevronDownFilled,
    index_IconCircleChevronLeft as IconCircleChevronLeft,
    index_IconCircleChevronLeftFilled as IconCircleChevronLeftFilled,
    index_IconCircleChevronRight as IconCircleChevronRight,
    index_IconCircleChevronRightFilled as IconCircleChevronRightFilled,
    index_IconCircleChevronUp as IconCircleChevronUp,
    index_IconCircleChevronUpFilled as IconCircleChevronUpFilled,
    index_IconCircleChevronsDown as IconCircleChevronsDown,
    index_IconCircleChevronsDownFilled as IconCircleChevronsDownFilled,
    index_IconCircleChevronsLeft as IconCircleChevronsLeft,
    index_IconCircleChevronsLeftFilled as IconCircleChevronsLeftFilled,
    index_IconCircleChevronsRight as IconCircleChevronsRight,
    index_IconCircleChevronsRightFilled as IconCircleChevronsRightFilled,
    index_IconCircleChevronsUp as IconCircleChevronsUp,
    index_IconCircleChevronsUpFilled as IconCircleChevronsUpFilled,
    index_IconCircleDashed as IconCircleDashed,
    index_IconCircleDashedCheck as IconCircleDashedCheck,
    index_IconCircleDashedLetterA as IconCircleDashedLetterA,
    index_IconCircleDashedLetterB as IconCircleDashedLetterB,
    index_IconCircleDashedLetterC as IconCircleDashedLetterC,
    index_IconCircleDashedLetterD as IconCircleDashedLetterD,
    index_IconCircleDashedLetterE as IconCircleDashedLetterE,
    index_IconCircleDashedLetterF as IconCircleDashedLetterF,
    index_IconCircleDashedLetterG as IconCircleDashedLetterG,
    index_IconCircleDashedLetterH as IconCircleDashedLetterH,
    index_IconCircleDashedLetterI as IconCircleDashedLetterI,
    index_IconCircleDashedLetterJ as IconCircleDashedLetterJ,
    index_IconCircleDashedLetterK as IconCircleDashedLetterK,
    index_IconCircleDashedLetterL as IconCircleDashedLetterL,
    index_IconCircleDashedLetterM as IconCircleDashedLetterM,
    index_IconCircleDashedLetterN as IconCircleDashedLetterN,
    index_IconCircleDashedLetterO as IconCircleDashedLetterO,
    index_IconCircleDashedLetterP as IconCircleDashedLetterP,
    index_IconCircleDashedLetterQ as IconCircleDashedLetterQ,
    index_IconCircleDashedLetterR as IconCircleDashedLetterR,
    index_IconCircleDashedLetterS as IconCircleDashedLetterS,
    index_IconCircleDashedLetterT as IconCircleDashedLetterT,
    index_IconCircleDashedLetterU as IconCircleDashedLetterU,
    index_IconCircleDashedLetterV as IconCircleDashedLetterV,
    index_IconCircleDashedLetterW as IconCircleDashedLetterW,
    index_IconCircleDashedLetterX as IconCircleDashedLetterX,
    index_IconCircleDashedLetterY as IconCircleDashedLetterY,
    index_IconCircleDashedLetterZ as IconCircleDashedLetterZ,
    index_IconCircleDashedMinus as IconCircleDashedMinus,
    index_IconCircleDashedNumber0 as IconCircleDashedNumber0,
    index_IconCircleDashedNumber1 as IconCircleDashedNumber1,
    index_IconCircleDashedNumber2 as IconCircleDashedNumber2,
    index_IconCircleDashedNumber3 as IconCircleDashedNumber3,
    index_IconCircleDashedNumber4 as IconCircleDashedNumber4,
    index_IconCircleDashedNumber5 as IconCircleDashedNumber5,
    index_IconCircleDashedNumber6 as IconCircleDashedNumber6,
    index_IconCircleDashedNumber7 as IconCircleDashedNumber7,
    index_IconCircleDashedNumber8 as IconCircleDashedNumber8,
    index_IconCircleDashedNumber9 as IconCircleDashedNumber9,
    index_IconCircleDashedPercentage as IconCircleDashedPercentage,
    index_IconCircleDashedPlus as IconCircleDashedPlus,
    index_IconCircleDashedX as IconCircleDashedX,
    index_IconCircleDot as IconCircleDot,
    index_IconCircleDotFilled as IconCircleDotFilled,
    index_IconCircleDotted as IconCircleDotted,
    index_IconCircleDottedLetterA as IconCircleDottedLetterA,
    index_IconCircleDottedLetterB as IconCircleDottedLetterB,
    index_IconCircleDottedLetterC as IconCircleDottedLetterC,
    index_IconCircleDottedLetterD as IconCircleDottedLetterD,
    index_IconCircleDottedLetterE as IconCircleDottedLetterE,
    index_IconCircleDottedLetterF as IconCircleDottedLetterF,
    index_IconCircleDottedLetterG as IconCircleDottedLetterG,
    index_IconCircleDottedLetterH as IconCircleDottedLetterH,
    index_IconCircleDottedLetterI as IconCircleDottedLetterI,
    index_IconCircleDottedLetterJ as IconCircleDottedLetterJ,
    index_IconCircleDottedLetterK as IconCircleDottedLetterK,
    index_IconCircleDottedLetterL as IconCircleDottedLetterL,
    index_IconCircleDottedLetterM as IconCircleDottedLetterM,
    index_IconCircleDottedLetterN as IconCircleDottedLetterN,
    index_IconCircleDottedLetterO as IconCircleDottedLetterO,
    index_IconCircleDottedLetterP as IconCircleDottedLetterP,
    index_IconCircleDottedLetterQ as IconCircleDottedLetterQ,
    index_IconCircleDottedLetterR as IconCircleDottedLetterR,
    index_IconCircleDottedLetterS as IconCircleDottedLetterS,
    index_IconCircleDottedLetterT as IconCircleDottedLetterT,
    index_IconCircleDottedLetterU as IconCircleDottedLetterU,
    index_IconCircleDottedLetterV as IconCircleDottedLetterV,
    index_IconCircleDottedLetterW as IconCircleDottedLetterW,
    index_IconCircleDottedLetterX as IconCircleDottedLetterX,
    index_IconCircleDottedLetterY as IconCircleDottedLetterY,
    index_IconCircleDottedLetterZ as IconCircleDottedLetterZ,
    index_IconCircleFilled as IconCircleFilled,
    index_IconCircleHalf as IconCircleHalf,
    index_IconCircleHalf2 as IconCircleHalf2,
    index_IconCircleHalfVertical as IconCircleHalfVertical,
    index_IconCircleKey as IconCircleKey,
    index_IconCircleKeyFilled as IconCircleKeyFilled,
    index_IconCircleLetterA as IconCircleLetterA,
    index_IconCircleLetterAFilled as IconCircleLetterAFilled,
    index_IconCircleLetterB as IconCircleLetterB,
    index_IconCircleLetterBFilled as IconCircleLetterBFilled,
    index_IconCircleLetterC as IconCircleLetterC,
    index_IconCircleLetterCFilled as IconCircleLetterCFilled,
    index_IconCircleLetterD as IconCircleLetterD,
    index_IconCircleLetterDFilled as IconCircleLetterDFilled,
    index_IconCircleLetterE as IconCircleLetterE,
    index_IconCircleLetterEFilled as IconCircleLetterEFilled,
    index_IconCircleLetterF as IconCircleLetterF,
    index_IconCircleLetterFFilled as IconCircleLetterFFilled,
    index_IconCircleLetterG as IconCircleLetterG,
    index_IconCircleLetterGFilled as IconCircleLetterGFilled,
    index_IconCircleLetterH as IconCircleLetterH,
    index_IconCircleLetterHFilled as IconCircleLetterHFilled,
    index_IconCircleLetterI as IconCircleLetterI,
    index_IconCircleLetterIFilled as IconCircleLetterIFilled,
    index_IconCircleLetterJ as IconCircleLetterJ,
    index_IconCircleLetterJFilled as IconCircleLetterJFilled,
    index_IconCircleLetterK as IconCircleLetterK,
    index_IconCircleLetterKFilled as IconCircleLetterKFilled,
    index_IconCircleLetterL as IconCircleLetterL,
    index_IconCircleLetterLFilled as IconCircleLetterLFilled,
    index_IconCircleLetterM as IconCircleLetterM,
    index_IconCircleLetterMFilled as IconCircleLetterMFilled,
    index_IconCircleLetterN as IconCircleLetterN,
    index_IconCircleLetterNFilled as IconCircleLetterNFilled,
    index_IconCircleLetterO as IconCircleLetterO,
    index_IconCircleLetterOFilled as IconCircleLetterOFilled,
    index_IconCircleLetterP as IconCircleLetterP,
    index_IconCircleLetterPFilled as IconCircleLetterPFilled,
    index_IconCircleLetterQ as IconCircleLetterQ,
    index_IconCircleLetterQFilled as IconCircleLetterQFilled,
    index_IconCircleLetterR as IconCircleLetterR,
    index_IconCircleLetterRFilled as IconCircleLetterRFilled,
    index_IconCircleLetterS as IconCircleLetterS,
    index_IconCircleLetterSFilled as IconCircleLetterSFilled,
    index_IconCircleLetterT as IconCircleLetterT,
    index_IconCircleLetterTFilled as IconCircleLetterTFilled,
    index_IconCircleLetterU as IconCircleLetterU,
    index_IconCircleLetterUFilled as IconCircleLetterUFilled,
    index_IconCircleLetterV as IconCircleLetterV,
    index_IconCircleLetterVFilled as IconCircleLetterVFilled,
    index_IconCircleLetterW as IconCircleLetterW,
    index_IconCircleLetterWFilled as IconCircleLetterWFilled,
    index_IconCircleLetterX as IconCircleLetterX,
    index_IconCircleLetterXFilled as IconCircleLetterXFilled,
    index_IconCircleLetterY as IconCircleLetterY,
    index_IconCircleLetterYFilled as IconCircleLetterYFilled,
    index_IconCircleLetterZ as IconCircleLetterZ,
    index_IconCircleLetterZFilled as IconCircleLetterZFilled,
    index_IconCircleMinus as IconCircleMinus,
    index_IconCircleMinus2 as IconCircleMinus2,
    index_IconCircleNumber0 as IconCircleNumber0,
    index_IconCircleNumber0Filled as IconCircleNumber0Filled,
    index_IconCircleNumber1 as IconCircleNumber1,
    index_IconCircleNumber1Filled as IconCircleNumber1Filled,
    index_IconCircleNumber2 as IconCircleNumber2,
    index_IconCircleNumber2Filled as IconCircleNumber2Filled,
    index_IconCircleNumber3 as IconCircleNumber3,
    index_IconCircleNumber3Filled as IconCircleNumber3Filled,
    index_IconCircleNumber4 as IconCircleNumber4,
    index_IconCircleNumber4Filled as IconCircleNumber4Filled,
    index_IconCircleNumber5 as IconCircleNumber5,
    index_IconCircleNumber5Filled as IconCircleNumber5Filled,
    index_IconCircleNumber6 as IconCircleNumber6,
    index_IconCircleNumber6Filled as IconCircleNumber6Filled,
    index_IconCircleNumber7 as IconCircleNumber7,
    index_IconCircleNumber7Filled as IconCircleNumber7Filled,
    index_IconCircleNumber8 as IconCircleNumber8,
    index_IconCircleNumber8Filled as IconCircleNumber8Filled,
    index_IconCircleNumber9 as IconCircleNumber9,
    index_IconCircleNumber9Filled as IconCircleNumber9Filled,
    index_IconCircleOff as IconCircleOff,
    index_IconCirclePercentage as IconCirclePercentage,
    index_IconCirclePercentageFilled as IconCirclePercentageFilled,
    index_IconCirclePlus as IconCirclePlus,
    index_IconCirclePlus2 as IconCirclePlus2,
    index_IconCirclePlusFilled as IconCirclePlusFilled,
    index_IconCircleRectangle as IconCircleRectangle,
    index_IconCircleRectangleFilled as IconCircleRectangleFilled,
    index_IconCircleRectangleOff as IconCircleRectangleOff,
    index_IconCircleSquare as IconCircleSquare,
    index_IconCircleTriangle as IconCircleTriangle,
    index_IconCircleX as IconCircleX,
    index_IconCircleXFilled as IconCircleXFilled,
    index_IconCircles as IconCircles,
    index_IconCirclesFilled as IconCirclesFilled,
    index_IconCirclesRelation as IconCirclesRelation,
    index_IconCircuitAmmeter as IconCircuitAmmeter,
    index_IconCircuitBattery as IconCircuitBattery,
    index_IconCircuitBulb as IconCircuitBulb,
    index_IconCircuitCapacitor as IconCircuitCapacitor,
    index_IconCircuitCapacitorPolarized as IconCircuitCapacitorPolarized,
    index_IconCircuitCell as IconCircuitCell,
    index_IconCircuitCellPlus as IconCircuitCellPlus,
    index_IconCircuitChangeover as IconCircuitChangeover,
    index_IconCircuitDiode as IconCircuitDiode,
    index_IconCircuitDiodeZener as IconCircuitDiodeZener,
    index_IconCircuitGround as IconCircuitGround,
    index_IconCircuitGroundDigital as IconCircuitGroundDigital,
    index_IconCircuitInductor as IconCircuitInductor,
    index_IconCircuitMotor as IconCircuitMotor,
    index_IconCircuitPushbutton as IconCircuitPushbutton,
    index_IconCircuitResistor as IconCircuitResistor,
    index_IconCircuitSwitchClosed as IconCircuitSwitchClosed,
    index_IconCircuitSwitchOpen as IconCircuitSwitchOpen,
    index_IconCircuitVoltmeter as IconCircuitVoltmeter,
    index_IconClearAll as IconClearAll,
    index_IconClearFormatting as IconClearFormatting,
    index_IconClick as IconClick,
    index_IconCliffJumping as IconCliffJumping,
    index_IconClipboard as IconClipboard,
    index_IconClipboardCheck as IconClipboardCheck,
    index_IconClipboardCheckFilled as IconClipboardCheckFilled,
    index_IconClipboardCopy as IconClipboardCopy,
    index_IconClipboardData as IconClipboardData,
    index_IconClipboardDataFilled as IconClipboardDataFilled,
    index_IconClipboardFilled as IconClipboardFilled,
    index_IconClipboardHeart as IconClipboardHeart,
    index_IconClipboardList as IconClipboardList,
    index_IconClipboardListFilled as IconClipboardListFilled,
    index_IconClipboardOff as IconClipboardOff,
    index_IconClipboardPlus as IconClipboardPlus,
    index_IconClipboardPlusFilled as IconClipboardPlusFilled,
    index_IconClipboardSearch as IconClipboardSearch,
    index_IconClipboardSmile as IconClipboardSmile,
    index_IconClipboardSmileFilled as IconClipboardSmileFilled,
    index_IconClipboardText as IconClipboardText,
    index_IconClipboardTextFilled as IconClipboardTextFilled,
    index_IconClipboardTypography as IconClipboardTypography,
    index_IconClipboardTypographyFilled as IconClipboardTypographyFilled,
    index_IconClipboardX as IconClipboardX,
    index_IconClipboardXFilled as IconClipboardXFilled,
    index_IconClock as IconClock,
    index_IconClock12 as IconClock12,
    index_IconClock2 as IconClock2,
    index_IconClock24 as IconClock24,
    index_IconClockBitcoin as IconClockBitcoin,
    index_IconClockBolt as IconClockBolt,
    index_IconClockCancel as IconClockCancel,
    index_IconClockCheck as IconClockCheck,
    index_IconClockCode as IconClockCode,
    index_IconClockCog as IconClockCog,
    index_IconClockDollar as IconClockDollar,
    index_IconClockDown as IconClockDown,
    index_IconClockEdit as IconClockEdit,
    index_IconClockExclamation as IconClockExclamation,
    index_IconClockFilled as IconClockFilled,
    index_IconClockHeart as IconClockHeart,
    index_IconClockHour1 as IconClockHour1,
    index_IconClockHour10 as IconClockHour10,
    index_IconClockHour10Filled as IconClockHour10Filled,
    index_IconClockHour11 as IconClockHour11,
    index_IconClockHour11Filled as IconClockHour11Filled,
    index_IconClockHour12 as IconClockHour12,
    index_IconClockHour12Filled as IconClockHour12Filled,
    index_IconClockHour1Filled as IconClockHour1Filled,
    index_IconClockHour2 as IconClockHour2,
    index_IconClockHour2Filled as IconClockHour2Filled,
    index_IconClockHour3 as IconClockHour3,
    index_IconClockHour3Filled as IconClockHour3Filled,
    index_IconClockHour4 as IconClockHour4,
    index_IconClockHour4Filled as IconClockHour4Filled,
    index_IconClockHour5 as IconClockHour5,
    index_IconClockHour5Filled as IconClockHour5Filled,
    index_IconClockHour6 as IconClockHour6,
    index_IconClockHour6Filled as IconClockHour6Filled,
    index_IconClockHour7 as IconClockHour7,
    index_IconClockHour7Filled as IconClockHour7Filled,
    index_IconClockHour8 as IconClockHour8,
    index_IconClockHour8Filled as IconClockHour8Filled,
    index_IconClockHour9 as IconClockHour9,
    index_IconClockHour9Filled as IconClockHour9Filled,
    index_IconClockMinus as IconClockMinus,
    index_IconClockOff as IconClockOff,
    index_IconClockPause as IconClockPause,
    index_IconClockPin as IconClockPin,
    index_IconClockPlay as IconClockPlay,
    index_IconClockPlus as IconClockPlus,
    index_IconClockQuestion as IconClockQuestion,
    index_IconClockRecord as IconClockRecord,
    index_IconClockSearch as IconClockSearch,
    index_IconClockShare as IconClockShare,
    index_IconClockShield as IconClockShield,
    index_IconClockStar as IconClockStar,
    index_IconClockStop as IconClockStop,
    index_IconClockUp as IconClockUp,
    index_IconClockX as IconClockX,
    index_IconClothesRack as IconClothesRack,
    index_IconClothesRackOff as IconClothesRackOff,
    index_IconCloud as IconCloud,
    index_IconCloudBitcoin as IconCloudBitcoin,
    index_IconCloudBolt as IconCloudBolt,
    index_IconCloudCancel as IconCloudCancel,
    index_IconCloudCheck as IconCloudCheck,
    index_IconCloudCode as IconCloudCode,
    index_IconCloudCog as IconCloudCog,
    index_IconCloudComputing as IconCloudComputing,
    index_IconCloudComputingFilled as IconCloudComputingFilled,
    index_IconCloudDataConnection as IconCloudDataConnection,
    index_IconCloudDataConnectionFilled as IconCloudDataConnectionFilled,
    index_IconCloudDollar as IconCloudDollar,
    index_IconCloudDown as IconCloudDown,
    index_IconCloudDownload as IconCloudDownload,
    index_IconCloudExclamation as IconCloudExclamation,
    index_IconCloudFilled as IconCloudFilled,
    index_IconCloudFog as IconCloudFog,
    index_IconCloudHeart as IconCloudHeart,
    index_IconCloudLock as IconCloudLock,
    index_IconCloudLockOpen as IconCloudLockOpen,
    index_IconCloudMinus as IconCloudMinus,
    index_IconCloudNetwork as IconCloudNetwork,
    index_IconCloudOff as IconCloudOff,
    index_IconCloudPause as IconCloudPause,
    index_IconCloudPin as IconCloudPin,
    index_IconCloudPlus as IconCloudPlus,
    index_IconCloudQuestion as IconCloudQuestion,
    index_IconCloudRain as IconCloudRain,
    index_IconCloudSearch as IconCloudSearch,
    index_IconCloudShare as IconCloudShare,
    index_IconCloudSnow as IconCloudSnow,
    index_IconCloudStar as IconCloudStar,
    index_IconCloudStorm as IconCloudStorm,
    index_IconCloudUp as IconCloudUp,
    index_IconCloudUpload as IconCloudUpload,
    index_IconCloudX as IconCloudX,
    index_IconClover as IconClover,
    index_IconClover2 as IconClover2,
    index_IconCloverFilled as IconCloverFilled,
    index_IconClubs as IconClubs,
    index_IconClubsFilled as IconClubsFilled,
    index_IconCode as IconCode,
    index_IconCodeAsterisk as IconCodeAsterisk,
    index_IconCodeCircle as IconCodeCircle,
    index_IconCodeCircle2 as IconCodeCircle2,
    index_IconCodeCircle2Filled as IconCodeCircle2Filled,
    index_IconCodeCircleFilled as IconCodeCircleFilled,
    index_IconCodeDots as IconCodeDots,
    index_IconCodeMinus as IconCodeMinus,
    index_IconCodeOff as IconCodeOff,
    index_IconCodePlus as IconCodePlus,
    index_IconCodeVariable as IconCodeVariable,
    index_IconCodeVariableMinus as IconCodeVariableMinus,
    index_IconCodeVariablePlus as IconCodeVariablePlus,
    index_IconCoffee as IconCoffee,
    index_IconCoffeeOff as IconCoffeeOff,
    index_IconCoffin as IconCoffin,
    index_IconCoin as IconCoin,
    index_IconCoinBitcoin as IconCoinBitcoin,
    index_IconCoinBitcoinFilled as IconCoinBitcoinFilled,
    index_IconCoinEuro as IconCoinEuro,
    index_IconCoinEuroFilled as IconCoinEuroFilled,
    index_IconCoinFilled as IconCoinFilled,
    index_IconCoinMonero as IconCoinMonero,
    index_IconCoinMoneroFilled as IconCoinMoneroFilled,
    index_IconCoinOff as IconCoinOff,
    index_IconCoinPound as IconCoinPound,
    index_IconCoinPoundFilled as IconCoinPoundFilled,
    index_IconCoinRupee as IconCoinRupee,
    index_IconCoinRupeeFilled as IconCoinRupeeFilled,
    index_IconCoinTaka as IconCoinTaka,
    index_IconCoinTakaFilled as IconCoinTakaFilled,
    index_IconCoinYen as IconCoinYen,
    index_IconCoinYenFilled as IconCoinYenFilled,
    index_IconCoinYuan as IconCoinYuan,
    index_IconCoinYuanFilled as IconCoinYuanFilled,
    index_IconCoins as IconCoins,
    index_IconColorFilter as IconColorFilter,
    index_IconColorPicker as IconColorPicker,
    index_IconColorPickerOff as IconColorPickerOff,
    index_IconColorSwatch as IconColorSwatch,
    index_IconColorSwatchOff as IconColorSwatchOff,
    index_IconColumnInsertLeft as IconColumnInsertLeft,
    index_IconColumnInsertRight as IconColumnInsertRight,
    index_IconColumnRemove as IconColumnRemove,
    index_IconColumns as IconColumns,
    index_IconColumns1 as IconColumns1,
    index_IconColumns1Filled as IconColumns1Filled,
    index_IconColumns2 as IconColumns2,
    index_IconColumns2Filled as IconColumns2Filled,
    index_IconColumns3 as IconColumns3,
    index_IconColumns3Filled as IconColumns3Filled,
    index_IconColumnsOff as IconColumnsOff,
    index_IconComet as IconComet,
    index_IconCommand as IconCommand,
    index_IconCommandOff as IconCommandOff,
    index_IconCompass as IconCompass,
    index_IconCompassFilled as IconCompassFilled,
    index_IconCompassOff as IconCompassOff,
    index_IconComponents as IconComponents,
    index_IconComponentsOff as IconComponentsOff,
    index_IconCone as IconCone,
    index_IconCone2 as IconCone2,
    index_IconCone2Filled as IconCone2Filled,
    index_IconConeFilled as IconConeFilled,
    index_IconConeOff as IconConeOff,
    index_IconConePlus as IconConePlus,
    index_IconConfetti as IconConfetti,
    index_IconConfettiFilled as IconConfettiFilled,
    index_IconConfettiOff as IconConfettiOff,
    index_IconConfucius as IconConfucius,
    index_IconCongruentTo as IconCongruentTo,
    index_IconContainer as IconContainer,
    index_IconContainerFilled as IconContainerFilled,
    index_IconContainerOff as IconContainerOff,
    index_IconContract as IconContract,
    index_IconContrast as IconContrast,
    index_IconContrast2 as IconContrast2,
    index_IconContrast2Filled as IconContrast2Filled,
    index_IconContrast2Off as IconContrast2Off,
    index_IconContrastFilled as IconContrastFilled,
    index_IconContrastOff as IconContrastOff,
    index_IconCooker as IconCooker,
    index_IconCookie as IconCookie,
    index_IconCookieFilled as IconCookieFilled,
    index_IconCookieMan as IconCookieMan,
    index_IconCookieManFilled as IconCookieManFilled,
    index_IconCookieOff as IconCookieOff,
    index_IconCopy as IconCopy,
    index_IconCopyCheck as IconCopyCheck,
    index_IconCopyCheckFilled as IconCopyCheckFilled,
    index_IconCopyMinus as IconCopyMinus,
    index_IconCopyMinusFilled as IconCopyMinusFilled,
    index_IconCopyOff as IconCopyOff,
    index_IconCopyPlus as IconCopyPlus,
    index_IconCopyPlusFilled as IconCopyPlusFilled,
    index_IconCopyX as IconCopyX,
    index_IconCopyXFilled as IconCopyXFilled,
    index_IconCopyleft as IconCopyleft,
    index_IconCopyleftFilled as IconCopyleftFilled,
    index_IconCopyleftOff as IconCopyleftOff,
    index_IconCopyright as IconCopyright,
    index_IconCopyrightFilled as IconCopyrightFilled,
    index_IconCopyrightOff as IconCopyrightOff,
    index_IconCornerDownLeft as IconCornerDownLeft,
    index_IconCornerDownLeftDouble as IconCornerDownLeftDouble,
    index_IconCornerDownRight as IconCornerDownRight,
    index_IconCornerDownRightDouble as IconCornerDownRightDouble,
    index_IconCornerLeftDown as IconCornerLeftDown,
    index_IconCornerLeftDownDouble as IconCornerLeftDownDouble,
    index_IconCornerLeftUp as IconCornerLeftUp,
    index_IconCornerLeftUpDouble as IconCornerLeftUpDouble,
    index_IconCornerRightDown as IconCornerRightDown,
    index_IconCornerRightDownDouble as IconCornerRightDownDouble,
    index_IconCornerRightUp as IconCornerRightUp,
    index_IconCornerRightUpDouble as IconCornerRightUpDouble,
    index_IconCornerUpLeft as IconCornerUpLeft,
    index_IconCornerUpLeftDouble as IconCornerUpLeftDouble,
    index_IconCornerUpRight as IconCornerUpRight,
    index_IconCornerUpRightDouble as IconCornerUpRightDouble,
    index_IconCpu as IconCpu,
    index_IconCpu2 as IconCpu2,
    index_IconCpuOff as IconCpuOff,
    index_IconCrane as IconCrane,
    index_IconCraneOff as IconCraneOff,
    index_IconCreativeCommons as IconCreativeCommons,
    index_IconCreativeCommonsBy as IconCreativeCommonsBy,
    index_IconCreativeCommonsNc as IconCreativeCommonsNc,
    index_IconCreativeCommonsNd as IconCreativeCommonsNd,
    index_IconCreativeCommonsOff as IconCreativeCommonsOff,
    index_IconCreativeCommonsSa as IconCreativeCommonsSa,
    index_IconCreativeCommonsZero as IconCreativeCommonsZero,
    index_IconCreditCard as IconCreditCard,
    index_IconCreditCardFilled as IconCreditCardFilled,
    index_IconCreditCardOff as IconCreditCardOff,
    index_IconCreditCardPay as IconCreditCardPay,
    index_IconCreditCardRefund as IconCreditCardRefund,
    index_IconCricket as IconCricket,
    index_IconCrop as IconCrop,
    index_IconCrop11 as IconCrop11,
    index_IconCrop11Filled as IconCrop11Filled,
    index_IconCrop169 as IconCrop169,
    index_IconCrop169Filled as IconCrop169Filled,
    index_IconCrop32 as IconCrop32,
    index_IconCrop32Filled as IconCrop32Filled,
    index_IconCrop54 as IconCrop54,
    index_IconCrop54Filled as IconCrop54Filled,
    index_IconCrop75 as IconCrop75,
    index_IconCrop75Filled as IconCrop75Filled,
    index_IconCropLandscape as IconCropLandscape,
    index_IconCropLandscapeFilled as IconCropLandscapeFilled,
    index_IconCropPortrait as IconCropPortrait,
    index_IconCropPortraitFilled as IconCropPortraitFilled,
    index_IconCross as IconCross,
    index_IconCrossFilled as IconCrossFilled,
    index_IconCrossOff as IconCrossOff,
    index_IconCrosshair as IconCrosshair,
    index_IconCrown as IconCrown,
    index_IconCrownFilled as IconCrownFilled,
    index_IconCrownOff as IconCrownOff,
    index_IconCrutches as IconCrutches,
    index_IconCrutchesOff as IconCrutchesOff,
    index_IconCrystalBall as IconCrystalBall,
    index_IconCsv as IconCsv,
    index_IconCube as IconCube,
    index_IconCube3dSphere as IconCube3dSphere,
    index_IconCube3dSphereOff as IconCube3dSphereOff,
    index_IconCubeOff as IconCubeOff,
    index_IconCubePlus as IconCubePlus,
    index_IconCubeSend as IconCubeSend,
    index_IconCubeSpark as IconCubeSpark,
    index_IconCubeUnfolded as IconCubeUnfolded,
    index_IconCup as IconCup,
    index_IconCupOff as IconCupOff,
    index_IconCurling as IconCurling,
    index_IconCurlyLoop as IconCurlyLoop,
    index_IconCurrency as IconCurrency,
    index_IconCurrencyAfghani as IconCurrencyAfghani,
    index_IconCurrencyBahraini as IconCurrencyBahraini,
    index_IconCurrencyBaht as IconCurrencyBaht,
    index_IconCurrencyBitcoin as IconCurrencyBitcoin,
    index_IconCurrencyCent as IconCurrencyCent,
    index_IconCurrencyDinar as IconCurrencyDinar,
    index_IconCurrencyDirham as IconCurrencyDirham,
    index_IconCurrencyDogecoin as IconCurrencyDogecoin,
    index_IconCurrencyDollar as IconCurrencyDollar,
    index_IconCurrencyDollarAustralian as IconCurrencyDollarAustralian,
    index_IconCurrencyDollarBrunei as IconCurrencyDollarBrunei,
    index_IconCurrencyDollarCanadian as IconCurrencyDollarCanadian,
    index_IconCurrencyDollarGuyanese as IconCurrencyDollarGuyanese,
    index_IconCurrencyDollarOff as IconCurrencyDollarOff,
    index_IconCurrencyDollarSingapore as IconCurrencyDollarSingapore,
    index_IconCurrencyDollarZimbabwean as IconCurrencyDollarZimbabwean,
    index_IconCurrencyDong as IconCurrencyDong,
    index_IconCurrencyDram as IconCurrencyDram,
    index_IconCurrencyEthereum as IconCurrencyEthereum,
    index_IconCurrencyEuro as IconCurrencyEuro,
    index_IconCurrencyEuroOff as IconCurrencyEuroOff,
    index_IconCurrencyFlorin as IconCurrencyFlorin,
    index_IconCurrencyForint as IconCurrencyForint,
    index_IconCurrencyFrank as IconCurrencyFrank,
    index_IconCurrencyGuarani as IconCurrencyGuarani,
    index_IconCurrencyHryvnia as IconCurrencyHryvnia,
    index_IconCurrencyIranianRial as IconCurrencyIranianRial,
    index_IconCurrencyKip as IconCurrencyKip,
    index_IconCurrencyKroneCzech as IconCurrencyKroneCzech,
    index_IconCurrencyKroneDanish as IconCurrencyKroneDanish,
    index_IconCurrencyKroneSwedish as IconCurrencyKroneSwedish,
    index_IconCurrencyLari as IconCurrencyLari,
    index_IconCurrencyLeu as IconCurrencyLeu,
    index_IconCurrencyLira as IconCurrencyLira,
    index_IconCurrencyLitecoin as IconCurrencyLitecoin,
    index_IconCurrencyLyd as IconCurrencyLyd,
    index_IconCurrencyManat as IconCurrencyManat,
    index_IconCurrencyMonero as IconCurrencyMonero,
    index_IconCurrencyNaira as IconCurrencyNaira,
    index_IconCurrencyNano as IconCurrencyNano,
    index_IconCurrencyOff as IconCurrencyOff,
    index_IconCurrencyPaanga as IconCurrencyPaanga,
    index_IconCurrencyPeso as IconCurrencyPeso,
    index_IconCurrencyPound as IconCurrencyPound,
    index_IconCurrencyPoundOff as IconCurrencyPoundOff,
    index_IconCurrencyQuetzal as IconCurrencyQuetzal,
    index_IconCurrencyReal as IconCurrencyReal,
    index_IconCurrencyRenminbi as IconCurrencyRenminbi,
    index_IconCurrencyRipple as IconCurrencyRipple,
    index_IconCurrencyRiyal as IconCurrencyRiyal,
    index_IconCurrencyRubel as IconCurrencyRubel,
    index_IconCurrencyRufiyaa as IconCurrencyRufiyaa,
    index_IconCurrencyRupee as IconCurrencyRupee,
    index_IconCurrencyRupeeNepalese as IconCurrencyRupeeNepalese,
    index_IconCurrencyShekel as IconCurrencyShekel,
    index_IconCurrencySolana as IconCurrencySolana,
    index_IconCurrencySom as IconCurrencySom,
    index_IconCurrencyTaka as IconCurrencyTaka,
    index_IconCurrencyTenge as IconCurrencyTenge,
    index_IconCurrencyTugrik as IconCurrencyTugrik,
    index_IconCurrencyWon as IconCurrencyWon,
    index_IconCurrencyXrp as IconCurrencyXrp,
    index_IconCurrencyYen as IconCurrencyYen,
    index_IconCurrencyYenOff as IconCurrencyYenOff,
    index_IconCurrencyYuan as IconCurrencyYuan,
    index_IconCurrencyZloty as IconCurrencyZloty,
    index_IconCurrentLocation as IconCurrentLocation,
    index_IconCurrentLocationFilled as IconCurrentLocationFilled,
    index_IconCurrentLocationOff as IconCurrentLocationOff,
    index_IconCursorOff as IconCursorOff,
    index_IconCursorText as IconCursorText,
    index_IconCut as IconCut,
    index_IconCylinder as IconCylinder,
    index_IconCylinderOff as IconCylinderOff,
    index_IconCylinderPlus as IconCylinderPlus,
    index_IconDashboard as IconDashboard,
    index_IconDashboardFilled as IconDashboardFilled,
    index_IconDashboardOff as IconDashboardOff,
    index_IconDatabase as IconDatabase,
    index_IconDatabaseCog as IconDatabaseCog,
    index_IconDatabaseDollar as IconDatabaseDollar,
    index_IconDatabaseEdit as IconDatabaseEdit,
    index_IconDatabaseExclamation as IconDatabaseExclamation,
    index_IconDatabaseExport as IconDatabaseExport,
    index_IconDatabaseHeart as IconDatabaseHeart,
    index_IconDatabaseImport as IconDatabaseImport,
    index_IconDatabaseLeak as IconDatabaseLeak,
    index_IconDatabaseMinus as IconDatabaseMinus,
    index_IconDatabaseOff as IconDatabaseOff,
    index_IconDatabasePlus as IconDatabasePlus,
    index_IconDatabaseSearch as IconDatabaseSearch,
    index_IconDatabaseShare as IconDatabaseShare,
    index_IconDatabaseSmile as IconDatabaseSmile,
    index_IconDatabaseStar as IconDatabaseStar,
    index_IconDatabaseX as IconDatabaseX,
    index_IconDeaf as IconDeaf,
    index_IconDecimal as IconDecimal,
    index_IconDeer as IconDeer,
    index_IconDelta as IconDelta,
    index_IconDental as IconDental,
    index_IconDentalBroken as IconDentalBroken,
    index_IconDentalOff as IconDentalOff,
    index_IconDeselect as IconDeselect,
    index_IconDesk as IconDesk,
    index_IconDetails as IconDetails,
    index_IconDetailsOff as IconDetailsOff,
    index_IconDeviceAirpods as IconDeviceAirpods,
    index_IconDeviceAirpodsCase as IconDeviceAirpodsCase,
    index_IconDeviceAirtag as IconDeviceAirtag,
    index_IconDeviceAnalytics as IconDeviceAnalytics,
    index_IconDeviceAudioTape as IconDeviceAudioTape,
    index_IconDeviceCameraPhone as IconDeviceCameraPhone,
    index_IconDeviceCctv as IconDeviceCctv,
    index_IconDeviceCctvFilled as IconDeviceCctvFilled,
    index_IconDeviceCctvOff as IconDeviceCctvOff,
    index_IconDeviceComputerCamera as IconDeviceComputerCamera,
    index_IconDeviceComputerCameraOff as IconDeviceComputerCameraOff,
    index_IconDeviceDesktop as IconDeviceDesktop,
    index_IconDeviceDesktopAnalytics as IconDeviceDesktopAnalytics,
    index_IconDeviceDesktopBolt as IconDeviceDesktopBolt,
    index_IconDeviceDesktopCancel as IconDeviceDesktopCancel,
    index_IconDeviceDesktopCheck as IconDeviceDesktopCheck,
    index_IconDeviceDesktopCode as IconDeviceDesktopCode,
    index_IconDeviceDesktopCog as IconDeviceDesktopCog,
    index_IconDeviceDesktopDollar as IconDeviceDesktopDollar,
    index_IconDeviceDesktopDown as IconDeviceDesktopDown,
    index_IconDeviceDesktopExclamation as IconDeviceDesktopExclamation,
    index_IconDeviceDesktopFilled as IconDeviceDesktopFilled,
    index_IconDeviceDesktopHeart as IconDeviceDesktopHeart,
    index_IconDeviceDesktopMinus as IconDeviceDesktopMinus,
    index_IconDeviceDesktopOff as IconDeviceDesktopOff,
    index_IconDeviceDesktopPause as IconDeviceDesktopPause,
    index_IconDeviceDesktopPin as IconDeviceDesktopPin,
    index_IconDeviceDesktopPlus as IconDeviceDesktopPlus,
    index_IconDeviceDesktopQuestion as IconDeviceDesktopQuestion,
    index_IconDeviceDesktopSearch as IconDeviceDesktopSearch,
    index_IconDeviceDesktopShare as IconDeviceDesktopShare,
    index_IconDeviceDesktopStar as IconDeviceDesktopStar,
    index_IconDeviceDesktopUp as IconDeviceDesktopUp,
    index_IconDeviceDesktopX as IconDeviceDesktopX,
    index_IconDeviceFloppy as IconDeviceFloppy,
    index_IconDeviceGamepad as IconDeviceGamepad,
    index_IconDeviceGamepad2 as IconDeviceGamepad2,
    index_IconDeviceGamepad3 as IconDeviceGamepad3,
    index_IconDeviceGamepad3Filled as IconDeviceGamepad3Filled,
    index_IconDeviceGamepadFilled as IconDeviceGamepadFilled,
    index_IconDeviceHeartMonitor as IconDeviceHeartMonitor,
    index_IconDeviceHeartMonitorFilled as IconDeviceHeartMonitorFilled,
    index_IconDeviceImac as IconDeviceImac,
    index_IconDeviceImacBolt as IconDeviceImacBolt,
    index_IconDeviceImacCancel as IconDeviceImacCancel,
    index_IconDeviceImacCheck as IconDeviceImacCheck,
    index_IconDeviceImacCode as IconDeviceImacCode,
    index_IconDeviceImacCog as IconDeviceImacCog,
    index_IconDeviceImacDollar as IconDeviceImacDollar,
    index_IconDeviceImacDown as IconDeviceImacDown,
    index_IconDeviceImacExclamation as IconDeviceImacExclamation,
    index_IconDeviceImacFilled as IconDeviceImacFilled,
    index_IconDeviceImacHeart as IconDeviceImacHeart,
    index_IconDeviceImacMinus as IconDeviceImacMinus,
    index_IconDeviceImacOff as IconDeviceImacOff,
    index_IconDeviceImacPause as IconDeviceImacPause,
    index_IconDeviceImacPin as IconDeviceImacPin,
    index_IconDeviceImacPlus as IconDeviceImacPlus,
    index_IconDeviceImacQuestion as IconDeviceImacQuestion,
    index_IconDeviceImacSearch as IconDeviceImacSearch,
    index_IconDeviceImacShare as IconDeviceImacShare,
    index_IconDeviceImacStar as IconDeviceImacStar,
    index_IconDeviceImacUp as IconDeviceImacUp,
    index_IconDeviceImacX as IconDeviceImacX,
    index_IconDeviceIpad as IconDeviceIpad,
    index_IconDeviceIpadBolt as IconDeviceIpadBolt,
    index_IconDeviceIpadCancel as IconDeviceIpadCancel,
    index_IconDeviceIpadCheck as IconDeviceIpadCheck,
    index_IconDeviceIpadCode as IconDeviceIpadCode,
    index_IconDeviceIpadCog as IconDeviceIpadCog,
    index_IconDeviceIpadDollar as IconDeviceIpadDollar,
    index_IconDeviceIpadDown as IconDeviceIpadDown,
    index_IconDeviceIpadExclamation as IconDeviceIpadExclamation,
    index_IconDeviceIpadFilled as IconDeviceIpadFilled,
    index_IconDeviceIpadHeart as IconDeviceIpadHeart,
    index_IconDeviceIpadHorizontal as IconDeviceIpadHorizontal,
    index_IconDeviceIpadHorizontalBolt as IconDeviceIpadHorizontalBolt,
    index_IconDeviceIpadHorizontalCancel as IconDeviceIpadHorizontalCancel,
    index_IconDeviceIpadHorizontalCheck as IconDeviceIpadHorizontalCheck,
    index_IconDeviceIpadHorizontalCode as IconDeviceIpadHorizontalCode,
    index_IconDeviceIpadHorizontalCog as IconDeviceIpadHorizontalCog,
    index_IconDeviceIpadHorizontalDollar as IconDeviceIpadHorizontalDollar,
    index_IconDeviceIpadHorizontalDown as IconDeviceIpadHorizontalDown,
    index_IconDeviceIpadHorizontalExclamation as IconDeviceIpadHorizontalExclamation,
    index_IconDeviceIpadHorizontalHeart as IconDeviceIpadHorizontalHeart,
    index_IconDeviceIpadHorizontalMinus as IconDeviceIpadHorizontalMinus,
    index_IconDeviceIpadHorizontalOff as IconDeviceIpadHorizontalOff,
    index_IconDeviceIpadHorizontalPause as IconDeviceIpadHorizontalPause,
    index_IconDeviceIpadHorizontalPin as IconDeviceIpadHorizontalPin,
    index_IconDeviceIpadHorizontalPlus as IconDeviceIpadHorizontalPlus,
    index_IconDeviceIpadHorizontalQuestion as IconDeviceIpadHorizontalQuestion,
    index_IconDeviceIpadHorizontalSearch as IconDeviceIpadHorizontalSearch,
    index_IconDeviceIpadHorizontalShare as IconDeviceIpadHorizontalShare,
    index_IconDeviceIpadHorizontalStar as IconDeviceIpadHorizontalStar,
    index_IconDeviceIpadHorizontalUp as IconDeviceIpadHorizontalUp,
    index_IconDeviceIpadHorizontalX as IconDeviceIpadHorizontalX,
    index_IconDeviceIpadMinus as IconDeviceIpadMinus,
    index_IconDeviceIpadOff as IconDeviceIpadOff,
    index_IconDeviceIpadPause as IconDeviceIpadPause,
    index_IconDeviceIpadPin as IconDeviceIpadPin,
    index_IconDeviceIpadPlus as IconDeviceIpadPlus,
    index_IconDeviceIpadQuestion as IconDeviceIpadQuestion,
    index_IconDeviceIpadSearch as IconDeviceIpadSearch,
    index_IconDeviceIpadShare as IconDeviceIpadShare,
    index_IconDeviceIpadStar as IconDeviceIpadStar,
    index_IconDeviceIpadUp as IconDeviceIpadUp,
    index_IconDeviceIpadX as IconDeviceIpadX,
    index_IconDeviceLandlinePhone as IconDeviceLandlinePhone,
    index_IconDeviceLaptop as IconDeviceLaptop,
    index_IconDeviceLaptopOff as IconDeviceLaptopOff,
    index_IconDeviceMobile as IconDeviceMobile,
    index_IconDeviceMobileBolt as IconDeviceMobileBolt,
    index_IconDeviceMobileCancel as IconDeviceMobileCancel,
    index_IconDeviceMobileCharging as IconDeviceMobileCharging,
    index_IconDeviceMobileCheck as IconDeviceMobileCheck,
    index_IconDeviceMobileCode as IconDeviceMobileCode,
    index_IconDeviceMobileCog as IconDeviceMobileCog,
    index_IconDeviceMobileDollar as IconDeviceMobileDollar,
    index_IconDeviceMobileDown as IconDeviceMobileDown,
    index_IconDeviceMobileExclamation as IconDeviceMobileExclamation,
    index_IconDeviceMobileFilled as IconDeviceMobileFilled,
    index_IconDeviceMobileHeart as IconDeviceMobileHeart,
    index_IconDeviceMobileMessage as IconDeviceMobileMessage,
    index_IconDeviceMobileMinus as IconDeviceMobileMinus,
    index_IconDeviceMobileOff as IconDeviceMobileOff,
    index_IconDeviceMobilePause as IconDeviceMobilePause,
    index_IconDeviceMobilePin as IconDeviceMobilePin,
    index_IconDeviceMobilePlus as IconDeviceMobilePlus,
    index_IconDeviceMobileQuestion as IconDeviceMobileQuestion,
    index_IconDeviceMobileRotated as IconDeviceMobileRotated,
    index_IconDeviceMobileSearch as IconDeviceMobileSearch,
    index_IconDeviceMobileShare as IconDeviceMobileShare,
    index_IconDeviceMobileStar as IconDeviceMobileStar,
    index_IconDeviceMobileUp as IconDeviceMobileUp,
    index_IconDeviceMobileVibration as IconDeviceMobileVibration,
    index_IconDeviceMobileX as IconDeviceMobileX,
    index_IconDeviceNintendo as IconDeviceNintendo,
    index_IconDeviceNintendoOff as IconDeviceNintendoOff,
    index_IconDeviceProjector as IconDeviceProjector,
    index_IconDeviceRemote as IconDeviceRemote,
    index_IconDeviceRemoteFilled as IconDeviceRemoteFilled,
    index_IconDeviceSdCard as IconDeviceSdCard,
    index_IconDeviceSim as IconDeviceSim,
    index_IconDeviceSim1 as IconDeviceSim1,
    index_IconDeviceSim2 as IconDeviceSim2,
    index_IconDeviceSim3 as IconDeviceSim3,
    index_IconDeviceSpeaker as IconDeviceSpeaker,
    index_IconDeviceSpeakerFilled as IconDeviceSpeakerFilled,
    index_IconDeviceSpeakerOff as IconDeviceSpeakerOff,
    index_IconDeviceTablet as IconDeviceTablet,
    index_IconDeviceTabletBolt as IconDeviceTabletBolt,
    index_IconDeviceTabletCancel as IconDeviceTabletCancel,
    index_IconDeviceTabletCheck as IconDeviceTabletCheck,
    index_IconDeviceTabletCode as IconDeviceTabletCode,
    index_IconDeviceTabletCog as IconDeviceTabletCog,
    index_IconDeviceTabletDollar as IconDeviceTabletDollar,
    index_IconDeviceTabletDown as IconDeviceTabletDown,
    index_IconDeviceTabletExclamation as IconDeviceTabletExclamation,
    index_IconDeviceTabletFilled as IconDeviceTabletFilled,
    index_IconDeviceTabletHeart as IconDeviceTabletHeart,
    index_IconDeviceTabletMinus as IconDeviceTabletMinus,
    index_IconDeviceTabletOff as IconDeviceTabletOff,
    index_IconDeviceTabletPause as IconDeviceTabletPause,
    index_IconDeviceTabletPin as IconDeviceTabletPin,
    index_IconDeviceTabletPlus as IconDeviceTabletPlus,
    index_IconDeviceTabletQuestion as IconDeviceTabletQuestion,
    index_IconDeviceTabletSearch as IconDeviceTabletSearch,
    index_IconDeviceTabletShare as IconDeviceTabletShare,
    index_IconDeviceTabletStar as IconDeviceTabletStar,
    index_IconDeviceTabletUp as IconDeviceTabletUp,
    index_IconDeviceTabletX as IconDeviceTabletX,
    index_IconDeviceTv as IconDeviceTv,
    index_IconDeviceTvFilled as IconDeviceTvFilled,
    index_IconDeviceTvOff as IconDeviceTvOff,
    index_IconDeviceTvOld as IconDeviceTvOld,
    index_IconDeviceTvOldFilled as IconDeviceTvOldFilled,
    index_IconDeviceUnknown as IconDeviceUnknown,
    index_IconDeviceUnknownFilled as IconDeviceUnknownFilled,
    index_IconDeviceUsb as IconDeviceUsb,
    index_IconDeviceUsbFilled as IconDeviceUsbFilled,
    index_IconDeviceVisionPro as IconDeviceVisionPro,
    index_IconDeviceVisionProFilled as IconDeviceVisionProFilled,
    index_IconDeviceWatch as IconDeviceWatch,
    index_IconDeviceWatchBolt as IconDeviceWatchBolt,
    index_IconDeviceWatchCancel as IconDeviceWatchCancel,
    index_IconDeviceWatchCheck as IconDeviceWatchCheck,
    index_IconDeviceWatchCode as IconDeviceWatchCode,
    index_IconDeviceWatchCog as IconDeviceWatchCog,
    index_IconDeviceWatchDollar as IconDeviceWatchDollar,
    index_IconDeviceWatchDown as IconDeviceWatchDown,
    index_IconDeviceWatchExclamation as IconDeviceWatchExclamation,
    index_IconDeviceWatchFilled as IconDeviceWatchFilled,
    index_IconDeviceWatchHeart as IconDeviceWatchHeart,
    index_IconDeviceWatchMinus as IconDeviceWatchMinus,
    index_IconDeviceWatchOff as IconDeviceWatchOff,
    index_IconDeviceWatchPause as IconDeviceWatchPause,
    index_IconDeviceWatchPin as IconDeviceWatchPin,
    index_IconDeviceWatchPlus as IconDeviceWatchPlus,
    index_IconDeviceWatchQuestion as IconDeviceWatchQuestion,
    index_IconDeviceWatchSearch as IconDeviceWatchSearch,
    index_IconDeviceWatchShare as IconDeviceWatchShare,
    index_IconDeviceWatchStar as IconDeviceWatchStar,
    index_IconDeviceWatchStats as IconDeviceWatchStats,
    index_IconDeviceWatchStats2 as IconDeviceWatchStats2,
    index_IconDeviceWatchUp as IconDeviceWatchUp,
    index_IconDeviceWatchX as IconDeviceWatchX,
    index_IconDevices as IconDevices,
    index_IconDevices2 as IconDevices2,
    index_IconDevicesBolt as IconDevicesBolt,
    index_IconDevicesCancel as IconDevicesCancel,
    index_IconDevicesCheck as IconDevicesCheck,
    index_IconDevicesCode as IconDevicesCode,
    index_IconDevicesCog as IconDevicesCog,
    index_IconDevicesDollar as IconDevicesDollar,
    index_IconDevicesDown as IconDevicesDown,
    index_IconDevicesExclamation as IconDevicesExclamation,
    index_IconDevicesHeart as IconDevicesHeart,
    index_IconDevicesMinus as IconDevicesMinus,
    index_IconDevicesOff as IconDevicesOff,
    index_IconDevicesPause as IconDevicesPause,
    index_IconDevicesPc as IconDevicesPc,
    index_IconDevicesPcOff as IconDevicesPcOff,
    index_IconDevicesPin as IconDevicesPin,
    index_IconDevicesPlus as IconDevicesPlus,
    index_IconDevicesQuestion as IconDevicesQuestion,
    index_IconDevicesSearch as IconDevicesSearch,
    index_IconDevicesShare as IconDevicesShare,
    index_IconDevicesStar as IconDevicesStar,
    index_IconDevicesUp as IconDevicesUp,
    index_IconDevicesX as IconDevicesX,
    index_IconDiabolo as IconDiabolo,
    index_IconDiaboloOff as IconDiaboloOff,
    index_IconDiaboloPlus as IconDiaboloPlus,
    index_IconDialpad as IconDialpad,
    index_IconDialpadFilled as IconDialpadFilled,
    index_IconDialpadOff as IconDialpadOff,
    index_IconDiamond as IconDiamond,
    index_IconDiamondFilled as IconDiamondFilled,
    index_IconDiamondOff as IconDiamondOff,
    index_IconDiamonds as IconDiamonds,
    index_IconDiamondsFilled as IconDiamondsFilled,
    index_IconDiaper as IconDiaper,
    index_IconDice as IconDice,
    index_IconDice1 as IconDice1,
    index_IconDice1Filled as IconDice1Filled,
    index_IconDice2 as IconDice2,
    index_IconDice2Filled as IconDice2Filled,
    index_IconDice3 as IconDice3,
    index_IconDice3Filled as IconDice3Filled,
    index_IconDice4 as IconDice4,
    index_IconDice4Filled as IconDice4Filled,
    index_IconDice5 as IconDice5,
    index_IconDice5Filled as IconDice5Filled,
    index_IconDice6 as IconDice6,
    index_IconDice6Filled as IconDice6Filled,
    index_IconDiceFilled as IconDiceFilled,
    index_IconDimensions as IconDimensions,
    index_IconDirection as IconDirection,
    index_IconDirectionArrows as IconDirectionArrows,
    index_IconDirectionArrowsFilled as IconDirectionArrowsFilled,
    index_IconDirectionHorizontal as IconDirectionHorizontal,
    index_IconDirectionSign as IconDirectionSign,
    index_IconDirectionSignFilled as IconDirectionSignFilled,
    index_IconDirectionSignOff as IconDirectionSignOff,
    index_IconDirections as IconDirections,
    index_IconDirectionsFilled as IconDirectionsFilled,
    index_IconDirectionsOff as IconDirectionsOff,
    index_IconDisabled as IconDisabled,
    index_IconDisabled2 as IconDisabled2,
    index_IconDisabledOff as IconDisabledOff,
    index_IconDisc as IconDisc,
    index_IconDiscFilled as IconDiscFilled,
    index_IconDiscGolf as IconDiscGolf,
    index_IconDiscOff as IconDiscOff,
    index_IconDiscount as IconDiscount,
    index_IconDiscountFilled as IconDiscountFilled,
    index_IconDiscountOff as IconDiscountOff,
    index_IconDivide as IconDivide,
    index_IconDna as IconDna,
    index_IconDna2 as IconDna2,
    index_IconDna2Off as IconDna2Off,
    index_IconDnaOff as IconDnaOff,
    index_IconDog as IconDog,
    index_IconDogBowl as IconDogBowl,
    index_IconDoor as IconDoor,
    index_IconDoorEnter as IconDoorEnter,
    index_IconDoorExit as IconDoorExit,
    index_IconDoorOff as IconDoorOff,
    index_IconDots as IconDots,
    index_IconDotsCircleHorizontal as IconDotsCircleHorizontal,
    index_IconDotsDiagonal as IconDotsDiagonal,
    index_IconDotsDiagonal2 as IconDotsDiagonal2,
    index_IconDotsVertical as IconDotsVertical,
    index_IconDownload as IconDownload,
    index_IconDownloadOff as IconDownloadOff,
    index_IconDragDrop as IconDragDrop,
    index_IconDragDrop2 as IconDragDrop2,
    index_IconDrone as IconDrone,
    index_IconDroneOff as IconDroneOff,
    index_IconDropCircle as IconDropCircle,
    index_IconDropCircleFilled as IconDropCircleFilled,
    index_IconDroplet as IconDroplet,
    index_IconDropletBolt as IconDropletBolt,
    index_IconDropletCancel as IconDropletCancel,
    index_IconDropletCheck as IconDropletCheck,
    index_IconDropletCode as IconDropletCode,
    index_IconDropletCog as IconDropletCog,
    index_IconDropletDollar as IconDropletDollar,
    index_IconDropletDown as IconDropletDown,
    index_IconDropletExclamation as IconDropletExclamation,
    index_IconDropletFilled as IconDropletFilled,
    index_IconDropletHalf as IconDropletHalf,
    index_IconDropletHalf2 as IconDropletHalf2,
    index_IconDropletHalf2Filled as IconDropletHalf2Filled,
    index_IconDropletHalfFilled as IconDropletHalfFilled,
    index_IconDropletHeart as IconDropletHeart,
    index_IconDropletMinus as IconDropletMinus,
    index_IconDropletOff as IconDropletOff,
    index_IconDropletPause as IconDropletPause,
    index_IconDropletPin as IconDropletPin,
    index_IconDropletPlus as IconDropletPlus,
    index_IconDropletQuestion as IconDropletQuestion,
    index_IconDropletSearch as IconDropletSearch,
    index_IconDropletShare as IconDropletShare,
    index_IconDropletStar as IconDropletStar,
    index_IconDropletUp as IconDropletUp,
    index_IconDropletX as IconDropletX,
    index_IconDroplets as IconDroplets,
    index_IconDropletsFilled as IconDropletsFilled,
    index_IconDualScreen as IconDualScreen,
    index_IconDualScreenFilled as IconDualScreenFilled,
    index_IconDumpling as IconDumpling,
    index_IconDumplingFilled as IconDumplingFilled,
    index_IconEPassport as IconEPassport,
    index_IconEar as IconEar,
    index_IconEarOff as IconEarOff,
    index_IconEarScan as IconEarScan,
    index_IconEaseIn as IconEaseIn,
    index_IconEaseInControlPoint as IconEaseInControlPoint,
    index_IconEaseInControlPointFilled as IconEaseInControlPointFilled,
    index_IconEaseInOut as IconEaseInOut,
    index_IconEaseInOutControlPoints as IconEaseInOutControlPoints,
    index_IconEaseInOutControlPointsFilled as IconEaseInOutControlPointsFilled,
    index_IconEaseOut as IconEaseOut,
    index_IconEaseOutControlPoint as IconEaseOutControlPoint,
    index_IconEaseOutControlPointFilled as IconEaseOutControlPointFilled,
    index_IconEdit as IconEdit,
    index_IconEditCircle as IconEditCircle,
    index_IconEditCircleOff as IconEditCircleOff,
    index_IconEditOff as IconEditOff,
    index_IconEgg as IconEgg,
    index_IconEggCracked as IconEggCracked,
    index_IconEggCrackedFilled as IconEggCrackedFilled,
    index_IconEggFilled as IconEggFilled,
    index_IconEggFried as IconEggFried,
    index_IconEggFriedFilled as IconEggFriedFilled,
    index_IconEggOff as IconEggOff,
    index_IconEggs as IconEggs,
    index_IconElevator as IconElevator,
    index_IconElevatorFilled as IconElevatorFilled,
    index_IconElevatorOff as IconElevatorOff,
    index_IconEmergencyBed as IconEmergencyBed,
    index_IconEmpathize as IconEmpathize,
    index_IconEmpathizeOff as IconEmpathizeOff,
    index_IconEmphasis as IconEmphasis,
    index_IconEngine as IconEngine,
    index_IconEngineFilled as IconEngineFilled,
    index_IconEngineOff as IconEngineOff,
    index_IconEqual as IconEqual,
    index_IconEqualDouble as IconEqualDouble,
    index_IconEqualNot as IconEqualNot,
    index_IconEraser as IconEraser,
    index_IconEraserOff as IconEraserOff,
    index_IconError404 as IconError404,
    index_IconError404Off as IconError404Off,
    index_IconEscalator as IconEscalator,
    index_IconEscalatorDown as IconEscalatorDown,
    index_IconEscalatorDownFilled as IconEscalatorDownFilled,
    index_IconEscalatorFilled as IconEscalatorFilled,
    index_IconEscalatorUp as IconEscalatorUp,
    index_IconEscalatorUpFilled as IconEscalatorUpFilled,
    index_IconExchange as IconExchange,
    index_IconExchangeFilled as IconExchangeFilled,
    index_IconExchangeOff as IconExchangeOff,
    index_IconExclamationCircle as IconExclamationCircle,
    index_IconExclamationCircleFilled as IconExclamationCircleFilled,
    index_IconExclamationMark as IconExclamationMark,
    index_IconExclamationMarkOff as IconExclamationMarkOff,
    index_IconExplicit as IconExplicit,
    index_IconExplicitFilled as IconExplicitFilled,
    index_IconExplicitOff as IconExplicitOff,
    index_IconExposure as IconExposure,
    index_IconExposure0 as IconExposure0,
    index_IconExposureFilled as IconExposureFilled,
    index_IconExposureMinus1 as IconExposureMinus1,
    index_IconExposureMinus2 as IconExposureMinus2,
    index_IconExposureOff as IconExposureOff,
    index_IconExposurePlus1 as IconExposurePlus1,
    index_IconExposurePlus2 as IconExposurePlus2,
    index_IconExternalLink as IconExternalLink,
    index_IconExternalLinkOff as IconExternalLinkOff,
    index_IconEye as IconEye,
    index_IconEyeBitcoin as IconEyeBitcoin,
    index_IconEyeBolt as IconEyeBolt,
    index_IconEyeCancel as IconEyeCancel,
    index_IconEyeCheck as IconEyeCheck,
    index_IconEyeClosed as IconEyeClosed,
    index_IconEyeCode as IconEyeCode,
    index_IconEyeCog as IconEyeCog,
    index_IconEyeDiscount as IconEyeDiscount,
    index_IconEyeDollar as IconEyeDollar,
    index_IconEyeDotted as IconEyeDotted,
    index_IconEyeDown as IconEyeDown,
    index_IconEyeEdit as IconEyeEdit,
    index_IconEyeExclamation as IconEyeExclamation,
    index_IconEyeFilled as IconEyeFilled,
    index_IconEyeHeart as IconEyeHeart,
    index_IconEyeMinus as IconEyeMinus,
    index_IconEyeOff as IconEyeOff,
    index_IconEyePause as IconEyePause,
    index_IconEyePin as IconEyePin,
    index_IconEyePlus as IconEyePlus,
    index_IconEyeQuestion as IconEyeQuestion,
    index_IconEyeSearch as IconEyeSearch,
    index_IconEyeShare as IconEyeShare,
    index_IconEyeSpark as IconEyeSpark,
    index_IconEyeStar as IconEyeStar,
    index_IconEyeTable as IconEyeTable,
    index_IconEyeTableFilled as IconEyeTableFilled,
    index_IconEyeUp as IconEyeUp,
    index_IconEyeX as IconEyeX,
    index_IconEyeglass as IconEyeglass,
    index_IconEyeglass2 as IconEyeglass2,
    index_IconEyeglass2Filled as IconEyeglass2Filled,
    index_IconEyeglassFilled as IconEyeglassFilled,
    index_IconEyeglassOff as IconEyeglassOff,
    index_IconFaceId as IconFaceId,
    index_IconFaceIdError as IconFaceIdError,
    index_IconFaceMask as IconFaceMask,
    index_IconFaceMaskFilled as IconFaceMaskFilled,
    index_IconFaceMaskOff as IconFaceMaskOff,
    index_IconFall as IconFall,
    index_IconFavicon as IconFavicon,
    index_IconFaviconFilled as IconFaviconFilled,
    index_IconFeather as IconFeather,
    index_IconFeatherFilled as IconFeatherFilled,
    index_IconFeatherOff as IconFeatherOff,
    index_IconFence as IconFence,
    index_IconFenceFilled as IconFenceFilled,
    index_IconFenceOff as IconFenceOff,
    index_IconFerry as IconFerry,
    index_IconFerryFilled as IconFerryFilled,
    index_IconFidgetSpinner as IconFidgetSpinner,
    index_IconFidgetSpinnerFilled as IconFidgetSpinnerFilled,
    index_IconFile as IconFile,
    index_IconFile3d as IconFile3d,
    index_IconFileAi as IconFileAi,
    index_IconFileAlert as IconFileAlert,
    index_IconFileAnalytics as IconFileAnalytics,
    index_IconFileAnalyticsFilled as IconFileAnalyticsFilled,
    index_IconFileArrowLeft as IconFileArrowLeft,
    index_IconFileArrowRight as IconFileArrowRight,
    index_IconFileBarcode as IconFileBarcode,
    index_IconFileBitcoin as IconFileBitcoin,
    index_IconFileBroken as IconFileBroken,
    index_IconFileCertificate as IconFileCertificate,
    index_IconFileChart as IconFileChart,
    index_IconFileCheck as IconFileCheck,
    index_IconFileCheckFilled as IconFileCheckFilled,
    index_IconFileCode as IconFileCode,
    index_IconFileCode2 as IconFileCode2,
    index_IconFileCode2Filled as IconFileCode2Filled,
    index_IconFileCodeFilled as IconFileCodeFilled,
    index_IconFileCv as IconFileCv,
    index_IconFileCvFilled as IconFileCvFilled,
    index_IconFileDatabase as IconFileDatabase,
    index_IconFileDelta as IconFileDelta,
    index_IconFileDeltaFilled as IconFileDeltaFilled,
    index_IconFileDescription as IconFileDescription,
    index_IconFileDescriptionFilled as IconFileDescriptionFilled,
    index_IconFileDiff as IconFileDiff,
    index_IconFileDiffFilled as IconFileDiffFilled,
    index_IconFileDigit as IconFileDigit,
    index_IconFileDigitFilled as IconFileDigitFilled,
    index_IconFileDislike as IconFileDislike,
    index_IconFileDollar as IconFileDollar,
    index_IconFileDollarFilled as IconFileDollarFilled,
    index_IconFileDots as IconFileDots,
    index_IconFileDotsFilled as IconFileDotsFilled,
    index_IconFileDownload as IconFileDownload,
    index_IconFileDownloadFilled as IconFileDownloadFilled,
    index_IconFileEuro as IconFileEuro,
    index_IconFileEuroFilled as IconFileEuroFilled,
    index_IconFileExcel as IconFileExcel,
    index_IconFileExport as IconFileExport,
    index_IconFileFilled as IconFileFilled,
    index_IconFileFunction as IconFileFunction,
    index_IconFileFunctionFilled as IconFileFunctionFilled,
    index_IconFileHorizontal as IconFileHorizontal,
    index_IconFileHorizontalFilled as IconFileHorizontalFilled,
    index_IconFileImport as IconFileImport,
    index_IconFileInfinity as IconFileInfinity,
    index_IconFileInfo as IconFileInfo,
    index_IconFileInfoFilled as IconFileInfoFilled,
    index_IconFileInvoice as IconFileInvoice,
    index_IconFileInvoiceFilled as IconFileInvoiceFilled,
    index_IconFileIsr as IconFileIsr,
    index_IconFileLambda as IconFileLambda,
    index_IconFileLambdaFilled as IconFileLambdaFilled,
    index_IconFileLike as IconFileLike,
    index_IconFileMinus as IconFileMinus,
    index_IconFileMinusFilled as IconFileMinusFilled,
    index_IconFileMusic as IconFileMusic,
    index_IconFileMusicFilled as IconFileMusicFilled,
    index_IconFileNeutral as IconFileNeutral,
    index_IconFileNeutralFilled as IconFileNeutralFilled,
    index_IconFileOff as IconFileOff,
    index_IconFileOrientation as IconFileOrientation,
    index_IconFilePencil as IconFilePencil,
    index_IconFilePencilFilled as IconFilePencilFilled,
    index_IconFilePercent as IconFilePercent,
    index_IconFilePercentFilled as IconFilePercentFilled,
    index_IconFilePhone as IconFilePhone,
    index_IconFilePhoneFilled as IconFilePhoneFilled,
    index_IconFilePlus as IconFilePlus,
    index_IconFilePower as IconFilePower,
    index_IconFilePowerFilled as IconFilePowerFilled,
    index_IconFileReport as IconFileReport,
    index_IconFileRss as IconFileRss,
    index_IconFileRssFilled as IconFileRssFilled,
    index_IconFileSad as IconFileSad,
    index_IconFileSadFilled as IconFileSadFilled,
    index_IconFileScissors as IconFileScissors,
    index_IconFileScissorsFilled as IconFileScissorsFilled,
    index_IconFileSearch as IconFileSearch,
    index_IconFileSettings as IconFileSettings,
    index_IconFileSettingsFilled as IconFileSettingsFilled,
    index_IconFileShredder as IconFileShredder,
    index_IconFileSignal as IconFileSignal,
    index_IconFileSignalFilled as IconFileSignalFilled,
    index_IconFileSmile as IconFileSmile,
    index_IconFileSmileFilled as IconFileSmileFilled,
    index_IconFileSpark as IconFileSpark,
    index_IconFileSpreadsheet as IconFileSpreadsheet,
    index_IconFileStack as IconFileStack,
    index_IconFileStar as IconFileStar,
    index_IconFileStarFilled as IconFileStarFilled,
    index_IconFileSymlink as IconFileSymlink,
    index_IconFileText as IconFileText,
    index_IconFileTextAi as IconFileTextAi,
    index_IconFileTextFilled as IconFileTextFilled,
    index_IconFileTextShield as IconFileTextShield,
    index_IconFileTextSpark as IconFileTextSpark,
    index_IconFileTime as IconFileTime,
    index_IconFileTimeFilled as IconFileTimeFilled,
    index_IconFileTypeBmp as IconFileTypeBmp,
    index_IconFileTypeCss as IconFileTypeCss,
    index_IconFileTypeCsv as IconFileTypeCsv,
    index_IconFileTypeDoc as IconFileTypeDoc,
    index_IconFileTypeDocx as IconFileTypeDocx,
    index_IconFileTypeHtml as IconFileTypeHtml,
    index_IconFileTypeJpg as IconFileTypeJpg,
    index_IconFileTypeJs as IconFileTypeJs,
    index_IconFileTypeJsx as IconFileTypeJsx,
    index_IconFileTypePdf as IconFileTypePdf,
    index_IconFileTypePhp as IconFileTypePhp,
    index_IconFileTypePng as IconFileTypePng,
    index_IconFileTypePpt as IconFileTypePpt,
    index_IconFileTypeRs as IconFileTypeRs,
    index_IconFileTypeSql as IconFileTypeSql,
    index_IconFileTypeSvg as IconFileTypeSvg,
    index_IconFileTypeTs as IconFileTypeTs,
    index_IconFileTypeTsx as IconFileTypeTsx,
    index_IconFileTypeTxt as IconFileTypeTxt,
    index_IconFileTypeVue as IconFileTypeVue,
    index_IconFileTypeXls as IconFileTypeXls,
    index_IconFileTypeXml as IconFileTypeXml,
    index_IconFileTypeZip as IconFileTypeZip,
    index_IconFileTypography as IconFileTypography,
    index_IconFileTypographyFilled as IconFileTypographyFilled,
    index_IconFileUnknown as IconFileUnknown,
    index_IconFileUnknownFilled as IconFileUnknownFilled,
    index_IconFileUpload as IconFileUpload,
    index_IconFileUploadFilled as IconFileUploadFilled,
    index_IconFileVector as IconFileVector,
    index_IconFileVectorFilled as IconFileVectorFilled,
    index_IconFileWord as IconFileWord,
    index_IconFileX as IconFileX,
    index_IconFileXFilled as IconFileXFilled,
    index_IconFileZip as IconFileZip,
    index_IconFiles as IconFiles,
    index_IconFilesFilled as IconFilesFilled,
    index_IconFilesOff as IconFilesOff,
    index_IconFilter as IconFilter,
    index_IconFilter2 as IconFilter2,
    index_IconFilter2Bolt as IconFilter2Bolt,
    index_IconFilter2Cancel as IconFilter2Cancel,
    index_IconFilter2Check as IconFilter2Check,
    index_IconFilter2Code as IconFilter2Code,
    index_IconFilter2Cog as IconFilter2Cog,
    index_IconFilter2Discount as IconFilter2Discount,
    index_IconFilter2Dollar as IconFilter2Dollar,
    index_IconFilter2Down as IconFilter2Down,
    index_IconFilter2Edit as IconFilter2Edit,
    index_IconFilter2Exclamation as IconFilter2Exclamation,
    index_IconFilter2Minus as IconFilter2Minus,
    index_IconFilter2Pause as IconFilter2Pause,
    index_IconFilter2Pin as IconFilter2Pin,
    index_IconFilter2Plus as IconFilter2Plus,
    index_IconFilter2Question as IconFilter2Question,
    index_IconFilter2Search as IconFilter2Search,
    index_IconFilter2Share as IconFilter2Share,
    index_IconFilter2Spark as IconFilter2Spark,
    index_IconFilter2Up as IconFilter2Up,
    index_IconFilter2X as IconFilter2X,
    index_IconFilterBolt as IconFilterBolt,
    index_IconFilterCancel as IconFilterCancel,
    index_IconFilterCheck as IconFilterCheck,
    index_IconFilterCode as IconFilterCode,
    index_IconFilterCog as IconFilterCog,
    index_IconFilterDiscount as IconFilterDiscount,
    index_IconFilterDollar as IconFilterDollar,
    index_IconFilterDown as IconFilterDown,
    index_IconFilterEdit as IconFilterEdit,
    index_IconFilterExclamation as IconFilterExclamation,
    index_IconFilterFilled as IconFilterFilled,
    index_IconFilterHeart as IconFilterHeart,
    index_IconFilterMinus as IconFilterMinus,
    index_IconFilterOff as IconFilterOff,
    index_IconFilterPause as IconFilterPause,
    index_IconFilterPin as IconFilterPin,
    index_IconFilterPlus as IconFilterPlus,
    index_IconFilterQuestion as IconFilterQuestion,
    index_IconFilterSearch as IconFilterSearch,
    index_IconFilterShare as IconFilterShare,
    index_IconFilterSpark as IconFilterSpark,
    index_IconFilterStar as IconFilterStar,
    index_IconFilterUp as IconFilterUp,
    index_IconFilterX as IconFilterX,
    index_IconFilters as IconFilters,
    index_IconFiltersFilled as IconFiltersFilled,
    index_IconFingerprint as IconFingerprint,
    index_IconFingerprintOff as IconFingerprintOff,
    index_IconFingerprintScan as IconFingerprintScan,
    index_IconFireExtinguisher as IconFireExtinguisher,
    index_IconFireHydrant as IconFireHydrant,
    index_IconFireHydrantOff as IconFireHydrantOff,
    index_IconFiretruck as IconFiretruck,
    index_IconFirstAidKit as IconFirstAidKit,
    index_IconFirstAidKitOff as IconFirstAidKitOff,
    index_IconFish as IconFish,
    index_IconFishBone as IconFishBone,
    index_IconFishBoneFilled as IconFishBoneFilled,
    index_IconFishChristianity as IconFishChristianity,
    index_IconFishHook as IconFishHook,
    index_IconFishHookOff as IconFishHookOff,
    index_IconFishOff as IconFishOff,
    index_IconFlag as IconFlag,
    index_IconFlag2 as IconFlag2,
    index_IconFlag2Filled as IconFlag2Filled,
    index_IconFlag2Off as IconFlag2Off,
    index_IconFlag3 as IconFlag3,
    index_IconFlag3Filled as IconFlag3Filled,
    index_IconFlagBitcoin as IconFlagBitcoin,
    index_IconFlagBolt as IconFlagBolt,
    index_IconFlagCancel as IconFlagCancel,
    index_IconFlagCheck as IconFlagCheck,
    index_IconFlagCode as IconFlagCode,
    index_IconFlagCog as IconFlagCog,
    index_IconFlagDiscount as IconFlagDiscount,
    index_IconFlagDollar as IconFlagDollar,
    index_IconFlagDown as IconFlagDown,
    index_IconFlagExclamation as IconFlagExclamation,
    index_IconFlagFilled as IconFlagFilled,
    index_IconFlagHeart as IconFlagHeart,
    index_IconFlagMinus as IconFlagMinus,
    index_IconFlagOff as IconFlagOff,
    index_IconFlagPause as IconFlagPause,
    index_IconFlagPin as IconFlagPin,
    index_IconFlagPlus as IconFlagPlus,
    index_IconFlagQuestion as IconFlagQuestion,
    index_IconFlagSearch as IconFlagSearch,
    index_IconFlagShare as IconFlagShare,
    index_IconFlagSpark as IconFlagSpark,
    index_IconFlagStar as IconFlagStar,
    index_IconFlagUp as IconFlagUp,
    index_IconFlagX as IconFlagX,
    index_IconFlame as IconFlame,
    index_IconFlameFilled as IconFlameFilled,
    index_IconFlameOff as IconFlameOff,
    index_IconFlare as IconFlare,
    index_IconFlareFilled as IconFlareFilled,
    index_IconFlask as IconFlask,
    index_IconFlask2 as IconFlask2,
    index_IconFlask2Filled as IconFlask2Filled,
    index_IconFlask2Off as IconFlask2Off,
    index_IconFlaskFilled as IconFlaskFilled,
    index_IconFlaskOff as IconFlaskOff,
    index_IconFlipFlops as IconFlipFlops,
    index_IconFlipHorizontal as IconFlipHorizontal,
    index_IconFlipVertical as IconFlipVertical,
    index_IconFloatCenter as IconFloatCenter,
    index_IconFloatLeft as IconFloatLeft,
    index_IconFloatNone as IconFloatNone,
    index_IconFloatRight as IconFloatRight,
    index_IconFlower as IconFlower,
    index_IconFlowerFilled as IconFlowerFilled,
    index_IconFlowerOff as IconFlowerOff,
    index_IconFocus as IconFocus,
    index_IconFocus2 as IconFocus2,
    index_IconFocusAuto as IconFocusAuto,
    index_IconFocusCentered as IconFocusCentered,
    index_IconFold as IconFold,
    index_IconFoldDown as IconFoldDown,
    index_IconFoldUp as IconFoldUp,
    index_IconFolder as IconFolder,
    index_IconFolderBolt as IconFolderBolt,
    index_IconFolderCancel as IconFolderCancel,
    index_IconFolderCheck as IconFolderCheck,
    index_IconFolderCode as IconFolderCode,
    index_IconFolderCog as IconFolderCog,
    index_IconFolderDollar as IconFolderDollar,
    index_IconFolderDown as IconFolderDown,
    index_IconFolderExclamation as IconFolderExclamation,
    index_IconFolderFilled as IconFolderFilled,
    index_IconFolderHeart as IconFolderHeart,
    index_IconFolderMinus as IconFolderMinus,
    index_IconFolderOff as IconFolderOff,
    index_IconFolderOpen as IconFolderOpen,
    index_IconFolderOpenFilled as IconFolderOpenFilled,
    index_IconFolderPause as IconFolderPause,
    index_IconFolderPin as IconFolderPin,
    index_IconFolderPlus as IconFolderPlus,
    index_IconFolderQuestion as IconFolderQuestion,
    index_IconFolderRoot as IconFolderRoot,
    index_IconFolderSearch as IconFolderSearch,
    index_IconFolderShare as IconFolderShare,
    index_IconFolderStar as IconFolderStar,
    index_IconFolderSymlink as IconFolderSymlink,
    index_IconFolderUp as IconFolderUp,
    index_IconFolderX as IconFolderX,
    index_IconFolders as IconFolders,
    index_IconFoldersFilled as IconFoldersFilled,
    index_IconFoldersOff as IconFoldersOff,
    index_IconForbid as IconForbid,
    index_IconForbid2 as IconForbid2,
    index_IconForbid2Filled as IconForbid2Filled,
    index_IconForbidFilled as IconForbidFilled,
    index_IconForklift as IconForklift,
    index_IconForms as IconForms,
    index_IconFountain as IconFountain,
    index_IconFountainFilled as IconFountainFilled,
    index_IconFountainOff as IconFountainOff,
    index_IconFrame as IconFrame,
    index_IconFrameOff as IconFrameOff,
    index_IconFreeRights as IconFreeRights,
    index_IconFreezeColumn as IconFreezeColumn,
    index_IconFreezeRow as IconFreezeRow,
    index_IconFreezeRowColumn as IconFreezeRowColumn,
    index_IconFridge as IconFridge,
    index_IconFridgeOff as IconFridgeOff,
    index_IconFriends as IconFriends,
    index_IconFriendsOff as IconFriendsOff,
    index_IconFrustum as IconFrustum,
    index_IconFrustumOff as IconFrustumOff,
    index_IconFrustumPlus as IconFrustumPlus,
    index_IconFunction as IconFunction,
    index_IconFunctionFilled as IconFunctionFilled,
    index_IconFunctionOff as IconFunctionOff,
    index_IconGalaxy as IconGalaxy,
    index_IconGardenCart as IconGardenCart,
    index_IconGardenCartFilled as IconGardenCartFilled,
    index_IconGardenCartOff as IconGardenCartOff,
    index_IconGasStation as IconGasStation,
    index_IconGasStationFilled as IconGasStationFilled,
    index_IconGasStationOff as IconGasStationOff,
    index_IconGauge as IconGauge,
    index_IconGaugeFilled as IconGaugeFilled,
    index_IconGaugeOff as IconGaugeOff,
    index_IconGavel as IconGavel,
    index_IconGenderAgender as IconGenderAgender,
    index_IconGenderAndrogyne as IconGenderAndrogyne,
    index_IconGenderBigender as IconGenderBigender,
    index_IconGenderDemiboy as IconGenderDemiboy,
    index_IconGenderDemigirl as IconGenderDemigirl,
    index_IconGenderEpicene as IconGenderEpicene,
    index_IconGenderFemale as IconGenderFemale,
    index_IconGenderFemme as IconGenderFemme,
    index_IconGenderGenderfluid as IconGenderGenderfluid,
    index_IconGenderGenderless as IconGenderGenderless,
    index_IconGenderGenderqueer as IconGenderGenderqueer,
    index_IconGenderHermaphrodite as IconGenderHermaphrodite,
    index_IconGenderIntergender as IconGenderIntergender,
    index_IconGenderMale as IconGenderMale,
    index_IconGenderNeutrois as IconGenderNeutrois,
    index_IconGenderThird as IconGenderThird,
    index_IconGenderTransgender as IconGenderTransgender,
    index_IconGenderTrasvesti as IconGenderTrasvesti,
    index_IconGeometry as IconGeometry,
    index_IconGhost as IconGhost,
    index_IconGhost2 as IconGhost2,
    index_IconGhost2Filled as IconGhost2Filled,
    index_IconGhost3 as IconGhost3,
    index_IconGhost3Filled as IconGhost3Filled,
    index_IconGhostFilled as IconGhostFilled,
    index_IconGhostOff as IconGhostOff,
    index_IconGif as IconGif,
    index_IconGift as IconGift,
    index_IconGiftCard as IconGiftCard,
    index_IconGiftCardFilled as IconGiftCardFilled,
    index_IconGiftFilled as IconGiftFilled,
    index_IconGiftOff as IconGiftOff,
    index_IconGitBranch as IconGitBranch,
    index_IconGitBranchDeleted as IconGitBranchDeleted,
    index_IconGitCherryPick as IconGitCherryPick,
    index_IconGitCommit as IconGitCommit,
    index_IconGitCompare as IconGitCompare,
    index_IconGitFork as IconGitFork,
    index_IconGitMerge as IconGitMerge,
    index_IconGitPullRequest as IconGitPullRequest,
    index_IconGitPullRequestClosed as IconGitPullRequestClosed,
    index_IconGitPullRequestDraft as IconGitPullRequestDraft,
    index_IconGizmo as IconGizmo,
    index_IconGlass as IconGlass,
    index_IconGlassChampagne as IconGlassChampagne,
    index_IconGlassCocktail as IconGlassCocktail,
    index_IconGlassFilled as IconGlassFilled,
    index_IconGlassFull as IconGlassFull,
    index_IconGlassFullFilled as IconGlassFullFilled,
    index_IconGlassGin as IconGlassGin,
    index_IconGlassOff as IconGlassOff,
    index_IconGlobe as IconGlobe,
    index_IconGlobeFilled as IconGlobeFilled,
    index_IconGlobeOff as IconGlobeOff,
    index_IconGoGame as IconGoGame,
    index_IconGolf as IconGolf,
    index_IconGolfFilled as IconGolfFilled,
    index_IconGolfOff as IconGolfOff,
    index_IconGps as IconGps,
    index_IconGpsFilled as IconGpsFilled,
    index_IconGradienter as IconGradienter,
    index_IconGrain as IconGrain,
    index_IconGraph as IconGraph,
    index_IconGraphFilled as IconGraphFilled,
    index_IconGraphOff as IconGraphOff,
    index_IconGrave as IconGrave,
    index_IconGrave2 as IconGrave2,
    index_IconGrid3x3 as IconGrid3x3,
    index_IconGrid4x4 as IconGrid4x4,
    index_IconGridDots as IconGridDots,
    index_IconGridGoldenratio as IconGridGoldenratio,
    index_IconGridPattern as IconGridPattern,
    index_IconGridPatternFilled as IconGridPatternFilled,
    index_IconGridScan as IconGridScan,
    index_IconGrill as IconGrill,
    index_IconGrillFork as IconGrillFork,
    index_IconGrillOff as IconGrillOff,
    index_IconGrillSpatula as IconGrillSpatula,
    index_IconGripHorizontal as IconGripHorizontal,
    index_IconGripVertical as IconGripVertical,
    index_IconGrowth as IconGrowth,
    index_IconGuitarPick as IconGuitarPick,
    index_IconGuitarPickFilled as IconGuitarPickFilled,
    index_IconGymnastics as IconGymnastics,
    index_IconH1 as IconH1,
    index_IconH2 as IconH2,
    index_IconH3 as IconH3,
    index_IconH4 as IconH4,
    index_IconH5 as IconH5,
    index_IconH6 as IconH6,
    index_IconHammer as IconHammer,
    index_IconHammerOff as IconHammerOff,
    index_IconHandClick as IconHandClick,
    index_IconHandClickOff as IconHandClickOff,
    index_IconHandFinger as IconHandFinger,
    index_IconHandFingerDown as IconHandFingerDown,
    index_IconHandFingerLeft as IconHandFingerLeft,
    index_IconHandFingerOff as IconHandFingerOff,
    index_IconHandFingerRight as IconHandFingerRight,
    index_IconHandGrab as IconHandGrab,
    index_IconHandLittleFinger as IconHandLittleFinger,
    index_IconHandLoveYou as IconHandLoveYou,
    index_IconHandMiddleFinger as IconHandMiddleFinger,
    index_IconHandMove as IconHandMove,
    index_IconHandOff as IconHandOff,
    index_IconHandRingFinger as IconHandRingFinger,
    index_IconHandSanitizer as IconHandSanitizer,
    index_IconHandStop as IconHandStop,
    index_IconHandThreeFingers as IconHandThreeFingers,
    index_IconHandTwoFingers as IconHandTwoFingers,
    index_IconHanger as IconHanger,
    index_IconHanger2 as IconHanger2,
    index_IconHanger2Filled as IconHanger2Filled,
    index_IconHangerOff as IconHangerOff,
    index_IconHash as IconHash,
    index_IconHaze as IconHaze,
    index_IconHazeMoon as IconHazeMoon,
    index_IconHdr as IconHdr,
    index_IconHeading as IconHeading,
    index_IconHeadingOff as IconHeadingOff,
    index_IconHeadphones as IconHeadphones,
    index_IconHeadphonesFilled as IconHeadphonesFilled,
    index_IconHeadphonesOff as IconHeadphonesOff,
    index_IconHeadset as IconHeadset,
    index_IconHeadsetOff as IconHeadsetOff,
    index_IconHealthRecognition as IconHealthRecognition,
    index_IconHeart as IconHeart,
    index_IconHeartBitcoin as IconHeartBitcoin,
    index_IconHeartBolt as IconHeartBolt,
    index_IconHeartBroken as IconHeartBroken,
    index_IconHeartBrokenFilled as IconHeartBrokenFilled,
    index_IconHeartCancel as IconHeartCancel,
    index_IconHeartCheck as IconHeartCheck,
    index_IconHeartCode as IconHeartCode,
    index_IconHeartCog as IconHeartCog,
    index_IconHeartDiscount as IconHeartDiscount,
    index_IconHeartDollar as IconHeartDollar,
    index_IconHeartDown as IconHeartDown,
    index_IconHeartExclamation as IconHeartExclamation,
    index_IconHeartFilled as IconHeartFilled,
    index_IconHeartHandshake as IconHeartHandshake,
    index_IconHeartMinus as IconHeartMinus,
    index_IconHeartOff as IconHeartOff,
    index_IconHeartPause as IconHeartPause,
    index_IconHeartPin as IconHeartPin,
    index_IconHeartPlus as IconHeartPlus,
    index_IconHeartQuestion as IconHeartQuestion,
    index_IconHeartRateMonitor as IconHeartRateMonitor,
    index_IconHeartSearch as IconHeartSearch,
    index_IconHeartShare as IconHeartShare,
    index_IconHeartSpark as IconHeartSpark,
    index_IconHeartStar as IconHeartStar,
    index_IconHeartUp as IconHeartUp,
    index_IconHeartX as IconHeartX,
    index_IconHeartbeat as IconHeartbeat,
    index_IconHearts as IconHearts,
    index_IconHeartsOff as IconHeartsOff,
    index_IconHelicopter as IconHelicopter,
    index_IconHelicopterFilled as IconHelicopterFilled,
    index_IconHelicopterLanding as IconHelicopterLanding,
    index_IconHelicopterLandingFilled as IconHelicopterLandingFilled,
    index_IconHelmet as IconHelmet,
    index_IconHelmetOff as IconHelmetOff,
    index_IconHelp as IconHelp,
    index_IconHelpCircle as IconHelpCircle,
    index_IconHelpCircleFilled as IconHelpCircleFilled,
    index_IconHelpHexagon as IconHelpHexagon,
    index_IconHelpHexagonFilled as IconHelpHexagonFilled,
    index_IconHelpOctagon as IconHelpOctagon,
    index_IconHelpOctagonFilled as IconHelpOctagonFilled,
    index_IconHelpOff as IconHelpOff,
    index_IconHelpSmall as IconHelpSmall,
    index_IconHelpSquare as IconHelpSquare,
    index_IconHelpSquareFilled as IconHelpSquareFilled,
    index_IconHelpSquareRounded as IconHelpSquareRounded,
    index_IconHelpSquareRoundedFilled as IconHelpSquareRoundedFilled,
    index_IconHelpTriangle as IconHelpTriangle,
    index_IconHelpTriangleFilled as IconHelpTriangleFilled,
    index_IconHemisphere as IconHemisphere,
    index_IconHemisphereOff as IconHemisphereOff,
    index_IconHemispherePlus as IconHemispherePlus,
    index_IconHexagon as IconHexagon,
    index_IconHexagon3d as IconHexagon3d,
    index_IconHexagonAsterisk as IconHexagonAsterisk,
    index_IconHexagonFilled as IconHexagonFilled,
    index_IconHexagonLetterA as IconHexagonLetterA,
    index_IconHexagonLetterAFilled as IconHexagonLetterAFilled,
    index_IconHexagonLetterB as IconHexagonLetterB,
    index_IconHexagonLetterBFilled as IconHexagonLetterBFilled,
    index_IconHexagonLetterC as IconHexagonLetterC,
    index_IconHexagonLetterCFilled as IconHexagonLetterCFilled,
    index_IconHexagonLetterD as IconHexagonLetterD,
    index_IconHexagonLetterDFilled as IconHexagonLetterDFilled,
    index_IconHexagonLetterE as IconHexagonLetterE,
    index_IconHexagonLetterEFilled as IconHexagonLetterEFilled,
    index_IconHexagonLetterF as IconHexagonLetterF,
    index_IconHexagonLetterFFilled as IconHexagonLetterFFilled,
    index_IconHexagonLetterG as IconHexagonLetterG,
    index_IconHexagonLetterGFilled as IconHexagonLetterGFilled,
    index_IconHexagonLetterH as IconHexagonLetterH,
    index_IconHexagonLetterHFilled as IconHexagonLetterHFilled,
    index_IconHexagonLetterI as IconHexagonLetterI,
    index_IconHexagonLetterIFilled as IconHexagonLetterIFilled,
    index_IconHexagonLetterJ as IconHexagonLetterJ,
    index_IconHexagonLetterJFilled as IconHexagonLetterJFilled,
    index_IconHexagonLetterK as IconHexagonLetterK,
    index_IconHexagonLetterKFilled as IconHexagonLetterKFilled,
    index_IconHexagonLetterL as IconHexagonLetterL,
    index_IconHexagonLetterLFilled as IconHexagonLetterLFilled,
    index_IconHexagonLetterM as IconHexagonLetterM,
    index_IconHexagonLetterMFilled as IconHexagonLetterMFilled,
    index_IconHexagonLetterN as IconHexagonLetterN,
    index_IconHexagonLetterNFilled as IconHexagonLetterNFilled,
    index_IconHexagonLetterO as IconHexagonLetterO,
    index_IconHexagonLetterOFilled as IconHexagonLetterOFilled,
    index_IconHexagonLetterP as IconHexagonLetterP,
    index_IconHexagonLetterPFilled as IconHexagonLetterPFilled,
    index_IconHexagonLetterQ as IconHexagonLetterQ,
    index_IconHexagonLetterQFilled as IconHexagonLetterQFilled,
    index_IconHexagonLetterR as IconHexagonLetterR,
    index_IconHexagonLetterRFilled as IconHexagonLetterRFilled,
    index_IconHexagonLetterS as IconHexagonLetterS,
    index_IconHexagonLetterSFilled as IconHexagonLetterSFilled,
    index_IconHexagonLetterT as IconHexagonLetterT,
    index_IconHexagonLetterTFilled as IconHexagonLetterTFilled,
    index_IconHexagonLetterU as IconHexagonLetterU,
    index_IconHexagonLetterUFilled as IconHexagonLetterUFilled,
    index_IconHexagonLetterV as IconHexagonLetterV,
    index_IconHexagonLetterVFilled as IconHexagonLetterVFilled,
    index_IconHexagonLetterW as IconHexagonLetterW,
    index_IconHexagonLetterWFilled as IconHexagonLetterWFilled,
    index_IconHexagonLetterX as IconHexagonLetterX,
    index_IconHexagonLetterXFilled as IconHexagonLetterXFilled,
    index_IconHexagonLetterY as IconHexagonLetterY,
    index_IconHexagonLetterYFilled as IconHexagonLetterYFilled,
    index_IconHexagonLetterZ as IconHexagonLetterZ,
    index_IconHexagonLetterZFilled as IconHexagonLetterZFilled,
    index_IconHexagonMinus as IconHexagonMinus,
    index_IconHexagonMinus2 as IconHexagonMinus2,
    index_IconHexagonMinusFilled as IconHexagonMinusFilled,
    index_IconHexagonNumber0 as IconHexagonNumber0,
    index_IconHexagonNumber0Filled as IconHexagonNumber0Filled,
    index_IconHexagonNumber1 as IconHexagonNumber1,
    index_IconHexagonNumber1Filled as IconHexagonNumber1Filled,
    index_IconHexagonNumber2 as IconHexagonNumber2,
    index_IconHexagonNumber2Filled as IconHexagonNumber2Filled,
    index_IconHexagonNumber3 as IconHexagonNumber3,
    index_IconHexagonNumber3Filled as IconHexagonNumber3Filled,
    index_IconHexagonNumber4 as IconHexagonNumber4,
    index_IconHexagonNumber4Filled as IconHexagonNumber4Filled,
    index_IconHexagonNumber5 as IconHexagonNumber5,
    index_IconHexagonNumber5Filled as IconHexagonNumber5Filled,
    index_IconHexagonNumber6 as IconHexagonNumber6,
    index_IconHexagonNumber6Filled as IconHexagonNumber6Filled,
    index_IconHexagonNumber7 as IconHexagonNumber7,
    index_IconHexagonNumber7Filled as IconHexagonNumber7Filled,
    index_IconHexagonNumber8 as IconHexagonNumber8,
    index_IconHexagonNumber8Filled as IconHexagonNumber8Filled,
    index_IconHexagonNumber9 as IconHexagonNumber9,
    index_IconHexagonNumber9Filled as IconHexagonNumber9Filled,
    index_IconHexagonOff as IconHexagonOff,
    index_IconHexagonPlus as IconHexagonPlus,
    index_IconHexagonPlus2 as IconHexagonPlus2,
    index_IconHexagonPlusFilled as IconHexagonPlusFilled,
    index_IconHexagonalPrism as IconHexagonalPrism,
    index_IconHexagonalPrismOff as IconHexagonalPrismOff,
    index_IconHexagonalPrismPlus as IconHexagonalPrismPlus,
    index_IconHexagonalPyramid as IconHexagonalPyramid,
    index_IconHexagonalPyramidOff as IconHexagonalPyramidOff,
    index_IconHexagonalPyramidPlus as IconHexagonalPyramidPlus,
    index_IconHexagons as IconHexagons,
    index_IconHexagonsOff as IconHexagonsOff,
    index_IconHierarchy as IconHierarchy,
    index_IconHierarchy2 as IconHierarchy2,
    index_IconHierarchy3 as IconHierarchy3,
    index_IconHierarchyOff as IconHierarchyOff,
    index_IconHighlight as IconHighlight,
    index_IconHighlightOff as IconHighlightOff,
    index_IconHistory as IconHistory,
    index_IconHistoryOff as IconHistoryOff,
    index_IconHistoryToggle as IconHistoryToggle,
    index_IconHome as IconHome,
    index_IconHome2 as IconHome2,
    index_IconHomeBitcoin as IconHomeBitcoin,
    index_IconHomeBolt as IconHomeBolt,
    index_IconHomeCancel as IconHomeCancel,
    index_IconHomeCheck as IconHomeCheck,
    index_IconHomeCog as IconHomeCog,
    index_IconHomeDollar as IconHomeDollar,
    index_IconHomeDot as IconHomeDot,
    index_IconHomeDown as IconHomeDown,
    index_IconHomeEco as IconHomeEco,
    index_IconHomeEdit as IconHomeEdit,
    index_IconHomeExclamation as IconHomeExclamation,
    index_IconHomeFilled as IconHomeFilled,
    index_IconHomeHand as IconHomeHand,
    index_IconHomeHeart as IconHomeHeart,
    index_IconHomeInfinity as IconHomeInfinity,
    index_IconHomeLink as IconHomeLink,
    index_IconHomeMinus as IconHomeMinus,
    index_IconHomeMove as IconHomeMove,
    index_IconHomeOff as IconHomeOff,
    index_IconHomePlus as IconHomePlus,
    index_IconHomeQuestion as IconHomeQuestion,
    index_IconHomeRibbon as IconHomeRibbon,
    index_IconHomeSearch as IconHomeSearch,
    index_IconHomeShare as IconHomeShare,
    index_IconHomeShield as IconHomeShield,
    index_IconHomeSignal as IconHomeSignal,
    index_IconHomeSpark as IconHomeSpark,
    index_IconHomeStar as IconHomeStar,
    index_IconHomeStats as IconHomeStats,
    index_IconHomeUp as IconHomeUp,
    index_IconHomeX as IconHomeX,
    index_IconHorse as IconHorse,
    index_IconHorseToy as IconHorseToy,
    index_IconHorseshoe as IconHorseshoe,
    index_IconHospital as IconHospital,
    index_IconHospitalCircle as IconHospitalCircle,
    index_IconHospitalCircleFilled as IconHospitalCircleFilled,
    index_IconHotelService as IconHotelService,
    index_IconHourglass as IconHourglass,
    index_IconHourglassEmpty as IconHourglassEmpty,
    index_IconHourglassFilled as IconHourglassFilled,
    index_IconHourglassHigh as IconHourglassHigh,
    index_IconHourglassLow as IconHourglassLow,
    index_IconHourglassOff as IconHourglassOff,
    index_IconHours12 as IconHours12,
    index_IconHours24 as IconHours24,
    index_IconHtml as IconHtml,
    index_IconHttpConnect as IconHttpConnect,
    index_IconHttpConnectOff as IconHttpConnectOff,
    index_IconHttpDelete as IconHttpDelete,
    index_IconHttpDeleteOff as IconHttpDeleteOff,
    index_IconHttpGet as IconHttpGet,
    index_IconHttpGetOff as IconHttpGetOff,
    index_IconHttpHead as IconHttpHead,
    index_IconHttpHeadOff as IconHttpHeadOff,
    index_IconHttpOptions as IconHttpOptions,
    index_IconHttpOptionsOff as IconHttpOptionsOff,
    index_IconHttpPatch as IconHttpPatch,
    index_IconHttpPatchOff as IconHttpPatchOff,
    index_IconHttpPost as IconHttpPost,
    index_IconHttpPostOff as IconHttpPostOff,
    index_IconHttpPut as IconHttpPut,
    index_IconHttpPutOff as IconHttpPutOff,
    index_IconHttpQue as IconHttpQue,
    index_IconHttpQueOff as IconHttpQueOff,
    index_IconHttpTrace as IconHttpTrace,
    index_IconHttpTraceOff as IconHttpTraceOff,
    index_IconIceCream as IconIceCream,
    index_IconIceCream2 as IconIceCream2,
    index_IconIceCreamOff as IconIceCreamOff,
    index_IconIceSkating as IconIceSkating,
    index_IconIcons as IconIcons,
    index_IconIconsFilled as IconIconsFilled,
    index_IconIconsOff as IconIconsOff,
    index_IconId as IconId,
    index_IconIdBadge as IconIdBadge,
    index_IconIdBadge2 as IconIdBadge2,
    index_IconIdBadgeOff as IconIdBadgeOff,
    index_IconIdOff as IconIdOff,
    index_IconIkosaedr as IconIkosaedr,
    index_IconImageInPicture as IconImageInPicture,
    index_IconInbox as IconInbox,
    index_IconInboxOff as IconInboxOff,
    index_IconIndentDecrease as IconIndentDecrease,
    index_IconIndentIncrease as IconIndentIncrease,
    index_IconInfinity as IconInfinity,
    index_IconInfinityOff as IconInfinityOff,
    index_IconInfoCircle as IconInfoCircle,
    index_IconInfoCircleFilled as IconInfoCircleFilled,
    index_IconInfoHexagon as IconInfoHexagon,
    index_IconInfoHexagonFilled as IconInfoHexagonFilled,
    index_IconInfoOctagon as IconInfoOctagon,
    index_IconInfoOctagonFilled as IconInfoOctagonFilled,
    index_IconInfoSmall as IconInfoSmall,
    index_IconInfoSquare as IconInfoSquare,
    index_IconInfoSquareFilled as IconInfoSquareFilled,
    index_IconInfoSquareRounded as IconInfoSquareRounded,
    index_IconInfoSquareRoundedFilled as IconInfoSquareRoundedFilled,
    index_IconInfoTriangle as IconInfoTriangle,
    index_IconInfoTriangleFilled as IconInfoTriangleFilled,
    index_IconInnerShadowBottom as IconInnerShadowBottom,
    index_IconInnerShadowBottomFilled as IconInnerShadowBottomFilled,
    index_IconInnerShadowBottomLeft as IconInnerShadowBottomLeft,
    index_IconInnerShadowBottomLeftFilled as IconInnerShadowBottomLeftFilled,
    index_IconInnerShadowBottomRight as IconInnerShadowBottomRight,
    index_IconInnerShadowBottomRightFilled as IconInnerShadowBottomRightFilled,
    index_IconInnerShadowLeft as IconInnerShadowLeft,
    index_IconInnerShadowLeftFilled as IconInnerShadowLeftFilled,
    index_IconInnerShadowRight as IconInnerShadowRight,
    index_IconInnerShadowRightFilled as IconInnerShadowRightFilled,
    index_IconInnerShadowTop as IconInnerShadowTop,
    index_IconInnerShadowTopFilled as IconInnerShadowTopFilled,
    index_IconInnerShadowTopLeft as IconInnerShadowTopLeft,
    index_IconInnerShadowTopLeftFilled as IconInnerShadowTopLeftFilled,
    index_IconInnerShadowTopRight as IconInnerShadowTopRight,
    index_IconInnerShadowTopRightFilled as IconInnerShadowTopRightFilled,
    index_IconInputAi as IconInputAi,
    index_IconInputCheck as IconInputCheck,
    index_IconInputSearch as IconInputSearch,
    index_IconInputSpark as IconInputSpark,
    index_IconInputX as IconInputX,
    index_IconInvoice as IconInvoice,
    index_IconIroning as IconIroning,
    index_IconIroning1 as IconIroning1,
    index_IconIroning1Filled as IconIroning1Filled,
    index_IconIroning2 as IconIroning2,
    index_IconIroning2Filled as IconIroning2Filled,
    index_IconIroning3 as IconIroning3,
    index_IconIroning3Filled as IconIroning3Filled,
    index_IconIroningFilled as IconIroningFilled,
    index_IconIroningOff as IconIroningOff,
    index_IconIroningSteam as IconIroningSteam,
    index_IconIroningSteamFilled as IconIroningSteamFilled,
    index_IconIroningSteamOff as IconIroningSteamOff,
    index_IconIrregularPolyhedron as IconIrregularPolyhedron,
    index_IconIrregularPolyhedronOff as IconIrregularPolyhedronOff,
    index_IconIrregularPolyhedronPlus as IconIrregularPolyhedronPlus,
    index_IconItalic as IconItalic,
    index_IconJacket as IconJacket,
    index_IconJetpack as IconJetpack,
    index_IconJetpackFilled as IconJetpackFilled,
    index_IconJewishStar as IconJewishStar,
    index_IconJewishStarFilled as IconJewishStarFilled,
    index_IconJoinBevel as IconJoinBevel,
    index_IconJoinRound as IconJoinRound,
    index_IconJoinStraight as IconJoinStraight,
    index_IconJoker as IconJoker,
    index_IconJpg as IconJpg,
    index_IconJson as IconJson,
    index_IconJumpRope as IconJumpRope,
    index_IconKarate as IconKarate,
    index_IconKayak as IconKayak,
    index_IconKerning as IconKerning,
    index_IconKey as IconKey,
    index_IconKeyFilled as IconKeyFilled,
    index_IconKeyOff as IconKeyOff,
    index_IconKeyboard as IconKeyboard,
    index_IconKeyboardFilled as IconKeyboardFilled,
    index_IconKeyboardHide as IconKeyboardHide,
    index_IconKeyboardOff as IconKeyboardOff,
    index_IconKeyboardShow as IconKeyboardShow,
    index_IconKeyframe as IconKeyframe,
    index_IconKeyframeAlignCenter as IconKeyframeAlignCenter,
    index_IconKeyframeAlignCenterFilled as IconKeyframeAlignCenterFilled,
    index_IconKeyframeAlignHorizontal as IconKeyframeAlignHorizontal,
    index_IconKeyframeAlignHorizontalFilled as IconKeyframeAlignHorizontalFilled,
    index_IconKeyframeAlignVertical as IconKeyframeAlignVertical,
    index_IconKeyframeAlignVerticalFilled as IconKeyframeAlignVerticalFilled,
    index_IconKeyframeFilled as IconKeyframeFilled,
    index_IconKeyframes as IconKeyframes,
    index_IconKeyframesFilled as IconKeyframesFilled,
    index_IconLabel as IconLabel,
    index_IconLabelFilled as IconLabelFilled,
    index_IconLabelImportant as IconLabelImportant,
    index_IconLabelImportantFilled as IconLabelImportantFilled,
    index_IconLabelOff as IconLabelOff,
    index_IconLadder as IconLadder,
    index_IconLadderOff as IconLadderOff,
    index_IconLadle as IconLadle,
    index_IconLambda as IconLambda,
    index_IconLamp as IconLamp,
    index_IconLamp2 as IconLamp2,
    index_IconLampOff as IconLampOff,
    index_IconLane as IconLane,
    index_IconLanguage as IconLanguage,
    index_IconLanguageHiragana as IconLanguageHiragana,
    index_IconLanguageKatakana as IconLanguageKatakana,
    index_IconLanguageOff as IconLanguageOff,
    index_IconLasso as IconLasso,
    index_IconLassoOff as IconLassoOff,
    index_IconLassoPolygon as IconLassoPolygon,
    index_IconLassoPolygonFilled as IconLassoPolygonFilled,
    index_IconLaurelWreath as IconLaurelWreath,
    index_IconLaurelWreath1 as IconLaurelWreath1,
    index_IconLaurelWreath1Filled as IconLaurelWreath1Filled,
    index_IconLaurelWreath2 as IconLaurelWreath2,
    index_IconLaurelWreath2Filled as IconLaurelWreath2Filled,
    index_IconLaurelWreath3 as IconLaurelWreath3,
    index_IconLaurelWreath3Filled as IconLaurelWreath3Filled,
    index_IconLaurelWreathFilled as IconLaurelWreathFilled,
    index_IconLayersDifference as IconLayersDifference,
    index_IconLayersIntersect as IconLayersIntersect,
    index_IconLayersIntersect2 as IconLayersIntersect2,
    index_IconLayersLinked as IconLayersLinked,
    index_IconLayersOff as IconLayersOff,
    index_IconLayersSelected as IconLayersSelected,
    index_IconLayersSelectedBottom as IconLayersSelectedBottom,
    index_IconLayersSubtract as IconLayersSubtract,
    index_IconLayersUnion as IconLayersUnion,
    index_IconLayout as IconLayout,
    index_IconLayout2 as IconLayout2,
    index_IconLayout2Filled as IconLayout2Filled,
    index_IconLayoutAlignBottom as IconLayoutAlignBottom,
    index_IconLayoutAlignBottomFilled as IconLayoutAlignBottomFilled,
    index_IconLayoutAlignCenter as IconLayoutAlignCenter,
    index_IconLayoutAlignCenterFilled as IconLayoutAlignCenterFilled,
    index_IconLayoutAlignLeft as IconLayoutAlignLeft,
    index_IconLayoutAlignLeftFilled as IconLayoutAlignLeftFilled,
    index_IconLayoutAlignMiddle as IconLayoutAlignMiddle,
    index_IconLayoutAlignMiddleFilled as IconLayoutAlignMiddleFilled,
    index_IconLayoutAlignRight as IconLayoutAlignRight,
    index_IconLayoutAlignRightFilled as IconLayoutAlignRightFilled,
    index_IconLayoutAlignTop as IconLayoutAlignTop,
    index_IconLayoutAlignTopFilled as IconLayoutAlignTopFilled,
    index_IconLayoutBoard as IconLayoutBoard,
    index_IconLayoutBoardFilled as IconLayoutBoardFilled,
    index_IconLayoutBoardSplit as IconLayoutBoardSplit,
    index_IconLayoutBoardSplitFilled as IconLayoutBoardSplitFilled,
    index_IconLayoutBottombar as IconLayoutBottombar,
    index_IconLayoutBottombarCollapse as IconLayoutBottombarCollapse,
    index_IconLayoutBottombarCollapseFilled as IconLayoutBottombarCollapseFilled,
    index_IconLayoutBottombarExpand as IconLayoutBottombarExpand,
    index_IconLayoutBottombarExpandFilled as IconLayoutBottombarExpandFilled,
    index_IconLayoutBottombarFilled as IconLayoutBottombarFilled,
    index_IconLayoutBottombarInactive as IconLayoutBottombarInactive,
    index_IconLayoutCards as IconLayoutCards,
    index_IconLayoutCardsFilled as IconLayoutCardsFilled,
    index_IconLayoutCollage as IconLayoutCollage,
    index_IconLayoutColumns as IconLayoutColumns,
    index_IconLayoutDashboard as IconLayoutDashboard,
    index_IconLayoutDashboardFilled as IconLayoutDashboardFilled,
    index_IconLayoutDistributeHorizontal as IconLayoutDistributeHorizontal,
    index_IconLayoutDistributeHorizontalFilled as IconLayoutDistributeHorizontalFilled,
    index_IconLayoutDistributeVertical as IconLayoutDistributeVertical,
    index_IconLayoutDistributeVerticalFilled as IconLayoutDistributeVerticalFilled,
    index_IconLayoutFilled as IconLayoutFilled,
    index_IconLayoutGrid as IconLayoutGrid,
    index_IconLayoutGridAdd as IconLayoutGridAdd,
    index_IconLayoutGridFilled as IconLayoutGridFilled,
    index_IconLayoutGridRemove as IconLayoutGridRemove,
    index_IconLayoutKanban as IconLayoutKanban,
    index_IconLayoutKanbanFilled as IconLayoutKanbanFilled,
    index_IconLayoutList as IconLayoutList,
    index_IconLayoutListFilled as IconLayoutListFilled,
    index_IconLayoutNavbar as IconLayoutNavbar,
    index_IconLayoutNavbarCollapse as IconLayoutNavbarCollapse,
    index_IconLayoutNavbarCollapseFilled as IconLayoutNavbarCollapseFilled,
    index_IconLayoutNavbarExpand as IconLayoutNavbarExpand,
    index_IconLayoutNavbarExpandFilled as IconLayoutNavbarExpandFilled,
    index_IconLayoutNavbarFilled as IconLayoutNavbarFilled,
    index_IconLayoutNavbarInactive as IconLayoutNavbarInactive,
    index_IconLayoutOff as IconLayoutOff,
    index_IconLayoutRows as IconLayoutRows,
    index_IconLayoutSidebar as IconLayoutSidebar,
    index_IconLayoutSidebarFilled as IconLayoutSidebarFilled,
    index_IconLayoutSidebarInactive as IconLayoutSidebarInactive,
    index_IconLayoutSidebarLeftCollapse as IconLayoutSidebarLeftCollapse,
    index_IconLayoutSidebarLeftCollapseFilled as IconLayoutSidebarLeftCollapseFilled,
    index_IconLayoutSidebarLeftExpand as IconLayoutSidebarLeftExpand,
    index_IconLayoutSidebarLeftExpandFilled as IconLayoutSidebarLeftExpandFilled,
    index_IconLayoutSidebarRight as IconLayoutSidebarRight,
    index_IconLayoutSidebarRightCollapse as IconLayoutSidebarRightCollapse,
    index_IconLayoutSidebarRightCollapseFilled as IconLayoutSidebarRightCollapseFilled,
    index_IconLayoutSidebarRightExpand as IconLayoutSidebarRightExpand,
    index_IconLayoutSidebarRightExpandFilled as IconLayoutSidebarRightExpandFilled,
    index_IconLayoutSidebarRightFilled as IconLayoutSidebarRightFilled,
    index_IconLayoutSidebarRightInactive as IconLayoutSidebarRightInactive,
    index_IconLeaf as IconLeaf,
    index_IconLeaf2 as IconLeaf2,
    index_IconLeafFilled as IconLeafFilled,
    index_IconLeafOff as IconLeafOff,
    index_IconLego as IconLego,
    index_IconLegoFilled as IconLegoFilled,
    index_IconLegoOff as IconLegoOff,
    index_IconLemon as IconLemon,
    index_IconLemon2 as IconLemon2,
    index_IconLemon2Filled as IconLemon2Filled,
    index_IconLetterA as IconLetterA,
    index_IconLetterASmall as IconLetterASmall,
    index_IconLetterB as IconLetterB,
    index_IconLetterBSmall as IconLetterBSmall,
    index_IconLetterC as IconLetterC,
    index_IconLetterCSmall as IconLetterCSmall,
    index_IconLetterCase as IconLetterCase,
    index_IconLetterCaseLower as IconLetterCaseLower,
    index_IconLetterCaseToggle as IconLetterCaseToggle,
    index_IconLetterCaseUpper as IconLetterCaseUpper,
    index_IconLetterD as IconLetterD,
    index_IconLetterDSmall as IconLetterDSmall,
    index_IconLetterE as IconLetterE,
    index_IconLetterESmall as IconLetterESmall,
    index_IconLetterF as IconLetterF,
    index_IconLetterFSmall as IconLetterFSmall,
    index_IconLetterG as IconLetterG,
    index_IconLetterGSmall as IconLetterGSmall,
    index_IconLetterH as IconLetterH,
    index_IconLetterHSmall as IconLetterHSmall,
    index_IconLetterI as IconLetterI,
    index_IconLetterISmall as IconLetterISmall,
    index_IconLetterJ as IconLetterJ,
    index_IconLetterJSmall as IconLetterJSmall,
    index_IconLetterK as IconLetterK,
    index_IconLetterKSmall as IconLetterKSmall,
    index_IconLetterL as IconLetterL,
    index_IconLetterLSmall as IconLetterLSmall,
    index_IconLetterM as IconLetterM,
    index_IconLetterMSmall as IconLetterMSmall,
    index_IconLetterN as IconLetterN,
    index_IconLetterNSmall as IconLetterNSmall,
    index_IconLetterO as IconLetterO,
    index_IconLetterOSmall as IconLetterOSmall,
    index_IconLetterP as IconLetterP,
    index_IconLetterPSmall as IconLetterPSmall,
    index_IconLetterQ as IconLetterQ,
    index_IconLetterQSmall as IconLetterQSmall,
    index_IconLetterR as IconLetterR,
    index_IconLetterRSmall as IconLetterRSmall,
    index_IconLetterS as IconLetterS,
    index_IconLetterSSmall as IconLetterSSmall,
    index_IconLetterSpacing as IconLetterSpacing,
    index_IconLetterT as IconLetterT,
    index_IconLetterTSmall as IconLetterTSmall,
    index_IconLetterU as IconLetterU,
    index_IconLetterUSmall as IconLetterUSmall,
    index_IconLetterV as IconLetterV,
    index_IconLetterVSmall as IconLetterVSmall,
    index_IconLetterW as IconLetterW,
    index_IconLetterWSmall as IconLetterWSmall,
    index_IconLetterX as IconLetterX,
    index_IconLetterXSmall as IconLetterXSmall,
    index_IconLetterY as IconLetterY,
    index_IconLetterYSmall as IconLetterYSmall,
    index_IconLetterZ as IconLetterZ,
    index_IconLetterZSmall as IconLetterZSmall,
    index_IconLibrary as IconLibrary,
    index_IconLibraryFilled as IconLibraryFilled,
    index_IconLibraryMinus as IconLibraryMinus,
    index_IconLibraryPhoto as IconLibraryPhoto,
    index_IconLibraryPlus as IconLibraryPlus,
    index_IconLibraryPlusFilled as IconLibraryPlusFilled,
    index_IconLicense as IconLicense,
    index_IconLicenseOff as IconLicenseOff,
    index_IconLifebuoy as IconLifebuoy,
    index_IconLifebuoyFilled as IconLifebuoyFilled,
    index_IconLifebuoyOff as IconLifebuoyOff,
    index_IconLighter as IconLighter,
    index_IconLine as IconLine,
    index_IconLineDashed as IconLineDashed,
    index_IconLineDotted as IconLineDotted,
    index_IconLineHeight as IconLineHeight,
    index_IconLineScan as IconLineScan,
    index_IconLink as IconLink,
    index_IconLinkMinus as IconLinkMinus,
    index_IconLinkOff as IconLinkOff,
    index_IconLinkPlus as IconLinkPlus,
    index_IconList as IconList,
    index_IconListCheck as IconListCheck,
    index_IconListDetails as IconListDetails,
    index_IconListLetters as IconListLetters,
    index_IconListNumbers as IconListNumbers,
    index_IconListSearch as IconListSearch,
    index_IconListTree as IconListTree,
    index_IconLivePhoto as IconLivePhoto,
    index_IconLivePhotoFilled as IconLivePhotoFilled,
    index_IconLivePhotoOff as IconLivePhotoOff,
    index_IconLiveView as IconLiveView,
    index_IconLiveViewFilled as IconLiveViewFilled,
    index_IconLoadBalancer as IconLoadBalancer,
    index_IconLoader as IconLoader,
    index_IconLoader2 as IconLoader2,
    index_IconLoader3 as IconLoader3,
    index_IconLoaderQuarter as IconLoaderQuarter,
    index_IconLocation as IconLocation,
    index_IconLocationBolt as IconLocationBolt,
    index_IconLocationBroken as IconLocationBroken,
    index_IconLocationCancel as IconLocationCancel,
    index_IconLocationCheck as IconLocationCheck,
    index_IconLocationCode as IconLocationCode,
    index_IconLocationCog as IconLocationCog,
    index_IconLocationDiscount as IconLocationDiscount,
    index_IconLocationDollar as IconLocationDollar,
    index_IconLocationDown as IconLocationDown,
    index_IconLocationExclamation as IconLocationExclamation,
    index_IconLocationFilled as IconLocationFilled,
    index_IconLocationHeart as IconLocationHeart,
    index_IconLocationMinus as IconLocationMinus,
    index_IconLocationOff as IconLocationOff,
    index_IconLocationPause as IconLocationPause,
    index_IconLocationPin as IconLocationPin,
    index_IconLocationPlus as IconLocationPlus,
    index_IconLocationQuestion as IconLocationQuestion,
    index_IconLocationSearch as IconLocationSearch,
    index_IconLocationShare as IconLocationShare,
    index_IconLocationStar as IconLocationStar,
    index_IconLocationUp as IconLocationUp,
    index_IconLocationX as IconLocationX,
    index_IconLock as IconLock,
    index_IconLockAccess as IconLockAccess,
    index_IconLockAccessOff as IconLockAccessOff,
    index_IconLockBitcoin as IconLockBitcoin,
    index_IconLockBolt as IconLockBolt,
    index_IconLockCancel as IconLockCancel,
    index_IconLockCheck as IconLockCheck,
    index_IconLockCode as IconLockCode,
    index_IconLockCog as IconLockCog,
    index_IconLockDollar as IconLockDollar,
    index_IconLockDown as IconLockDown,
    index_IconLockExclamation as IconLockExclamation,
    index_IconLockFilled as IconLockFilled,
    index_IconLockHeart as IconLockHeart,
    index_IconLockMinus as IconLockMinus,
    index_IconLockOff as IconLockOff,
    index_IconLockOpen as IconLockOpen,
    index_IconLockOpen2 as IconLockOpen2,
    index_IconLockOpenOff as IconLockOpenOff,
    index_IconLockPassword as IconLockPassword,
    index_IconLockPause as IconLockPause,
    index_IconLockPin as IconLockPin,
    index_IconLockPlus as IconLockPlus,
    index_IconLockQuestion as IconLockQuestion,
    index_IconLockSearch as IconLockSearch,
    index_IconLockShare as IconLockShare,
    index_IconLockSquare as IconLockSquare,
    index_IconLockSquareRounded as IconLockSquareRounded,
    index_IconLockSquareRoundedFilled as IconLockSquareRoundedFilled,
    index_IconLockStar as IconLockStar,
    index_IconLockUp as IconLockUp,
    index_IconLockX as IconLockX,
    index_IconLogicAnd as IconLogicAnd,
    index_IconLogicBuffer as IconLogicBuffer,
    index_IconLogicNand as IconLogicNand,
    index_IconLogicNor as IconLogicNor,
    index_IconLogicNot as IconLogicNot,
    index_IconLogicOr as IconLogicOr,
    index_IconLogicXnor as IconLogicXnor,
    index_IconLogicXor as IconLogicXor,
    index_IconLogin as IconLogin,
    index_IconLogin2 as IconLogin2,
    index_IconLogout as IconLogout,
    index_IconLogout2 as IconLogout2,
    index_IconLogs as IconLogs,
    index_IconLollipop as IconLollipop,
    index_IconLollipopOff as IconLollipopOff,
    index_IconLuggage as IconLuggage,
    index_IconLuggageOff as IconLuggageOff,
    index_IconLungs as IconLungs,
    index_IconLungsFilled as IconLungsFilled,
    index_IconLungsOff as IconLungsOff,
    index_IconMacro as IconMacro,
    index_IconMacroFilled as IconMacroFilled,
    index_IconMacroOff as IconMacroOff,
    index_IconMagnet as IconMagnet,
    index_IconMagnetFilled as IconMagnetFilled,
    index_IconMagnetOff as IconMagnetOff,
    index_IconMagnetic as IconMagnetic,
    index_IconMail as IconMail,
    index_IconMailAi as IconMailAi,
    index_IconMailBitcoin as IconMailBitcoin,
    index_IconMailBolt as IconMailBolt,
    index_IconMailCancel as IconMailCancel,
    index_IconMailCheck as IconMailCheck,
    index_IconMailCode as IconMailCode,
    index_IconMailCog as IconMailCog,
    index_IconMailDollar as IconMailDollar,
    index_IconMailDown as IconMailDown,
    index_IconMailExclamation as IconMailExclamation,
    index_IconMailFast as IconMailFast,
    index_IconMailFilled as IconMailFilled,
    index_IconMailForward as IconMailForward,
    index_IconMailHeart as IconMailHeart,
    index_IconMailMinus as IconMailMinus,
    index_IconMailOff as IconMailOff,
    index_IconMailOpened as IconMailOpened,
    index_IconMailOpenedFilled as IconMailOpenedFilled,
    index_IconMailPause as IconMailPause,
    index_IconMailPin as IconMailPin,
    index_IconMailPlus as IconMailPlus,
    index_IconMailQuestion as IconMailQuestion,
    index_IconMailSearch as IconMailSearch,
    index_IconMailShare as IconMailShare,
    index_IconMailSpark as IconMailSpark,
    index_IconMailStar as IconMailStar,
    index_IconMailUp as IconMailUp,
    index_IconMailX as IconMailX,
    index_IconMailbox as IconMailbox,
    index_IconMailboxOff as IconMailboxOff,
    index_IconMan as IconMan,
    index_IconManFilled as IconManFilled,
    index_IconManualGearbox as IconManualGearbox,
    index_IconManualGearboxFilled as IconManualGearboxFilled,
    index_IconMap as IconMap,
    index_IconMap2 as IconMap2,
    index_IconMapBolt as IconMapBolt,
    index_IconMapCancel as IconMapCancel,
    index_IconMapCheck as IconMapCheck,
    index_IconMapCode as IconMapCode,
    index_IconMapCog as IconMapCog,
    index_IconMapDiscount as IconMapDiscount,
    index_IconMapDollar as IconMapDollar,
    index_IconMapDown as IconMapDown,
    index_IconMapEast as IconMapEast,
    index_IconMapExclamation as IconMapExclamation,
    index_IconMapHeart as IconMapHeart,
    index_IconMapMinus as IconMapMinus,
    index_IconMapNorth as IconMapNorth,
    index_IconMapOff as IconMapOff,
    index_IconMapPause as IconMapPause,
    index_IconMapPin as IconMapPin,
    index_IconMapPin2 as IconMapPin2,
    index_IconMapPinBolt as IconMapPinBolt,
    index_IconMapPinCancel as IconMapPinCancel,
    index_IconMapPinCheck as IconMapPinCheck,
    index_IconMapPinCode as IconMapPinCode,
    index_IconMapPinCog as IconMapPinCog,
    index_IconMapPinDollar as IconMapPinDollar,
    index_IconMapPinDown as IconMapPinDown,
    index_IconMapPinExclamation as IconMapPinExclamation,
    index_IconMapPinFilled as IconMapPinFilled,
    index_IconMapPinHeart as IconMapPinHeart,
    index_IconMapPinMinus as IconMapPinMinus,
    index_IconMapPinOff as IconMapPinOff,
    index_IconMapPinPause as IconMapPinPause,
    index_IconMapPinPin as IconMapPinPin,
    index_IconMapPinPlus as IconMapPinPlus,
    index_IconMapPinQuestion as IconMapPinQuestion,
    index_IconMapPinSearch as IconMapPinSearch,
    index_IconMapPinShare as IconMapPinShare,
    index_IconMapPinStar as IconMapPinStar,
    index_IconMapPinUp as IconMapPinUp,
    index_IconMapPinX as IconMapPinX,
    index_IconMapPins as IconMapPins,
    index_IconMapPlus as IconMapPlus,
    index_IconMapQuestion as IconMapQuestion,
    index_IconMapRoute as IconMapRoute,
    index_IconMapSearch as IconMapSearch,
    index_IconMapShare as IconMapShare,
    index_IconMapSouth as IconMapSouth,
    index_IconMapStar as IconMapStar,
    index_IconMapUp as IconMapUp,
    index_IconMapWest as IconMapWest,
    index_IconMapX as IconMapX,
    index_IconMarkdown as IconMarkdown,
    index_IconMarkdownOff as IconMarkdownOff,
    index_IconMarquee as IconMarquee,
    index_IconMarquee2 as IconMarquee2,
    index_IconMarqueeOff as IconMarqueeOff,
    index_IconMars as IconMars,
    index_IconMask as IconMask,
    index_IconMaskOff as IconMaskOff,
    index_IconMasksTheater as IconMasksTheater,
    index_IconMasksTheaterOff as IconMasksTheaterOff,
    index_IconMassage as IconMassage,
    index_IconMatchstick as IconMatchstick,
    index_IconMath as IconMath,
    index_IconMath1Divide2 as IconMath1Divide2,
    index_IconMath1Divide3 as IconMath1Divide3,
    index_IconMathAvg as IconMathAvg,
    index_IconMathCos as IconMathCos,
    index_IconMathCtg as IconMathCtg,
    index_IconMathEqualGreater as IconMathEqualGreater,
    index_IconMathEqualLower as IconMathEqualLower,
    index_IconMathFunction as IconMathFunction,
    index_IconMathFunctionOff as IconMathFunctionOff,
    index_IconMathFunctionY as IconMathFunctionY,
    index_IconMathGreater as IconMathGreater,
    index_IconMathIntegral as IconMathIntegral,
    index_IconMathIntegralX as IconMathIntegralX,
    index_IconMathIntegrals as IconMathIntegrals,
    index_IconMathLower as IconMathLower,
    index_IconMathMax as IconMathMax,
    index_IconMathMaxMin as IconMathMaxMin,
    index_IconMathMin as IconMathMin,
    index_IconMathNot as IconMathNot,
    index_IconMathOff as IconMathOff,
    index_IconMathPi as IconMathPi,
    index_IconMathPiDivide2 as IconMathPiDivide2,
    index_IconMathSec as IconMathSec,
    index_IconMathSin as IconMathSin,
    index_IconMathSymbols as IconMathSymbols,
    index_IconMathTg as IconMathTg,
    index_IconMathXDivide2 as IconMathXDivide2,
    index_IconMathXDivideY as IconMathXDivideY,
    index_IconMathXDivideY2 as IconMathXDivideY2,
    index_IconMathXFloorDivideY as IconMathXFloorDivideY,
    index_IconMathXMinusX as IconMathXMinusX,
    index_IconMathXMinusY as IconMathXMinusY,
    index_IconMathXPlusX as IconMathXPlusX,
    index_IconMathXPlusY as IconMathXPlusY,
    index_IconMathXy as IconMathXy,
    index_IconMathYMinusY as IconMathYMinusY,
    index_IconMathYPlusY as IconMathYPlusY,
    index_IconMatrix as IconMatrix,
    index_IconMaximize as IconMaximize,
    index_IconMaximizeOff as IconMaximizeOff,
    index_IconMeat as IconMeat,
    index_IconMeatOff as IconMeatOff,
    index_IconMedal as IconMedal,
    index_IconMedal2 as IconMedal2,
    index_IconMedicalCross as IconMedicalCross,
    index_IconMedicalCrossCircle as IconMedicalCrossCircle,
    index_IconMedicalCrossFilled as IconMedicalCrossFilled,
    index_IconMedicalCrossOff as IconMedicalCrossOff,
    index_IconMedicineSyrup as IconMedicineSyrup,
    index_IconMeeple as IconMeeple,
    index_IconMeepleFilled as IconMeepleFilled,
    index_IconMelon as IconMelon,
    index_IconMelonFilled as IconMelonFilled,
    index_IconMenorah as IconMenorah,
    index_IconMenu as IconMenu,
    index_IconMenu2 as IconMenu2,
    index_IconMenu3 as IconMenu3,
    index_IconMenu4 as IconMenu4,
    index_IconMenuDeep as IconMenuDeep,
    index_IconMenuOrder as IconMenuOrder,
    index_IconMessage as IconMessage,
    index_IconMessage2 as IconMessage2,
    index_IconMessage2Bolt as IconMessage2Bolt,
    index_IconMessage2Cancel as IconMessage2Cancel,
    index_IconMessage2Check as IconMessage2Check,
    index_IconMessage2Code as IconMessage2Code,
    index_IconMessage2Cog as IconMessage2Cog,
    index_IconMessage2Dollar as IconMessage2Dollar,
    index_IconMessage2Down as IconMessage2Down,
    index_IconMessage2Exclamation as IconMessage2Exclamation,
    index_IconMessage2Filled as IconMessage2Filled,
    index_IconMessage2Heart as IconMessage2Heart,
    index_IconMessage2Minus as IconMessage2Minus,
    index_IconMessage2Off as IconMessage2Off,
    index_IconMessage2Pause as IconMessage2Pause,
    index_IconMessage2Pin as IconMessage2Pin,
    index_IconMessage2Plus as IconMessage2Plus,
    index_IconMessage2Question as IconMessage2Question,
    index_IconMessage2Search as IconMessage2Search,
    index_IconMessage2Share as IconMessage2Share,
    index_IconMessage2Star as IconMessage2Star,
    index_IconMessage2Up as IconMessage2Up,
    index_IconMessage2X as IconMessage2X,
    index_IconMessageBolt as IconMessageBolt,
    index_IconMessageCancel as IconMessageCancel,
    index_IconMessageChatbot as IconMessageChatbot,
    index_IconMessageChatbotFilled as IconMessageChatbotFilled,
    index_IconMessageCheck as IconMessageCheck,
    index_IconMessageCircle as IconMessageCircle,
    index_IconMessageCircleBolt as IconMessageCircleBolt,
    index_IconMessageCircleCancel as IconMessageCircleCancel,
    index_IconMessageCircleCheck as IconMessageCircleCheck,
    index_IconMessageCircleCode as IconMessageCircleCode,
    index_IconMessageCircleCog as IconMessageCircleCog,
    index_IconMessageCircleDollar as IconMessageCircleDollar,
    index_IconMessageCircleDown as IconMessageCircleDown,
    index_IconMessageCircleExclamation as IconMessageCircleExclamation,
    index_IconMessageCircleFilled as IconMessageCircleFilled,
    index_IconMessageCircleHeart as IconMessageCircleHeart,
    index_IconMessageCircleMinus as IconMessageCircleMinus,
    index_IconMessageCircleOff as IconMessageCircleOff,
    index_IconMessageCirclePause as IconMessageCirclePause,
    index_IconMessageCirclePin as IconMessageCirclePin,
    index_IconMessageCirclePlus as IconMessageCirclePlus,
    index_IconMessageCircleQuestion as IconMessageCircleQuestion,
    index_IconMessageCircleSearch as IconMessageCircleSearch,
    index_IconMessageCircleShare as IconMessageCircleShare,
    index_IconMessageCircleStar as IconMessageCircleStar,
    index_IconMessageCircleUp as IconMessageCircleUp,
    index_IconMessageCircleUser as IconMessageCircleUser,
    index_IconMessageCircleX as IconMessageCircleX,
    index_IconMessageCode as IconMessageCode,
    index_IconMessageCog as IconMessageCog,
    index_IconMessageDollar as IconMessageDollar,
    index_IconMessageDots as IconMessageDots,
    index_IconMessageDown as IconMessageDown,
    index_IconMessageExclamation as IconMessageExclamation,
    index_IconMessageFilled as IconMessageFilled,
    index_IconMessageForward as IconMessageForward,
    index_IconMessageHeart as IconMessageHeart,
    index_IconMessageLanguage as IconMessageLanguage,
    index_IconMessageMinus as IconMessageMinus,
    index_IconMessageOff as IconMessageOff,
    index_IconMessagePause as IconMessagePause,
    index_IconMessagePin as IconMessagePin,
    index_IconMessagePlus as IconMessagePlus,
    index_IconMessageQuestion as IconMessageQuestion,
    index_IconMessageReply as IconMessageReply,
    index_IconMessageReport as IconMessageReport,
    index_IconMessageReportFilled as IconMessageReportFilled,
    index_IconMessageSearch as IconMessageSearch,
    index_IconMessageShare as IconMessageShare,
    index_IconMessageStar as IconMessageStar,
    index_IconMessageUp as IconMessageUp,
    index_IconMessageUser as IconMessageUser,
    index_IconMessageX as IconMessageX,
    index_IconMessages as IconMessages,
    index_IconMessagesOff as IconMessagesOff,
    index_IconMeteor as IconMeteor,
    index_IconMeteorFilled as IconMeteorFilled,
    index_IconMeteorOff as IconMeteorOff,
    index_IconMeterCube as IconMeterCube,
    index_IconMeterSquare as IconMeterSquare,
    index_IconMetronome as IconMetronome,
    index_IconMichelinBibGourmand as IconMichelinBibGourmand,
    index_IconMichelinStar as IconMichelinStar,
    index_IconMichelinStarFilled as IconMichelinStarFilled,
    index_IconMichelinStarGreen as IconMichelinStarGreen,
    index_IconMickey as IconMickey,
    index_IconMickeyFilled as IconMickeyFilled,
    index_IconMicrophone as IconMicrophone,
    index_IconMicrophone2 as IconMicrophone2,
    index_IconMicrophone2Off as IconMicrophone2Off,
    index_IconMicrophoneFilled as IconMicrophoneFilled,
    index_IconMicrophoneOff as IconMicrophoneOff,
    index_IconMicroscope as IconMicroscope,
    index_IconMicroscopeFilled as IconMicroscopeFilled,
    index_IconMicroscopeOff as IconMicroscopeOff,
    index_IconMicrowave as IconMicrowave,
    index_IconMicrowaveFilled as IconMicrowaveFilled,
    index_IconMicrowaveOff as IconMicrowaveOff,
    index_IconMilitaryAward as IconMilitaryAward,
    index_IconMilitaryRank as IconMilitaryRank,
    index_IconMilitaryRankFilled as IconMilitaryRankFilled,
    index_IconMilk as IconMilk,
    index_IconMilkFilled as IconMilkFilled,
    index_IconMilkOff as IconMilkOff,
    index_IconMilkshake as IconMilkshake,
    index_IconMinimize as IconMinimize,
    index_IconMinus as IconMinus,
    index_IconMinusVertical as IconMinusVertical,
    index_IconMist as IconMist,
    index_IconMistOff as IconMistOff,
    index_IconMobiledata as IconMobiledata,
    index_IconMobiledataOff as IconMobiledataOff,
    index_IconMoneybag as IconMoneybag,
    index_IconMoneybagEdit as IconMoneybagEdit,
    index_IconMoneybagHeart as IconMoneybagHeart,
    index_IconMoneybagMinus as IconMoneybagMinus,
    index_IconMoneybagMove as IconMoneybagMove,
    index_IconMoneybagMoveBack as IconMoneybagMoveBack,
    index_IconMoneybagPlus as IconMoneybagPlus,
    index_IconMonkeybar as IconMonkeybar,
    index_IconMoodAngry as IconMoodAngry,
    index_IconMoodAngryFilled as IconMoodAngryFilled,
    index_IconMoodAnnoyed as IconMoodAnnoyed,
    index_IconMoodAnnoyed2 as IconMoodAnnoyed2,
    index_IconMoodBitcoin as IconMoodBitcoin,
    index_IconMoodBoy as IconMoodBoy,
    index_IconMoodCheck as IconMoodCheck,
    index_IconMoodCog as IconMoodCog,
    index_IconMoodConfuzed as IconMoodConfuzed,
    index_IconMoodConfuzedFilled as IconMoodConfuzedFilled,
    index_IconMoodCrazyHappy as IconMoodCrazyHappy,
    index_IconMoodCrazyHappyFilled as IconMoodCrazyHappyFilled,
    index_IconMoodCry as IconMoodCry,
    index_IconMoodDollar as IconMoodDollar,
    index_IconMoodEdit as IconMoodEdit,
    index_IconMoodEmpty as IconMoodEmpty,
    index_IconMoodEmptyFilled as IconMoodEmptyFilled,
    index_IconMoodHappy as IconMoodHappy,
    index_IconMoodHappyFilled as IconMoodHappyFilled,
    index_IconMoodHeart as IconMoodHeart,
    index_IconMoodKid as IconMoodKid,
    index_IconMoodKidFilled as IconMoodKidFilled,
    index_IconMoodLookDown as IconMoodLookDown,
    index_IconMoodLookLeft as IconMoodLookLeft,
    index_IconMoodLookRight as IconMoodLookRight,
    index_IconMoodLookUp as IconMoodLookUp,
    index_IconMoodMinus as IconMoodMinus,
    index_IconMoodNerd as IconMoodNerd,
    index_IconMoodNervous as IconMoodNervous,
    index_IconMoodNeutral as IconMoodNeutral,
    index_IconMoodNeutralFilled as IconMoodNeutralFilled,
    index_IconMoodOff as IconMoodOff,
    index_IconMoodPin as IconMoodPin,
    index_IconMoodPlus as IconMoodPlus,
    index_IconMoodPuzzled as IconMoodPuzzled,
    index_IconMoodSad as IconMoodSad,
    index_IconMoodSad2 as IconMoodSad2,
    index_IconMoodSadDizzy as IconMoodSadDizzy,
    index_IconMoodSadFilled as IconMoodSadFilled,
    index_IconMoodSadSquint as IconMoodSadSquint,
    index_IconMoodSearch as IconMoodSearch,
    index_IconMoodShare as IconMoodShare,
    index_IconMoodSick as IconMoodSick,
    index_IconMoodSilence as IconMoodSilence,
    index_IconMoodSing as IconMoodSing,
    index_IconMoodSmile as IconMoodSmile,
    index_IconMoodSmileBeam as IconMoodSmileBeam,
    index_IconMoodSmileDizzy as IconMoodSmileDizzy,
    index_IconMoodSmileFilled as IconMoodSmileFilled,
    index_IconMoodSpark as IconMoodSpark,
    index_IconMoodSurprised as IconMoodSurprised,
    index_IconMoodTongue as IconMoodTongue,
    index_IconMoodTongueWink as IconMoodTongueWink,
    index_IconMoodTongueWink2 as IconMoodTongueWink2,
    index_IconMoodUnamused as IconMoodUnamused,
    index_IconMoodUp as IconMoodUp,
    index_IconMoodWink as IconMoodWink,
    index_IconMoodWink2 as IconMoodWink2,
    index_IconMoodWrrr as IconMoodWrrr,
    index_IconMoodWrrrFilled as IconMoodWrrrFilled,
    index_IconMoodX as IconMoodX,
    index_IconMoodXd as IconMoodXd,
    index_IconMoon as IconMoon,
    index_IconMoon2 as IconMoon2,
    index_IconMoonFilled as IconMoonFilled,
    index_IconMoonOff as IconMoonOff,
    index_IconMoonStars as IconMoonStars,
    index_IconMoped as IconMoped,
    index_IconMotorbike as IconMotorbike,
    index_IconMotorbikeFilled as IconMotorbikeFilled,
    index_IconMountain as IconMountain,
    index_IconMountainFilled as IconMountainFilled,
    index_IconMountainOff as IconMountainOff,
    index_IconMouse as IconMouse,
    index_IconMouse2 as IconMouse2,
    index_IconMouseFilled as IconMouseFilled,
    index_IconMouseOff as IconMouseOff,
    index_IconMoustache as IconMoustache,
    index_IconMovie as IconMovie,
    index_IconMovieOff as IconMovieOff,
    index_IconMug as IconMug,
    index_IconMugFilled as IconMugFilled,
    index_IconMugOff as IconMugOff,
    index_IconMultiplier05x as IconMultiplier05x,
    index_IconMultiplier15x as IconMultiplier15x,
    index_IconMultiplier1x as IconMultiplier1x,
    index_IconMultiplier2x as IconMultiplier2x,
    index_IconMushroom as IconMushroom,
    index_IconMushroomFilled as IconMushroomFilled,
    index_IconMushroomOff as IconMushroomOff,
    index_IconMusic as IconMusic,
    index_IconMusicBolt as IconMusicBolt,
    index_IconMusicCancel as IconMusicCancel,
    index_IconMusicCheck as IconMusicCheck,
    index_IconMusicCode as IconMusicCode,
    index_IconMusicCog as IconMusicCog,
    index_IconMusicDiscount as IconMusicDiscount,
    index_IconMusicDollar as IconMusicDollar,
    index_IconMusicDown as IconMusicDown,
    index_IconMusicExclamation as IconMusicExclamation,
    index_IconMusicHeart as IconMusicHeart,
    index_IconMusicMinus as IconMusicMinus,
    index_IconMusicOff as IconMusicOff,
    index_IconMusicPause as IconMusicPause,
    index_IconMusicPin as IconMusicPin,
    index_IconMusicPlus as IconMusicPlus,
    index_IconMusicQuestion as IconMusicQuestion,
    index_IconMusicSearch as IconMusicSearch,
    index_IconMusicShare as IconMusicShare,
    index_IconMusicStar as IconMusicStar,
    index_IconMusicUp as IconMusicUp,
    index_IconMusicX as IconMusicX,
    index_IconNavigation as IconNavigation,
    index_IconNavigationBolt as IconNavigationBolt,
    index_IconNavigationCancel as IconNavigationCancel,
    index_IconNavigationCheck as IconNavigationCheck,
    index_IconNavigationCode as IconNavigationCode,
    index_IconNavigationCog as IconNavigationCog,
    index_IconNavigationDiscount as IconNavigationDiscount,
    index_IconNavigationDollar as IconNavigationDollar,
    index_IconNavigationDown as IconNavigationDown,
    index_IconNavigationEast as IconNavigationEast,
    index_IconNavigationExclamation as IconNavigationExclamation,
    index_IconNavigationFilled as IconNavigationFilled,
    index_IconNavigationHeart as IconNavigationHeart,
    index_IconNavigationMinus as IconNavigationMinus,
    index_IconNavigationNorth as IconNavigationNorth,
    index_IconNavigationOff as IconNavigationOff,
    index_IconNavigationPause as IconNavigationPause,
    index_IconNavigationPin as IconNavigationPin,
    index_IconNavigationPlus as IconNavigationPlus,
    index_IconNavigationQuestion as IconNavigationQuestion,
    index_IconNavigationSearch as IconNavigationSearch,
    index_IconNavigationShare as IconNavigationShare,
    index_IconNavigationSouth as IconNavigationSouth,
    index_IconNavigationStar as IconNavigationStar,
    index_IconNavigationTop as IconNavigationTop,
    index_IconNavigationUp as IconNavigationUp,
    index_IconNavigationWest as IconNavigationWest,
    index_IconNavigationX as IconNavigationX,
    index_IconNeedle as IconNeedle,
    index_IconNeedleThread as IconNeedleThread,
    index_IconNetwork as IconNetwork,
    index_IconNetworkOff as IconNetworkOff,
    index_IconNewSection as IconNewSection,
    index_IconNews as IconNews,
    index_IconNewsOff as IconNewsOff,
    index_IconNfc as IconNfc,
    index_IconNfcOff as IconNfcOff,
    index_IconNoCopyright as IconNoCopyright,
    index_IconNoCreativeCommons as IconNoCreativeCommons,
    index_IconNoDerivatives as IconNoDerivatives,
    index_IconNorthStar as IconNorthStar,
    index_IconNote as IconNote,
    index_IconNoteOff as IconNoteOff,
    index_IconNotebook as IconNotebook,
    index_IconNotebookOff as IconNotebookOff,
    index_IconNotes as IconNotes,
    index_IconNotesOff as IconNotesOff,
    index_IconNotification as IconNotification,
    index_IconNotificationOff as IconNotificationOff,
    index_IconNumber as IconNumber,
    index_IconNumber0 as IconNumber0,
    index_IconNumber0Small as IconNumber0Small,
    index_IconNumber1 as IconNumber1,
    index_IconNumber10 as IconNumber10,
    index_IconNumber100Small as IconNumber100Small,
    index_IconNumber10Small as IconNumber10Small,
    index_IconNumber11 as IconNumber11,
    index_IconNumber11Small as IconNumber11Small,
    index_IconNumber123 as IconNumber123,
    index_IconNumber12Small as IconNumber12Small,
    index_IconNumber13Small as IconNumber13Small,
    index_IconNumber14Small as IconNumber14Small,
    index_IconNumber15Small as IconNumber15Small,
    index_IconNumber16Small as IconNumber16Small,
    index_IconNumber17Small as IconNumber17Small,
    index_IconNumber18Small as IconNumber18Small,
    index_IconNumber19Small as IconNumber19Small,
    index_IconNumber1Small as IconNumber1Small,
    index_IconNumber2 as IconNumber2,
    index_IconNumber20Small as IconNumber20Small,
    index_IconNumber21Small as IconNumber21Small,
    index_IconNumber22Small as IconNumber22Small,
    index_IconNumber23Small as IconNumber23Small,
    index_IconNumber24Small as IconNumber24Small,
    index_IconNumber25Small as IconNumber25Small,
    index_IconNumber26Small as IconNumber26Small,
    index_IconNumber27Small as IconNumber27Small,
    index_IconNumber28Small as IconNumber28Small,
    index_IconNumber29Small as IconNumber29Small,
    index_IconNumber2Small as IconNumber2Small,
    index_IconNumber3 as IconNumber3,
    index_IconNumber30Small as IconNumber30Small,
    index_IconNumber31Small as IconNumber31Small,
    index_IconNumber32Small as IconNumber32Small,
    index_IconNumber33Small as IconNumber33Small,
    index_IconNumber34Small as IconNumber34Small,
    index_IconNumber35Small as IconNumber35Small,
    index_IconNumber36Small as IconNumber36Small,
    index_IconNumber37Small as IconNumber37Small,
    index_IconNumber38Small as IconNumber38Small,
    index_IconNumber39Small as IconNumber39Small,
    index_IconNumber3Small as IconNumber3Small,
    index_IconNumber4 as IconNumber4,
    index_IconNumber40Small as IconNumber40Small,
    index_IconNumber41Small as IconNumber41Small,
    index_IconNumber42Small as IconNumber42Small,
    index_IconNumber43Small as IconNumber43Small,
    index_IconNumber44Small as IconNumber44Small,
    index_IconNumber45Small as IconNumber45Small,
    index_IconNumber46Small as IconNumber46Small,
    index_IconNumber47Small as IconNumber47Small,
    index_IconNumber48Small as IconNumber48Small,
    index_IconNumber49Small as IconNumber49Small,
    index_IconNumber4Small as IconNumber4Small,
    index_IconNumber5 as IconNumber5,
    index_IconNumber50Small as IconNumber50Small,
    index_IconNumber51Small as IconNumber51Small,
    index_IconNumber52Small as IconNumber52Small,
    index_IconNumber53Small as IconNumber53Small,
    index_IconNumber54Small as IconNumber54Small,
    index_IconNumber55Small as IconNumber55Small,
    index_IconNumber56Small as IconNumber56Small,
    index_IconNumber57Small as IconNumber57Small,
    index_IconNumber58Small as IconNumber58Small,
    index_IconNumber59Small as IconNumber59Small,
    index_IconNumber5Small as IconNumber5Small,
    index_IconNumber6 as IconNumber6,
    index_IconNumber60Small as IconNumber60Small,
    index_IconNumber61Small as IconNumber61Small,
    index_IconNumber62Small as IconNumber62Small,
    index_IconNumber63Small as IconNumber63Small,
    index_IconNumber64Small as IconNumber64Small,
    index_IconNumber65Small as IconNumber65Small,
    index_IconNumber66Small as IconNumber66Small,
    index_IconNumber67Small as IconNumber67Small,
    index_IconNumber68Small as IconNumber68Small,
    index_IconNumber69Small as IconNumber69Small,
    index_IconNumber6Small as IconNumber6Small,
    index_IconNumber7 as IconNumber7,
    index_IconNumber70Small as IconNumber70Small,
    index_IconNumber71Small as IconNumber71Small,
    index_IconNumber72Small as IconNumber72Small,
    index_IconNumber73Small as IconNumber73Small,
    index_IconNumber74Small as IconNumber74Small,
    index_IconNumber75Small as IconNumber75Small,
    index_IconNumber76Small as IconNumber76Small,
    index_IconNumber77Small as IconNumber77Small,
    index_IconNumber78Small as IconNumber78Small,
    index_IconNumber79Small as IconNumber79Small,
    index_IconNumber7Small as IconNumber7Small,
    index_IconNumber8 as IconNumber8,
    index_IconNumber80Small as IconNumber80Small,
    index_IconNumber81Small as IconNumber81Small,
    index_IconNumber82Small as IconNumber82Small,
    index_IconNumber83Small as IconNumber83Small,
    index_IconNumber84Small as IconNumber84Small,
    index_IconNumber85Small as IconNumber85Small,
    index_IconNumber86Small as IconNumber86Small,
    index_IconNumber87Small as IconNumber87Small,
    index_IconNumber88Small as IconNumber88Small,
    index_IconNumber89Small as IconNumber89Small,
    index_IconNumber8Small as IconNumber8Small,
    index_IconNumber9 as IconNumber9,
    index_IconNumber90Small as IconNumber90Small,
    index_IconNumber91Small as IconNumber91Small,
    index_IconNumber92Small as IconNumber92Small,
    index_IconNumber93Small as IconNumber93Small,
    index_IconNumber94Small as IconNumber94Small,
    index_IconNumber95Small as IconNumber95Small,
    index_IconNumber96Small as IconNumber96Small,
    index_IconNumber97Small as IconNumber97Small,
    index_IconNumber98Small as IconNumber98Small,
    index_IconNumber99Small as IconNumber99Small,
    index_IconNumber9Small as IconNumber9Small,
    index_IconNumbers as IconNumbers,
    index_IconNurse as IconNurse,
    index_IconNurseFilled as IconNurseFilled,
    index_IconNut as IconNut,
    index_IconObjectScan as IconObjectScan,
    index_IconOctagon as IconOctagon,
    index_IconOctagonFilled as IconOctagonFilled,
    index_IconOctagonMinus as IconOctagonMinus,
    index_IconOctagonMinus2 as IconOctagonMinus2,
    index_IconOctagonMinusFilled as IconOctagonMinusFilled,
    index_IconOctagonOff as IconOctagonOff,
    index_IconOctagonPlus as IconOctagonPlus,
    index_IconOctagonPlus2 as IconOctagonPlus2,
    index_IconOctagonPlusFilled as IconOctagonPlusFilled,
    index_IconOctahedron as IconOctahedron,
    index_IconOctahedronOff as IconOctahedronOff,
    index_IconOctahedronPlus as IconOctahedronPlus,
    index_IconOld as IconOld,
    index_IconOlympics as IconOlympics,
    index_IconOlympicsOff as IconOlympicsOff,
    index_IconOm as IconOm,
    index_IconOmega as IconOmega,
    index_IconOption as IconOption,
    index_IconOutbound as IconOutbound,
    index_IconOutlet as IconOutlet,
    index_IconOval as IconOval,
    index_IconOvalFilled as IconOvalFilled,
    index_IconOvalVertical as IconOvalVertical,
    index_IconOvalVerticalFilled as IconOvalVerticalFilled,
    index_IconOverline as IconOverline,
    index_IconPackage as IconPackage,
    index_IconPackageExport as IconPackageExport,
    index_IconPackageImport as IconPackageImport,
    index_IconPackageOff as IconPackageOff,
    index_IconPackages as IconPackages,
    index_IconPacman as IconPacman,
    index_IconPacmanFilled as IconPacmanFilled,
    index_IconPageBreak as IconPageBreak,
    index_IconPaint as IconPaint,
    index_IconPaintFilled as IconPaintFilled,
    index_IconPaintOff as IconPaintOff,
    index_IconPalette as IconPalette,
    index_IconPaletteFilled as IconPaletteFilled,
    index_IconPaletteOff as IconPaletteOff,
    index_IconPanoramaHorizontal as IconPanoramaHorizontal,
    index_IconPanoramaHorizontalFilled as IconPanoramaHorizontalFilled,
    index_IconPanoramaHorizontalOff as IconPanoramaHorizontalOff,
    index_IconPanoramaVertical as IconPanoramaVertical,
    index_IconPanoramaVerticalFilled as IconPanoramaVerticalFilled,
    index_IconPanoramaVerticalOff as IconPanoramaVerticalOff,
    index_IconPaperBag as IconPaperBag,
    index_IconPaperBagOff as IconPaperBagOff,
    index_IconPaperclip as IconPaperclip,
    index_IconParachute as IconParachute,
    index_IconParachuteOff as IconParachuteOff,
    index_IconParentheses as IconParentheses,
    index_IconParenthesesOff as IconParenthesesOff,
    index_IconParking as IconParking,
    index_IconParkingCircle as IconParkingCircle,
    index_IconParkingCircleFilled as IconParkingCircleFilled,
    index_IconParkingOff as IconParkingOff,
    index_IconPassword as IconPassword,
    index_IconPasswordFingerprint as IconPasswordFingerprint,
    index_IconPasswordMobilePhone as IconPasswordMobilePhone,
    index_IconPasswordUser as IconPasswordUser,
    index_IconPaw as IconPaw,
    index_IconPawFilled as IconPawFilled,
    index_IconPawOff as IconPawOff,
    index_IconPaywall as IconPaywall,
    index_IconPdf as IconPdf,
    index_IconPeace as IconPeace,
    index_IconPencil as IconPencil,
    index_IconPencilBolt as IconPencilBolt,
    index_IconPencilCancel as IconPencilCancel,
    index_IconPencilCheck as IconPencilCheck,
    index_IconPencilCode as IconPencilCode,
    index_IconPencilCog as IconPencilCog,
    index_IconPencilDiscount as IconPencilDiscount,
    index_IconPencilDollar as IconPencilDollar,
    index_IconPencilDown as IconPencilDown,
    index_IconPencilExclamation as IconPencilExclamation,
    index_IconPencilHeart as IconPencilHeart,
    index_IconPencilMinus as IconPencilMinus,
    index_IconPencilOff as IconPencilOff,
    index_IconPencilPause as IconPencilPause,
    index_IconPencilPin as IconPencilPin,
    index_IconPencilPlus as IconPencilPlus,
    index_IconPencilQuestion as IconPencilQuestion,
    index_IconPencilSearch as IconPencilSearch,
    index_IconPencilShare as IconPencilShare,
    index_IconPencilStar as IconPencilStar,
    index_IconPencilUp as IconPencilUp,
    index_IconPencilX as IconPencilX,
    index_IconPennant as IconPennant,
    index_IconPennant2 as IconPennant2,
    index_IconPennant2Filled as IconPennant2Filled,
    index_IconPennantFilled as IconPennantFilled,
    index_IconPennantOff as IconPennantOff,
    index_IconPentagon as IconPentagon,
    index_IconPentagonFilled as IconPentagonFilled,
    index_IconPentagonMinus as IconPentagonMinus,
    index_IconPentagonNumber0 as IconPentagonNumber0,
    index_IconPentagonNumber1 as IconPentagonNumber1,
    index_IconPentagonNumber2 as IconPentagonNumber2,
    index_IconPentagonNumber3 as IconPentagonNumber3,
    index_IconPentagonNumber4 as IconPentagonNumber4,
    index_IconPentagonNumber5 as IconPentagonNumber5,
    index_IconPentagonNumber6 as IconPentagonNumber6,
    index_IconPentagonNumber7 as IconPentagonNumber7,
    index_IconPentagonNumber8 as IconPentagonNumber8,
    index_IconPentagonNumber9 as IconPentagonNumber9,
    index_IconPentagonOff as IconPentagonOff,
    index_IconPentagonPlus as IconPentagonPlus,
    index_IconPentagonX as IconPentagonX,
    index_IconPentagram as IconPentagram,
    index_IconPepper as IconPepper,
    index_IconPepperOff as IconPepperOff,
    index_IconPercentage as IconPercentage,
    index_IconPercentage0 as IconPercentage0,
    index_IconPercentage10 as IconPercentage10,
    index_IconPercentage100 as IconPercentage100,
    index_IconPercentage20 as IconPercentage20,
    index_IconPercentage25 as IconPercentage25,
    index_IconPercentage30 as IconPercentage30,
    index_IconPercentage33 as IconPercentage33,
    index_IconPercentage40 as IconPercentage40,
    index_IconPercentage50 as IconPercentage50,
    index_IconPercentage60 as IconPercentage60,
    index_IconPercentage66 as IconPercentage66,
    index_IconPercentage70 as IconPercentage70,
    index_IconPercentage75 as IconPercentage75,
    index_IconPercentage80 as IconPercentage80,
    index_IconPercentage90 as IconPercentage90,
    index_IconPerfume as IconPerfume,
    index_IconPerspective as IconPerspective,
    index_IconPerspectiveOff as IconPerspectiveOff,
    index_IconPhone as IconPhone,
    index_IconPhoneCall as IconPhoneCall,
    index_IconPhoneCallFilled as IconPhoneCallFilled,
    index_IconPhoneCalling as IconPhoneCalling,
    index_IconPhoneCallingFilled as IconPhoneCallingFilled,
    index_IconPhoneCheck as IconPhoneCheck,
    index_IconPhoneCheckFilled as IconPhoneCheckFilled,
    index_IconPhoneDone as IconPhoneDone,
    index_IconPhoneEnd as IconPhoneEnd,
    index_IconPhoneFilled as IconPhoneFilled,
    index_IconPhoneIncoming as IconPhoneIncoming,
    index_IconPhoneOff as IconPhoneOff,
    index_IconPhoneOutgoing as IconPhoneOutgoing,
    index_IconPhonePause as IconPhonePause,
    index_IconPhonePlus as IconPhonePlus,
    index_IconPhoneRinging as IconPhoneRinging,
    index_IconPhoneSpark as IconPhoneSpark,
    index_IconPhoneX as IconPhoneX,
    index_IconPhoneXFilled as IconPhoneXFilled,
    index_IconPhoto as IconPhoto,
    index_IconPhotoAi as IconPhotoAi,
    index_IconPhotoBitcoin as IconPhotoBitcoin,
    index_IconPhotoBolt as IconPhotoBolt,
    index_IconPhotoCancel as IconPhotoCancel,
    index_IconPhotoCheck as IconPhotoCheck,
    index_IconPhotoCircle as IconPhotoCircle,
    index_IconPhotoCircleMinus as IconPhotoCircleMinus,
    index_IconPhotoCirclePlus as IconPhotoCirclePlus,
    index_IconPhotoCode as IconPhotoCode,
    index_IconPhotoCog as IconPhotoCog,
    index_IconPhotoDollar as IconPhotoDollar,
    index_IconPhotoDown as IconPhotoDown,
    index_IconPhotoEdit as IconPhotoEdit,
    index_IconPhotoExclamation as IconPhotoExclamation,
    index_IconPhotoFilled as IconPhotoFilled,
    index_IconPhotoHeart as IconPhotoHeart,
    index_IconPhotoHexagon as IconPhotoHexagon,
    index_IconPhotoMinus as IconPhotoMinus,
    index_IconPhotoOff as IconPhotoOff,
    index_IconPhotoPause as IconPhotoPause,
    index_IconPhotoPentagon as IconPhotoPentagon,
    index_IconPhotoPin as IconPhotoPin,
    index_IconPhotoPlus as IconPhotoPlus,
    index_IconPhotoQuestion as IconPhotoQuestion,
    index_IconPhotoScan as IconPhotoScan,
    index_IconPhotoSearch as IconPhotoSearch,
    index_IconPhotoSensor as IconPhotoSensor,
    index_IconPhotoSensor2 as IconPhotoSensor2,
    index_IconPhotoSensor3 as IconPhotoSensor3,
    index_IconPhotoShare as IconPhotoShare,
    index_IconPhotoShield as IconPhotoShield,
    index_IconPhotoSpark as IconPhotoSpark,
    index_IconPhotoSquareRounded as IconPhotoSquareRounded,
    index_IconPhotoStar as IconPhotoStar,
    index_IconPhotoUp as IconPhotoUp,
    index_IconPhotoVideo as IconPhotoVideo,
    index_IconPhotoX as IconPhotoX,
    index_IconPhysotherapist as IconPhysotherapist,
    index_IconPiano as IconPiano,
    index_IconPick as IconPick,
    index_IconPicnicTable as IconPicnicTable,
    index_IconPictureInPicture as IconPictureInPicture,
    index_IconPictureInPictureFilled as IconPictureInPictureFilled,
    index_IconPictureInPictureOff as IconPictureInPictureOff,
    index_IconPictureInPictureOn as IconPictureInPictureOn,
    index_IconPictureInPictureTop as IconPictureInPictureTop,
    index_IconPictureInPictureTopFilled as IconPictureInPictureTopFilled,
    index_IconPig as IconPig,
    index_IconPigFilled as IconPigFilled,
    index_IconPigMoney as IconPigMoney,
    index_IconPigOff as IconPigOff,
    index_IconPilcrow as IconPilcrow,
    index_IconPilcrowLeft as IconPilcrowLeft,
    index_IconPilcrowRight as IconPilcrowRight,
    index_IconPill as IconPill,
    index_IconPillFilled as IconPillFilled,
    index_IconPillOff as IconPillOff,
    index_IconPills as IconPills,
    index_IconPin as IconPin,
    index_IconPinEnd as IconPinEnd,
    index_IconPinFilled as IconPinFilled,
    index_IconPinInvoke as IconPinInvoke,
    index_IconPingPong as IconPingPong,
    index_IconPinned as IconPinned,
    index_IconPinnedFilled as IconPinnedFilled,
    index_IconPinnedOff as IconPinnedOff,
    index_IconPizza as IconPizza,
    index_IconPizzaFilled as IconPizzaFilled,
    index_IconPizzaOff as IconPizzaOff,
    index_IconPlaceholder as IconPlaceholder,
    index_IconPlane as IconPlane,
    index_IconPlaneArrival as IconPlaneArrival,
    index_IconPlaneArrivalFilled as IconPlaneArrivalFilled,
    index_IconPlaneDeparture as IconPlaneDeparture,
    index_IconPlaneDepartureFilled as IconPlaneDepartureFilled,
    index_IconPlaneFilled as IconPlaneFilled,
    index_IconPlaneInflight as IconPlaneInflight,
    index_IconPlaneOff as IconPlaneOff,
    index_IconPlaneTilt as IconPlaneTilt,
    index_IconPlaneTiltFilled as IconPlaneTiltFilled,
    index_IconPlanet as IconPlanet,
    index_IconPlanetOff as IconPlanetOff,
    index_IconPlant as IconPlant,
    index_IconPlant2 as IconPlant2,
    index_IconPlant2Off as IconPlant2Off,
    index_IconPlantOff as IconPlantOff,
    index_IconPlayBasketball as IconPlayBasketball,
    index_IconPlayCard as IconPlayCard,
    index_IconPlayCard1 as IconPlayCard1,
    index_IconPlayCard10 as IconPlayCard10,
    index_IconPlayCard10Filled as IconPlayCard10Filled,
    index_IconPlayCard1Filled as IconPlayCard1Filled,
    index_IconPlayCard2 as IconPlayCard2,
    index_IconPlayCard2Filled as IconPlayCard2Filled,
    index_IconPlayCard3 as IconPlayCard3,
    index_IconPlayCard3Filled as IconPlayCard3Filled,
    index_IconPlayCard4 as IconPlayCard4,
    index_IconPlayCard4Filled as IconPlayCard4Filled,
    index_IconPlayCard5 as IconPlayCard5,
    index_IconPlayCard5Filled as IconPlayCard5Filled,
    index_IconPlayCard6 as IconPlayCard6,
    index_IconPlayCard6Filled as IconPlayCard6Filled,
    index_IconPlayCard7 as IconPlayCard7,
    index_IconPlayCard7Filled as IconPlayCard7Filled,
    index_IconPlayCard8 as IconPlayCard8,
    index_IconPlayCard8Filled as IconPlayCard8Filled,
    index_IconPlayCard9 as IconPlayCard9,
    index_IconPlayCard9Filled as IconPlayCard9Filled,
    index_IconPlayCardA as IconPlayCardA,
    index_IconPlayCardAFilled as IconPlayCardAFilled,
    index_IconPlayCardFilled as IconPlayCardFilled,
    index_IconPlayCardJ as IconPlayCardJ,
    index_IconPlayCardJFilled as IconPlayCardJFilled,
    index_IconPlayCardK as IconPlayCardK,
    index_IconPlayCardKFilled as IconPlayCardKFilled,
    index_IconPlayCardOff as IconPlayCardOff,
    index_IconPlayCardQ as IconPlayCardQ,
    index_IconPlayCardQFilled as IconPlayCardQFilled,
    index_IconPlayCardStar as IconPlayCardStar,
    index_IconPlayCardStarFilled as IconPlayCardStarFilled,
    index_IconPlayFootball as IconPlayFootball,
    index_IconPlayHandball as IconPlayHandball,
    index_IconPlayVolleyball as IconPlayVolleyball,
    index_IconPlayerEject as IconPlayerEject,
    index_IconPlayerEjectFilled as IconPlayerEjectFilled,
    index_IconPlayerPause as IconPlayerPause,
    index_IconPlayerPauseFilled as IconPlayerPauseFilled,
    index_IconPlayerPlay as IconPlayerPlay,
    index_IconPlayerPlayFilled as IconPlayerPlayFilled,
    index_IconPlayerRecord as IconPlayerRecord,
    index_IconPlayerRecordFilled as IconPlayerRecordFilled,
    index_IconPlayerSkipBack as IconPlayerSkipBack,
    index_IconPlayerSkipBackFilled as IconPlayerSkipBackFilled,
    index_IconPlayerSkipForward as IconPlayerSkipForward,
    index_IconPlayerSkipForwardFilled as IconPlayerSkipForwardFilled,
    index_IconPlayerStop as IconPlayerStop,
    index_IconPlayerStopFilled as IconPlayerStopFilled,
    index_IconPlayerTrackNext as IconPlayerTrackNext,
    index_IconPlayerTrackNextFilled as IconPlayerTrackNextFilled,
    index_IconPlayerTrackPrev as IconPlayerTrackPrev,
    index_IconPlayerTrackPrevFilled as IconPlayerTrackPrevFilled,
    index_IconPlaylist as IconPlaylist,
    index_IconPlaylistAdd as IconPlaylistAdd,
    index_IconPlaylistFilled as IconPlaylistFilled,
    index_IconPlaylistOff as IconPlaylistOff,
    index_IconPlaylistX as IconPlaylistX,
    index_IconPlaystationCircle as IconPlaystationCircle,
    index_IconPlaystationSquare as IconPlaystationSquare,
    index_IconPlaystationTriangle as IconPlaystationTriangle,
    index_IconPlaystationX as IconPlaystationX,
    index_IconPlug as IconPlug,
    index_IconPlugConnected as IconPlugConnected,
    index_IconPlugConnectedX as IconPlugConnectedX,
    index_IconPlugOff as IconPlugOff,
    index_IconPlugX as IconPlugX,
    index_IconPlus as IconPlus,
    index_IconPlusEqual as IconPlusEqual,
    index_IconPlusMinus as IconPlusMinus,
    index_IconPng as IconPng,
    index_IconPodium as IconPodium,
    index_IconPodiumOff as IconPodiumOff,
    index_IconPoint as IconPoint,
    index_IconPointFilled as IconPointFilled,
    index_IconPointOff as IconPointOff,
    index_IconPointer as IconPointer,
    index_IconPointerBolt as IconPointerBolt,
    index_IconPointerCancel as IconPointerCancel,
    index_IconPointerCheck as IconPointerCheck,
    index_IconPointerCode as IconPointerCode,
    index_IconPointerCog as IconPointerCog,
    index_IconPointerDollar as IconPointerDollar,
    index_IconPointerDown as IconPointerDown,
    index_IconPointerExclamation as IconPointerExclamation,
    index_IconPointerFilled as IconPointerFilled,
    index_IconPointerHeart as IconPointerHeart,
    index_IconPointerMinus as IconPointerMinus,
    index_IconPointerOff as IconPointerOff,
    index_IconPointerPause as IconPointerPause,
    index_IconPointerPin as IconPointerPin,
    index_IconPointerPlus as IconPointerPlus,
    index_IconPointerQuestion as IconPointerQuestion,
    index_IconPointerSearch as IconPointerSearch,
    index_IconPointerShare as IconPointerShare,
    index_IconPointerStar as IconPointerStar,
    index_IconPointerUp as IconPointerUp,
    index_IconPointerX as IconPointerX,
    index_IconPokeball as IconPokeball,
    index_IconPokeballOff as IconPokeballOff,
    index_IconPokerChip as IconPokerChip,
    index_IconPolaroid as IconPolaroid,
    index_IconPolaroidFilled as IconPolaroidFilled,
    index_IconPolygon as IconPolygon,
    index_IconPolygonOff as IconPolygonOff,
    index_IconPoo as IconPoo,
    index_IconPooFilled as IconPooFilled,
    index_IconPool as IconPool,
    index_IconPoolOff as IconPoolOff,
    index_IconPower as IconPower,
    index_IconPray as IconPray,
    index_IconPremiumRights as IconPremiumRights,
    index_IconPrescription as IconPrescription,
    index_IconPresentation as IconPresentation,
    index_IconPresentationAnalytics as IconPresentationAnalytics,
    index_IconPresentationAnalyticsFilled as IconPresentationAnalyticsFilled,
    index_IconPresentationFilled as IconPresentationFilled,
    index_IconPresentationOff as IconPresentationOff,
    index_IconPrinter as IconPrinter,
    index_IconPrinterOff as IconPrinterOff,
    index_IconPrism as IconPrism,
    index_IconPrismLight as IconPrismLight,
    index_IconPrismOff as IconPrismOff,
    index_IconPrismPlus as IconPrismPlus,
    index_IconPrison as IconPrison,
    index_IconProgress as IconProgress,
    index_IconProgressAlert as IconProgressAlert,
    index_IconProgressBolt as IconProgressBolt,
    index_IconProgressCheck as IconProgressCheck,
    index_IconProgressDown as IconProgressDown,
    index_IconProgressHelp as IconProgressHelp,
    index_IconProgressX as IconProgressX,
    index_IconPrompt as IconPrompt,
    index_IconProng as IconProng,
    index_IconPropeller as IconPropeller,
    index_IconPropellerOff as IconPropellerOff,
    index_IconProtocol as IconProtocol,
    index_IconPumpkinScary as IconPumpkinScary,
    index_IconPuzzle as IconPuzzle,
    index_IconPuzzle2 as IconPuzzle2,
    index_IconPuzzleFilled as IconPuzzleFilled,
    index_IconPuzzleOff as IconPuzzleOff,
    index_IconPyramid as IconPyramid,
    index_IconPyramidOff as IconPyramidOff,
    index_IconPyramidPlus as IconPyramidPlus,
    index_IconQrcode as IconQrcode,
    index_IconQrcodeOff as IconQrcodeOff,
    index_IconQuestionMark as IconQuestionMark,
    index_IconQuote as IconQuote,
    index_IconQuoteFilled as IconQuoteFilled,
    index_IconQuoteOff as IconQuoteOff,
    index_IconQuotes as IconQuotes,
    index_IconRadar as IconRadar,
    index_IconRadar2 as IconRadar2,
    index_IconRadarFilled as IconRadarFilled,
    index_IconRadarOff as IconRadarOff,
    index_IconRadio as IconRadio,
    index_IconRadioOff as IconRadioOff,
    index_IconRadioactive as IconRadioactive,
    index_IconRadioactiveFilled as IconRadioactiveFilled,
    index_IconRadioactiveOff as IconRadioactiveOff,
    index_IconRadiusBottomLeft as IconRadiusBottomLeft,
    index_IconRadiusBottomRight as IconRadiusBottomRight,
    index_IconRadiusTopLeft as IconRadiusTopLeft,
    index_IconRadiusTopRight as IconRadiusTopRight,
    index_IconRainbow as IconRainbow,
    index_IconRainbowOff as IconRainbowOff,
    index_IconRating12Plus as IconRating12Plus,
    index_IconRating14Plus as IconRating14Plus,
    index_IconRating16Plus as IconRating16Plus,
    index_IconRating18Plus as IconRating18Plus,
    index_IconRating21Plus as IconRating21Plus,
    index_IconRazor as IconRazor,
    index_IconRazorElectric as IconRazorElectric,
    index_IconReceipt as IconReceipt,
    index_IconReceipt2 as IconReceipt2,
    index_IconReceiptBitcoin as IconReceiptBitcoin,
    index_IconReceiptDollar as IconReceiptDollar,
    index_IconReceiptDollarFilled as IconReceiptDollarFilled,
    index_IconReceiptEuro as IconReceiptEuro,
    index_IconReceiptEuroFilled as IconReceiptEuroFilled,
    index_IconReceiptFilled as IconReceiptFilled,
    index_IconReceiptOff as IconReceiptOff,
    index_IconReceiptPound as IconReceiptPound,
    index_IconReceiptPoundFilled as IconReceiptPoundFilled,
    index_IconReceiptRefund as IconReceiptRefund,
    index_IconReceiptRupee as IconReceiptRupee,
    index_IconReceiptRupeeFilled as IconReceiptRupeeFilled,
    index_IconReceiptTax as IconReceiptTax,
    index_IconReceiptYen as IconReceiptYen,
    index_IconReceiptYenFilled as IconReceiptYenFilled,
    index_IconReceiptYuan as IconReceiptYuan,
    index_IconReceiptYuanFilled as IconReceiptYuanFilled,
    index_IconRecharging as IconRecharging,
    index_IconRecordMail as IconRecordMail,
    index_IconRecordMailOff as IconRecordMailOff,
    index_IconRectangle as IconRectangle,
    index_IconRectangleFilled as IconRectangleFilled,
    index_IconRectangleRoundedBottom as IconRectangleRoundedBottom,
    index_IconRectangleRoundedTop as IconRectangleRoundedTop,
    index_IconRectangleVertical as IconRectangleVertical,
    index_IconRectangleVerticalFilled as IconRectangleVerticalFilled,
    index_IconRectangularPrism as IconRectangularPrism,
    index_IconRectangularPrismOff as IconRectangularPrismOff,
    index_IconRectangularPrismPlus as IconRectangularPrismPlus,
    index_IconRecycle as IconRecycle,
    index_IconRecycleOff as IconRecycleOff,
    index_IconRefresh as IconRefresh,
    index_IconRefreshAlert as IconRefreshAlert,
    index_IconRefreshDot as IconRefreshDot,
    index_IconRefreshOff as IconRefreshOff,
    index_IconRegex as IconRegex,
    index_IconRegexOff as IconRegexOff,
    index_IconRegistered as IconRegistered,
    index_IconRegisteredFilled as IconRegisteredFilled,
    index_IconRelationManyToMany as IconRelationManyToMany,
    index_IconRelationManyToManyFilled as IconRelationManyToManyFilled,
    index_IconRelationOneToMany as IconRelationOneToMany,
    index_IconRelationOneToManyFilled as IconRelationOneToManyFilled,
    index_IconRelationOneToOne as IconRelationOneToOne,
    index_IconRelationOneToOneFilled as IconRelationOneToOneFilled,
    index_IconReload as IconReload,
    index_IconReorder as IconReorder,
    index_IconRepeat as IconRepeat,
    index_IconRepeatOff as IconRepeatOff,
    index_IconRepeatOnce as IconRepeatOnce,
    index_IconReplace as IconReplace,
    index_IconReplaceFilled as IconReplaceFilled,
    index_IconReplaceOff as IconReplaceOff,
    index_IconReplaceUser as IconReplaceUser,
    index_IconReport as IconReport,
    index_IconReportAnalytics as IconReportAnalytics,
    index_IconReportAnalyticsFilled as IconReportAnalyticsFilled,
    index_IconReportMedical as IconReportMedical,
    index_IconReportMoney as IconReportMoney,
    index_IconReportMoneyFilled as IconReportMoneyFilled,
    index_IconReportOff as IconReportOff,
    index_IconReportSearch as IconReportSearch,
    index_IconReservedLine as IconReservedLine,
    index_IconResize as IconResize,
    index_IconRestore as IconRestore,
    index_IconRewindBackward10 as IconRewindBackward10,
    index_IconRewindBackward15 as IconRewindBackward15,
    index_IconRewindBackward20 as IconRewindBackward20,
    index_IconRewindBackward30 as IconRewindBackward30,
    index_IconRewindBackward40 as IconRewindBackward40,
    index_IconRewindBackward5 as IconRewindBackward5,
    index_IconRewindBackward50 as IconRewindBackward50,
    index_IconRewindBackward60 as IconRewindBackward60,
    index_IconRewindForward10 as IconRewindForward10,
    index_IconRewindForward15 as IconRewindForward15,
    index_IconRewindForward20 as IconRewindForward20,
    index_IconRewindForward30 as IconRewindForward30,
    index_IconRewindForward40 as IconRewindForward40,
    index_IconRewindForward5 as IconRewindForward5,
    index_IconRewindForward50 as IconRewindForward50,
    index_IconRewindForward60 as IconRewindForward60,
    index_IconRibbonHealth as IconRibbonHealth,
    index_IconRings as IconRings,
    index_IconRipple as IconRipple,
    index_IconRippleDown as IconRippleDown,
    index_IconRippleOff as IconRippleOff,
    index_IconRippleUp as IconRippleUp,
    index_IconRoad as IconRoad,
    index_IconRoadOff as IconRoadOff,
    index_IconRoadSign as IconRoadSign,
    index_IconRobot as IconRobot,
    index_IconRobotFace as IconRobotFace,
    index_IconRobotOff as IconRobotOff,
    index_IconRocket as IconRocket,
    index_IconRocketOff as IconRocketOff,
    index_IconRollerSkating as IconRollerSkating,
    index_IconRollercoaster as IconRollercoaster,
    index_IconRollercoasterFilled as IconRollercoasterFilled,
    index_IconRollercoasterOff as IconRollercoasterOff,
    index_IconRosette as IconRosette,
    index_IconRosetteAsterisk as IconRosetteAsterisk,
    index_IconRosetteDiscount as IconRosetteDiscount,
    index_IconRosetteDiscountCheck as IconRosetteDiscountCheck,
    index_IconRosetteDiscountCheckFilled as IconRosetteDiscountCheckFilled,
    index_IconRosetteDiscountCheckOff as IconRosetteDiscountCheckOff,
    index_IconRosetteDiscountFilled as IconRosetteDiscountFilled,
    index_IconRosetteDiscountOff as IconRosetteDiscountOff,
    index_IconRosetteFilled as IconRosetteFilled,
    index_IconRosetteNumber0 as IconRosetteNumber0,
    index_IconRosetteNumber1 as IconRosetteNumber1,
    index_IconRosetteNumber2 as IconRosetteNumber2,
    index_IconRosetteNumber3 as IconRosetteNumber3,
    index_IconRosetteNumber4 as IconRosetteNumber4,
    index_IconRosetteNumber5 as IconRosetteNumber5,
    index_IconRosetteNumber6 as IconRosetteNumber6,
    index_IconRosetteNumber7 as IconRosetteNumber7,
    index_IconRosetteNumber8 as IconRosetteNumber8,
    index_IconRosetteNumber9 as IconRosetteNumber9,
    index_IconRotate as IconRotate,
    index_IconRotate2 as IconRotate2,
    index_IconRotate360 as IconRotate360,
    index_IconRotate3d as IconRotate3d,
    index_IconRotateClockwise as IconRotateClockwise,
    index_IconRotateClockwise2 as IconRotateClockwise2,
    index_IconRotateDot as IconRotateDot,
    index_IconRotateRectangle as IconRotateRectangle,
    index_IconRoute as IconRoute,
    index_IconRoute2 as IconRoute2,
    index_IconRouteAltLeft as IconRouteAltLeft,
    index_IconRouteAltRight as IconRouteAltRight,
    index_IconRouteOff as IconRouteOff,
    index_IconRouteScan as IconRouteScan,
    index_IconRouteSquare as IconRouteSquare,
    index_IconRouteSquare2 as IconRouteSquare2,
    index_IconRouteX as IconRouteX,
    index_IconRouteX2 as IconRouteX2,
    index_IconRouter as IconRouter,
    index_IconRouterOff as IconRouterOff,
    index_IconRowInsertBottom as IconRowInsertBottom,
    index_IconRowInsertTop as IconRowInsertTop,
    index_IconRowRemove as IconRowRemove,
    index_IconRss as IconRss,
    index_IconRubberStamp as IconRubberStamp,
    index_IconRubberStampOff as IconRubberStampOff,
    index_IconRuler as IconRuler,
    index_IconRuler2 as IconRuler2,
    index_IconRuler2Off as IconRuler2Off,
    index_IconRuler3 as IconRuler3,
    index_IconRulerMeasure as IconRulerMeasure,
    index_IconRulerMeasure2 as IconRulerMeasure2,
    index_IconRulerOff as IconRulerOff,
    index_IconRun as IconRun,
    index_IconRvTruck as IconRvTruck,
    index_IconSTurnDown as IconSTurnDown,
    index_IconSTurnLeft as IconSTurnLeft,
    index_IconSTurnRight as IconSTurnRight,
    index_IconSTurnUp as IconSTurnUp,
    index_IconSailboat as IconSailboat,
    index_IconSailboat2 as IconSailboat2,
    index_IconSailboatOff as IconSailboatOff,
    index_IconSalad as IconSalad,
    index_IconSaladFilled as IconSaladFilled,
    index_IconSalt as IconSalt,
    index_IconSandbox as IconSandbox,
    index_IconSatellite as IconSatellite,
    index_IconSatelliteFilled as IconSatelliteFilled,
    index_IconSatelliteOff as IconSatelliteOff,
    index_IconSausage as IconSausage,
    index_IconScale as IconScale,
    index_IconScaleOff as IconScaleOff,
    index_IconScaleOutline as IconScaleOutline,
    index_IconScaleOutlineOff as IconScaleOutlineOff,
    index_IconScan as IconScan,
    index_IconScanEye as IconScanEye,
    index_IconScanPosition as IconScanPosition,
    index_IconSchema as IconSchema,
    index_IconSchemaOff as IconSchemaOff,
    index_IconSchool as IconSchool,
    index_IconSchoolBell as IconSchoolBell,
    index_IconSchoolOff as IconSchoolOff,
    index_IconScissors as IconScissors,
    index_IconScissorsOff as IconScissorsOff,
    index_IconScooter as IconScooter,
    index_IconScooterElectric as IconScooterElectric,
    index_IconScoreboard as IconScoreboard,
    index_IconScreenShare as IconScreenShare,
    index_IconScreenShareOff as IconScreenShareOff,
    index_IconScreenshot as IconScreenshot,
    index_IconScribble as IconScribble,
    index_IconScribbleOff as IconScribbleOff,
    index_IconScript as IconScript,
    index_IconScriptMinus as IconScriptMinus,
    index_IconScriptPlus as IconScriptPlus,
    index_IconScriptX as IconScriptX,
    index_IconScubaDiving as IconScubaDiving,
    index_IconScubaDivingTank as IconScubaDivingTank,
    index_IconScubaDivingTankFilled as IconScubaDivingTankFilled,
    index_IconScubaMask as IconScubaMask,
    index_IconScubaMaskOff as IconScubaMaskOff,
    index_IconSdk as IconSdk,
    index_IconSearch as IconSearch,
    index_IconSearchOff as IconSearchOff,
    index_IconSection as IconSection,
    index_IconSectionFilled as IconSectionFilled,
    index_IconSectionSign as IconSectionSign,
    index_IconSeedling as IconSeedling,
    index_IconSeedlingFilled as IconSeedlingFilled,
    index_IconSeedlingOff as IconSeedlingOff,
    index_IconSelect as IconSelect,
    index_IconSelectAll as IconSelectAll,
    index_IconSelector as IconSelector,
    index_IconSend as IconSend,
    index_IconSend2 as IconSend2,
    index_IconSendOff as IconSendOff,
    index_IconSeo as IconSeo,
    index_IconSeparator as IconSeparator,
    index_IconSeparatorHorizontal as IconSeparatorHorizontal,
    index_IconSeparatorVertical as IconSeparatorVertical,
    index_IconServer as IconServer,
    index_IconServer2 as IconServer2,
    index_IconServerBolt as IconServerBolt,
    index_IconServerCog as IconServerCog,
    index_IconServerOff as IconServerOff,
    index_IconServerSpark as IconServerSpark,
    index_IconServicemark as IconServicemark,
    index_IconSettings as IconSettings,
    index_IconSettings2 as IconSettings2,
    index_IconSettingsAi as IconSettingsAi,
    index_IconSettingsAutomation as IconSettingsAutomation,
    index_IconSettingsBolt as IconSettingsBolt,
    index_IconSettingsCancel as IconSettingsCancel,
    index_IconSettingsCheck as IconSettingsCheck,
    index_IconSettingsCode as IconSettingsCode,
    index_IconSettingsCog as IconSettingsCog,
    index_IconSettingsDollar as IconSettingsDollar,
    index_IconSettingsDown as IconSettingsDown,
    index_IconSettingsExclamation as IconSettingsExclamation,
    index_IconSettingsFilled as IconSettingsFilled,
    index_IconSettingsHeart as IconSettingsHeart,
    index_IconSettingsMinus as IconSettingsMinus,
    index_IconSettingsOff as IconSettingsOff,
    index_IconSettingsPause as IconSettingsPause,
    index_IconSettingsPin as IconSettingsPin,
    index_IconSettingsPlus as IconSettingsPlus,
    index_IconSettingsQuestion as IconSettingsQuestion,
    index_IconSettingsSearch as IconSettingsSearch,
    index_IconSettingsShare as IconSettingsShare,
    index_IconSettingsSpark as IconSettingsSpark,
    index_IconSettingsStar as IconSettingsStar,
    index_IconSettingsUp as IconSettingsUp,
    index_IconSettingsX as IconSettingsX,
    index_IconShadow as IconShadow,
    index_IconShadowOff as IconShadowOff,
    index_IconShape as IconShape,
    index_IconShape2 as IconShape2,
    index_IconShape3 as IconShape3,
    index_IconShapeOff as IconShapeOff,
    index_IconShare as IconShare,
    index_IconShare2 as IconShare2,
    index_IconShare3 as IconShare3,
    index_IconShareOff as IconShareOff,
    index_IconShareplay as IconShareplay,
    index_IconShield as IconShield,
    index_IconShieldBolt as IconShieldBolt,
    index_IconShieldCancel as IconShieldCancel,
    index_IconShieldCheck as IconShieldCheck,
    index_IconShieldCheckFilled as IconShieldCheckFilled,
    index_IconShieldCheckered as IconShieldCheckered,
    index_IconShieldCheckeredFilled as IconShieldCheckeredFilled,
    index_IconShieldChevron as IconShieldChevron,
    index_IconShieldCode as IconShieldCode,
    index_IconShieldCog as IconShieldCog,
    index_IconShieldDollar as IconShieldDollar,
    index_IconShieldDown as IconShieldDown,
    index_IconShieldExclamation as IconShieldExclamation,
    index_IconShieldFilled as IconShieldFilled,
    index_IconShieldHalf as IconShieldHalf,
    index_IconShieldHalfFilled as IconShieldHalfFilled,
    index_IconShieldHeart as IconShieldHeart,
    index_IconShieldLock as IconShieldLock,
    index_IconShieldLockFilled as IconShieldLockFilled,
    index_IconShieldMinus as IconShieldMinus,
    index_IconShieldOff as IconShieldOff,
    index_IconShieldPause as IconShieldPause,
    index_IconShieldPin as IconShieldPin,
    index_IconShieldPlus as IconShieldPlus,
    index_IconShieldQuestion as IconShieldQuestion,
    index_IconShieldSearch as IconShieldSearch,
    index_IconShieldShare as IconShieldShare,
    index_IconShieldStar as IconShieldStar,
    index_IconShieldUp as IconShieldUp,
    index_IconShieldX as IconShieldX,
    index_IconShip as IconShip,
    index_IconShipOff as IconShipOff,
    index_IconShirt as IconShirt,
    index_IconShirtFilled as IconShirtFilled,
    index_IconShirtOff as IconShirtOff,
    index_IconShirtSport as IconShirtSport,
    index_IconShoe as IconShoe,
    index_IconShoeOff as IconShoeOff,
    index_IconShoppingBag as IconShoppingBag,
    index_IconShoppingBagCheck as IconShoppingBagCheck,
    index_IconShoppingBagDiscount as IconShoppingBagDiscount,
    index_IconShoppingBagEdit as IconShoppingBagEdit,
    index_IconShoppingBagExclamation as IconShoppingBagExclamation,
    index_IconShoppingBagHeart as IconShoppingBagHeart,
    index_IconShoppingBagMinus as IconShoppingBagMinus,
    index_IconShoppingBagPlus as IconShoppingBagPlus,
    index_IconShoppingBagSearch as IconShoppingBagSearch,
    index_IconShoppingBagX as IconShoppingBagX,
    index_IconShoppingCart as IconShoppingCart,
    index_IconShoppingCartBolt as IconShoppingCartBolt,
    index_IconShoppingCartCancel as IconShoppingCartCancel,
    index_IconShoppingCartCheck as IconShoppingCartCheck,
    index_IconShoppingCartCode as IconShoppingCartCode,
    index_IconShoppingCartCog as IconShoppingCartCog,
    index_IconShoppingCartCopy as IconShoppingCartCopy,
    index_IconShoppingCartDiscount as IconShoppingCartDiscount,
    index_IconShoppingCartDollar as IconShoppingCartDollar,
    index_IconShoppingCartDown as IconShoppingCartDown,
    index_IconShoppingCartExclamation as IconShoppingCartExclamation,
    index_IconShoppingCartFilled as IconShoppingCartFilled,
    index_IconShoppingCartHeart as IconShoppingCartHeart,
    index_IconShoppingCartMinus as IconShoppingCartMinus,
    index_IconShoppingCartOff as IconShoppingCartOff,
    index_IconShoppingCartPause as IconShoppingCartPause,
    index_IconShoppingCartPin as IconShoppingCartPin,
    index_IconShoppingCartPlus as IconShoppingCartPlus,
    index_IconShoppingCartQuestion as IconShoppingCartQuestion,
    index_IconShoppingCartSearch as IconShoppingCartSearch,
    index_IconShoppingCartShare as IconShoppingCartShare,
    index_IconShoppingCartStar as IconShoppingCartStar,
    index_IconShoppingCartUp as IconShoppingCartUp,
    index_IconShoppingCartX as IconShoppingCartX,
    index_IconShovel as IconShovel,
    index_IconShovelPitchforks as IconShovelPitchforks,
    index_IconShredder as IconShredder,
    index_IconSignLeft as IconSignLeft,
    index_IconSignLeftFilled as IconSignLeftFilled,
    index_IconSignRight as IconSignRight,
    index_IconSignRightFilled as IconSignRightFilled,
    index_IconSignal2g as IconSignal2g,
    index_IconSignal3g as IconSignal3g,
    index_IconSignal4g as IconSignal4g,
    index_IconSignal4gPlus as IconSignal4gPlus,
    index_IconSignal5g as IconSignal5g,
    index_IconSignal6g as IconSignal6g,
    index_IconSignalE as IconSignalE,
    index_IconSignalG as IconSignalG,
    index_IconSignalH as IconSignalH,
    index_IconSignalHPlus as IconSignalHPlus,
    index_IconSignalLte as IconSignalLte,
    index_IconSignature as IconSignature,
    index_IconSignatureOff as IconSignatureOff,
    index_IconSitemap as IconSitemap,
    index_IconSitemapFilled as IconSitemapFilled,
    index_IconSitemapOff as IconSitemapOff,
    index_IconSkateboard as IconSkateboard,
    index_IconSkateboardOff as IconSkateboardOff,
    index_IconSkateboarding as IconSkateboarding,
    index_IconSkewX as IconSkewX,
    index_IconSkewY as IconSkewY,
    index_IconSkiJumping as IconSkiJumping,
    index_IconSkull as IconSkull,
    index_IconSlash as IconSlash,
    index_IconSlashes as IconSlashes,
    index_IconSleigh as IconSleigh,
    index_IconSlice as IconSlice,
    index_IconSlideshow as IconSlideshow,
    index_IconSmartHome as IconSmartHome,
    index_IconSmartHomeOff as IconSmartHomeOff,
    index_IconSmoking as IconSmoking,
    index_IconSmokingNo as IconSmokingNo,
    index_IconSnowboarding as IconSnowboarding,
    index_IconSnowflake as IconSnowflake,
    index_IconSnowflakeOff as IconSnowflakeOff,
    index_IconSnowman as IconSnowman,
    index_IconSoccerField as IconSoccerField,
    index_IconSocial as IconSocial,
    index_IconSocialOff as IconSocialOff,
    index_IconSock as IconSock,
    index_IconSofa as IconSofa,
    index_IconSofaOff as IconSofaOff,
    index_IconSolarElectricity as IconSolarElectricity,
    index_IconSolarPanel as IconSolarPanel,
    index_IconSolarPanel2 as IconSolarPanel2,
    index_IconSort09 as IconSort09,
    index_IconSort90 as IconSort90,
    index_IconSortAZ as IconSortAZ,
    index_IconSortAscending as IconSortAscending,
    index_IconSortAscending2 as IconSortAscending2,
    index_IconSortAscending2Filled as IconSortAscending2Filled,
    index_IconSortAscendingLetters as IconSortAscendingLetters,
    index_IconSortAscendingNumbers as IconSortAscendingNumbers,
    index_IconSortAscendingShapes as IconSortAscendingShapes,
    index_IconSortAscendingShapesFilled as IconSortAscendingShapesFilled,
    index_IconSortAscendingSmallBig as IconSortAscendingSmallBig,
    index_IconSortDescending as IconSortDescending,
    index_IconSortDescending2 as IconSortDescending2,
    index_IconSortDescending2Filled as IconSortDescending2Filled,
    index_IconSortDescendingLetters as IconSortDescendingLetters,
    index_IconSortDescendingNumbers as IconSortDescendingNumbers,
    index_IconSortDescendingShapes as IconSortDescendingShapes,
    index_IconSortDescendingShapesFilled as IconSortDescendingShapesFilled,
    index_IconSortDescendingSmallBig as IconSortDescendingSmallBig,
    index_IconSortZA as IconSortZA,
    index_IconSos as IconSos,
    index_IconSoup as IconSoup,
    index_IconSoupFilled as IconSoupFilled,
    index_IconSoupOff as IconSoupOff,
    index_IconSourceCode as IconSourceCode,
    index_IconSpace as IconSpace,
    index_IconSpaceOff as IconSpaceOff,
    index_IconSpaces as IconSpaces,
    index_IconSpacingHorizontal as IconSpacingHorizontal,
    index_IconSpacingVertical as IconSpacingVertical,
    index_IconSpade as IconSpade,
    index_IconSpadeFilled as IconSpadeFilled,
    index_IconSparkles as IconSparkles,
    index_IconSparkles2 as IconSparkles2,
    index_IconSparkles2Filled as IconSparkles2Filled,
    index_IconSparklesFilled as IconSparklesFilled,
    index_IconSpeakerphone as IconSpeakerphone,
    index_IconSpeedboat as IconSpeedboat,
    index_IconSpeedboatFilled as IconSpeedboatFilled,
    index_IconSphere as IconSphere,
    index_IconSphereOff as IconSphereOff,
    index_IconSpherePlus as IconSpherePlus,
    index_IconSpider as IconSpider,
    index_IconSpiderFilled as IconSpiderFilled,
    index_IconSpiral as IconSpiral,
    index_IconSpiralOff as IconSpiralOff,
    index_IconSportBillard as IconSportBillard,
    index_IconSpray as IconSpray,
    index_IconSpy as IconSpy,
    index_IconSpyOff as IconSpyOff,
    index_IconSql as IconSql,
    index_IconSquare as IconSquare,
    index_IconSquareArrowDown as IconSquareArrowDown,
    index_IconSquareArrowDownFilled as IconSquareArrowDownFilled,
    index_IconSquareArrowLeft as IconSquareArrowLeft,
    index_IconSquareArrowLeftFilled as IconSquareArrowLeftFilled,
    index_IconSquareArrowRight as IconSquareArrowRight,
    index_IconSquareArrowRightFilled as IconSquareArrowRightFilled,
    index_IconSquareArrowUp as IconSquareArrowUp,
    index_IconSquareArrowUpFilled as IconSquareArrowUpFilled,
    index_IconSquareAsterisk as IconSquareAsterisk,
    index_IconSquareAsteriskFilled as IconSquareAsteriskFilled,
    index_IconSquareCheck as IconSquareCheck,
    index_IconSquareCheckFilled as IconSquareCheckFilled,
    index_IconSquareChevronDown as IconSquareChevronDown,
    index_IconSquareChevronDownFilled as IconSquareChevronDownFilled,
    index_IconSquareChevronLeft as IconSquareChevronLeft,
    index_IconSquareChevronLeftFilled as IconSquareChevronLeftFilled,
    index_IconSquareChevronRight as IconSquareChevronRight,
    index_IconSquareChevronRightFilled as IconSquareChevronRightFilled,
    index_IconSquareChevronUp as IconSquareChevronUp,
    index_IconSquareChevronUpFilled as IconSquareChevronUpFilled,
    index_IconSquareChevronsDown as IconSquareChevronsDown,
    index_IconSquareChevronsDownFilled as IconSquareChevronsDownFilled,
    index_IconSquareChevronsLeft as IconSquareChevronsLeft,
    index_IconSquareChevronsLeftFilled as IconSquareChevronsLeftFilled,
    index_IconSquareChevronsRight as IconSquareChevronsRight,
    index_IconSquareChevronsRightFilled as IconSquareChevronsRightFilled,
    index_IconSquareChevronsUp as IconSquareChevronsUp,
    index_IconSquareChevronsUpFilled as IconSquareChevronsUpFilled,
    index_IconSquareDashed as IconSquareDashed,
    index_IconSquareDot as IconSquareDot,
    index_IconSquareDotFilled as IconSquareDotFilled,
    index_IconSquareF0 as IconSquareF0,
    index_IconSquareF0Filled as IconSquareF0Filled,
    index_IconSquareF1 as IconSquareF1,
    index_IconSquareF1Filled as IconSquareF1Filled,
    index_IconSquareF2 as IconSquareF2,
    index_IconSquareF2Filled as IconSquareF2Filled,
    index_IconSquareF3 as IconSquareF3,
    index_IconSquareF3Filled as IconSquareF3Filled,
    index_IconSquareF4 as IconSquareF4,
    index_IconSquareF4Filled as IconSquareF4Filled,
    index_IconSquareF5 as IconSquareF5,
    index_IconSquareF5Filled as IconSquareF5Filled,
    index_IconSquareF6 as IconSquareF6,
    index_IconSquareF6Filled as IconSquareF6Filled,
    index_IconSquareF7 as IconSquareF7,
    index_IconSquareF7Filled as IconSquareF7Filled,
    index_IconSquareF8 as IconSquareF8,
    index_IconSquareF8Filled as IconSquareF8Filled,
    index_IconSquareF9 as IconSquareF9,
    index_IconSquareF9Filled as IconSquareF9Filled,
    index_IconSquareFilled as IconSquareFilled,
    index_IconSquareForbid as IconSquareForbid,
    index_IconSquareForbid2 as IconSquareForbid2,
    index_IconSquareHalf as IconSquareHalf,
    index_IconSquareKey as IconSquareKey,
    index_IconSquareLetterA as IconSquareLetterA,
    index_IconSquareLetterAFilled as IconSquareLetterAFilled,
    index_IconSquareLetterB as IconSquareLetterB,
    index_IconSquareLetterBFilled as IconSquareLetterBFilled,
    index_IconSquareLetterC as IconSquareLetterC,
    index_IconSquareLetterCFilled as IconSquareLetterCFilled,
    index_IconSquareLetterD as IconSquareLetterD,
    index_IconSquareLetterDFilled as IconSquareLetterDFilled,
    index_IconSquareLetterE as IconSquareLetterE,
    index_IconSquareLetterEFilled as IconSquareLetterEFilled,
    index_IconSquareLetterF as IconSquareLetterF,
    index_IconSquareLetterFFilled as IconSquareLetterFFilled,
    index_IconSquareLetterG as IconSquareLetterG,
    index_IconSquareLetterGFilled as IconSquareLetterGFilled,
    index_IconSquareLetterH as IconSquareLetterH,
    index_IconSquareLetterHFilled as IconSquareLetterHFilled,
    index_IconSquareLetterI as IconSquareLetterI,
    index_IconSquareLetterIFilled as IconSquareLetterIFilled,
    index_IconSquareLetterJ as IconSquareLetterJ,
    index_IconSquareLetterJFilled as IconSquareLetterJFilled,
    index_IconSquareLetterK as IconSquareLetterK,
    index_IconSquareLetterKFilled as IconSquareLetterKFilled,
    index_IconSquareLetterL as IconSquareLetterL,
    index_IconSquareLetterLFilled as IconSquareLetterLFilled,
    index_IconSquareLetterM as IconSquareLetterM,
    index_IconSquareLetterMFilled as IconSquareLetterMFilled,
    index_IconSquareLetterN as IconSquareLetterN,
    index_IconSquareLetterNFilled as IconSquareLetterNFilled,
    index_IconSquareLetterO as IconSquareLetterO,
    index_IconSquareLetterOFilled as IconSquareLetterOFilled,
    index_IconSquareLetterP as IconSquareLetterP,
    index_IconSquareLetterPFilled as IconSquareLetterPFilled,
    index_IconSquareLetterQ as IconSquareLetterQ,
    index_IconSquareLetterQFilled as IconSquareLetterQFilled,
    index_IconSquareLetterR as IconSquareLetterR,
    index_IconSquareLetterRFilled as IconSquareLetterRFilled,
    index_IconSquareLetterS as IconSquareLetterS,
    index_IconSquareLetterSFilled as IconSquareLetterSFilled,
    index_IconSquareLetterT as IconSquareLetterT,
    index_IconSquareLetterTFilled as IconSquareLetterTFilled,
    index_IconSquareLetterU as IconSquareLetterU,
    index_IconSquareLetterUFilled as IconSquareLetterUFilled,
    index_IconSquareLetterV as IconSquareLetterV,
    index_IconSquareLetterVFilled as IconSquareLetterVFilled,
    index_IconSquareLetterW as IconSquareLetterW,
    index_IconSquareLetterWFilled as IconSquareLetterWFilled,
    index_IconSquareLetterX as IconSquareLetterX,
    index_IconSquareLetterXFilled as IconSquareLetterXFilled,
    index_IconSquareLetterY as IconSquareLetterY,
    index_IconSquareLetterYFilled as IconSquareLetterYFilled,
    index_IconSquareLetterZ as IconSquareLetterZ,
    index_IconSquareLetterZFilled as IconSquareLetterZFilled,
    index_IconSquareMinus as IconSquareMinus,
    index_IconSquareMinus2 as IconSquareMinus2,
    index_IconSquareMinusFilled as IconSquareMinusFilled,
    index_IconSquareNumber0 as IconSquareNumber0,
    index_IconSquareNumber0Filled as IconSquareNumber0Filled,
    index_IconSquareNumber1 as IconSquareNumber1,
    index_IconSquareNumber1Filled as IconSquareNumber1Filled,
    index_IconSquareNumber2 as IconSquareNumber2,
    index_IconSquareNumber2Filled as IconSquareNumber2Filled,
    index_IconSquareNumber3 as IconSquareNumber3,
    index_IconSquareNumber3Filled as IconSquareNumber3Filled,
    index_IconSquareNumber4 as IconSquareNumber4,
    index_IconSquareNumber4Filled as IconSquareNumber4Filled,
    index_IconSquareNumber5 as IconSquareNumber5,
    index_IconSquareNumber5Filled as IconSquareNumber5Filled,
    index_IconSquareNumber6 as IconSquareNumber6,
    index_IconSquareNumber6Filled as IconSquareNumber6Filled,
    index_IconSquareNumber7 as IconSquareNumber7,
    index_IconSquareNumber7Filled as IconSquareNumber7Filled,
    index_IconSquareNumber8 as IconSquareNumber8,
    index_IconSquareNumber8Filled as IconSquareNumber8Filled,
    index_IconSquareNumber9 as IconSquareNumber9,
    index_IconSquareNumber9Filled as IconSquareNumber9Filled,
    index_IconSquareOff as IconSquareOff,
    index_IconSquarePercentage as IconSquarePercentage,
    index_IconSquarePlus as IconSquarePlus,
    index_IconSquarePlus2 as IconSquarePlus2,
    index_IconSquareRoot as IconSquareRoot,
    index_IconSquareRoot2 as IconSquareRoot2,
    index_IconSquareRotated as IconSquareRotated,
    index_IconSquareRotatedAsterisk as IconSquareRotatedAsterisk,
    index_IconSquareRotatedFilled as IconSquareRotatedFilled,
    index_IconSquareRotatedForbid as IconSquareRotatedForbid,
    index_IconSquareRotatedForbid2 as IconSquareRotatedForbid2,
    index_IconSquareRotatedOff as IconSquareRotatedOff,
    index_IconSquareRounded as IconSquareRounded,
    index_IconSquareRoundedArrowDown as IconSquareRoundedArrowDown,
    index_IconSquareRoundedArrowDownFilled as IconSquareRoundedArrowDownFilled,
    index_IconSquareRoundedArrowLeft as IconSquareRoundedArrowLeft,
    index_IconSquareRoundedArrowLeftFilled as IconSquareRoundedArrowLeftFilled,
    index_IconSquareRoundedArrowRight as IconSquareRoundedArrowRight,
    index_IconSquareRoundedArrowRightFilled as IconSquareRoundedArrowRightFilled,
    index_IconSquareRoundedArrowUp as IconSquareRoundedArrowUp,
    index_IconSquareRoundedArrowUpFilled as IconSquareRoundedArrowUpFilled,
    index_IconSquareRoundedCheck as IconSquareRoundedCheck,
    index_IconSquareRoundedCheckFilled as IconSquareRoundedCheckFilled,
    index_IconSquareRoundedChevronDown as IconSquareRoundedChevronDown,
    index_IconSquareRoundedChevronDownFilled as IconSquareRoundedChevronDownFilled,
    index_IconSquareRoundedChevronLeft as IconSquareRoundedChevronLeft,
    index_IconSquareRoundedChevronLeftFilled as IconSquareRoundedChevronLeftFilled,
    index_IconSquareRoundedChevronRight as IconSquareRoundedChevronRight,
    index_IconSquareRoundedChevronRightFilled as IconSquareRoundedChevronRightFilled,
    index_IconSquareRoundedChevronUp as IconSquareRoundedChevronUp,
    index_IconSquareRoundedChevronUpFilled as IconSquareRoundedChevronUpFilled,
    index_IconSquareRoundedChevronsDown as IconSquareRoundedChevronsDown,
    index_IconSquareRoundedChevronsDownFilled as IconSquareRoundedChevronsDownFilled,
    index_IconSquareRoundedChevronsLeft as IconSquareRoundedChevronsLeft,
    index_IconSquareRoundedChevronsLeftFilled as IconSquareRoundedChevronsLeftFilled,
    index_IconSquareRoundedChevronsRight as IconSquareRoundedChevronsRight,
    index_IconSquareRoundedChevronsRightFilled as IconSquareRoundedChevronsRightFilled,
    index_IconSquareRoundedChevronsUp as IconSquareRoundedChevronsUp,
    index_IconSquareRoundedChevronsUpFilled as IconSquareRoundedChevronsUpFilled,
    index_IconSquareRoundedFilled as IconSquareRoundedFilled,
    index_IconSquareRoundedLetterA as IconSquareRoundedLetterA,
    index_IconSquareRoundedLetterAFilled as IconSquareRoundedLetterAFilled,
    index_IconSquareRoundedLetterB as IconSquareRoundedLetterB,
    index_IconSquareRoundedLetterBFilled as IconSquareRoundedLetterBFilled,
    index_IconSquareRoundedLetterC as IconSquareRoundedLetterC,
    index_IconSquareRoundedLetterCFilled as IconSquareRoundedLetterCFilled,
    index_IconSquareRoundedLetterD as IconSquareRoundedLetterD,
    index_IconSquareRoundedLetterDFilled as IconSquareRoundedLetterDFilled,
    index_IconSquareRoundedLetterE as IconSquareRoundedLetterE,
    index_IconSquareRoundedLetterEFilled as IconSquareRoundedLetterEFilled,
    index_IconSquareRoundedLetterF as IconSquareRoundedLetterF,
    index_IconSquareRoundedLetterFFilled as IconSquareRoundedLetterFFilled,
    index_IconSquareRoundedLetterG as IconSquareRoundedLetterG,
    index_IconSquareRoundedLetterGFilled as IconSquareRoundedLetterGFilled,
    index_IconSquareRoundedLetterH as IconSquareRoundedLetterH,
    index_IconSquareRoundedLetterHFilled as IconSquareRoundedLetterHFilled,
    index_IconSquareRoundedLetterI as IconSquareRoundedLetterI,
    index_IconSquareRoundedLetterIFilled as IconSquareRoundedLetterIFilled,
    index_IconSquareRoundedLetterJ as IconSquareRoundedLetterJ,
    index_IconSquareRoundedLetterJFilled as IconSquareRoundedLetterJFilled,
    index_IconSquareRoundedLetterK as IconSquareRoundedLetterK,
    index_IconSquareRoundedLetterKFilled as IconSquareRoundedLetterKFilled,
    index_IconSquareRoundedLetterL as IconSquareRoundedLetterL,
    index_IconSquareRoundedLetterLFilled as IconSquareRoundedLetterLFilled,
    index_IconSquareRoundedLetterM as IconSquareRoundedLetterM,
    index_IconSquareRoundedLetterMFilled as IconSquareRoundedLetterMFilled,
    index_IconSquareRoundedLetterN as IconSquareRoundedLetterN,
    index_IconSquareRoundedLetterNFilled as IconSquareRoundedLetterNFilled,
    index_IconSquareRoundedLetterO as IconSquareRoundedLetterO,
    index_IconSquareRoundedLetterOFilled as IconSquareRoundedLetterOFilled,
    index_IconSquareRoundedLetterP as IconSquareRoundedLetterP,
    index_IconSquareRoundedLetterPFilled as IconSquareRoundedLetterPFilled,
    index_IconSquareRoundedLetterQ as IconSquareRoundedLetterQ,
    index_IconSquareRoundedLetterQFilled as IconSquareRoundedLetterQFilled,
    index_IconSquareRoundedLetterR as IconSquareRoundedLetterR,
    index_IconSquareRoundedLetterRFilled as IconSquareRoundedLetterRFilled,
    index_IconSquareRoundedLetterS as IconSquareRoundedLetterS,
    index_IconSquareRoundedLetterSFilled as IconSquareRoundedLetterSFilled,
    index_IconSquareRoundedLetterT as IconSquareRoundedLetterT,
    index_IconSquareRoundedLetterTFilled as IconSquareRoundedLetterTFilled,
    index_IconSquareRoundedLetterU as IconSquareRoundedLetterU,
    index_IconSquareRoundedLetterUFilled as IconSquareRoundedLetterUFilled,
    index_IconSquareRoundedLetterV as IconSquareRoundedLetterV,
    index_IconSquareRoundedLetterVFilled as IconSquareRoundedLetterVFilled,
    index_IconSquareRoundedLetterW as IconSquareRoundedLetterW,
    index_IconSquareRoundedLetterWFilled as IconSquareRoundedLetterWFilled,
    index_IconSquareRoundedLetterX as IconSquareRoundedLetterX,
    index_IconSquareRoundedLetterXFilled as IconSquareRoundedLetterXFilled,
    index_IconSquareRoundedLetterY as IconSquareRoundedLetterY,
    index_IconSquareRoundedLetterYFilled as IconSquareRoundedLetterYFilled,
    index_IconSquareRoundedLetterZ as IconSquareRoundedLetterZ,
    index_IconSquareRoundedLetterZFilled as IconSquareRoundedLetterZFilled,
    index_IconSquareRoundedMinus as IconSquareRoundedMinus,
    index_IconSquareRoundedMinus2 as IconSquareRoundedMinus2,
    index_IconSquareRoundedMinusFilled as IconSquareRoundedMinusFilled,
    index_IconSquareRoundedNumber0 as IconSquareRoundedNumber0,
    index_IconSquareRoundedNumber0Filled as IconSquareRoundedNumber0Filled,
    index_IconSquareRoundedNumber1 as IconSquareRoundedNumber1,
    index_IconSquareRoundedNumber1Filled as IconSquareRoundedNumber1Filled,
    index_IconSquareRoundedNumber2 as IconSquareRoundedNumber2,
    index_IconSquareRoundedNumber2Filled as IconSquareRoundedNumber2Filled,
    index_IconSquareRoundedNumber3 as IconSquareRoundedNumber3,
    index_IconSquareRoundedNumber3Filled as IconSquareRoundedNumber3Filled,
    index_IconSquareRoundedNumber4 as IconSquareRoundedNumber4,
    index_IconSquareRoundedNumber4Filled as IconSquareRoundedNumber4Filled,
    index_IconSquareRoundedNumber5 as IconSquareRoundedNumber5,
    index_IconSquareRoundedNumber5Filled as IconSquareRoundedNumber5Filled,
    index_IconSquareRoundedNumber6 as IconSquareRoundedNumber6,
    index_IconSquareRoundedNumber6Filled as IconSquareRoundedNumber6Filled,
    index_IconSquareRoundedNumber7 as IconSquareRoundedNumber7,
    index_IconSquareRoundedNumber7Filled as IconSquareRoundedNumber7Filled,
    index_IconSquareRoundedNumber8 as IconSquareRoundedNumber8,
    index_IconSquareRoundedNumber8Filled as IconSquareRoundedNumber8Filled,
    index_IconSquareRoundedNumber9 as IconSquareRoundedNumber9,
    index_IconSquareRoundedNumber9Filled as IconSquareRoundedNumber9Filled,
    index_IconSquareRoundedPercentage as IconSquareRoundedPercentage,
    index_IconSquareRoundedPlus as IconSquareRoundedPlus,
    index_IconSquareRoundedPlus2 as IconSquareRoundedPlus2,
    index_IconSquareRoundedPlusFilled as IconSquareRoundedPlusFilled,
    index_IconSquareRoundedX as IconSquareRoundedX,
    index_IconSquareRoundedXFilled as IconSquareRoundedXFilled,
    index_IconSquareToggle as IconSquareToggle,
    index_IconSquareToggleHorizontal as IconSquareToggleHorizontal,
    index_IconSquareX as IconSquareX,
    index_IconSquareXFilled as IconSquareXFilled,
    index_IconSquares as IconSquares,
    index_IconSquaresDiagonal as IconSquaresDiagonal,
    index_IconSquaresFilled as IconSquaresFilled,
    index_IconSquaresSelected as IconSquaresSelected,
    index_IconStack as IconStack,
    index_IconStack2 as IconStack2,
    index_IconStack2Filled as IconStack2Filled,
    index_IconStack3 as IconStack3,
    index_IconStack3Filled as IconStack3Filled,
    index_IconStackBack as IconStackBack,
    index_IconStackBackward as IconStackBackward,
    index_IconStackFilled as IconStackFilled,
    index_IconStackForward as IconStackForward,
    index_IconStackFront as IconStackFront,
    index_IconStackMiddle as IconStackMiddle,
    index_IconStackPop as IconStackPop,
    index_IconStackPush as IconStackPush,
    index_IconStairs as IconStairs,
    index_IconStairsDown as IconStairsDown,
    index_IconStairsUp as IconStairsUp,
    index_IconStar as IconStar,
    index_IconStarFilled as IconStarFilled,
    index_IconStarHalf as IconStarHalf,
    index_IconStarHalfFilled as IconStarHalfFilled,
    index_IconStarOff as IconStarOff,
    index_IconStars as IconStars,
    index_IconStarsFilled as IconStarsFilled,
    index_IconStarsOff as IconStarsOff,
    index_IconStatusChange as IconStatusChange,
    index_IconSteam as IconSteam,
    index_IconSteeringWheel as IconSteeringWheel,
    index_IconSteeringWheelFilled as IconSteeringWheelFilled,
    index_IconSteeringWheelOff as IconSteeringWheelOff,
    index_IconStepInto as IconStepInto,
    index_IconStepOut as IconStepOut,
    index_IconStereoGlasses as IconStereoGlasses,
    index_IconStethoscope as IconStethoscope,
    index_IconStethoscopeOff as IconStethoscopeOff,
    index_IconSticker as IconSticker,
    index_IconSticker2 as IconSticker2,
    index_IconStopwatch as IconStopwatch,
    index_IconStorm as IconStorm,
    index_IconStormOff as IconStormOff,
    index_IconStretching as IconStretching,
    index_IconStretching2 as IconStretching2,
    index_IconStrikethrough as IconStrikethrough,
    index_IconSubmarine as IconSubmarine,
    index_IconSubscript as IconSubscript,
    index_IconSubtask as IconSubtask,
    index_IconSubtitles as IconSubtitles,
    index_IconSubtitlesAi as IconSubtitlesAi,
    index_IconSubtitlesEdit as IconSubtitlesEdit,
    index_IconSubtitlesOff as IconSubtitlesOff,
    index_IconSum as IconSum,
    index_IconSumOff as IconSumOff,
    index_IconSun as IconSun,
    index_IconSunElectricity as IconSunElectricity,
    index_IconSunFilled as IconSunFilled,
    index_IconSunHigh as IconSunHigh,
    index_IconSunHighFilled as IconSunHighFilled,
    index_IconSunLow as IconSunLow,
    index_IconSunLowFilled as IconSunLowFilled,
    index_IconSunMoon as IconSunMoon,
    index_IconSunOff as IconSunOff,
    index_IconSunWind as IconSunWind,
    index_IconSunglasses as IconSunglasses,
    index_IconSunglassesFilled as IconSunglassesFilled,
    index_IconSunrise as IconSunrise,
    index_IconSunriseFilled as IconSunriseFilled,
    index_IconSunset as IconSunset,
    index_IconSunset2 as IconSunset2,
    index_IconSunset2Filled as IconSunset2Filled,
    index_IconSunsetFilled as IconSunsetFilled,
    index_IconSuperscript as IconSuperscript,
    index_IconSvg as IconSvg,
    index_IconSwimming as IconSwimming,
    index_IconSwipe as IconSwipe,
    index_IconSwipeDown as IconSwipeDown,
    index_IconSwipeDownFilled as IconSwipeDownFilled,
    index_IconSwipeLeft as IconSwipeLeft,
    index_IconSwipeLeftFilled as IconSwipeLeftFilled,
    index_IconSwipeRight as IconSwipeRight,
    index_IconSwipeRightFilled as IconSwipeRightFilled,
    index_IconSwipeUp as IconSwipeUp,
    index_IconSwipeUpFilled as IconSwipeUpFilled,
    index_IconSwitch as IconSwitch,
    index_IconSwitch2 as IconSwitch2,
    index_IconSwitch3 as IconSwitch3,
    index_IconSwitchHorizontal as IconSwitchHorizontal,
    index_IconSwitchVertical as IconSwitchVertical,
    index_IconSword as IconSword,
    index_IconSwordOff as IconSwordOff,
    index_IconSwords as IconSwords,
    index_IconTable as IconTable,
    index_IconTableAlias as IconTableAlias,
    index_IconTableColumn as IconTableColumn,
    index_IconTableDashed as IconTableDashed,
    index_IconTableDown as IconTableDown,
    index_IconTableExport as IconTableExport,
    index_IconTableFilled as IconTableFilled,
    index_IconTableHeart as IconTableHeart,
    index_IconTableImport as IconTableImport,
    index_IconTableMinus as IconTableMinus,
    index_IconTableOff as IconTableOff,
    index_IconTableOptions as IconTableOptions,
    index_IconTablePlus as IconTablePlus,
    index_IconTableRow as IconTableRow,
    index_IconTableShare as IconTableShare,
    index_IconTableShortcut as IconTableShortcut,
    index_IconTableSpark as IconTableSpark,
    index_IconTag as IconTag,
    index_IconTagFilled as IconTagFilled,
    index_IconTagMinus as IconTagMinus,
    index_IconTagOff as IconTagOff,
    index_IconTagPlus as IconTagPlus,
    index_IconTagStarred as IconTagStarred,
    index_IconTags as IconTags,
    index_IconTagsFilled as IconTagsFilled,
    index_IconTagsOff as IconTagsOff,
    index_IconTallymark1 as IconTallymark1,
    index_IconTallymark2 as IconTallymark2,
    index_IconTallymark3 as IconTallymark3,
    index_IconTallymark4 as IconTallymark4,
    index_IconTallymarks as IconTallymarks,
    index_IconTank as IconTank,
    index_IconTarget as IconTarget,
    index_IconTargetArrow as IconTargetArrow,
    index_IconTargetOff as IconTargetOff,
    index_IconTax as IconTax,
    index_IconTaxEuro as IconTaxEuro,
    index_IconTaxPound as IconTaxPound,
    index_IconTeapot as IconTeapot,
    index_IconTelescope as IconTelescope,
    index_IconTelescopeOff as IconTelescopeOff,
    index_IconTemperature as IconTemperature,
    index_IconTemperatureCelsius as IconTemperatureCelsius,
    index_IconTemperatureFahrenheit as IconTemperatureFahrenheit,
    index_IconTemperatureMinus as IconTemperatureMinus,
    index_IconTemperatureMinusFilled as IconTemperatureMinusFilled,
    index_IconTemperatureOff as IconTemperatureOff,
    index_IconTemperaturePlus as IconTemperaturePlus,
    index_IconTemperaturePlusFilled as IconTemperaturePlusFilled,
    index_IconTemperatureSnow as IconTemperatureSnow,
    index_IconTemperatureSun as IconTemperatureSun,
    index_IconTemplate as IconTemplate,
    index_IconTemplateFilled as IconTemplateFilled,
    index_IconTemplateOff as IconTemplateOff,
    index_IconTent as IconTent,
    index_IconTentOff as IconTentOff,
    index_IconTerminal as IconTerminal,
    index_IconTerminal2 as IconTerminal2,
    index_IconTestPipe as IconTestPipe,
    index_IconTestPipe2 as IconTestPipe2,
    index_IconTestPipe2Filled as IconTestPipe2Filled,
    index_IconTestPipeOff as IconTestPipeOff,
    index_IconTex as IconTex,
    index_IconTextCaption as IconTextCaption,
    index_IconTextColor as IconTextColor,
    index_IconTextDecrease as IconTextDecrease,
    index_IconTextDirectionLtr as IconTextDirectionLtr,
    index_IconTextDirectionRtl as IconTextDirectionRtl,
    index_IconTextGrammar as IconTextGrammar,
    index_IconTextIncrease as IconTextIncrease,
    index_IconTextOrientation as IconTextOrientation,
    index_IconTextPlus as IconTextPlus,
    index_IconTextRecognition as IconTextRecognition,
    index_IconTextResize as IconTextResize,
    index_IconTextScan2 as IconTextScan2,
    index_IconTextSize as IconTextSize,
    index_IconTextSpellcheck as IconTextSpellcheck,
    index_IconTextWrap as IconTextWrap,
    index_IconTextWrapColumn as IconTextWrapColumn,
    index_IconTextWrapDisabled as IconTextWrapDisabled,
    index_IconTexture as IconTexture,
    index_IconTheater as IconTheater,
    index_IconThermometer as IconThermometer,
    index_IconThumbDown as IconThumbDown,
    index_IconThumbDownFilled as IconThumbDownFilled,
    index_IconThumbDownOff as IconThumbDownOff,
    index_IconThumbUp as IconThumbUp,
    index_IconThumbUpFilled as IconThumbUpFilled,
    index_IconThumbUpOff as IconThumbUpOff,
    index_IconTicTac as IconTicTac,
    index_IconTicket as IconTicket,
    index_IconTicketOff as IconTicketOff,
    index_IconTie as IconTie,
    index_IconTilde as IconTilde,
    index_IconTiltShift as IconTiltShift,
    index_IconTiltShiftFilled as IconTiltShiftFilled,
    index_IconTiltShiftOff as IconTiltShiftOff,
    index_IconTimeDuration0 as IconTimeDuration0,
    index_IconTimeDuration10 as IconTimeDuration10,
    index_IconTimeDuration15 as IconTimeDuration15,
    index_IconTimeDuration30 as IconTimeDuration30,
    index_IconTimeDuration45 as IconTimeDuration45,
    index_IconTimeDuration5 as IconTimeDuration5,
    index_IconTimeDuration60 as IconTimeDuration60,
    index_IconTimeDuration90 as IconTimeDuration90,
    index_IconTimeDurationOff as IconTimeDurationOff,
    index_IconTimeline as IconTimeline,
    index_IconTimelineEvent as IconTimelineEvent,
    index_IconTimelineEventExclamation as IconTimelineEventExclamation,
    index_IconTimelineEventFilled as IconTimelineEventFilled,
    index_IconTimelineEventMinus as IconTimelineEventMinus,
    index_IconTimelineEventPlus as IconTimelineEventPlus,
    index_IconTimelineEventText as IconTimelineEventText,
    index_IconTimelineEventX as IconTimelineEventX,
    index_IconTimezone as IconTimezone,
    index_IconTipJar as IconTipJar,
    index_IconTipJarEuro as IconTipJarEuro,
    index_IconTipJarPound as IconTipJarPound,
    index_IconTir as IconTir,
    index_IconToggleLeft as IconToggleLeft,
    index_IconToggleLeftFilled as IconToggleLeftFilled,
    index_IconToggleRight as IconToggleRight,
    index_IconToggleRightFilled as IconToggleRightFilled,
    index_IconToiletPaper as IconToiletPaper,
    index_IconToiletPaperOff as IconToiletPaperOff,
    index_IconToml as IconToml,
    index_IconTool as IconTool,
    index_IconTools as IconTools,
    index_IconToolsKitchen as IconToolsKitchen,
    index_IconToolsKitchen2 as IconToolsKitchen2,
    index_IconToolsKitchen2Off as IconToolsKitchen2Off,
    index_IconToolsKitchen3 as IconToolsKitchen3,
    index_IconToolsKitchenOff as IconToolsKitchenOff,
    index_IconToolsOff as IconToolsOff,
    index_IconTooltip as IconTooltip,
    index_IconTopologyBus as IconTopologyBus,
    index_IconTopologyComplex as IconTopologyComplex,
    index_IconTopologyFull as IconTopologyFull,
    index_IconTopologyFullHierarchy as IconTopologyFullHierarchy,
    index_IconTopologyRing as IconTopologyRing,
    index_IconTopologyRing2 as IconTopologyRing2,
    index_IconTopologyRing3 as IconTopologyRing3,
    index_IconTopologyStar as IconTopologyStar,
    index_IconTopologyStar2 as IconTopologyStar2,
    index_IconTopologyStar3 as IconTopologyStar3,
    index_IconTopologyStarRing as IconTopologyStarRing,
    index_IconTopologyStarRing2 as IconTopologyStarRing2,
    index_IconTopologyStarRing3 as IconTopologyStarRing3,
    index_IconTorii as IconTorii,
    index_IconTornado as IconTornado,
    index_IconTournament as IconTournament,
    index_IconTower as IconTower,
    index_IconTowerOff as IconTowerOff,
    index_IconTrack as IconTrack,
    index_IconTractor as IconTractor,
    index_IconTrademark as IconTrademark,
    index_IconTrafficCone as IconTrafficCone,
    index_IconTrafficConeOff as IconTrafficConeOff,
    index_IconTrafficLights as IconTrafficLights,
    index_IconTrafficLightsOff as IconTrafficLightsOff,
    index_IconTrain as IconTrain,
    index_IconTrainFilled as IconTrainFilled,
    index_IconTransactionBitcoin as IconTransactionBitcoin,
    index_IconTransactionDollar as IconTransactionDollar,
    index_IconTransactionEuro as IconTransactionEuro,
    index_IconTransactionPound as IconTransactionPound,
    index_IconTransactionRupee as IconTransactionRupee,
    index_IconTransactionYen as IconTransactionYen,
    index_IconTransactionYuan as IconTransactionYuan,
    index_IconTransfer as IconTransfer,
    index_IconTransferIn as IconTransferIn,
    index_IconTransferOut as IconTransferOut,
    index_IconTransferVertical as IconTransferVertical,
    index_IconTransform as IconTransform,
    index_IconTransformFilled as IconTransformFilled,
    index_IconTransformPoint as IconTransformPoint,
    index_IconTransformPointBottomLeft as IconTransformPointBottomLeft,
    index_IconTransformPointBottomRight as IconTransformPointBottomRight,
    index_IconTransformPointTopLeft as IconTransformPointTopLeft,
    index_IconTransformPointTopRight as IconTransformPointTopRight,
    index_IconTransitionBottom as IconTransitionBottom,
    index_IconTransitionBottomFilled as IconTransitionBottomFilled,
    index_IconTransitionLeft as IconTransitionLeft,
    index_IconTransitionLeftFilled as IconTransitionLeftFilled,
    index_IconTransitionRight as IconTransitionRight,
    index_IconTransitionRightFilled as IconTransitionRightFilled,
    index_IconTransitionTop as IconTransitionTop,
    index_IconTransitionTopFilled as IconTransitionTopFilled,
    index_IconTrash as IconTrash,
    index_IconTrashFilled as IconTrashFilled,
    index_IconTrashOff as IconTrashOff,
    index_IconTrashX as IconTrashX,
    index_IconTrashXFilled as IconTrashXFilled,
    index_IconTreadmill as IconTreadmill,
    index_IconTree as IconTree,
    index_IconTrees as IconTrees,
    index_IconTrekking as IconTrekking,
    index_IconTrendingDown as IconTrendingDown,
    index_IconTrendingDown2 as IconTrendingDown2,
    index_IconTrendingDown3 as IconTrendingDown3,
    index_IconTrendingUp as IconTrendingUp,
    index_IconTrendingUp2 as IconTrendingUp2,
    index_IconTrendingUp3 as IconTrendingUp3,
    index_IconTriangle as IconTriangle,
    index_IconTriangleFilled as IconTriangleFilled,
    index_IconTriangleInverted as IconTriangleInverted,
    index_IconTriangleInvertedFilled as IconTriangleInvertedFilled,
    index_IconTriangleMinus as IconTriangleMinus,
    index_IconTriangleMinus2 as IconTriangleMinus2,
    index_IconTriangleOff as IconTriangleOff,
    index_IconTrianglePlus as IconTrianglePlus,
    index_IconTrianglePlus2 as IconTrianglePlus2,
    index_IconTriangleSquareCircle as IconTriangleSquareCircle,
    index_IconTriangleSquareCircleFilled as IconTriangleSquareCircleFilled,
    index_IconTriangles as IconTriangles,
    index_IconTrident as IconTrident,
    index_IconTrolley as IconTrolley,
    index_IconTrolleyFilled as IconTrolleyFilled,
    index_IconTrophy as IconTrophy,
    index_IconTrophyFilled as IconTrophyFilled,
    index_IconTrophyOff as IconTrophyOff,
    index_IconTrowel as IconTrowel,
    index_IconTruck as IconTruck,
    index_IconTruckDelivery as IconTruckDelivery,
    index_IconTruckFilled as IconTruckFilled,
    index_IconTruckLoading as IconTruckLoading,
    index_IconTruckOff as IconTruckOff,
    index_IconTruckReturn as IconTruckReturn,
    index_IconTxt as IconTxt,
    index_IconTypeface as IconTypeface,
    index_IconTypography as IconTypography,
    index_IconTypographyOff as IconTypographyOff,
    index_IconUTurnLeft as IconUTurnLeft,
    index_IconUTurnRight as IconUTurnRight,
    index_IconUfo as IconUfo,
    index_IconUfoFilled as IconUfoFilled,
    index_IconUfoOff as IconUfoOff,
    index_IconUhd as IconUhd,
    index_IconUmbrella as IconUmbrella,
    index_IconUmbrella2 as IconUmbrella2,
    index_IconUmbrellaClosed as IconUmbrellaClosed,
    index_IconUmbrellaClosed2 as IconUmbrellaClosed2,
    index_IconUmbrellaFilled as IconUmbrellaFilled,
    index_IconUmbrellaOff as IconUmbrellaOff,
    index_IconUnderline as IconUnderline,
    index_IconUniverse as IconUniverse,
    index_IconUnlink as IconUnlink,
    index_IconUpload as IconUpload,
    index_IconUrgent as IconUrgent,
    index_IconUsb as IconUsb,
    index_IconUser as IconUser,
    index_IconUserBitcoin as IconUserBitcoin,
    index_IconUserBolt as IconUserBolt,
    index_IconUserCancel as IconUserCancel,
    index_IconUserCheck as IconUserCheck,
    index_IconUserCircle as IconUserCircle,
    index_IconUserCode as IconUserCode,
    index_IconUserCog as IconUserCog,
    index_IconUserDollar as IconUserDollar,
    index_IconUserDown as IconUserDown,
    index_IconUserEdit as IconUserEdit,
    index_IconUserExclamation as IconUserExclamation,
    index_IconUserFilled as IconUserFilled,
    index_IconUserHeart as IconUserHeart,
    index_IconUserHexagon as IconUserHexagon,
    index_IconUserMinus as IconUserMinus,
    index_IconUserOff as IconUserOff,
    index_IconUserPause as IconUserPause,
    index_IconUserPentagon as IconUserPentagon,
    index_IconUserPin as IconUserPin,
    index_IconUserPlus as IconUserPlus,
    index_IconUserQuestion as IconUserQuestion,
    index_IconUserScan as IconUserScan,
    index_IconUserScreen as IconUserScreen,
    index_IconUserSearch as IconUserSearch,
    index_IconUserShare as IconUserShare,
    index_IconUserShield as IconUserShield,
    index_IconUserSquare as IconUserSquare,
    index_IconUserSquareRounded as IconUserSquareRounded,
    index_IconUserStar as IconUserStar,
    index_IconUserUp as IconUserUp,
    index_IconUserX as IconUserX,
    index_IconUsers as IconUsers,
    index_IconUsersGroup as IconUsersGroup,
    index_IconUsersMinus as IconUsersMinus,
    index_IconUsersPlus as IconUsersPlus,
    index_IconUvIndex as IconUvIndex,
    index_IconUxCircle as IconUxCircle,
    index_IconVaccine as IconVaccine,
    index_IconVaccineBottle as IconVaccineBottle,
    index_IconVaccineBottleOff as IconVaccineBottleOff,
    index_IconVaccineOff as IconVaccineOff,
    index_IconVacuumCleaner as IconVacuumCleaner,
    index_IconVariable as IconVariable,
    index_IconVariableMinus as IconVariableMinus,
    index_IconVariableOff as IconVariableOff,
    index_IconVariablePlus as IconVariablePlus,
    index_IconVector as IconVector,
    index_IconVectorBezier as IconVectorBezier,
    index_IconVectorBezier2 as IconVectorBezier2,
    index_IconVectorBezierArc as IconVectorBezierArc,
    index_IconVectorBezierCircle as IconVectorBezierCircle,
    index_IconVectorOff as IconVectorOff,
    index_IconVectorSpline as IconVectorSpline,
    index_IconVectorTriangle as IconVectorTriangle,
    index_IconVectorTriangleOff as IconVectorTriangleOff,
    index_IconVenus as IconVenus,
    index_IconVersions as IconVersions,
    index_IconVersionsFilled as IconVersionsFilled,
    index_IconVersionsOff as IconVersionsOff,
    index_IconVideo as IconVideo,
    index_IconVideoFilled as IconVideoFilled,
    index_IconVideoMinus as IconVideoMinus,
    index_IconVideoMinusFilled as IconVideoMinusFilled,
    index_IconVideoOff as IconVideoOff,
    index_IconVideoPlus as IconVideoPlus,
    index_IconVideoPlusFilled as IconVideoPlusFilled,
    index_IconView360 as IconView360,
    index_IconView360Arrow as IconView360Arrow,
    index_IconView360Number as IconView360Number,
    index_IconView360Off as IconView360Off,
    index_IconViewfinder as IconViewfinder,
    index_IconViewfinderOff as IconViewfinderOff,
    index_IconViewportNarrow as IconViewportNarrow,
    index_IconViewportShort as IconViewportShort,
    index_IconViewportTall as IconViewportTall,
    index_IconViewportWide as IconViewportWide,
    index_IconVinyl as IconVinyl,
    index_IconVip as IconVip,
    index_IconVipOff as IconVipOff,
    index_IconVirus as IconVirus,
    index_IconVirusOff as IconVirusOff,
    index_IconVirusSearch as IconVirusSearch,
    index_IconVocabulary as IconVocabulary,
    index_IconVocabularyOff as IconVocabularyOff,
    index_IconVolcano as IconVolcano,
    index_IconVolume as IconVolume,
    index_IconVolume2 as IconVolume2,
    index_IconVolume3 as IconVolume3,
    index_IconVolume4 as IconVolume4,
    index_IconVolumeOff as IconVolumeOff,
    index_IconVs as IconVs,
    index_IconWalk as IconWalk,
    index_IconWall as IconWall,
    index_IconWallOff as IconWallOff,
    index_IconWallet as IconWallet,
    index_IconWalletOff as IconWalletOff,
    index_IconWallpaper as IconWallpaper,
    index_IconWallpaperOff as IconWallpaperOff,
    index_IconWand as IconWand,
    index_IconWandOff as IconWandOff,
    index_IconWash as IconWash,
    index_IconWashDry as IconWashDry,
    index_IconWashDry1 as IconWashDry1,
    index_IconWashDry2 as IconWashDry2,
    index_IconWashDry3 as IconWashDry3,
    index_IconWashDryA as IconWashDryA,
    index_IconWashDryDip as IconWashDryDip,
    index_IconWashDryF as IconWashDryF,
    index_IconWashDryFlat as IconWashDryFlat,
    index_IconWashDryHang as IconWashDryHang,
    index_IconWashDryOff as IconWashDryOff,
    index_IconWashDryP as IconWashDryP,
    index_IconWashDryShade as IconWashDryShade,
    index_IconWashDryW as IconWashDryW,
    index_IconWashDryclean as IconWashDryclean,
    index_IconWashDrycleanOff as IconWashDrycleanOff,
    index_IconWashEco as IconWashEco,
    index_IconWashGentle as IconWashGentle,
    index_IconWashHand as IconWashHand,
    index_IconWashMachine as IconWashMachine,
    index_IconWashOff as IconWashOff,
    index_IconWashPress as IconWashPress,
    index_IconWashTemperature1 as IconWashTemperature1,
    index_IconWashTemperature2 as IconWashTemperature2,
    index_IconWashTemperature3 as IconWashTemperature3,
    index_IconWashTemperature4 as IconWashTemperature4,
    index_IconWashTemperature5 as IconWashTemperature5,
    index_IconWashTemperature6 as IconWashTemperature6,
    index_IconWashTumbleDry as IconWashTumbleDry,
    index_IconWashTumbleOff as IconWashTumbleOff,
    index_IconWaterpolo as IconWaterpolo,
    index_IconWaveSawTool as IconWaveSawTool,
    index_IconWaveSine as IconWaveSine,
    index_IconWaveSquare as IconWaveSquare,
    index_IconWavesElectricity as IconWavesElectricity,
    index_IconWebhook as IconWebhook,
    index_IconWebhookOff as IconWebhookOff,
    index_IconWeight as IconWeight,
    index_IconWheat as IconWheat,
    index_IconWheatOff as IconWheatOff,
    index_IconWheel as IconWheel,
    index_IconWheelchair as IconWheelchair,
    index_IconWheelchairOff as IconWheelchairOff,
    index_IconWhirl as IconWhirl,
    index_IconWhisk as IconWhisk,
    index_IconWifi as IconWifi,
    index_IconWifi0 as IconWifi0,
    index_IconWifi1 as IconWifi1,
    index_IconWifi2 as IconWifi2,
    index_IconWifiOff as IconWifiOff,
    index_IconWind as IconWind,
    index_IconWindElectricity as IconWindElectricity,
    index_IconWindOff as IconWindOff,
    index_IconWindmill as IconWindmill,
    index_IconWindmillFilled as IconWindmillFilled,
    index_IconWindmillOff as IconWindmillOff,
    index_IconWindow as IconWindow,
    index_IconWindowMaximize as IconWindowMaximize,
    index_IconWindowMinimize as IconWindowMinimize,
    index_IconWindowOff as IconWindowOff,
    index_IconWindsock as IconWindsock,
    index_IconWindsockFilled as IconWindsockFilled,
    index_IconWiper as IconWiper,
    index_IconWiperWash as IconWiperWash,
    index_IconWoman as IconWoman,
    index_IconWomanFilled as IconWomanFilled,
    index_IconWood as IconWood,
    index_IconWorld as IconWorld,
    index_IconWorldBolt as IconWorldBolt,
    index_IconWorldCancel as IconWorldCancel,
    index_IconWorldCheck as IconWorldCheck,
    index_IconWorldCode as IconWorldCode,
    index_IconWorldCog as IconWorldCog,
    index_IconWorldDollar as IconWorldDollar,
    index_IconWorldDown as IconWorldDown,
    index_IconWorldDownload as IconWorldDownload,
    index_IconWorldExclamation as IconWorldExclamation,
    index_IconWorldHeart as IconWorldHeart,
    index_IconWorldLatitude as IconWorldLatitude,
    index_IconWorldLongitude as IconWorldLongitude,
    index_IconWorldMinus as IconWorldMinus,
    index_IconWorldOff as IconWorldOff,
    index_IconWorldPause as IconWorldPause,
    index_IconWorldPin as IconWorldPin,
    index_IconWorldPlus as IconWorldPlus,
    index_IconWorldQuestion as IconWorldQuestion,
    index_IconWorldSearch as IconWorldSearch,
    index_IconWorldShare as IconWorldShare,
    index_IconWorldStar as IconWorldStar,
    index_IconWorldUp as IconWorldUp,
    index_IconWorldUpload as IconWorldUpload,
    index_IconWorldWww as IconWorldWww,
    index_IconWorldX as IconWorldX,
    index_IconWreckingBall as IconWreckingBall,
    index_IconWriting as IconWriting,
    index_IconWritingFilled as IconWritingFilled,
    index_IconWritingOff as IconWritingOff,
    index_IconWritingSign as IconWritingSign,
    index_IconWritingSignFilled as IconWritingSignFilled,
    index_IconWritingSignOff as IconWritingSignOff,
    index_IconX as IconX,
    index_IconXPowerY as IconXPowerY,
    index_IconXboxA as IconXboxA,
    index_IconXboxAFilled as IconXboxAFilled,
    index_IconXboxB as IconXboxB,
    index_IconXboxBFilled as IconXboxBFilled,
    index_IconXboxX as IconXboxX,
    index_IconXboxXFilled as IconXboxXFilled,
    index_IconXboxY as IconXboxY,
    index_IconXboxYFilled as IconXboxYFilled,
    index_IconXd as IconXd,
    index_IconXxx as IconXxx,
    index_IconYinYang as IconYinYang,
    index_IconYinYangFilled as IconYinYangFilled,
    index_IconYoga as IconYoga,
    index_IconZeppelin as IconZeppelin,
    index_IconZeppelinFilled as IconZeppelinFilled,
    index_IconZeppelinOff as IconZeppelinOff,
    index_IconZip as IconZip,
    index_IconZodiacAquarius as IconZodiacAquarius,
    index_IconZodiacAries as IconZodiacAries,
    index_IconZodiacCancer as IconZodiacCancer,
    index_IconZodiacCapricorn as IconZodiacCapricorn,
    index_IconZodiacGemini as IconZodiacGemini,
    index_IconZodiacLeo as IconZodiacLeo,
    index_IconZodiacLibra as IconZodiacLibra,
    index_IconZodiacPisces as IconZodiacPisces,
    index_IconZodiacSagittarius as IconZodiacSagittarius,
    index_IconZodiacScorpio as IconZodiacScorpio,
    index_IconZodiacTaurus as IconZodiacTaurus,
    index_IconZodiacVirgo as IconZodiacVirgo,
    index_IconZoom as IconZoom,
    index_IconZoomCancel as IconZoomCancel,
    index_IconZoomCancelFilled as IconZoomCancelFilled,
    index_IconZoomCheck as IconZoomCheck,
    index_IconZoomCheckFilled as IconZoomCheckFilled,
    index_IconZoomCode as IconZoomCode,
    index_IconZoomCodeFilled as IconZoomCodeFilled,
    index_IconZoomExclamation as IconZoomExclamation,
    index_IconZoomExclamationFilled as IconZoomExclamationFilled,
    index_IconZoomFilled as IconZoomFilled,
    index_IconZoomIn as IconZoomIn,
    index_IconZoomInArea as IconZoomInArea,
    index_IconZoomInAreaFilled as IconZoomInAreaFilled,
    index_IconZoomInFilled as IconZoomInFilled,
    index_IconZoomMoney as IconZoomMoney,
    index_IconZoomMoneyFilled as IconZoomMoneyFilled,
    index_IconZoomOut as IconZoomOut,
    index_IconZoomOutArea as IconZoomOutArea,
    index_IconZoomOutAreaFilled as IconZoomOutAreaFilled,
    index_IconZoomOutFilled as IconZoomOutFilled,
    index_IconZoomPan as IconZoomPan,
    index_IconZoomPanFilled as IconZoomPanFilled,
    index_IconZoomQuestion as IconZoomQuestion,
    index_IconZoomQuestionFilled as IconZoomQuestionFilled,
    index_IconZoomReplace as IconZoomReplace,
    index_IconZoomReset as IconZoomReset,
    index_IconZoomScan as IconZoomScan,
    index_IconZoomScanFilled as IconZoomScanFilled,
    index_IconZzz as IconZzz,
    index_IconZzzOff as IconZzzOff,
  };
}

declare const _default: string[];

declare namespace iconsList {
  export {
    _default as default,
  };
}

declare const createReactComponent: (type: "outline" | "filled", iconName: string, iconNamePascal: string, iconNode: IconNode) => react.ForwardRefExoticComponent<IconProps & react.RefAttributes<SVGSVGElement>>;

export { IconNumber123 as Icon123, IconHours12 as Icon12Hours, IconHours24 as Icon24Hours, IconAuth2fa as Icon2fa, IconView360Arrow as Icon360, IconView360Number as Icon360View, IconCube3dSphere as Icon3dCubeSphere, IconCube3dSphereOff as Icon3dCubeSphereOff, IconRotate3d as Icon3dRotate, IconAB, IconAB2, IconABOff, IconAbacus, IconAbacusOff, IconAbc, IconAccessPoint, IconAccessPointOff, IconAccessible, IconAccessibleFilled, IconAccessibleOff, IconActivity, IconActivityHeartbeat, IconAd, IconAd2, IconAdCircle, IconAdCircleFilled, IconAdCircleOff, IconAdFilled, IconAdOff, IconAddressBook, IconAddressBookOff, IconAdjustments, IconAdjustmentsAlt, IconAdjustmentsBolt, IconAdjustmentsCancel, IconAdjustmentsCheck, IconAdjustmentsCode, IconAdjustmentsCog, IconAdjustmentsDollar, IconAdjustmentsDown, IconAdjustmentsExclamation, IconAdjustmentsFilled, IconAdjustmentsHeart, IconAdjustmentsHorizontal, IconAdjustmentsMinus, IconAdjustmentsOff, IconAdjustmentsPause, IconAdjustmentsPin, IconAdjustmentsPlus, IconAdjustmentsQuestion, IconAdjustmentsSearch, IconAdjustmentsShare, IconAdjustmentsSpark, IconAdjustmentsStar, IconAdjustmentsUp, IconAdjustmentsX, IconAerialLift, IconAerialLiftFilled, IconAffiliate, IconAffiliateFilled, IconAi, IconAirBalloon, IconAirBalloonFilled, IconAirConditioning, IconAirConditioningDisabled, IconAirTrafficControl, IconAlarm, IconAlarmAverage, IconAlarmFilled, IconAlarmMinus, IconAlarmMinusFilled, IconAlarmOff, IconAlarmPlus, IconAlarmPlusFilled, IconAlarmSmoke, IconAlarmSnooze, IconAlarmSnoozeFilled, IconAlbum, IconAlbumOff, IconAlertCircle, IconAlertCircleFilled, IconAlertCircleOff, IconAlertHexagon, IconAlertHexagonFilled, IconAlertHexagonOff, IconAlertOctagon, IconAlertOctagonFilled, IconAlertSmall, IconAlertSmallOff, IconAlertSquare, IconAlertSquareFilled, IconAlertSquareRounded, IconAlertSquareRoundedFilled, IconAlertSquareRoundedOff, IconAlertTriangle, IconAlertTriangleFilled, IconAlertTriangleOff, IconAlien, IconAlienFilled, IconAlignBoxBottomCenter, IconAlignBoxBottomCenterFilled, IconAlignBoxBottomLeft, IconAlignBoxBottomLeftFilled, IconAlignBoxBottomRight, IconAlignBoxBottomRightFilled, IconAlignBoxCenterBottom, IconAlignBoxCenterMiddle, IconAlignBoxCenterMiddleFilled, IconAlignBoxCenterStretch, IconAlignBoxCenterTop, IconAlignBoxLeftBottom, IconAlignBoxLeftBottomFilled, IconAlignBoxLeftMiddle, IconAlignBoxLeftMiddleFilled, IconAlignBoxLeftStretch, IconAlignBoxLeftTop, IconAlignBoxLeftTopFilled, IconAlignBoxRightBottom, IconAlignBoxRightBottomFilled, IconAlignBoxRightMiddle, IconAlignBoxRightMiddleFilled, IconAlignBoxRightStretch, IconAlignBoxRightTop, IconAlignBoxRightTopFilled, IconAlignBoxTopCenter, IconAlignBoxTopCenterFilled, IconAlignBoxTopLeft, IconAlignBoxTopLeftFilled, IconAlignBoxTopRight, IconAlignBoxTopRightFilled, IconAlignCenter, IconAlignJustified, IconAlignLeft, IconAlignLeft2, IconAlignRight, IconAlignRight2, IconAlpha, IconAlphabetArabic, IconAlphabetBangla, IconAlphabetCyrillic, IconAlphabetGreek, IconAlphabetHebrew, IconAlphabetKorean, IconAlphabetLatin, IconAlphabetPolish, IconAlphabetRunes, IconAlphabetThai, IconAlt, IconAmbulance, IconAmpersand, IconAnalyze, IconAnalyzeFilled, IconAnalyzeOff, IconAnchor, IconAnchorOff, IconAngle, IconAnkh, IconAntenna, IconAntennaBars1, IconAntennaBars2, IconAntennaBars3, IconAntennaBars4, IconAntennaBars5, IconAntennaBarsOff, IconAntennaOff, IconAperture, IconApertureOff, IconApi, IconApiApp, IconApiAppOff, IconApiOff, IconAppWindow, IconAppWindowFilled, IconApple, IconAppleFilled, IconApps, IconAppsFilled, IconAppsOff, IconArcheryArrow, IconArchive, IconArchiveFilled, IconArchiveOff, IconArmchair, IconArmchair2, IconArmchair2Off, IconArmchairOff, IconArrowAutofitContent, IconArrowAutofitContentFilled, IconArrowAutofitDown, IconArrowAutofitDownFilled, IconArrowAutofitHeight, IconArrowAutofitHeightFilled, IconArrowAutofitLeft, IconArrowAutofitLeftFilled, IconArrowAutofitRight, IconArrowAutofitRightFilled, IconArrowAutofitUp, IconArrowAutofitUpFilled, IconArrowAutofitWidth, IconArrowAutofitWidthFilled, IconArrowBack, IconArrowBackUp, IconArrowBackUpDouble, IconArrowBadgeDown, IconArrowBadgeDownFilled, IconArrowBadgeLeft, IconArrowBadgeLeftFilled, IconArrowBadgeRight, IconArrowBadgeRightFilled, IconArrowBadgeUp, IconArrowBadgeUpFilled, IconArrowBarBoth, IconArrowBarDown, IconArrowBarLeft, IconArrowBarRight, IconArrowBarToDown, IconArrowBarToDownDashed, IconArrowBarToLeft, IconArrowBarToLeftDashed, IconArrowBarToRight, IconArrowBarToRightDashed, IconArrowBarToUp, IconArrowBarToUpDashed, IconArrowBarUp, IconArrowBearLeft, IconArrowBearLeft2, IconArrowBearRight, IconArrowBearRight2, IconArrowBigDown, IconArrowBigDownFilled, IconArrowBigDownLine, IconArrowBigDownLineFilled, IconArrowBigDownLines, IconArrowBigDownLinesFilled, IconArrowBigLeft, IconArrowBigLeftFilled, IconArrowBigLeftLine, IconArrowBigLeftLineFilled, IconArrowBigLeftLines, IconArrowBigLeftLinesFilled, IconArrowBigRight, IconArrowBigRightFilled, IconArrowBigRightLine, IconArrowBigRightLineFilled, IconArrowBigRightLines, IconArrowBigRightLinesFilled, IconArrowBigUp, IconArrowBigUpFilled, IconArrowBigUpLine, IconArrowBigUpLineFilled, IconArrowBigUpLines, IconArrowBigUpLinesFilled, IconArrowBounce, IconArrowCapsule, IconArrowCurveLeft, IconArrowCurveRight, IconArrowDown, IconArrowDownBar, IconArrowDownCircle, IconArrowDownCircleFilled, IconArrowDownDashed, IconArrowDownFromArc, IconArrowDownLeft, IconArrowDownLeftCircle, IconArrowDownRhombus, IconArrowDownRhombusFilled, IconArrowDownRight, IconArrowDownRightCircle, IconArrowDownSquare, IconArrowDownSquareFilled, IconArrowDownTail, IconArrowDownToArc, IconArrowElbowLeft, IconArrowElbowRight, IconArrowFork, IconArrowForward, IconArrowForwardUp, IconArrowForwardUpDouble, IconArrowGuide, IconArrowGuideFilled, IconArrowIteration, IconArrowLeft, IconArrowLeftBar, IconArrowLeftCircle, IconArrowLeftCircleFilled, IconArrowLeftDashed, IconArrowLeftFromArc, IconArrowLeftRhombus, IconArrowLeftRhombusFilled, IconArrowLeftRight, IconArrowLeftSquare, IconArrowLeftSquareFilled, IconArrowLeftTail, IconArrowLeftToArc, IconArrowLoopLeft, IconArrowLoopLeft2, IconArrowLoopRight, IconArrowLoopRight2, IconArrowMerge, IconArrowMergeAltLeft, IconArrowMergeAltRight, IconArrowMergeBoth, IconArrowMergeLeft, IconArrowMergeRight, IconArrowMoveDown, IconArrowMoveDownFilled, IconArrowMoveLeft, IconArrowMoveLeftFilled, IconArrowMoveRight, IconArrowMoveRightFilled, IconArrowMoveUp, IconArrowMoveUpFilled, IconArrowNarrowDown, IconArrowNarrowDownDashed, IconArrowNarrowLeft, IconArrowNarrowLeftDashed, IconArrowNarrowRight, IconArrowNarrowRightDashed, IconArrowNarrowUp, IconArrowNarrowUpDashed, IconArrowRampLeft, IconArrowRampLeft2, IconArrowRampLeft3, IconArrowRampRight, IconArrowRampRight2, IconArrowRampRight3, IconArrowRight, IconArrowRightBar, IconArrowRightCircle, IconArrowRightCircleFilled, IconArrowRightDashed, IconArrowRightFromArc, IconArrowRightRhombus, IconArrowRightRhombusFilled, IconArrowRightSquare, IconArrowRightSquareFilled, IconArrowRightTail, IconArrowRightToArc, IconArrowRotaryFirstLeft, IconArrowRotaryFirstRight, IconArrowRotaryLastLeft, IconArrowRotaryLastRight, IconArrowRotaryLeft, IconArrowRotaryRight, IconArrowRotaryStraight, IconArrowRoundaboutLeft, IconArrowRoundaboutRight, IconArrowSharpTurnLeft, IconArrowSharpTurnRight, IconArrowUp, IconArrowUpBar, IconArrowUpCircle, IconArrowUpCircleFilled, IconArrowUpDashed, IconArrowUpFromArc, IconArrowUpLeft, IconArrowUpLeftCircle, IconArrowUpRhombus, IconArrowUpRhombusFilled, IconArrowUpRight, IconArrowUpRightCircle, IconArrowUpSquare, IconArrowUpSquareFilled, IconArrowUpTail, IconArrowUpToArc, IconArrowWaveLeftDown, IconArrowWaveLeftUp, IconArrowWaveRightDown, IconArrowWaveRightUp, IconArrowZigZag, IconArrowsCross, IconArrowsDiagonal, IconArrowsDiagonal2, IconArrowsDiagonalMinimize, IconArrowsDiagonalMinimize2, IconArrowsDiff, IconArrowsDoubleNeSw, IconArrowsDoubleNwSe, IconArrowsDoubleSeNw, IconArrowsDoubleSwNe, IconArrowsDown, IconArrowsDownUp, IconArrowsExchange, IconArrowsExchange2, IconArrowsHorizontal, IconArrowsJoin, IconArrowsJoin2, IconArrowsLeft, IconArrowsLeftDown, IconArrowsLeftRight, IconArrowsMaximize, IconArrowsMinimize, IconArrowsMove, IconArrowsMoveHorizontal, IconArrowsMoveVertical, IconArrowsRandom, IconArrowsRight, IconArrowsRightDown, IconArrowsRightLeft, IconArrowsShuffle, IconArrowsShuffle2, IconArrowsSort, IconArrowsSplit, IconArrowsSplit2, IconArrowsTransferDown, IconArrowsTransferUp, IconArrowsTransferUpDown, IconArrowsUp, IconArrowsUpDown, IconArrowsUpLeft, IconArrowsUpRight, IconArrowsVertical, IconArtboard, IconArtboardFilled, IconArtboardOff, IconArticle, IconArticleFilled, IconArticleOff, IconAspectRatio, IconAspectRatioFilled, IconAspectRatioOff, IconAssembly, IconAssemblyFilled, IconAssemblyOff, IconAsset, IconAssetFilled, IconAsterisk, IconAsteriskSimple, IconAt, IconAtOff, IconAtom, IconAtom2, IconAtom2Filled, IconAtomOff, IconAugmentedReality, IconAugmentedReality2, IconAugmentedRealityOff, IconAuth2fa, IconAutomaticGearbox, IconAutomaticGearboxFilled, IconAutomation, IconAvocado, IconAward, IconAwardFilled, IconAwardOff, IconAxe, IconAxisX, IconAxisY, IconBabyBottle, IconBabyCarriage, IconBabyCarriageFilled, IconBackground, IconBackhoe, IconBackpack, IconBackpackOff, IconBackslash, IconBackspace, IconBackspaceFilled, IconBadge, IconBadge2k, IconBadge3d, IconBadge3dFilled, IconBadge3k, IconBadge4k, IconBadge4kFilled, IconBadge5k, IconBadge8k, IconBadge8kFilled, IconBadgeAd, IconBadgeAdFilled, IconBadgeAdOff, IconBadgeAr, IconBadgeArFilled, IconBadgeCc, IconBadgeCcFilled, IconBadgeFilled, IconBadgeHd, IconBadgeHdFilled, IconBadgeOff, IconBadgeSd, IconBadgeSdFilled, IconBadgeTm, IconBadgeTmFilled, IconBadgeVo, IconBadgeVoFilled, IconBadgeVr, IconBadgeVrFilled, IconBadgeWc, IconBadgeWcFilled, IconBadges, IconBadgesFilled, IconBadgesOff, IconBaguette, IconBallAmericanFootball, IconBallAmericanFootballOff, IconBallBaseball, IconBallBasketball, IconBallBowling, IconBallBowlingFilled, IconBallFootball, IconBallFootballOff, IconBallTennis, IconBallVolleyball, IconBalloon, IconBalloonFilled, IconBalloonOff, IconBallpen, IconBallpenFilled, IconBallpenOff, IconBan, IconBandage, IconBandageFilled, IconBandageOff, IconBarbell, IconBarbellFilled, IconBarbellOff, IconBarcode, IconBarcodeOff, IconBarrel, IconBarrelOff, IconBarrierBlock, IconBarrierBlockFilled, IconBarrierBlockOff, IconBaseline, IconBaselineDensityLarge, IconBaselineDensityMedium, IconBaselineDensitySmall, IconBasket, IconBasketBolt, IconBasketCancel, IconBasketCheck, IconBasketCode, IconBasketCog, IconBasketDiscount, IconBasketDollar, IconBasketDown, IconBasketExclamation, IconBasketFilled, IconBasketHeart, IconBasketMinus, IconBasketOff, IconBasketPause, IconBasketPin, IconBasketPlus, IconBasketQuestion, IconBasketSearch, IconBasketShare, IconBasketStar, IconBasketUp, IconBasketX, IconBat, IconBath, IconBathFilled, IconBathOff, IconBattery, IconBattery1, IconBattery1Filled, IconBattery2, IconBattery2Filled, IconBattery3, IconBattery3Filled, IconBattery4, IconBattery4Filled, IconBatteryAutomotive, IconBatteryAutomotiveFilled, IconBatteryCharging, IconBatteryCharging2, IconBatteryEco, IconBatteryExclamation, IconBatteryFilled, IconBatteryOff, IconBatterySpark, IconBatteryVertical, IconBatteryVertical1, IconBatteryVertical1Filled, IconBatteryVertical2, IconBatteryVertical2Filled, IconBatteryVertical3, IconBatteryVertical3Filled, IconBatteryVertical4, IconBatteryVertical4Filled, IconBatteryVerticalCharging, IconBatteryVerticalCharging2, IconBatteryVerticalEco, IconBatteryVerticalExclamation, IconBatteryVerticalFilled, IconBatteryVerticalOff, IconBeach, IconBeachOff, IconBed, IconBedFilled, IconBedFlat, IconBedFlatFilled, IconBedOff, IconBeer, IconBeerFilled, IconBeerOff, IconBell, IconBellBolt, IconBellCancel, IconBellCheck, IconBellCode, IconBellCog, IconBellDollar, IconBellDown, IconBellExclamation, IconBellFilled, IconBellHeart, IconBellMinus, IconBellMinusFilled, IconBellOff, IconBellPause, IconBellPin, IconBellPlus, IconBellPlusFilled, IconBellQuestion, IconBellRinging, IconBellRinging2, IconBellRinging2Filled, IconBellRingingFilled, IconBellSchool, IconBellSearch, IconBellShare, IconBellStar, IconBellUp, IconBellX, IconBellXFilled, IconBellZ, IconBellZFilled, IconBeta, IconBible, IconBike, IconBikeFilled, IconBikeOff, IconBinary, IconBinaryOff, IconBinaryTree, IconBinaryTree2, IconBinaryTree2Filled, IconBinaryTreeFilled, IconBinoculars, IconBinocularsFilled, IconBiohazard, IconBiohazardFilled, IconBiohazardOff, IconBlade, IconBladeFilled, IconBleach, IconBleachChlorine, IconBleachNoChlorine, IconBleachOff, IconBlendMode, IconBlender, IconBlenderFilled, IconBlind, IconBlob, IconBlobFilled, IconBlockquote, IconBlocks, IconBluetooth, IconBluetoothConnected, IconBluetoothOff, IconBluetoothX, IconBlur, IconBlurOff, IconBmp, IconBodyScan, IconBold, IconBoldOff, IconBolt, IconBoltFilled, IconBoltOff, IconBomb, IconBombFilled, IconBone, IconBoneFilled, IconBoneOff, IconBong, IconBongFilled, IconBongOff, IconBook, IconBook2, IconBookDownload, IconBookFilled, IconBookOff, IconBookUpload, IconBookmark, IconBookmarkAi, IconBookmarkEdit, IconBookmarkFilled, IconBookmarkMinus, IconBookmarkOff, IconBookmarkPlus, IconBookmarkQuestion, IconBookmarks, IconBookmarksFilled, IconBookmarksOff, IconBooks, IconBooksOff, IconBoom, IconBoomFilled, IconBorderAll, IconBorderBottom, IconBorderBottomPlus, IconBorderCornerIos, IconBorderCornerPill, IconBorderCornerRounded, IconBorderCornerSquare, IconBorderCorners, IconBorderHorizontal, IconBorderInner, IconBorderLeft, IconBorderLeftPlus, IconBorderNone, IconBorderOuter, IconBorderRadius, IconBorderRight, IconBorderRightPlus, IconBorderSides, IconBorderStyle, IconBorderStyle2, IconBorderTop, IconBorderTopPlus, IconBorderVertical, IconBottle, IconBottleFilled, IconBottleOff, IconBounceLeft, IconBounceLeftFilled, IconBounceRight, IconBounceRightFilled, IconBow, IconBowFilled, IconBowl, IconBowlChopsticks, IconBowlChopsticksFilled, IconBowlFilled, IconBowlSpoon, IconBowlSpoonFilled, IconBowling, IconBox, IconBoxAlignBottom, IconBoxAlignBottomFilled, IconBoxAlignBottomLeft, IconBoxAlignBottomLeftFilled, IconBoxAlignBottomRight, IconBoxAlignBottomRightFilled, IconBoxAlignLeft, IconBoxAlignLeftFilled, IconBoxAlignRight, IconBoxAlignRightFilled, IconBoxAlignTop, IconBoxAlignTopFilled, IconBoxAlignTopLeft, IconBoxAlignTopLeftFilled, IconBoxAlignTopRight, IconBoxAlignTopRightFilled, IconBoxMargin, IconBoxModel, IconBoxModel2, IconBoxModel2Off, IconBoxModelOff, IconBoxMultiple, IconBoxMultiple0, IconBoxMultiple1, IconBoxMultiple2, IconBoxMultiple3, IconBoxMultiple4, IconBoxMultiple5, IconBoxMultiple6, IconBoxMultiple7, IconBoxMultiple8, IconBoxMultiple9, IconBoxMultipleFilled, IconBoxOff, IconBoxPadding, IconPackage as IconBoxSeam, IconBraces, IconBracesOff, IconBrackets, IconBracketsAngle, IconBracketsAngleOff, IconBracketsContain, IconBracketsContainEnd, IconBracketsContainStart, IconBracketsOff, IconBraille, IconBrain, IconBrand4chan, IconBrandAbstract, IconBrandAdobe, IconBrandAdobeAfterEffect, IconBrandAdobeIllustrator, IconBrandAdobeIndesign, IconBrandAdobePhotoshop, IconBrandAdobePremiere as IconBrandAdobePremier, IconBrandAdobePremiere, IconBrandAdobeXd, IconBrandAdonisJs, IconBrandAirbnb, IconBrandAirtable, IconBrandAlgolia, IconBrandAlipay, IconBrandAlpineJs, IconBrandAmazon, IconBrandAmd, IconBrandAmie, IconBrandAmigo, IconBrandAmongUs, IconBrandAndroid, IconBrandAngular, IconBrandAngularFilled, IconBrandAnsible, IconBrandAo3, IconBrandAppgallery, IconBrandApple, IconBrandAppleArcade, IconBrandAppleFilled, IconBrandAppleNews, IconBrandApplePodcast, IconBrandAppstore, IconBrandArc, IconBrandAsana, IconBrandAstro, IconBrandAuth0, IconBrandAws, IconBrandAzure, IconBrandBackbone, IconBrandBadoo, IconBrandBaidu, IconBrandBandcamp, IconBrandBandlab, IconBrandBeats, IconBrandBebo, IconBrandBehance, IconBrandBilibili, IconBrandBinance, IconBrandBing, IconBrandBitbucket, IconBrandBitbucketFilled, IconBrandBlackberry, IconBrandBlender, IconBrandBlogger, IconBrandBluesky, IconBrandBooking, IconBrandBootstrap, IconBrandBulma, IconBrandBumble, IconBrandBunpo, IconBrandCSharp, IconBrandCake, IconBrandCakephp, IconBrandCampaignmonitor, IconBrandCarbon, IconBrandCashapp, IconBrandChrome, IconBrandCinema4d, IconBrandCitymapper, IconBrandCloudflare, IconBrandCodecov, IconBrandCodepen, IconBrandCodesandbox, IconBrandCohost, IconBrandCoinbase, IconBrandComedyCentral, IconBrandCoreos, IconBrandCouchdb, IconBrandCouchsurfing, IconBrandCpp, IconBrandCraft, IconBrandCrunchbase, IconBrandCss3, IconBrandCtemplar, IconBrandCucumber, IconBrandCupra, IconBrandCypress, IconBrandD3, IconBrandDatabricks, IconBrandDaysCounter, IconBrandDcos, IconBrandDebian, IconBrandDeezer, IconBrandDeliveroo, IconBrandDeno, IconBrandDenodo, IconBrandDeviantart, IconBrandDigg, IconBrandDingtalk, IconBrandDiscord, IconBrandDiscordFilled, IconBrandDisney, IconBrandDisqus, IconBrandDjango, IconBrandDocker, IconBrandDoctrine, IconBrandDolbyDigital, IconBrandDouban, IconBrandDribbble, IconBrandDribbbleFilled, IconBrandDropbox, IconBrandDrops, IconBrandDrupal, IconBrandEdge, IconBrandElastic, IconBrandElectronicArts, IconBrandEmber, IconBrandEnvato, IconBrandEtsy, IconBrandEvernote, IconBrandFacebook, IconBrandFacebookFilled, IconBrandFeedly, IconBrandFigma, IconBrandFilezilla, IconBrandFinder, IconBrandFirebase, IconBrandFirefox, IconBrandFiverr, IconBrandFlickr, IconBrandFlightradar24, IconBrandFlipboard, IconBrandFlutter, IconBrandFortnite, IconBrandFoursquare, IconBrandFramer, IconBrandFramerMotion, IconBrandFunimation, IconBrandGatsby, IconBrandGit, IconBrandGithub, IconBrandGithubCopilot, IconBrandGithubFilled, IconBrandGitlab, IconBrandGmail, IconBrandGolang, IconBrandGoogle, IconBrandGoogleAnalytics, IconBrandGoogleBigQuery, IconBrandGoogleDrive, IconBrandGoogleFilled, IconBrandGoogleFit, IconBrandGoogleHome, IconBrandGoogleMaps, IconBrandGoogleOne, IconBrandGooglePhotos, IconBrandGooglePlay, IconBrandGooglePodcasts, IconBrandGrammarly, IconBrandGraphql, IconBrandGravatar, IconBrandGrindr, IconBrandGuardian, IconBrandGumroad, IconBrandHackerrank, IconBrandHbo, IconBrandHeadlessui, IconBrandHexo, IconBrandHipchat, IconBrandHtml5, IconBrandInertia, IconBrandInstagram, IconBrandInstagramFilled, IconBrandIntercom, IconBrandItch, IconBrandJavascript, IconBrandJuejin, IconBrandKakoTalk, IconBrandKbin, IconBrandKick, IconBrandKickFilled, IconBrandKickstarter, IconBrandKotlin, IconBrandLaravel, IconBrandLastfm, IconBrandLeetcode, IconBrandLetterboxd, IconBrandLine, IconBrandLinkedin, IconBrandLinkedinFilled, IconBrandLinktree, IconBrandLinqpad, IconBrandLivewire, IconBrandLoom, IconBrandMailgun, IconBrandMantine, IconBrandMastercard, IconBrandMastodon, IconBrandMatrix, IconBrandMcdonalds, IconBrandMedium, IconBrandMeetup, IconBrandMercedes, IconBrandMessenger, IconBrandMessengerFilled, IconBrandMeta, IconBrandMetabrainz, IconBrandMinecraft, IconBrandMiniprogram, IconBrandMixpanel, IconBrandMonday, IconBrandMongodb, IconBrandMyOppo, IconBrandMysql, IconBrandNationalGeographic, IconBrandNem, IconBrandNetbeans, IconBrandNeteaseMusic, IconBrandNetflix, IconBrandNexo, IconBrandNextcloud, IconBrandNextjs, IconBrandNodejs, IconBrandNordVpn, IconBrandNotion, IconBrandNpm, IconBrandNuxt, IconBrandNytimes, IconBrandOauth, IconBrandOffice, IconBrandOkRu, IconBrandOnedrive, IconBrandOnlyfans, IconBrandOpenSource, IconBrandOpenSourceFilled, IconBrandOpenai, IconBrandOpenvpn, IconBrandOpera, IconBrandOperaFilled, IconBrandPagekit, IconBrandParsinta, IconBrandPatreon, IconBrandPatreonFilled, IconBrandPaypal, IconBrandPaypalFilled, IconBrandPaypay, IconBrandPeanut, IconBrandPepsi, IconBrandPhp, IconBrandPicsart, IconBrandPinterest, IconBrandPinterestFilled, IconBrandPlanetscale, IconBrandPnpm, IconBrandPocket, IconBrandPolymer, IconBrandPowershell, IconBrandPrintables, IconBrandPrisma, IconBrandProducthunt, IconBrandPushbullet, IconBrandPushover, IconBrandPython, IconBrandQq, IconBrandRadixUi, IconBrandReact, IconBrandReactNative, IconBrandReason, IconBrandReddit, IconBrandRedhat, IconBrandRedux, IconBrandRevolut, IconBrandRumble, IconBrandRust, IconBrandSafari, IconBrandSamsungpass, IconBrandSass, IconBrandSentry, IconBrandSharik, IconBrandShazam, IconBrandShopee, IconBrandSketch, IconBrandSketchFilled, IconBrandSkype, IconBrandSlack, IconBrandSnapchat, IconBrandSnapchatFilled, IconBrandSnapseed, IconBrandSnowflake, IconBrandSocketIo, IconBrandSolidjs, IconBrandSoundcloud, IconBrandSpacehey, IconBrandSpeedtest, IconBrandSpotify, IconBrandSpotifyFilled, IconBrandStackoverflow, IconBrandStackshare, IconBrandSteam, IconBrandSteamFilled, IconBrandStocktwits, IconBrandStorj, IconBrandStorybook, IconBrandStorytel, IconBrandStrava, IconBrandStripe, IconBrandStripeFilled, IconBrandSublimeText, IconBrandSugarizer, IconBrandSupabase, IconBrandSuperhuman, IconBrandSupernova, IconBrandSurfshark, IconBrandSvelte, IconBrandSwift, IconBrandSymfony, IconBrandTabler, IconBrandTablerFilled, IconBrandTabnine, IconBrandTailwind, IconBrandTaobao, IconBrandTeams, IconBrandTed, IconBrandTelegram, IconBrandTerraform, IconBrandTesla, IconBrandTether, IconBrandThingiverse, IconBrandThreads, IconBrandThreejs, IconBrandTidal, IconBrandTiktok, IconBrandTiktokFilled, IconBrandTinder, IconBrandTinderFilled, IconBrandTopbuzz, IconBrandTorchain, IconBrandToyota, IconBrandTrello, IconBrandTripadvisor, IconBrandTumblr, IconBrandTumblrFilled, IconBrandTwilio, IconBrandTwitch, IconBrandTwitter, IconBrandTwitterFilled, IconBrandTypescript, IconBrandUber, IconBrandUbuntu, IconBrandUnity, IconBrandUnsplash, IconBrandUpwork, IconBrandValorant, IconBrandVercel, IconBrandVercelFilled, IconBrandVimeo, IconBrandVimeoFilled, IconBrandVinted, IconBrandVisa, IconBrandVisualStudio, IconBrandVite, IconBrandVivaldi, IconBrandVk, IconBrandVlc, IconBrandVolkswagen, IconBrandVsco, IconBrandVscode, IconBrandVue, IconBrandWalmart, IconBrandWaze, IconBrandWebflow, IconBrandWechat, IconBrandWeibo, IconBrandWeiboFilled, IconBrandWhatsapp, IconBrandWhatsappFilled, IconBrandWikipedia, IconBrandWindows, IconBrandWindowsFilled, IconBrandWindy, IconBrandWish, IconBrandWix, IconBrandWordpress, IconBrandX, IconBrandXFilled, IconBrandXamarin, IconBrandXbox, IconBrandXdeep, IconBrandXing, IconBrandYahoo, IconBrandYandex, IconBrandYarn, IconBrandYatse, IconBrandYcombinator, IconBrandYoutube, IconBrandYoutubeFilled, IconBrandYoutubeKids, IconBrandZalando, IconBrandZapier, IconBrandZeit, IconBrandZhihu, IconBrandZoom, IconBrandZulip, IconBrandZwift, IconBread, IconBreadFilled, IconBreadOff, IconBriefcase, IconBriefcase2, IconBriefcase2Filled, IconBriefcaseFilled, IconBriefcaseOff, IconBrightness, IconBrightness2, IconBrightnessAuto, IconBrightnessAutoFilled, IconBrightnessDown, IconBrightnessDownFilled, IconBrightnessFilled, IconBrightnessHalf, IconBrightnessOff, IconBrightnessUp, IconBrightnessUpFilled, IconBroadcast, IconBroadcastOff, IconBrowser, IconBrowserCheck, IconBrowserMaximize, IconBrowserMinus, IconBrowserOff, IconBrowserPlus, IconBrowserShare, IconBrowserX, IconBrush, IconBrushOff, IconBubble, IconBubbleFilled, IconBubbleMinus, IconBubblePlus, IconBubbleTea, IconBubbleTea2, IconBubbleText, IconBubbleTextFilled, IconBubbleX, IconBucket, IconBucketDroplet, IconBucketOff, IconBug, IconBugFilled, IconBugOff, IconBuilding, IconBuildingAirport, IconBuildingArch, IconBuildingBank, IconBuildingBridge, IconBuildingBridge2, IconBuildingBridge2Filled, IconBuildingBroadcastTower, IconBuildingBroadcastTowerFilled, IconBuildingBurjAlArab, IconBuildingCarousel, IconBuildingCastle, IconBuildingChurch, IconBuildingCircus, IconBuildingCog, IconBuildingCommunity, IconBuildingCottage, IconBuildingEstate, IconBuildingFactory, IconBuildingFactory2, IconBuildingFortress, IconBuildingHospital, IconBuildingLighthouse, IconBuildingMinus, IconBuildingMonument, IconBuildingMosque, IconBuildingOff, IconBuildingPavilion, IconBuildingPlus, IconBuildingSkyscraper, IconBuildingStadium, IconBuildingStore, IconBuildingTunnel, IconBuildingWarehouse, IconBuildingWindTurbine, IconBuildings, IconBulb, IconBulbFilled, IconBulbOff, IconBulldozer, IconBurger, IconBus, IconBusFilled, IconBusOff, IconBusStop, IconBusinessplan, IconButterfly, IconButterflyFilled, IconCactus, IconCactusFilled, IconCactusOff, IconCake, IconCakeOff, IconCakeRoll, IconCalculator, IconCalculatorFilled, IconCalculatorOff, IconCalendar, IconCalendarBolt, IconCalendarCancel, IconCalendarCheck, IconCalendarClock, IconCalendarCode, IconCalendarCog, IconCalendarDollar, IconCalendarDot, IconCalendarDown, IconCalendarDue, IconCalendarEvent, IconCalendarEventFilled, IconCalendarExclamation, IconCalendarFilled, IconCalendarHeart, IconCalendarMinus, IconCalendarMonth, IconCalendarMonthFilled, IconCalendarOff, IconCalendarPause, IconCalendarPin, IconCalendarPlus, IconCalendarQuestion, IconCalendarRepeat, IconCalendarSad, IconCalendarSearch, IconCalendarShare, IconCalendarSmile, IconCalendarStar, IconCalendarStats, IconCalendarTime, IconCalendarUp, IconCalendarUser, IconCalendarWeek, IconCalendarWeekFilled, IconCalendarX, IconCamera, IconCameraAi, IconCameraBitcoin, IconCameraBolt, IconCameraCancel, IconCameraCheck, IconCameraCode, IconCameraCog, IconCameraDollar, IconCameraDown, IconCameraExclamation, IconCameraFilled, IconCameraHeart, IconCameraMinus, IconCameraMoon, IconCameraOff, IconCameraPause, IconCameraPin, IconCameraPlus, IconCameraQuestion, IconCameraRotate, IconCameraSearch, IconCameraSelfie, IconCameraShare, IconCameraSpark, IconCameraStar, IconCameraUp, IconCameraX, IconCamper, IconCampfire, IconCampfireFilled, IconCancel, IconCandle, IconCandleFilled, IconCandy, IconCandyOff, IconCane, IconCannabis, IconCannabisFilled, IconCapProjecting, IconCapRounded, IconCapStraight, IconCapsule, IconCapsuleFilled, IconCapsuleHorizontal, IconCapsuleHorizontalFilled, IconCapture, IconCaptureFilled, IconCaptureOff, IconCar, IconCar4wd, IconCar4wdFilled, IconCarCrane, IconCarCraneFilled, IconCarCrash, IconCarFan, IconCarFan1, IconCarFan2, IconCarFan3, IconCarFanAuto, IconCarFanFilled, IconCarFilled, IconCarGarage, IconCarOff, IconCarSuv, IconCarSuvFilled, IconCarTurbine, IconCarambola, IconCarambolaFilled, IconCaravan, IconCaravanFilled, IconCardboards, IconCardboardsFilled, IconCardboardsOff, IconCards, IconCardsFilled, IconCaretDown, IconCaretDownFilled, IconCaretLeft, IconCaretLeftFilled, IconCaretLeftRight, IconCaretLeftRightFilled, IconCaretRight, IconCaretRightFilled, IconCaretUp, IconCaretUpDown, IconCaretUpDownFilled, IconCaretUpFilled, IconCarouselHorizontal, IconCarouselHorizontalFilled, IconCarouselVertical, IconCarouselVerticalFilled, IconCarrot, IconCarrotOff, IconCash, IconCashBanknote, IconCashBanknoteEdit, IconCashBanknoteFilled, IconCashBanknoteHeart, IconCashBanknoteMinus, IconCashBanknoteMove, IconCashBanknoteMoveBack, IconCashBanknoteOff, IconCashBanknotePlus, IconCashEdit, IconCashHeart, IconCashMinus, IconCashMove, IconCashMoveBack, IconCashOff, IconCashPlus, IconCashRegister, IconCast, IconCastOff, IconCat, IconCategory, IconCategory2, IconCategoryFilled, IconCategoryMinus, IconCategoryPlus, IconCe, IconCeOff, IconCell, IconCellSignal1, IconCellSignal2, IconCellSignal3, IconCellSignal4, IconCellSignal5, IconCellSignalOff, IconCertificate, IconCertificate2, IconCertificate2Off, IconCertificateOff, IconChairDirector, IconChalkboard, IconChalkboardOff, IconChalkboardTeacher, IconChargingPile, IconChargingPileFilled, IconChartArcs, IconChartArcs3, IconChartArea, IconChartAreaFilled, IconChartAreaLine, IconChartAreaLineFilled, IconChartArrows, IconChartArrowsVertical, IconChartBar, IconChartBarOff, IconChartBarPopular, IconChartBubble, IconChartBubbleFilled, IconChartCandle, IconChartCandleFilled, IconChartCircles, IconChartCohort, IconChartColumn, IconChartCovariate, IconChartDonut, IconChartDonut2, IconChartDonut3, IconChartDonut4, IconChartDonutFilled, IconChartDots, IconChartDots2, IconChartDots2Filled, IconChartDots3, IconChartDots3Filled, IconChartDotsFilled, IconChartFunnel, IconChartFunnelFilled, IconChartGridDots, IconChartGridDotsFilled, IconChartHistogram, IconChartInfographic, IconChartLine, IconChartPie, IconChartPie2, IconChartPie2Filled, IconChartPie3, IconChartPie3Filled, IconChartPie4, IconChartPie4Filled, IconChartPieFilled, IconChartPieOff, IconChartPpf, IconChartRadar, IconChartSankey, IconChartScatter, IconChartScatter3d, IconChartTreemap, IconCheck, IconCheckbox, IconChecklist, IconChecks, IconCheckupList, IconCheese, IconChefHat, IconChefHatFilled, IconChefHatOff, IconCherry, IconCherryFilled, IconChess, IconChessBishop, IconChessBishopFilled, IconChessFilled, IconChessKing, IconChessKingFilled, IconChessKnight, IconChessKnightFilled, IconChessQueen, IconChessQueenFilled, IconChessRook, IconChessRookFilled, IconChevronCompactDown, IconChevronCompactLeft, IconChevronCompactRight, IconChevronCompactUp, IconChevronDown, IconChevronDownLeft, IconChevronDownRight, IconChevronLeft, IconChevronLeftPipe, IconChevronRight, IconChevronRightPipe, IconChevronUp, IconChevronUpLeft, IconChevronUpRight, IconChevronsDown, IconChevronsDownLeft, IconChevronsDownRight, IconChevronsLeft, IconChevronsRight, IconChevronsUp, IconChevronsUpLeft, IconChevronsUpRight, IconChisel, IconChristmasBall, IconChristmasTree, IconChristmasTreeFilled, IconChristmasTreeOff, IconCircle, IconCircleNumber0 as IconCircle0, IconCircleNumber1 as IconCircle1, IconCircleNumber2 as IconCircle2, IconCircleNumber3 as IconCircle3, IconCircleNumber4 as IconCircle4, IconCircleNumber5 as IconCircle5, IconCircleNumber6 as IconCircle6, IconCircleNumber7 as IconCircle7, IconCircleNumber8 as IconCircle8, IconCircleNumber9 as IconCircle9, IconCircleArrowDown, IconCircleArrowDownFilled, IconCircleArrowDownLeft, IconCircleArrowDownLeftFilled, IconCircleArrowDownRight, IconCircleArrowDownRightFilled, IconCircleArrowLeft, IconCircleArrowLeftFilled, IconCircleArrowRight, IconCircleArrowRightFilled, IconCircleArrowUp, IconCircleArrowUpFilled, IconCircleArrowUpLeft, IconCircleArrowUpLeftFilled, IconCircleArrowUpRight, IconCircleArrowUpRightFilled, IconCircleAsterisk, IconCircleCaretDown, IconCircleCaretDownFilled, IconCircleCaretLeft, IconCircleCaretLeftFilled, IconCircleCaretRight, IconCircleCaretRightFilled, IconCircleCaretUp, IconCircleCaretUpFilled, IconCircleCheck, IconCircleCheckFilled, IconCircleChevronDown, IconCircleChevronDownFilled, IconCircleChevronLeft, IconCircleChevronLeftFilled, IconCircleChevronRight, IconCircleChevronRightFilled, IconCircleChevronUp, IconCircleChevronUpFilled, IconCircleChevronsDown, IconCircleChevronsDownFilled, IconCircleChevronsLeft, IconCircleChevronsLeftFilled, IconCircleChevronsRight, IconCircleChevronsRightFilled, IconCircleChevronsUp, IconCircleChevronsUpFilled, IconCircleDashed, IconCircleDashedCheck, IconCircleDashedLetterA, IconCircleDashedLetterB, IconCircleDashedLetterC, IconCircleDashedLetterD, IconCircleDashedLetterE, IconCircleDashedLetterF, IconCircleDashedLetterG, IconCircleDashedLetterH, IconCircleDashedLetterI, IconCircleDashedLetterJ, IconCircleDashedLetterK, IconCircleDashedLetterL, IconCircleDashedLetterV as IconCircleDashedLetterLetterV, IconCircleDashedLetterM, IconCircleDashedLetterN, IconCircleDashedLetterO, IconCircleDashedLetterP, IconCircleDashedLetterQ, IconCircleDashedLetterR, IconCircleDashedLetterS, IconCircleDashedLetterT, IconCircleDashedLetterU, IconCircleDashedLetterV, IconCircleDashedLetterW, IconCircleDashedLetterX, IconCircleDashedLetterY, IconCircleDashedLetterZ, IconCircleDashedMinus, IconCircleDashedNumber0, IconCircleDashedNumber1, IconCircleDashedNumber2, IconCircleDashedNumber3, IconCircleDashedNumber4, IconCircleDashedNumber5, IconCircleDashedNumber6, IconCircleDashedNumber7, IconCircleDashedNumber8, IconCircleDashedNumber9, IconCircleDashedPercentage, IconCircleDashedPlus, IconCircleDashedX, IconCircleDot, IconCircleDotFilled, IconCircleDotted, IconCircleDottedLetterA, IconCircleDottedLetterB, IconCircleDottedLetterC, IconCircleDottedLetterD, IconCircleDottedLetterE, IconCircleDottedLetterF, IconCircleDottedLetterG, IconCircleDottedLetterH, IconCircleDottedLetterI, IconCircleDottedLetterJ, IconCircleDottedLetterK, IconCircleDottedLetterL, IconCircleDottedLetterM, IconCircleDottedLetterN, IconCircleDottedLetterO, IconCircleDottedLetterP, IconCircleDottedLetterQ, IconCircleDottedLetterR, IconCircleDottedLetterS, IconCircleDottedLetterT, IconCircleDottedLetterU, IconCircleDottedLetterV, IconCircleDottedLetterW, IconCircleDottedLetterX, IconCircleDottedLetterY, IconCircleDottedLetterZ, IconCircleFilled, IconCircleHalf, IconCircleHalf2, IconCircleHalfVertical, IconCircleKey, IconCircleKeyFilled, IconCircleLetterA, IconCircleLetterAFilled, IconCircleLetterB, IconCircleLetterBFilled, IconCircleLetterC, IconCircleLetterCFilled, IconCircleLetterD, IconCircleLetterDFilled, IconCircleLetterE, IconCircleLetterEFilled, IconCircleLetterF, IconCircleLetterFFilled, IconCircleLetterG, IconCircleLetterGFilled, IconCircleLetterH, IconCircleLetterHFilled, IconCircleLetterI, IconCircleLetterIFilled, IconCircleLetterJ, IconCircleLetterJFilled, IconCircleLetterK, IconCircleLetterKFilled, IconCircleLetterL, IconCircleLetterLFilled, IconCircleLetterM, IconCircleLetterMFilled, IconCircleLetterN, IconCircleLetterNFilled, IconCircleLetterO, IconCircleLetterOFilled, IconCircleLetterP, IconCircleLetterPFilled, IconCircleLetterQ, IconCircleLetterQFilled, IconCircleLetterR, IconCircleLetterRFilled, IconCircleLetterS, IconCircleLetterSFilled, IconCircleLetterT, IconCircleLetterTFilled, IconCircleLetterU, IconCircleLetterUFilled, IconCircleLetterV, IconCircleLetterVFilled, IconCircleLetterW, IconCircleLetterWFilled, IconCircleLetterX, IconCircleLetterXFilled, IconCircleLetterY, IconCircleLetterYFilled, IconCircleLetterZ, IconCircleLetterZFilled, IconCircleMinus, IconCircleMinus2, IconCircleNumber0, IconCircleNumber0Filled, IconCircleNumber1, IconCircleNumber1Filled, IconCircleNumber2, IconCircleNumber2Filled, IconCircleNumber3, IconCircleNumber3Filled, IconCircleNumber4, IconCircleNumber4Filled, IconCircleNumber5, IconCircleNumber5Filled, IconCircleNumber6, IconCircleNumber6Filled, IconCircleNumber7, IconCircleNumber7Filled, IconCircleNumber8, IconCircleNumber8Filled, IconCircleNumber9, IconCircleNumber9Filled, IconCircleOff, IconCirclePercentage, IconCirclePercentageFilled, IconCirclePlus, IconCirclePlus2, IconCirclePlusFilled, IconCircleRectangle, IconCircleRectangleFilled, IconCircleRectangleOff, IconCircleSquare, IconCircleTriangle, IconCircleX, IconCircleXFilled, IconCircles, IconCirclesFilled, IconCirclesRelation, IconCircuitAmmeter, IconCircuitBattery, IconCircuitBulb, IconCircuitCapacitor, IconCircuitCapacitorPolarized, IconCircuitCell, IconCircuitCellPlus, IconCircuitChangeover, IconCircuitDiode, IconCircuitDiodeZener, IconCircuitGround, IconCircuitGroundDigital, IconCircuitInductor, IconCircuitMotor, IconCircuitPushbutton, IconCircuitResistor, IconCircuitSwitchClosed, IconCircuitSwitchOpen, IconCircuitVoltmeter, IconClearAll, IconClearFormatting, IconClick, IconCliffJumping, IconClipboard, IconClipboardCheck, IconClipboardCheckFilled, IconClipboardCopy, IconClipboardData, IconClipboardDataFilled, IconClipboardFilled, IconClipboardHeart, IconClipboardList, IconClipboardListFilled, IconClipboardOff, IconClipboardPlus, IconClipboardPlusFilled, IconClipboardSearch, IconClipboardSmile, IconClipboardSmileFilled, IconClipboardText, IconClipboardTextFilled, IconClipboardTypography, IconClipboardTypographyFilled, IconClipboardX, IconClipboardXFilled, IconClock, IconClock12, IconClock2, IconClock24, IconClockBitcoin, IconClockBolt, IconClockCancel, IconClockCheck, IconClockCode, IconClockCog, IconClockDollar, IconClockDown, IconClockEdit, IconClockExclamation, IconClockFilled, IconClockHeart, IconClockHour1, IconClockHour10, IconClockHour10Filled, IconClockHour11, IconClockHour11Filled, IconClockHour12, IconClockHour12Filled, IconClockHour1Filled, IconClockHour2, IconClockHour2Filled, IconClockHour3, IconClockHour3Filled, IconClockHour4, IconClockHour4Filled, IconClockHour5, IconClockHour5Filled, IconClockHour6, IconClockHour6Filled, IconClockHour7, IconClockHour7Filled, IconClockHour8, IconClockHour8Filled, IconClockHour9, IconClockHour9Filled, IconClockMinus, IconClockOff, IconClockPause, IconClockPin, IconClockPlay, IconClockPlus, IconClockQuestion, IconClockRecord, IconClockSearch, IconClockShare, IconClockShield, IconClockStar, IconClockStop, IconClockUp, IconClockX, IconClothesRack, IconClothesRackOff, IconCloud, IconCloudBitcoin, IconCloudBolt, IconCloudCancel, IconCloudCheck, IconCloudCode, IconCloudCog, IconCloudComputing, IconCloudComputingFilled, IconCloudDataConnection, IconCloudDataConnectionFilled, IconCloudDollar, IconCloudDown, IconCloudDownload, IconCloudExclamation, IconCloudFilled, IconCloudFog, IconCloudHeart, IconCloudLock, IconCloudLockOpen, IconCloudMinus, IconCloudNetwork, IconCloudOff, IconCloudPause, IconCloudPin, IconCloudPlus, IconCloudQuestion, IconCloudRain, IconCloudSearch, IconCloudShare, IconCloudSnow, IconCloudStar, IconCloudStorm, IconCloudUp, IconCloudUpload, IconCloudX, IconClover, IconClover2, IconCloverFilled, IconClubs, IconClubsFilled, IconCode, IconCodeAsterisk, IconCodeAsterisk as IconCodeAsterix, IconCodeCircle, IconCodeCircle2, IconCodeCircle2Filled, IconCodeCircleFilled, IconCodeDots, IconCodeMinus, IconCodeOff, IconCodePlus, IconCodeVariable, IconCodeVariableMinus, IconCodeVariablePlus, IconCoffee, IconCoffeeOff, IconCoffin, IconCoin, IconCoinBitcoin, IconCoinBitcoinFilled, IconCoinEuro, IconCoinEuroFilled, IconCoinFilled, IconCoinMonero, IconCoinMoneroFilled, IconCoinOff, IconCoinPound, IconCoinPoundFilled, IconCoinRupee, IconCoinRupeeFilled, IconCoinTaka, IconCoinTakaFilled, IconCoinYen, IconCoinYenFilled, IconCoinYuan, IconCoinYuanFilled, IconCoins, IconColorFilter, IconColorPicker, IconColorPickerOff, IconColorSwatch, IconColorSwatchOff, IconColumnInsertLeft, IconColumnInsertRight, IconColumnRemove, IconColumns, IconColumns1, IconColumns1Filled, IconColumns2, IconColumns2Filled, IconColumns3, IconColumns3Filled, IconColumnsOff, IconComet, IconCommand, IconCommandOff, IconCompass, IconCompassFilled, IconCompassOff, IconComponents, IconComponentsOff, IconCone, IconCone2, IconCone2Filled, IconConeFilled, IconConeOff, IconConePlus, IconConfetti, IconConfettiFilled, IconConfettiOff, IconConfucius, IconCongruentTo, IconContainer, IconContainerFilled, IconContainerOff, IconContract, IconContrast, IconContrast2, IconContrast2Filled, IconContrast2Off, IconContrastFilled, IconContrastOff, IconCooker, IconCookie, IconCookieFilled, IconCookieMan, IconCookieManFilled, IconCookieOff, IconCopy, IconCopyCheck, IconCopyCheckFilled, IconCopyMinus, IconCopyMinusFilled, IconCopyOff, IconCopyPlus, IconCopyPlusFilled, IconCopyX, IconCopyXFilled, IconCopyleft, IconCopyleftFilled, IconCopyleftOff, IconCopyright, IconCopyrightFilled, IconCopyrightOff, IconCornerDownLeft, IconCornerDownLeftDouble, IconCornerDownRight, IconCornerDownRightDouble, IconCornerLeftDown, IconCornerLeftDownDouble, IconCornerLeftUp, IconCornerLeftUpDouble, IconCornerRightDown, IconCornerRightDownDouble, IconCornerRightUp, IconCornerRightUpDouble, IconCornerUpLeft, IconCornerUpLeftDouble, IconCornerUpRight, IconCornerUpRightDouble, IconCpu, IconCpu2, IconCpuOff, IconCrane, IconCraneOff, IconCreativeCommons, IconCreativeCommonsBy, IconCreativeCommonsNc, IconCreativeCommonsNd, IconCreativeCommonsOff, IconCreativeCommonsSa, IconCreativeCommonsZero, IconCreditCard, IconCreditCardFilled, IconCreditCardOff, IconCreditCardPay, IconCreditCardRefund, IconCricket, IconCrop, IconCrop11, IconCrop11Filled, IconCrop169, IconCrop169Filled, IconCrop32, IconCrop32Filled, IconCrop54, IconCrop54Filled, IconCrop75, IconCrop75Filled, IconCropLandscape, IconCropLandscapeFilled, IconCropPortrait, IconCropPortraitFilled, IconCross, IconCrossFilled, IconCrossOff, IconCrosshair, IconCrown, IconCrownFilled, IconCrownOff, IconCrutches, IconCrutchesOff, IconCrystalBall, IconCsv, IconCube, IconCube3dSphere, IconCube3dSphereOff, IconCubeOff, IconCubePlus, IconCubeSend, IconCubeSpark, IconCubeUnfolded, IconCup, IconCupOff, IconCurling, IconCurlyLoop, IconCurrency, IconCurrencyAfghani, IconCurrencyBahraini, IconCurrencyBaht, IconCurrencyBitcoin, IconCurrencyCent, IconCurrencyDinar, IconCurrencyDirham, IconCurrencyDogecoin, IconCurrencyDollar, IconCurrencyDollarAustralian, IconCurrencyDollarBrunei, IconCurrencyDollarCanadian, IconCurrencyDollarGuyanese, IconCurrencyDollarOff, IconCurrencyDollarSingapore, IconCurrencyDollarZimbabwean, IconCurrencyDong, IconCurrencyDram, IconCurrencyEthereum, IconCurrencyEuro, IconCurrencyEuroOff, IconCurrencyFlorin, IconCurrencyForint, IconCurrencyFrank, IconCurrencyGuarani, IconCurrencyHryvnia, IconCurrencyIranianRial, IconCurrencyKip, IconCurrencyKroneCzech, IconCurrencyKroneDanish, IconCurrencyKroneSwedish, IconCurrencyLari, IconCurrencyLeu, IconCurrencyLira, IconCurrencyLitecoin, IconCurrencyLyd, IconCurrencyManat, IconCurrencyMonero, IconCurrencyNaira, IconCurrencyNano, IconCurrencyOff, IconCurrencyPaanga, IconCurrencyPeso, IconCurrencyPound, IconCurrencyPoundOff, IconCurrencyQuetzal, IconCurrencyReal, IconCurrencyRenminbi, IconCurrencyRipple, IconCurrencyRiyal, IconCurrencyRubel, IconCurrencyRufiyaa, IconCurrencyRupee, IconCurrencyRupeeNepalese, IconCurrencyShekel, IconCurrencySolana, IconCurrencySom, IconCurrencyTaka, IconCurrencyTenge, IconCurrencyTugrik, IconCurrencyWon, IconCurrencyXrp, IconCurrencyYen, IconCurrencyYenOff, IconCurrencyYuan, IconCurrencyZloty, IconCurrentLocation, IconCurrentLocationFilled, IconCurrentLocationOff, IconCursorOff, IconCursorText, IconCut, IconCylinder, IconCylinderOff, IconCylinderPlus, IconDashboard, IconDashboardFilled, IconDashboardOff, IconDatabase, IconDatabaseCog, IconDatabaseDollar, IconDatabaseEdit, IconDatabaseExclamation, IconDatabaseExport, IconDatabaseHeart, IconDatabaseImport, IconDatabaseLeak, IconDatabaseMinus, IconDatabaseOff, IconDatabasePlus, IconDatabaseSearch, IconDatabaseShare, IconDatabaseSmile, IconDatabaseStar, IconDatabaseX, IconDeaf, IconDecimal, IconDeer, IconDelta, IconDental, IconDentalBroken, IconDentalOff, IconDeselect, IconDesk, IconDetails, IconDetailsOff, IconDeviceAirpods, IconDeviceAirpodsCase, IconDeviceAirtag, IconDeviceAnalytics, IconDeviceAudioTape, IconDeviceCameraPhone, IconDeviceCctv, IconDeviceCctvFilled, IconDeviceCctvOff, IconDeviceComputerCamera, IconDeviceComputerCameraOff, IconDeviceDesktop, IconDeviceDesktopAnalytics, IconDeviceDesktopBolt, IconDeviceDesktopCancel, IconDeviceDesktopCheck, IconDeviceDesktopCode, IconDeviceDesktopCog, IconDeviceDesktopDollar, IconDeviceDesktopDown, IconDeviceDesktopExclamation, IconDeviceDesktopFilled, IconDeviceDesktopHeart, IconDeviceDesktopMinus, IconDeviceDesktopOff, IconDeviceDesktopPause, IconDeviceDesktopPin, IconDeviceDesktopPlus, IconDeviceDesktopQuestion, IconDeviceDesktopSearch, IconDeviceDesktopShare, IconDeviceDesktopStar, IconDeviceDesktopUp, IconDeviceDesktopX, IconDeviceFloppy, IconDeviceGamepad, IconDeviceGamepad2, IconDeviceGamepad3, IconDeviceGamepad3Filled, IconDeviceGamepadFilled, IconDeviceHeartMonitor, IconDeviceHeartMonitorFilled, IconDeviceImac, IconDeviceImacBolt, IconDeviceImacCancel, IconDeviceImacCheck, IconDeviceImacCode, IconDeviceImacCog, IconDeviceImacDollar, IconDeviceImacDown, IconDeviceImacExclamation, IconDeviceImacFilled, IconDeviceImacHeart, IconDeviceImacMinus, IconDeviceImacOff, IconDeviceImacPause, IconDeviceImacPin, IconDeviceImacPlus, IconDeviceImacQuestion, IconDeviceImacSearch, IconDeviceImacShare, IconDeviceImacStar, IconDeviceImacUp, IconDeviceImacX, IconDeviceIpad, IconDeviceIpadBolt, IconDeviceIpadCancel, IconDeviceIpadCheck, IconDeviceIpadCode, IconDeviceIpadCog, IconDeviceIpadDollar, IconDeviceIpadDown, IconDeviceIpadExclamation, IconDeviceIpadFilled, IconDeviceIpadHeart, IconDeviceIpadHorizontal, IconDeviceIpadHorizontalBolt, IconDeviceIpadHorizontalCancel, IconDeviceIpadHorizontalCheck, IconDeviceIpadHorizontalCode, IconDeviceIpadHorizontalCog, IconDeviceIpadHorizontalDollar, IconDeviceIpadHorizontalDown, IconDeviceIpadHorizontalExclamation, IconDeviceIpadHorizontalHeart, IconDeviceIpadHorizontalMinus, IconDeviceIpadHorizontalOff, IconDeviceIpadHorizontalPause, IconDeviceIpadHorizontalPin, IconDeviceIpadHorizontalPlus, IconDeviceIpadHorizontalQuestion, IconDeviceIpadHorizontalSearch, IconDeviceIpadHorizontalShare, IconDeviceIpadHorizontalStar, IconDeviceIpadHorizontalUp, IconDeviceIpadHorizontalX, IconDeviceIpadMinus, IconDeviceIpadOff, IconDeviceIpadPause, IconDeviceIpadPin, IconDeviceIpadPlus, IconDeviceIpadQuestion, IconDeviceIpadSearch, IconDeviceIpadShare, IconDeviceIpadStar, IconDeviceIpadUp, IconDeviceIpadX, IconDeviceLandlinePhone, IconDeviceLaptop, IconDeviceLaptopOff, IconDeviceMobile, IconDeviceMobileBolt, IconDeviceMobileCancel, IconDeviceMobileCharging, IconDeviceMobileCheck, IconDeviceMobileCode, IconDeviceMobileCog, IconDeviceMobileDollar, IconDeviceMobileDown, IconDeviceMobileExclamation, IconDeviceMobileFilled, IconDeviceMobileHeart, IconDeviceMobileMessage, IconDeviceMobileMinus, IconDeviceMobileOff, IconDeviceMobilePause, IconDeviceMobilePin, IconDeviceMobilePlus, IconDeviceMobileQuestion, IconDeviceMobileRotated, IconDeviceMobileSearch, IconDeviceMobileShare, IconDeviceMobileStar, IconDeviceMobileUp, IconDeviceMobileVibration, IconDeviceMobileX, IconDeviceNintendo, IconDeviceNintendoOff, IconDeviceProjector, IconDeviceRemote, IconDeviceRemoteFilled, IconDeviceSdCard, IconDeviceSim, IconDeviceSim1, IconDeviceSim2, IconDeviceSim3, IconDeviceSpeaker, IconDeviceSpeakerFilled, IconDeviceSpeakerOff, IconDeviceTablet, IconDeviceTabletBolt, IconDeviceTabletCancel, IconDeviceTabletCheck, IconDeviceTabletCode, IconDeviceTabletCog, IconDeviceTabletDollar, IconDeviceTabletDown, IconDeviceTabletExclamation, IconDeviceTabletFilled, IconDeviceTabletHeart, IconDeviceTabletMinus, IconDeviceTabletOff, IconDeviceTabletPause, IconDeviceTabletPin, IconDeviceTabletPlus, IconDeviceTabletQuestion, IconDeviceTabletSearch, IconDeviceTabletShare, IconDeviceTabletStar, IconDeviceTabletUp, IconDeviceTabletX, IconDeviceTv, IconDeviceTvFilled, IconDeviceTvOff, IconDeviceTvOld, IconDeviceTvOldFilled, IconDeviceUnknown, IconDeviceUnknownFilled, IconDeviceUsb, IconDeviceUsbFilled, IconDeviceVisionPro, IconDeviceVisionProFilled, IconDeviceWatch, IconDeviceWatchBolt, IconDeviceWatchCancel, IconDeviceWatchCheck, IconDeviceWatchCode, IconDeviceWatchCog, IconDeviceWatchDollar, IconDeviceWatchDown, IconDeviceWatchExclamation, IconDeviceWatchFilled, IconDeviceWatchHeart, IconDeviceWatchMinus, IconDeviceWatchOff, IconDeviceWatchPause, IconDeviceWatchPin, IconDeviceWatchPlus, IconDeviceWatchQuestion, IconDeviceWatchSearch, IconDeviceWatchShare, IconDeviceWatchStar, IconDeviceWatchStats, IconDeviceWatchStats2, IconDeviceWatchUp, IconDeviceWatchX, IconDevices, IconDevices2, IconDevicesBolt, IconDevicesCancel, IconDevicesCheck, IconDevicesCode, IconDevicesCog, IconDevicesDollar, IconDevicesDown, IconDevicesExclamation, IconDevicesHeart, IconDevicesMinus, IconDevicesOff, IconDevicesPause, IconDevicesPc, IconDevicesPcOff, IconDevicesPin, IconDevicesPlus, IconDevicesQuestion, IconDevicesSearch, IconDevicesShare, IconDevicesStar, IconDevicesUp, IconDevicesX, IconDiabolo, IconDiaboloOff, IconDiaboloPlus, IconDialpad, IconDialpadFilled, IconDialpadOff, IconDiamond, IconDiamondFilled, IconDiamondOff, IconDiamonds, IconDiamondsFilled, IconDiaper, IconDice, IconDice1, IconDice1Filled, IconDice2, IconDice2Filled, IconDice3, IconDice3Filled, IconDice4, IconDice4Filled, IconDice5, IconDice5Filled, IconDice6, IconDice6Filled, IconDiceFilled, IconDimensions, IconDirection, IconDirectionArrows, IconDirectionArrowsFilled, IconDirectionHorizontal, IconDirectionSign, IconDirectionSignFilled, IconDirectionSignOff, IconDirections, IconDirectionsFilled, IconDirectionsOff, IconDisabled, IconDisabled2, IconDisabledOff, IconDisc, IconDiscFilled, IconDiscGolf, IconDiscOff, IconDiscount, IconRosetteDiscount as IconDiscount2, IconRosetteDiscountOff as IconDiscount2Off, IconRosetteDiscountCheck as IconDiscountCheck, IconRosetteDiscountCheckFilled as IconDiscountCheckFilled, IconDiscountFilled, IconDiscountOff, IconDivide, IconDna, IconDna2, IconDna2Off, IconDnaOff, IconDog, IconDogBowl, IconDoor, IconDoorEnter, IconDoorExit, IconDoorOff, IconDots, IconDotsCircleHorizontal, IconDotsDiagonal, IconDotsDiagonal2, IconDotsVertical, IconDownload, IconDownloadOff, IconDragDrop, IconDragDrop2, IconDrone, IconDroneOff, IconDropCircle, IconDropCircleFilled, IconDroplet, IconDropletBolt, IconDropletCancel, IconDropletCheck, IconDropletCode, IconDropletCog, IconDropletDollar, IconDropletDown, IconDropletExclamation, IconDropletFilled, IconDropletHalf, IconDropletHalf2, IconDropletHalf2Filled, IconDropletHalfFilled, IconDropletHeart, IconDropletMinus, IconDropletOff, IconDropletPause, IconDropletPin, IconDropletPlus, IconDropletQuestion, IconDropletSearch, IconDropletShare, IconDropletStar, IconDropletUp, IconDropletX, IconDroplets, IconDropletsFilled, IconDualScreen, IconDualScreenFilled, IconDumpling, IconDumplingFilled, IconEPassport, IconEar, IconEarOff, IconEarScan, IconEaseIn, IconEaseInControlPoint, IconEaseInControlPointFilled, IconEaseInOut, IconEaseInOutControlPoints, IconEaseInOutControlPointsFilled, IconEaseOut, IconEaseOutControlPoint, IconEaseOutControlPointFilled, IconEdit, IconEditCircle, IconEditCircleOff, IconEditOff, IconEgg, IconEggCracked, IconEggCrackedFilled, IconEggFilled, IconEggFried, IconEggFriedFilled, IconEggOff, IconEggs, IconElevator, IconElevatorFilled, IconElevatorOff, IconEmergencyBed, IconEmpathize, IconEmpathizeOff, IconEmphasis, IconEngine, IconEngineFilled, IconEngineOff, IconEqual, IconEqualDouble, IconEqualNot, IconEraser, IconEraserOff, IconError404, IconError404Off, IconEscalator, IconEscalatorDown, IconEscalatorDownFilled, IconEscalatorFilled, IconEscalatorUp, IconEscalatorUpFilled, IconExchange, IconExchangeFilled, IconExchangeOff, IconExclamationCircle, IconExclamationCircleFilled, IconExclamationMark, IconExclamationMarkOff, IconExplicit, IconExplicitFilled, IconExplicitOff, IconExposure, IconExposure0, IconExposureFilled, IconExposureMinus1, IconExposureMinus2, IconExposureOff, IconExposurePlus1, IconExposurePlus2, IconExternalLink, IconExternalLinkOff, IconEye, IconEyeBitcoin, IconEyeBolt, IconEyeCancel, IconEyeCheck, IconEyeClosed, IconEyeCode, IconEyeCog, IconEyeDiscount, IconEyeDollar, IconEyeDotted, IconEyeDown, IconEyeEdit, IconEyeExclamation, IconEyeFilled, IconEyeHeart, IconEyeMinus, IconEyeOff, IconEyePause, IconEyePin, IconEyePlus, IconEyeQuestion, IconEyeSearch, IconEyeShare, IconEyeSpark, IconEyeStar, IconEyeTable, IconEyeTableFilled, IconEyeUp, IconEyeX, IconEyeglass, IconEyeglass2, IconEyeglass2Filled, IconEyeglassFilled, IconEyeglassOff, IconFaceId, IconFaceIdError, IconFaceMask, IconFaceMaskFilled, IconFaceMaskOff, IconFall, IconFavicon, IconFaviconFilled, IconFeather, IconFeatherFilled, IconFeatherOff, IconFence, IconFenceFilled, IconFenceOff, IconFerry, IconFerryFilled, IconFidgetSpinner, IconFidgetSpinnerFilled, IconFile, IconFile3d, IconFileAi, IconFileAlert, IconFileAnalytics, IconFileAnalyticsFilled, IconFileArrowLeft, IconFileArrowRight, IconFileBarcode, IconFileBitcoin, IconFileBroken, IconFileCertificate, IconFileChart, IconFileCheck, IconFileCheckFilled, IconFileCode, IconFileCode2, IconFileCode2Filled, IconFileCodeFilled, IconFileCv, IconFileCvFilled, IconFileDatabase, IconFileDelta, IconFileDeltaFilled, IconFileDescription, IconFileDescriptionFilled, IconFileDiff, IconFileDiffFilled, IconFileDigit, IconFileDigitFilled, IconFileDislike, IconFileDollar, IconFileDollarFilled, IconFileDots, IconFileDotsFilled, IconFileDownload, IconFileDownloadFilled, IconFileEuro, IconFileEuroFilled, IconFileExcel, IconFileExport, IconFileFilled, IconFileFunction, IconFileFunctionFilled, IconFileHorizontal, IconFileHorizontalFilled, IconFileImport, IconFileInfinity, IconFileInfo, IconFileInfoFilled, IconFileInvoice, IconFileInvoiceFilled, IconFileIsr, IconFileLambda, IconFileLambdaFilled, IconFileLike, IconFileMinus, IconFileMinusFilled, IconFileMusic, IconFileMusicFilled, IconFileNeutral, IconFileNeutralFilled, IconFileOff, IconFileOrientation, IconFilePencil, IconFilePencilFilled, IconFilePercent, IconFilePercentFilled, IconFilePhone, IconFilePhoneFilled, IconFilePlus, IconFilePower, IconFilePowerFilled, IconFileReport, IconFileRss, IconFileRssFilled, IconFileSad, IconFileSadFilled, IconFileScissors, IconFileScissorsFilled, IconFileSearch, IconFileSettings, IconFileSettingsFilled, IconFileShredder, IconFileSignal, IconFileSignalFilled, IconFileSmile, IconFileSmileFilled, IconFileSpark, IconFileSpreadsheet, IconFileStack, IconFileStar, IconFileStarFilled, IconFileSymlink, IconFileText, IconFileTextAi, IconFileTextFilled, IconFileTextShield, IconFileTextSpark, IconFileTime, IconFileTimeFilled, IconFileTypeBmp, IconFileTypeCss, IconFileTypeCsv, IconFileTypeDoc, IconFileTypeDocx, IconFileTypeHtml, IconFileTypeJpg, IconFileTypeJs, IconFileTypeJsx, IconFileTypePdf, IconFileTypePhp, IconFileTypePng, IconFileTypePpt, IconFileTypeRs, IconFileTypeSql, IconFileTypeSvg, IconFileTypeTs, IconFileTypeTsx, IconFileTypeTxt, IconFileTypeVue, IconFileTypeXls, IconFileTypeXml, IconFileTypeZip, IconFileTypography, IconFileTypographyFilled, IconFileUnknown, IconFileUnknownFilled, IconFileUpload, IconFileUploadFilled, IconFileVector, IconFileVectorFilled, IconFileWord, IconFileX, IconFileXFilled, IconFileZip, IconFiles, IconFilesFilled, IconFilesOff, IconFilter, IconFilter2, IconFilter2Bolt, IconFilter2Cancel, IconFilter2Check, IconFilter2Code, IconFilter2Cog, IconFilter2Discount, IconFilter2Dollar, IconFilter2Down, IconFilter2Edit, IconFilter2Exclamation, IconFilter2Minus, IconFilter2Pause, IconFilter2Pin, IconFilter2Plus, IconFilter2Question, IconFilter2Search, IconFilter2Share, IconFilter2Spark, IconFilter2Up, IconFilter2X, IconFilterBolt, IconFilterCancel, IconFilterCheck, IconFilterCode, IconFilterCog, IconFilterDiscount, IconFilterDollar, IconFilterDown, IconFilterEdit, IconFilterExclamation, IconFilterFilled, IconFilterHeart, IconFilterMinus, IconFilterOff, IconFilterPause, IconFilterPin, IconFilterPlus, IconFilterQuestion, IconFilterSearch, IconFilterShare, IconFilterSpark, IconFilterStar, IconFilterUp, IconFilterX, IconFilters, IconFiltersFilled, IconFingerprint, IconFingerprintOff, IconFingerprintScan, IconFireExtinguisher, IconFireHydrant, IconFireHydrantOff, IconFiretruck, IconFirstAidKit, IconFirstAidKitOff, IconFish, IconFishBone, IconFishBoneFilled, IconFishChristianity, IconFishHook, IconFishHookOff, IconFishOff, IconFlag, IconFlag2, IconFlag2Filled, IconFlag2Off, IconFlag3, IconFlag3Filled, IconFlagBitcoin, IconFlagBolt, IconFlagCancel, IconFlagCheck, IconFlagCode, IconFlagCog, IconFlagDiscount, IconFlagDollar, IconFlagDown, IconFlagExclamation, IconFlagFilled, IconFlagHeart, IconFlagMinus, IconFlagOff, IconFlagPause, IconFlagPin, IconFlagPlus, IconFlagQuestion, IconFlagSearch, IconFlagShare, IconFlagSpark, IconFlagStar, IconFlagUp, IconFlagX, IconFlame, IconFlameFilled, IconFlameOff, IconFlare, IconFlareFilled, IconFlask, IconFlask2, IconFlask2Filled, IconFlask2Off, IconFlaskFilled, IconFlaskOff, IconFlipFlops, IconFlipHorizontal, IconFlipVertical, IconFloatCenter, IconFloatLeft, IconFloatNone, IconFloatRight, IconFlower, IconFlowerFilled, IconFlowerOff, IconFocus, IconFocus2, IconFocusAuto, IconFocusCentered, IconFold, IconFoldDown, IconFoldUp, IconFolder, IconFolderBolt, IconFolderCancel, IconFolderCheck, IconFolderCode, IconFolderCog, IconFolderDollar, IconFolderDown, IconFolderExclamation, IconFolderFilled, IconFolderHeart, IconFolderMinus, IconFolderOff, IconFolderOpen, IconFolderOpenFilled, IconFolderPause, IconFolderPin, IconFolderPlus, IconFolderQuestion, IconFolderRoot, IconFolderSearch, IconFolderShare, IconFolderStar, IconFolderSymlink, IconFolderUp, IconFolderX, IconFolders, IconFoldersFilled, IconFoldersOff, IconForbid, IconForbid2, IconForbid2Filled, IconForbidFilled, IconForklift, IconForms, IconFountain, IconFountainFilled, IconFountainOff, IconFrame, IconFrameOff, IconFreeRights, IconFreezeColumn, IconFreezeRow, IconFreezeRowColumn, IconFridge, IconFridgeOff, IconFriends, IconFriendsOff, IconFrustum, IconFrustumOff, IconFrustumPlus, IconFunction, IconFunctionFilled, IconFunctionOff, IconGalaxy, IconGardenCart, IconGardenCartFilled, IconGardenCartOff, IconGasStation, IconGasStationFilled, IconGasStationOff, IconGauge, IconGaugeFilled, IconGaugeOff, IconGavel, IconGenderAgender, IconGenderAndrogyne, IconGenderBigender, IconGenderDemiboy, IconGenderDemigirl, IconGenderEpicene, IconGenderFemale, IconGenderFemme, IconGenderGenderfluid, IconGenderGenderless, IconGenderGenderqueer, IconGenderHermaphrodite, IconGenderIntergender, IconGenderMale, IconGenderNeutrois, IconGenderThird, IconGenderTransgender, IconGenderTrasvesti, IconGeometry, IconGhost, IconGhost2, IconGhost2Filled, IconGhost3, IconGhost3Filled, IconGhostFilled, IconGhostOff, IconGif, IconGift, IconGiftCard, IconGiftCardFilled, IconGiftFilled, IconGiftOff, IconGitBranch, IconGitBranchDeleted, IconGitCherryPick, IconGitCommit, IconGitCompare, IconGitFork, IconGitMerge, IconGitPullRequest, IconGitPullRequestClosed, IconGitPullRequestDraft, IconGizmo, IconGlass, IconGlassChampagne, IconGlassCocktail, IconGlassFilled, IconGlassFull, IconGlassFullFilled, IconGlassGin, IconGlassOff, IconGlobe, IconGlobeFilled, IconGlobeOff, IconGoGame, IconGolf, IconGolfFilled, IconGolfOff, IconGps, IconGpsFilled, IconGradienter, IconGrain, IconGraph, IconGraphFilled, IconGraphOff, IconGrave, IconGrave2, IconGrid3x3, IconGrid4x4, IconGridDots, IconGridGoldenratio, IconGridPattern, IconGridPatternFilled, IconGridScan, IconGrill, IconGrillFork, IconGrillOff, IconGrillSpatula, IconGripHorizontal, IconGripVertical, IconGrowth, IconGuitarPick, IconGuitarPickFilled, IconGymnastics, IconH1, IconH2, IconH3, IconH4, IconH5, IconH6, IconHammer, IconHammerOff, IconHandClick, IconHandClickOff, IconHandFinger, IconHandFingerDown, IconHandFingerLeft, IconHandFingerOff, IconHandFingerRight, IconHandGrab, IconHandLittleFinger, IconHandLoveYou, IconHandMiddleFinger, IconHandMove, IconHandOff, IconHandRingFinger, IconHandLoveYou as IconHandRock, IconHandSanitizer, IconHandStop, IconHandThreeFingers, IconHandTwoFingers, IconHanger, IconHanger2, IconHanger2Filled, IconHangerOff, IconHash, IconHaze, IconHazeMoon, IconHdr, IconHeading, IconHeadingOff, IconHeadphones, IconHeadphonesFilled, IconHeadphonesOff, IconHeadset, IconHeadsetOff, IconHealthRecognition, IconHeart, IconHeartBitcoin, IconHeartBolt, IconHeartBroken, IconHeartBrokenFilled, IconHeartCancel, IconHeartCheck, IconHeartCode, IconHeartCog, IconHeartDiscount, IconHeartDollar, IconHeartDown, IconHeartExclamation, IconHeartFilled, IconHeartHandshake, IconHeartMinus, IconHeartOff, IconHeartPause, IconHeartPin, IconHeartPlus, IconHeartQuestion, IconHeartRateMonitor, IconHeartSearch, IconHeartShare, IconHeartSpark, IconHeartStar, IconHeartUp, IconHeartX, IconHeartbeat, IconHearts, IconHeartsOff, IconHelicopter, IconHelicopterFilled, IconHelicopterLanding, IconHelicopterLandingFilled, IconHelmet, IconHelmetOff, IconHelp, IconHelpCircle, IconHelpCircleFilled, IconHelpHexagon, IconHelpHexagonFilled, IconHelpOctagon, IconHelpOctagonFilled, IconHelpOff, IconHelpSmall, IconHelpSquare, IconHelpSquareFilled, IconHelpSquareRounded, IconHelpSquareRoundedFilled, IconHelpTriangle, IconHelpTriangleFilled, IconHemisphere, IconHemisphereOff, IconHemispherePlus, IconHexagon, IconHexagonNumber0 as IconHexagon0, IconHexagonNumber1 as IconHexagon1, IconHexagonNumber2 as IconHexagon2, IconHexagonNumber3 as IconHexagon3, IconHexagon3d, IconHexagonNumber4 as IconHexagon4, IconHexagonNumber5 as IconHexagon5, IconHexagonNumber6 as IconHexagon6, IconHexagonNumber7 as IconHexagon7, IconHexagonNumber8 as IconHexagon8, IconHexagonNumber9 as IconHexagon9, IconHexagonAsterisk, IconHexagonFilled, IconHexagonLetterA, IconHexagonLetterAFilled, IconHexagonLetterB, IconHexagonLetterBFilled, IconHexagonLetterC, IconHexagonLetterCFilled, IconHexagonLetterD, IconHexagonLetterDFilled, IconHexagonLetterE, IconHexagonLetterEFilled, IconHexagonLetterF, IconHexagonLetterFFilled, IconHexagonLetterG, IconHexagonLetterGFilled, IconHexagonLetterH, IconHexagonLetterHFilled, IconHexagonLetterI, IconHexagonLetterIFilled, IconHexagonLetterJ, IconHexagonLetterJFilled, IconHexagonLetterK, IconHexagonLetterKFilled, IconHexagonLetterL, IconHexagonLetterLFilled, IconHexagonLetterM, IconHexagonLetterMFilled, IconHexagonLetterN, IconHexagonLetterNFilled, IconHexagonLetterO, IconHexagonLetterOFilled, IconHexagonLetterP, IconHexagonLetterPFilled, IconHexagonLetterQ, IconHexagonLetterQFilled, IconHexagonLetterR, IconHexagonLetterRFilled, IconHexagonLetterS, IconHexagonLetterSFilled, IconHexagonLetterT, IconHexagonLetterTFilled, IconHexagonLetterU, IconHexagonLetterUFilled, IconHexagonLetterV, IconHexagonLetterVFilled, IconHexagonLetterW, IconHexagonLetterWFilled, IconHexagonLetterX, IconHexagonLetterXFilled, IconHexagonLetterY, IconHexagonLetterYFilled, IconHexagonLetterZ, IconHexagonLetterZFilled, IconHexagonMinus, IconHexagonMinus2, IconHexagonMinusFilled, IconHexagonNumber0, IconHexagonNumber0Filled, IconHexagonNumber1, IconHexagonNumber1Filled, IconHexagonNumber2, IconHexagonNumber2Filled, IconHexagonNumber3, IconHexagonNumber3Filled, IconHexagonNumber4, IconHexagonNumber4Filled, IconHexagonNumber5, IconHexagonNumber5Filled, IconHexagonNumber6, IconHexagonNumber6Filled, IconHexagonNumber7, IconHexagonNumber7Filled, IconHexagonNumber8, IconHexagonNumber8Filled, IconHexagonNumber9, IconHexagonNumber9Filled, IconHexagonOff, IconHexagonPlus, IconHexagonPlus2, IconHexagonPlusFilled, IconHexagonalPrism, IconHexagonalPrismOff, IconHexagonalPrismPlus, IconHexagonalPyramid, IconHexagonalPyramidOff, IconHexagonalPyramidPlus, IconHexagons, IconHexagonsOff, IconHierarchy, IconHierarchy2, IconHierarchy3, IconHierarchyOff, IconHighlight, IconHighlightOff, IconHistory, IconHistoryOff, IconHistoryToggle, IconHome, IconHome2, IconHomeBitcoin, IconHomeBolt, IconHomeCancel, IconHomeCheck, IconHomeCog, IconHomeDollar, IconHomeDot, IconHomeDown, IconHomeEco, IconHomeEdit, IconHomeExclamation, IconHomeFilled, IconHomeHand, IconHomeHeart, IconHomeInfinity, IconHomeLink, IconHomeMinus, IconHomeMove, IconHomeOff, IconHomePlus, IconHomeQuestion, IconHomeRibbon, IconHomeSearch, IconHomeShare, IconHomeShield, IconHomeSignal, IconHomeSpark, IconHomeStar, IconHomeStats, IconHomeUp, IconHomeX, IconHorse, IconHorseToy, IconHorseshoe, IconHospital, IconHospitalCircle, IconHospitalCircleFilled, IconHotelService, IconHourglass, IconHourglassEmpty, IconHourglassFilled, IconHourglassHigh, IconHourglassLow, IconHourglassOff, IconHours12, IconHours24, IconHtml, IconHttpConnect, IconHttpConnectOff, IconHttpDelete, IconHttpDeleteOff, IconHttpGet, IconHttpGetOff, IconHttpHead, IconHttpHeadOff, IconHttpOptions, IconHttpOptionsOff, IconHttpPatch, IconHttpPatchOff, IconHttpPost, IconHttpPostOff, IconHttpPut, IconHttpPutOff, IconHttpQue, IconHttpQueOff, IconHttpTrace, IconHttpTraceOff, IconIceCream, IconIceCream2, IconIceCreamOff, IconIceSkating, IconIcons, IconIconsFilled, IconIconsOff, IconId, IconIdBadge, IconIdBadge2, IconIdBadgeOff, IconIdOff, IconIkosaedr, IconImageInPicture, IconInbox, IconInboxOff, IconIndentDecrease, IconIndentIncrease, IconInfinity, IconInfinityOff, IconInfoCircle, IconInfoCircleFilled, IconInfoHexagon, IconInfoHexagonFilled, IconInfoOctagon, IconInfoOctagonFilled, IconInfoSmall, IconInfoSquare, IconInfoSquareFilled, IconInfoSquareRounded, IconInfoSquareRoundedFilled, IconInfoTriangle, IconInfoTriangleFilled, IconInnerShadowBottom, IconInnerShadowBottomFilled, IconInnerShadowBottomLeft, IconInnerShadowBottomLeftFilled, IconInnerShadowBottomRight, IconInnerShadowBottomRightFilled, IconInnerShadowLeft, IconInnerShadowLeftFilled, IconInnerShadowRight, IconInnerShadowRightFilled, IconInnerShadowTop, IconInnerShadowTopFilled, IconInnerShadowTopLeft, IconInnerShadowTopLeftFilled, IconInnerShadowTopRight, IconInnerShadowTopRightFilled, IconInputAi, IconInputCheck, IconInputSearch, IconInputSpark, IconInputX, IconInvoice, IconIroning, IconIroning1, IconIroning1Filled, IconIroning2, IconIroning2Filled, IconIroning3, IconIroning3Filled, IconIroningFilled, IconIroningOff, IconIroningSteam, IconIroningSteamFilled, IconIroningSteamOff, IconIrregularPolyhedron, IconIrregularPolyhedronOff, IconIrregularPolyhedronPlus, IconItalic, IconJacket, IconJetpack, IconJetpackFilled, IconJewishStar, IconJewishStarFilled, IconJoinBevel, IconJoinRound, IconJoinStraight, IconJoker, IconJpg, IconJson, IconJumpRope, IconKarate, IconKayak, IconKerning as IconKering, IconKerning, IconKey, IconKeyFilled, IconKeyOff, IconKeyboard, IconKeyboardFilled, IconKeyboardHide, IconKeyboardOff, IconKeyboardShow, IconKeyframe, IconKeyframeAlignCenter, IconKeyframeAlignCenterFilled, IconKeyframeAlignHorizontal, IconKeyframeAlignHorizontalFilled, IconKeyframeAlignVertical, IconKeyframeAlignVerticalFilled, IconKeyframeFilled, IconKeyframes, IconKeyframesFilled, IconLabel, IconLabelFilled, IconLabelImportant, IconLabelImportantFilled, IconLabelOff, IconLadder, IconLadderOff, IconLadle, IconLambda, IconLamp, IconLamp2, IconLampOff, IconLane, IconLanguage, IconLanguageHiragana, IconLanguageKatakana, IconLanguageOff, IconLasso, IconLassoOff, IconLassoPolygon, IconLassoPolygonFilled, IconLaurelWreath, IconLaurelWreath1, IconLaurelWreath1Filled, IconLaurelWreath2, IconLaurelWreath2Filled, IconLaurelWreath3, IconLaurelWreath3Filled, IconLaurelWreathFilled, IconLayersDifference, IconLayersIntersect, IconLayersIntersect2, IconLayersLinked, IconLayersOff, IconLayersSelected, IconLayersSelectedBottom, IconLayersSubtract, IconLayersUnion, IconLayout, IconLayout2, IconLayout2Filled, IconLayoutAlignBottom, IconLayoutAlignBottomFilled, IconLayoutAlignCenter, IconLayoutAlignCenterFilled, IconLayoutAlignLeft, IconLayoutAlignLeftFilled, IconLayoutAlignMiddle, IconLayoutAlignMiddleFilled, IconLayoutAlignRight, IconLayoutAlignRightFilled, IconLayoutAlignTop, IconLayoutAlignTopFilled, IconLayoutBoard, IconLayoutBoardFilled, IconLayoutBoardSplit, IconLayoutBoardSplitFilled, IconLayoutBottombar, IconLayoutBottombarCollapse, IconLayoutBottombarCollapseFilled, IconLayoutBottombarExpand, IconLayoutBottombarExpandFilled, IconLayoutBottombarFilled, IconLayoutBottombarInactive, IconLayoutCards, IconLayoutCardsFilled, IconLayoutCollage, IconLayoutColumns, IconLayoutDashboard, IconLayoutDashboardFilled, IconLayoutDistributeHorizontal, IconLayoutDistributeHorizontalFilled, IconLayoutDistributeVertical, IconLayoutDistributeVerticalFilled, IconLayoutFilled, IconLayoutGrid, IconLayoutGridAdd, IconLayoutGridFilled, IconLayoutGridRemove, IconLayoutKanban, IconLayoutKanbanFilled, IconLayoutList, IconLayoutListFilled, IconLayoutNavbar, IconLayoutNavbarCollapse, IconLayoutNavbarCollapseFilled, IconLayoutNavbarExpand, IconLayoutNavbarExpandFilled, IconLayoutNavbarFilled, IconLayoutNavbarInactive, IconLayoutOff, IconLayoutRows, IconLayoutSidebar, IconLayoutSidebarFilled, IconLayoutSidebarInactive, IconLayoutSidebarLeftCollapse, IconLayoutSidebarLeftCollapseFilled, IconLayoutSidebarLeftExpand, IconLayoutSidebarLeftExpandFilled, IconLayoutSidebarRight, IconLayoutSidebarRightCollapse, IconLayoutSidebarRightCollapseFilled, IconLayoutSidebarRightExpand, IconLayoutSidebarRightExpandFilled, IconLayoutSidebarRightFilled, IconLayoutSidebarRightInactive, IconLeaf, IconLeaf2, IconLeafFilled, IconLeafOff, IconLego, IconLegoFilled, IconLegoOff, IconLemon, IconLemon2, IconLemon2Filled, IconLetterA, IconLetterASmall, IconLetterB, IconLetterBSmall, IconLetterC, IconLetterCSmall, IconLetterCase, IconLetterCaseLower, IconLetterCaseToggle, IconLetterCaseUpper, IconLetterD, IconLetterDSmall, IconLetterE, IconLetterESmall, IconLetterF, IconLetterFSmall, IconLetterG, IconLetterGSmall, IconLetterH, IconLetterHSmall, IconLetterI, IconLetterISmall, IconLetterJ, IconLetterJSmall, IconLetterK, IconLetterKSmall, IconLetterL, IconLetterLSmall, IconLetterM, IconLetterMSmall, IconLetterN, IconLetterNSmall, IconLetterO, IconLetterOSmall, IconLetterP, IconLetterPSmall, IconLetterQ, IconLetterQSmall, IconLetterR, IconLetterRSmall, IconLetterS, IconLetterSSmall, IconLetterSpacing, IconLetterT, IconLetterTSmall, IconLetterU, IconLetterUSmall, IconLetterV, IconLetterVSmall, IconLetterW, IconLetterWSmall, IconLetterX, IconLetterXSmall, IconLetterY, IconLetterYSmall, IconLetterZ, IconLetterZSmall, IconLibrary, IconLibraryFilled, IconLibraryMinus, IconLibraryPhoto, IconLibraryPlus, IconLibraryPlusFilled, IconLicense, IconLicenseOff, IconLifebuoy, IconLifebuoyFilled, IconLifebuoyOff, IconLighter, IconLine, IconLineDashed, IconLineDotted, IconLineHeight, IconLineScan, IconLink, IconLinkMinus, IconLinkOff, IconLinkPlus, IconList, IconListCheck, IconListDetails, IconListLetters, IconListNumbers, IconListSearch, IconListTree, IconLivePhoto, IconLivePhotoFilled, IconLivePhotoOff, IconLiveView, IconLiveViewFilled, IconLoadBalancer, IconLoader, IconLoader2, IconLoader3, IconLoaderQuarter, IconLocation, IconLocationBolt, IconLocationBroken, IconLocationCancel, IconLocationCheck, IconLocationCode, IconLocationCog, IconLocationDiscount, IconLocationDollar, IconLocationDown, IconLocationExclamation, IconLocationFilled, IconLocationHeart, IconLocationMinus, IconLocationOff, IconLocationPause, IconLocationPin, IconLocationPlus, IconLocationQuestion, IconLocationSearch, IconLocationShare, IconLocationStar, IconLocationUp, IconLocationX, IconLock, IconLockAccess, IconLockAccessOff, IconLockBitcoin, IconLockBolt, IconLockCancel, IconLockCheck, IconLockCode, IconLockCog, IconLockDollar, IconLockDown, IconLockExclamation, IconLockFilled, IconLockHeart, IconLockMinus, IconLockOff, IconLockOpen, IconLockOpen2, IconLockOpenOff, IconLockPassword, IconLockPause, IconLockPin, IconLockPlus, IconLockQuestion, IconLockSearch, IconLockShare, IconLockSquare, IconLockSquareRounded, IconLockSquareRoundedFilled, IconLockStar, IconLockUp, IconLockX, IconLogicAnd, IconLogicBuffer, IconLogicNand, IconLogicNor, IconLogicNot, IconLogicOr, IconLogicXnor, IconLogicXor, IconLogin, IconLogin2, IconLogout, IconLogout2, IconLogs, IconLollipop, IconLollipopOff, IconLuggage, IconLuggageOff, IconLungs, IconLungsFilled, IconLungsOff, IconMacro, IconMacroFilled, IconMacroOff, IconMagnet, IconMagnetFilled, IconMagnetOff, IconMagnetic, IconMail, IconMailAi, IconMailBitcoin, IconMailBolt, IconMailCancel, IconMailCheck, IconMailCode, IconMailCog, IconMailDollar, IconMailDown, IconMailExclamation, IconMailFast, IconMailFilled, IconMailForward, IconMailHeart, IconMailMinus, IconMailOff, IconMailOpened, IconMailOpenedFilled, IconMailPause, IconMailPin, IconMailPlus, IconMailQuestion, IconMailSearch, IconMailShare, IconMailSpark, IconMailStar, IconMailUp, IconMailX, IconMailbox, IconMailboxOff, IconMan, IconManFilled, IconManualGearbox, IconManualGearboxFilled, IconMap, IconMap2, IconMapBolt, IconMapCancel, IconMapCheck, IconMapCode, IconMapCog, IconMapDiscount, IconMapDollar, IconMapDown, IconMapEast, IconMapExclamation, IconMapHeart, IconMapMinus, IconMapNorth, IconMapOff, IconMapPause, IconMapPin, IconMapPin2, IconMapPinBolt, IconMapPinCancel, IconMapPinCheck, IconMapPinCode, IconMapPinCog, IconMapPinDollar, IconMapPinDown, IconMapPinExclamation, IconMapPinFilled, IconMapPinHeart, IconMapPinMinus, IconMapPinOff, IconMapPinPause, IconMapPinPin, IconMapPinPlus, IconMapPinQuestion, IconMapPinSearch, IconMapPinShare, IconMapPinStar, IconMapPinUp, IconMapPinX, IconMapPins, IconMapPlus, IconMapQuestion, IconMapRoute, IconMapSearch, IconMapShare, IconMapSouth, IconMapStar, IconMapUp, IconMapWest, IconMapX, IconMarkdown, IconMarkdownOff, IconMarquee, IconMarquee2, IconMarqueeOff, IconMars, IconMask, IconMaskOff, IconMasksTheater, IconMasksTheaterOff, IconMassage, IconMatchstick, IconMath, IconMath1Divide2, IconMath1Divide3, IconMathAvg, IconMathCos, IconMathCtg, IconMathEqualGreater, IconMathEqualLower, IconMathFunction, IconMathFunctionOff, IconMathFunctionY, IconMathGreater, IconMathIntegral, IconMathIntegralX, IconMathIntegrals, IconMathLower, IconMathMax, IconMathMaxMin, IconMathMin, IconMathNot, IconMathOff, IconMathPi, IconMathPiDivide2, IconMathSec, IconMathSin, IconMathSymbols, IconMathTg, IconMathXDivide2, IconMathXDivideY, IconMathXDivideY2, IconMathXFloorDivideY, IconMathXMinusX, IconMathXMinusY, IconMathXPlusX, IconMathXPlusY, IconMathXy, IconMathYMinusY, IconMathYPlusY, IconMatrix, IconMaximize, IconMaximizeOff, IconMeat, IconMeatOff, IconMedal, IconMedal2, IconMedicalCross, IconMedicalCrossCircle, IconMedicalCrossFilled, IconMedicalCrossOff, IconMedicineSyrup, IconMeeple, IconMeepleFilled, IconMelon, IconMelonFilled, IconMenorah, IconMenu, IconMenu2, IconMenu3, IconMenu4, IconMenuDeep, IconMenuOrder, IconMessage, IconMessage2, IconMessage2Bolt, IconMessage2Cancel, IconMessage2Check, IconMessage2Code, IconMessage2Cog, IconMessage2Dollar, IconMessage2Down, IconMessage2Exclamation, IconMessage2Filled, IconMessage2Heart, IconMessage2Minus, IconMessage2Off, IconMessage2Pause, IconMessage2Pin, IconMessage2Plus, IconMessage2Question, IconMessage2Search, IconMessage2Share, IconMessage2Star, IconMessage2Up, IconMessage2X, IconMessageBolt, IconMessageCancel, IconMessageChatbot, IconMessageChatbotFilled, IconMessageCheck, IconMessageCircle, IconMessageCircle as IconMessageCircle2, IconMessageCircleFilled as IconMessageCircle2Filled, IconMessageCircleBolt, IconMessageCircleCancel, IconMessageCircleCheck, IconMessageCircleCode, IconMessageCircleCog, IconMessageCircleDollar, IconMessageCircleDown, IconMessageCircleExclamation, IconMessageCircleFilled, IconMessageCircleHeart, IconMessageCircleMinus, IconMessageCircleOff, IconMessageCirclePause, IconMessageCirclePin, IconMessageCirclePlus, IconMessageCircleQuestion, IconMessageCircleSearch, IconMessageCircleShare, IconMessageCircleStar, IconMessageCircleUp, IconMessageCircleUser, IconMessageCircleX, IconMessageCode, IconMessageCog, IconMessageDollar, IconMessageDots, IconMessageDown, IconMessageExclamation, IconMessageFilled, IconMessageForward, IconMessageHeart, IconMessageLanguage, IconMessageMinus, IconMessageOff, IconMessagePause, IconMessagePin, IconMessagePlus, IconMessageQuestion, IconMessageReply, IconMessageReport, IconMessageReportFilled, IconMessageSearch, IconMessageShare, IconMessageStar, IconMessageUp, IconMessageUser, IconMessageX, IconMessages, IconMessagesOff, IconMeteor, IconMeteorFilled, IconMeteorOff, IconMeterCube, IconMeterSquare, IconMetronome, IconMichelinBibGourmand, IconMichelinStar, IconMichelinStarFilled, IconMichelinStarGreen, IconMickey, IconMickeyFilled, IconMicrophone, IconMicrophone2, IconMicrophone2Off, IconMicrophoneFilled, IconMicrophoneOff, IconMicroscope, IconMicroscopeFilled, IconMicroscopeOff, IconMicrowave, IconMicrowaveFilled, IconMicrowaveOff, IconMilitaryAward, IconMilitaryRank, IconMilitaryRankFilled, IconMilk, IconMilkFilled, IconMilkOff, IconMilkshake, IconMinimize, IconMinus, IconMinusVertical, IconMist, IconMistOff, IconMobiledata, IconMobiledataOff, IconMoneybag, IconMoneybagEdit, IconMoneybagHeart, IconMoneybagMinus, IconMoneybagMove, IconMoneybagMoveBack, IconMoneybagPlus, IconMonkeybar, IconMoodAngry, IconMoodAngryFilled, IconMoodAnnoyed, IconMoodAnnoyed2, IconMoodBitcoin, IconMoodBoy, IconMoodCheck, IconMoodCog, IconMoodConfuzed, IconMoodConfuzedFilled, IconMoodCrazyHappy, IconMoodCrazyHappyFilled, IconMoodCry, IconMoodDollar, IconMoodEdit, IconMoodEmpty, IconMoodEmptyFilled, IconMoodHappy, IconMoodHappyFilled, IconMoodHeart, IconMoodKid, IconMoodKidFilled, IconMoodLookDown, IconMoodLookLeft, IconMoodLookRight, IconMoodLookUp, IconMoodMinus, IconMoodNerd, IconMoodNervous, IconMoodNeutral, IconMoodNeutralFilled, IconMoodOff, IconMoodPin, IconMoodPlus, IconMoodPuzzled, IconMoodSad, IconMoodSad2, IconMoodSadDizzy, IconMoodSadFilled, IconMoodSadSquint, IconMoodSearch, IconMoodShare, IconMoodSick, IconMoodSilence, IconMoodSing, IconMoodSmile, IconMoodSmileBeam, IconMoodSmileDizzy, IconMoodSmileFilled, IconMoodSpark, IconMoodSurprised as IconMoodSuprised, IconMoodSurprised, IconMoodTongue, IconMoodTongueWink, IconMoodTongueWink2, IconMoodUnamused, IconMoodUp, IconMoodWink, IconMoodWink2, IconMoodWrrr, IconMoodWrrrFilled, IconMoodX, IconMoodXd, IconMoon, IconMoon2, IconMoonFilled, IconMoonOff, IconMoonStars, IconMoped, IconMotorbike, IconMotorbikeFilled, IconMountain, IconMountainFilled, IconMountainOff, IconMouse, IconMouse2, IconMouseFilled, IconMouseOff, IconMoustache, IconMovie, IconMovieOff, IconMug, IconMugFilled, IconMugOff, IconMultiplier05x, IconMultiplier15x, IconMultiplier1x, IconMultiplier2x, IconMushroom, IconMushroomFilled, IconMushroomOff, IconMusic, IconMusicBolt, IconMusicCancel, IconMusicCheck, IconMusicCode, IconMusicCog, IconMusicDiscount, IconMusicDollar, IconMusicDown, IconMusicExclamation, IconMusicHeart, IconMusicMinus, IconMusicOff, IconMusicPause, IconMusicPin, IconMusicPlus, IconMusicQuestion, IconMusicSearch, IconMusicShare, IconMusicStar, IconMusicUp, IconMusicX, IconNavigation, IconNavigationBolt, IconNavigationCancel, IconNavigationCheck, IconNavigationCode, IconNavigationCog, IconNavigationDiscount, IconNavigationDollar, IconNavigationDown, IconNavigationEast, IconNavigationExclamation, IconNavigationFilled, IconNavigationHeart, IconNavigationMinus, IconNavigationNorth, IconNavigationOff, IconNavigationPause, IconNavigationPin, IconNavigationPlus, IconNavigationQuestion, IconNavigationSearch, IconNavigationShare, IconNavigationSouth, IconNavigationStar, IconNavigationTop, IconNavigationUp, IconNavigationWest, IconNavigationX, IconNeedle, IconNeedleThread, IconNetwork, IconNetworkOff, IconNewSection, IconNews, IconNewsOff, IconNfc, IconNfcOff, IconNoCopyright, IconNoCreativeCommons, IconNoDerivatives, IconNorthStar, IconNote, IconNoteOff, IconNotebook, IconNotebookOff, IconNotes, IconNotesOff, IconNotification, IconNotificationOff, IconNumber, IconNumber0, IconNumber0Small, IconNumber1, IconNumber10, IconNumber100Small, IconNumber10Small, IconNumber11, IconNumber11Small, IconNumber123, IconNumber12Small, IconNumber13Small, IconNumber14Small, IconNumber15Small, IconNumber16Small, IconNumber17Small, IconNumber18Small, IconNumber19Small, IconNumber1Small, IconNumber2, IconNumber20Small, IconNumber21Small, IconNumber22Small, IconNumber23Small, IconNumber24Small, IconNumber25Small, IconNumber26Small, IconNumber27Small, IconNumber28Small, IconNumber29Small, IconNumber2Small, IconNumber3, IconNumber30Small, IconNumber31Small, IconNumber32Small, IconNumber33Small, IconNumber34Small, IconNumber35Small, IconNumber36Small, IconNumber37Small, IconNumber38Small, IconNumber39Small, IconNumber3Small, IconNumber4, IconNumber40Small, IconNumber41Small, IconNumber42Small, IconNumber43Small, IconNumber44Small, IconNumber45Small, IconNumber46Small, IconNumber47Small, IconNumber48Small, IconNumber49Small, IconNumber4Small, IconNumber5, IconNumber50Small, IconNumber51Small, IconNumber52Small, IconNumber53Small, IconNumber54Small, IconNumber55Small, IconNumber56Small, IconNumber57Small, IconNumber58Small, IconNumber59Small, IconNumber5Small, IconNumber6, IconNumber60Small, IconNumber61Small, IconNumber62Small, IconNumber63Small, IconNumber64Small, IconNumber65Small, IconNumber66Small, IconNumber67Small, IconNumber68Small, IconNumber69Small, IconNumber6Small, IconNumber7, IconNumber70Small, IconNumber71Small, IconNumber72Small, IconNumber73Small, IconNumber74Small, IconNumber75Small, IconNumber76Small, IconNumber77Small, IconNumber78Small, IconNumber79Small, IconNumber7Small, IconNumber8, IconNumber80Small, IconNumber81Small, IconNumber82Small, IconNumber83Small, IconNumber84Small, IconNumber85Small, IconNumber86Small, IconNumber87Small, IconNumber88Small, IconNumber89Small, IconNumber8Small, IconNumber9, IconNumber90Small, IconNumber91Small, IconNumber92Small, IconNumber93Small, IconNumber94Small, IconNumber95Small, IconNumber96Small, IconNumber97Small, IconNumber98Small, IconNumber99Small, IconNumber9Small, IconNumbers, IconNurse, IconNurseFilled, IconNut, IconObjectScan, IconOctagon, IconOctagonFilled, IconOctagonMinus, IconOctagonMinus2, IconOctagonMinusFilled, IconOctagonOff, IconOctagonPlus, IconOctagonPlus2, IconOctagonPlusFilled, IconOctahedron, IconOctahedronOff, IconOctahedronPlus, IconOld, IconOlympics, IconOlympicsOff, IconOm, IconOmega, IconOption, IconOutbound, IconOutlet, IconOval, IconOvalFilled, IconOvalVertical, IconOvalVerticalFilled, IconOverline, IconPackage, IconPackageExport, IconPackageImport, IconPackageOff, IconPackages, IconPacman, IconPacmanFilled, IconPageBreak, IconPaint, IconPaintFilled, IconPaintOff, IconPalette, IconPaletteFilled, IconPaletteOff, IconPanoramaHorizontal, IconPanoramaHorizontalFilled, IconPanoramaHorizontalOff, IconPanoramaVertical, IconPanoramaVerticalFilled, IconPanoramaVerticalOff, IconPaperBag, IconPaperBagOff, IconPaperclip, IconParachute, IconParachuteOff, IconParentheses, IconParenthesesOff, IconParking, IconParkingCircle, IconParkingCircleFilled, IconParkingOff, IconPassword, IconPasswordFingerprint, IconPasswordMobilePhone, IconPasswordUser, IconPaw, IconPawFilled, IconPawOff, IconPaywall, IconPdf, IconPeace, IconPencil, IconPencilBolt, IconPencilCancel, IconPencilCheck, IconPencilCode, IconPencilCog, IconPencilDiscount, IconPencilDollar, IconPencilDown, IconPencilExclamation, IconPencilHeart, IconPencilMinus, IconPencilOff, IconPencilPause, IconPencilPin, IconPencilPlus, IconPencilQuestion, IconPencilSearch, IconPencilShare, IconPencilStar, IconPencilUp, IconPencilX, IconPennant, IconPennant2, IconPennant2Filled, IconPennantFilled, IconPennantOff, IconPentagon, IconPentagonFilled, IconPentagonMinus, IconPentagonNumber0, IconPentagonNumber1, IconPentagonNumber2, IconPentagonNumber3, IconPentagonNumber4, IconPentagonNumber5, IconPentagonNumber6, IconPentagonNumber7, IconPentagonNumber8, IconPentagonNumber9, IconPentagonOff, IconPentagonPlus, IconPentagonX, IconPentagram, IconPepper, IconPepperOff, IconPercentage, IconPercentage0, IconPercentage10, IconPercentage100, IconPercentage20, IconPercentage25, IconPercentage30, IconPercentage33, IconPercentage40, IconPercentage50, IconPercentage60, IconPercentage66, IconPercentage70, IconPercentage75, IconPercentage80, IconPercentage90, IconPerfume, IconPerspective, IconPerspectiveOff, IconPhone, IconPhoneCall, IconPhoneCallFilled, IconPhoneCalling, IconPhoneCallingFilled, IconPhoneCheck, IconPhoneCheckFilled, IconPhoneDone, IconPhoneEnd, IconPhoneFilled, IconPhoneIncoming, IconPhoneOff, IconPhoneOutgoing, IconPhonePause, IconPhonePlus, IconPhoneRinging, IconPhoneSpark, IconPhoneX, IconPhoneXFilled, IconPhoto, IconPhotoAi, IconPhotoBitcoin, IconPhotoBolt, IconPhotoCancel, IconPhotoCheck, IconPhotoCircle, IconPhotoCircleMinus, IconPhotoCirclePlus, IconPhotoCode, IconPhotoCog, IconPhotoDollar, IconPhotoDown, IconPhotoEdit, IconPhotoExclamation, IconPhotoFilled, IconPhotoHeart, IconPhotoHexagon, IconPhotoMinus, IconPhotoOff, IconPhotoPause, IconPhotoPentagon, IconPhotoPin, IconPhotoPlus, IconPhotoQuestion, IconPhotoScan, IconPhotoSearch, IconPhotoSensor, IconPhotoSensor2, IconPhotoSensor3, IconPhotoShare, IconPhotoShield, IconPhotoSpark, IconPhotoSquareRounded, IconPhotoStar, IconPhotoUp, IconPhotoVideo, IconPhotoX, IconPhysotherapist, IconPiano, IconPick, IconPicnicTable, IconPictureInPicture, IconPictureInPictureFilled, IconPictureInPictureOff, IconPictureInPictureOn, IconPictureInPictureTop, IconPictureInPictureTopFilled, IconPig, IconPigFilled, IconPigMoney, IconPigOff, IconPilcrow, IconPilcrowLeft, IconPilcrowRight, IconPill, IconPillFilled, IconPillOff, IconPills, IconPin, IconPinEnd, IconPinFilled, IconPinInvoke, IconPingPong, IconPinned, IconPinnedFilled, IconPinnedOff, IconPizza, IconPizzaFilled, IconPizzaOff, IconPlaceholder, IconPlane, IconPlaneArrival, IconPlaneArrivalFilled, IconPlaneDeparture, IconPlaneDepartureFilled, IconPlaneFilled, IconPlaneInflight, IconPlaneOff, IconPlaneTilt, IconPlaneTiltFilled, IconPlanet, IconPlanetOff, IconPlant, IconPlant2, IconPlant2Off, IconPlantOff, IconPlayBasketball, IconPlayCard, IconPlayCard1, IconPlayCard10, IconPlayCard10Filled, IconPlayCard1Filled, IconPlayCard2, IconPlayCard2Filled, IconPlayCard3, IconPlayCard3Filled, IconPlayCard4, IconPlayCard4Filled, IconPlayCard5, IconPlayCard5Filled, IconPlayCard6, IconPlayCard6Filled, IconPlayCard7, IconPlayCard7Filled, IconPlayCard8, IconPlayCard8Filled, IconPlayCard9, IconPlayCard9Filled, IconPlayCardA, IconPlayCardAFilled, IconPlayCardFilled, IconPlayCardJ, IconPlayCardJFilled, IconPlayCardK, IconPlayCardKFilled, IconPlayCardOff, IconPlayCardQ, IconPlayCardQFilled, IconPlayCardStar, IconPlayCardStarFilled, IconPlayFootball, IconPlayHandball, IconPlayVolleyball, IconPlayerEject, IconPlayerEjectFilled, IconPlayerPause, IconPlayerPauseFilled, IconPlayerPlay, IconPlayerPlayFilled, IconPlayerRecord, IconPlayerRecordFilled, IconPlayerSkipBack, IconPlayerSkipBackFilled, IconPlayerSkipForward, IconPlayerSkipForwardFilled, IconPlayerStop, IconPlayerStopFilled, IconPlayerTrackNext, IconPlayerTrackNextFilled, IconPlayerTrackPrev, IconPlayerTrackPrevFilled, IconPlaylist, IconPlaylistAdd, IconPlaylistFilled, IconPlaylistOff, IconPlaylistX, IconPlaystationCircle, IconPlaystationSquare, IconPlaystationTriangle, IconPlaystationX, IconPlug, IconPlugConnected, IconPlugConnectedX, IconPlugOff, IconPlugX, IconPlus, IconPlusEqual, IconPlusMinus, IconPng, IconPodium, IconPodiumOff, IconPoint, IconPointFilled, IconPointOff, IconPointer, IconPointerBolt, IconPointerCancel, IconPointerCheck, IconPointerCode, IconPointerCog, IconPointerDollar, IconPointerDown, IconPointerExclamation, IconPointerFilled, IconPointerHeart, IconPointerMinus, IconPointerOff, IconPointerPause, IconPointerPin, IconPointerPlus, IconPointerQuestion, IconPointerSearch, IconPointerShare, IconPointerStar, IconPointerUp, IconPointerX, IconPokeball, IconPokeballOff, IconPokerChip, IconPolaroid, IconPolaroidFilled, IconPolygon, IconPolygonOff, IconPoo, IconPooFilled, IconPool, IconPoolOff, IconPower, IconPray, IconPremiumRights, IconPrescription, IconPresentation, IconPresentationAnalytics, IconPresentationAnalyticsFilled, IconPresentationFilled, IconPresentationOff, IconPrinter, IconPrinterOff, IconPrism, IconPrismLight, IconPrismOff, IconPrismPlus, IconPrison, IconProgress, IconProgressAlert, IconProgressBolt, IconProgressCheck, IconProgressDown, IconProgressHelp, IconProgressX, IconPrompt, IconProng, IconPropeller, IconPropellerOff, IconProtocol, IconPumpkinScary, IconPuzzle, IconPuzzle2, IconPuzzleFilled, IconPuzzleOff, IconPyramid, IconPyramidOff, IconPyramidPlus, IconQrcode, IconQrcodeOff, IconQuestionMark, IconQuote, IconQuoteFilled, IconQuoteOff, IconQuotes, IconRadar, IconRadar2, IconRadarFilled, IconRadarOff, IconRadio, IconRadioOff, IconRadioactive, IconRadioactiveFilled, IconRadioactiveOff, IconRadiusBottomLeft, IconRadiusBottomRight, IconRadiusTopLeft, IconRadiusTopRight, IconRainbow, IconRainbowOff, IconRating12Plus, IconRating14Plus, IconRating16Plus, IconRating18Plus, IconRating21Plus, IconRazor, IconRazorElectric, IconReceipt, IconReceipt2, IconReceiptBitcoin, IconReceiptDollar, IconReceiptDollarFilled, IconReceiptEuro, IconReceiptEuroFilled, IconReceiptFilled, IconReceiptOff, IconReceiptPound, IconReceiptPoundFilled, IconReceiptRefund, IconReceiptRupee, IconReceiptRupeeFilled, IconReceiptTax, IconReceiptYen, IconReceiptYenFilled, IconReceiptYuan, IconReceiptYuanFilled, IconRecharging, IconRecordMail, IconRecordMailOff, IconRectangle, IconRectangleFilled, IconRectangleRoundedBottom, IconRectangleRoundedTop, IconRectangleVertical, IconRectangleVerticalFilled, IconRectangularPrism, IconRectangularPrismOff, IconRectangularPrismPlus, IconRecycle, IconRecycleOff, IconRefresh, IconRefreshAlert, IconRefreshDot, IconRefreshOff, IconRegex, IconRegexOff, IconRegistered, IconRegisteredFilled, IconRelationManyToMany, IconRelationManyToManyFilled, IconRelationOneToMany, IconRelationOneToManyFilled, IconRelationOneToOne, IconRelationOneToOneFilled, IconReload, IconReorder, IconRepeat, IconRepeatOff, IconRepeatOnce, IconReplace, IconReplaceFilled, IconReplaceOff, IconReplaceUser, IconReport, IconReportAnalytics, IconReportAnalyticsFilled, IconReportMedical, IconReportMoney, IconReportMoneyFilled, IconReportOff, IconReportSearch, IconReservedLine, IconResize, IconRestore, IconRewindBackward10, IconRewindBackward15, IconRewindBackward20, IconRewindBackward30, IconRewindBackward40, IconRewindBackward5, IconRewindBackward50, IconRewindBackward60, IconRewindForward10, IconRewindForward15, IconRewindForward20, IconRewindForward30, IconRewindForward40, IconRewindForward5, IconRewindForward50, IconRewindForward60, IconRibbonHealth, IconRings, IconRipple, IconRippleDown, IconRippleOff, IconRippleUp, IconRoad, IconRoadOff, IconRoadSign, IconRobot, IconRobotFace, IconRobotOff, IconRocket, IconRocketOff, IconRollerSkating, IconRollercoaster, IconRollercoasterFilled, IconRollercoasterOff, IconRosette, IconRosetteAsterisk, IconRosetteDiscount, IconRosetteDiscountCheck, IconRosetteDiscountCheckFilled, IconRosetteDiscountCheckOff, IconRosetteDiscountFilled, IconRosetteDiscountOff, IconRosetteFilled, IconRosetteNumber0, IconRosetteNumber1, IconRosetteNumber2, IconRosetteNumber3, IconRosetteNumber4, IconRosetteNumber5, IconRosetteNumber6, IconRosetteNumber7, IconRosetteNumber8, IconRosetteNumber9, IconRotate, IconRotate2, IconRotate360, IconRotate3d, IconRotateClockwise, IconRotateClockwise2, IconRotateDot, IconRotateRectangle, IconRoute, IconRoute2, IconRouteAltLeft, IconRouteAltRight, IconRouteOff, IconRouteScan, IconRouteSquare, IconRouteSquare2, IconRouteX, IconRouteX2, IconRouter, IconRouterOff, IconRowInsertBottom, IconRowInsertTop, IconRowRemove, IconRss, IconRubberStamp, IconRubberStampOff, IconRuler, IconRuler2, IconRuler2Off, IconRuler3, IconRulerMeasure, IconRulerMeasure2, IconRulerOff, IconRun, IconRvTruck, IconSTurnDown, IconSTurnLeft, IconSTurnRight, IconSTurnUp, IconSailboat, IconSailboat2, IconSailboatOff, IconSalad, IconSaladFilled, IconSalt, IconSandbox, IconSatellite, IconSatelliteFilled, IconSatelliteOff, IconSausage, IconScale, IconScaleOff, IconScaleOutline, IconScaleOutlineOff, IconScan, IconScanEye, IconScanPosition, IconSchema, IconSchemaOff, IconSchool, IconSchoolBell, IconSchoolOff, IconScissors, IconScissorsOff, IconScooter, IconScooterElectric, IconScoreboard, IconScreenShare, IconScreenShareOff, IconScreenshot, IconScribble, IconScribbleOff, IconScript, IconScriptMinus, IconScriptPlus, IconScriptX, IconScubaDiving, IconScubaDivingTank, IconScubaDivingTankFilled, IconScubaMask, IconScubaMaskOff, IconSdk, IconSearch, IconSearchOff, IconSection, IconSectionFilled, IconSectionSign, IconSeedling as IconSeeding, IconSeedlingFilled as IconSeedingFilled, IconSeedlingOff as IconSeedingOff, IconSeedling, IconSeedlingFilled, IconSeedlingOff, IconSelect, IconSelectAll, IconSelector, IconSend, IconSend2, IconSendOff, IconSeo, IconSeparator, IconSeparatorHorizontal, IconSeparatorVertical, IconServer, IconServer2, IconServerBolt, IconServerCog, IconServerOff, IconServerSpark, IconServicemark, IconSettings, IconSettings2, IconSettingsAi, IconSettingsAutomation, IconSettingsBolt, IconSettingsCancel, IconSettingsCheck, IconSettingsCode, IconSettingsCog, IconSettingsDollar, IconSettingsDown, IconSettingsExclamation, IconSettingsFilled, IconSettingsHeart, IconSettingsMinus, IconSettingsOff, IconSettingsPause, IconSettingsPin, IconSettingsPlus, IconSettingsQuestion, IconSettingsSearch, IconSettingsShare, IconSettingsSpark, IconSettingsStar, IconSettingsUp, IconSettingsX, IconShadow, IconShadowOff, IconShape, IconShape2, IconShape3, IconShapeOff, IconShare, IconShare2, IconShare3, IconShareOff, IconShareplay, IconSkiJumping as IconShiJumping, IconShield, IconShieldBolt, IconShieldCancel, IconShieldCheck, IconShieldCheckFilled, IconShieldCheckered, IconShieldCheckeredFilled, IconShieldChevron, IconShieldCode, IconShieldCog, IconShieldDollar, IconShieldDown, IconShieldExclamation, IconShieldFilled, IconShieldHalf, IconShieldHalfFilled, IconShieldHeart, IconShieldLock, IconShieldLockFilled, IconShieldMinus, IconShieldOff, IconShieldPause, IconShieldPin, IconShieldPlus, IconShieldQuestion, IconShieldSearch, IconShieldShare, IconShieldStar, IconShieldUp, IconShieldX, IconShip, IconShipOff, IconShirt, IconShirtFilled, IconShirtOff, IconShirtSport, IconShoe, IconShoeOff, IconShoppingBag, IconShoppingBagCheck, IconShoppingBagDiscount, IconShoppingBagEdit, IconShoppingBagExclamation, IconShoppingBagHeart, IconShoppingBagMinus, IconShoppingBagPlus, IconShoppingBagSearch, IconShoppingBagX, IconShoppingCart, IconShoppingCartBolt, IconShoppingCartCancel, IconShoppingCartCheck, IconShoppingCartCode, IconShoppingCartCog, IconShoppingCartCopy, IconShoppingCartDiscount, IconShoppingCartDollar, IconShoppingCartDown, IconShoppingCartExclamation, IconShoppingCartFilled, IconShoppingCartHeart, IconShoppingCartMinus, IconShoppingCartOff, IconShoppingCartPause, IconShoppingCartPin, IconShoppingCartPlus, IconShoppingCartQuestion, IconShoppingCartSearch, IconShoppingCartShare, IconShoppingCartStar, IconShoppingCartUp, IconShoppingCartX, IconShovel, IconShovelPitchforks, IconShredder, IconSignLeft, IconSignLeftFilled, IconSignRight, IconSignRightFilled, IconSignal2g, IconSignal3g, IconSignal4g, IconSignal4gPlus, IconSignal5g, IconSignal6g, IconSignalE, IconSignalG, IconSignalH, IconSignalHPlus, IconSignalLte, IconSignature, IconSignatureOff, IconSitemap, IconSitemapFilled, IconSitemapOff, IconSkateboard, IconSkateboardOff, IconSkateboarding, IconSkewX, IconSkewY, IconSkiJumping, IconSkull, IconSlash, IconSlashes, IconSleigh, IconSlice, IconSlideshow, IconSmartHome, IconSmartHomeOff, IconSmoking, IconSmokingNo, IconSnowboarding, IconSnowflake, IconSnowflakeOff, IconSnowman, IconSoccerField, IconSocial, IconSocialOff, IconSock, IconSofa, IconSofaOff, IconSolarElectricity, IconSolarPanel, IconSolarPanel2, IconSort09, IconSort90, IconSortAZ, IconSortAscending, IconSortAscending2, IconSortAscending2Filled, IconSortAscendingLetters, IconSortAscendingNumbers, IconSortAscendingShapes, IconSortAscendingShapesFilled, IconSortAscendingSmallBig, IconSortDescendingSmallBig as IconSortDeacendingSmallBig, IconSortDescending, IconSortDescending2, IconSortDescending2Filled, IconSortDescendingLetters, IconSortDescendingNumbers, IconSortDescendingShapes, IconSortDescendingShapesFilled, IconSortDescendingSmallBig, IconSortZA, IconSos, IconSoup, IconSoupFilled, IconSoupOff, IconSourceCode, IconSpace, IconSpaceOff, IconSpaces, IconSpacingHorizontal, IconSpacingVertical, IconSpade, IconSpadeFilled, IconSparkles, IconSparkles2, IconSparkles2Filled, IconSparklesFilled, IconSpeakerphone, IconSpeedboat, IconSpeedboatFilled, IconSphere, IconSphereOff, IconSpherePlus, IconSpider, IconSpiderFilled, IconSpiral, IconSpiralOff, IconSportBillard, IconSpray, IconSpy, IconSpyOff, IconSql, IconSquare, IconSquareNumber0 as IconSquare0, IconSquareNumber1 as IconSquare1, IconSquareNumber2 as IconSquare2, IconSquareNumber3 as IconSquare3, IconSquareNumber4 as IconSquare4, IconSquareNumber5 as IconSquare5, IconSquareNumber6 as IconSquare6, IconSquareNumber7 as IconSquare7, IconSquareNumber8 as IconSquare8, IconSquareNumber9 as IconSquare9, IconSquareArrowDown, IconSquareArrowDownFilled, IconSquareArrowLeft, IconSquareArrowLeftFilled, IconSquareArrowRight, IconSquareArrowRightFilled, IconSquareArrowUp, IconSquareArrowUpFilled, IconSquareAsterisk, IconSquareAsteriskFilled, IconSquareCheck, IconSquareCheckFilled, IconSquareChevronDown, IconSquareChevronDownFilled, IconSquareChevronLeft, IconSquareChevronLeftFilled, IconSquareChevronRight, IconSquareChevronRightFilled, IconSquareChevronUp, IconSquareChevronUpFilled, IconSquareChevronsDown, IconSquareChevronsDownFilled, IconSquareChevronsLeft, IconSquareChevronsLeftFilled, IconSquareChevronsRight, IconSquareChevronsRightFilled, IconSquareChevronsUp, IconSquareChevronsUpFilled, IconSquareDashed, IconSquareDot, IconSquareDotFilled, IconSquareF0, IconSquareF0Filled, IconSquareF1, IconSquareF1Filled, IconSquareF2, IconSquareF2Filled, IconSquareF3, IconSquareF3Filled, IconSquareF4, IconSquareF4Filled, IconSquareF5, IconSquareF5Filled, IconSquareF6, IconSquareF6Filled, IconSquareF7, IconSquareF7Filled, IconSquareF8, IconSquareF8Filled, IconSquareF9, IconSquareF9Filled, IconSquareFilled, IconSquareForbid, IconSquareForbid2, IconSquareHalf, IconSquareKey, IconSquareLetterA, IconSquareLetterAFilled, IconSquareLetterB, IconSquareLetterBFilled, IconSquareLetterC, IconSquareLetterCFilled, IconSquareLetterD, IconSquareLetterDFilled, IconSquareLetterE, IconSquareLetterEFilled, IconSquareLetterF, IconSquareLetterFFilled, IconSquareLetterG, IconSquareLetterGFilled, IconSquareLetterH, IconSquareLetterHFilled, IconSquareLetterI, IconSquareLetterIFilled, IconSquareLetterJ, IconSquareLetterJFilled, IconSquareLetterK, IconSquareLetterKFilled, IconSquareLetterL, IconSquareLetterLFilled, IconSquareLetterM, IconSquareLetterMFilled, IconSquareLetterN, IconSquareLetterNFilled, IconSquareLetterO, IconSquareLetterOFilled, IconSquareLetterP, IconSquareLetterPFilled, IconSquareLetterQ, IconSquareLetterQFilled, IconSquareLetterR, IconSquareLetterRFilled, IconSquareLetterS, IconSquareLetterSFilled, IconSquareLetterT, IconSquareLetterTFilled, IconSquareLetterU, IconSquareLetterUFilled, IconSquareLetterV, IconSquareLetterVFilled, IconSquareLetterW, IconSquareLetterWFilled, IconSquareLetterX, IconSquareLetterXFilled, IconSquareLetterY, IconSquareLetterYFilled, IconSquareLetterZ, IconSquareLetterZFilled, IconSquareMinus, IconSquareMinus2, IconSquareMinusFilled, IconSquareNumber0, IconSquareNumber0Filled, IconSquareNumber1, IconSquareNumber1Filled, IconSquareNumber2, IconSquareNumber2Filled, IconSquareNumber3, IconSquareNumber3Filled, IconSquareNumber4, IconSquareNumber4Filled, IconSquareNumber5, IconSquareNumber5Filled, IconSquareNumber6, IconSquareNumber6Filled, IconSquareNumber7, IconSquareNumber7Filled, IconSquareNumber8, IconSquareNumber8Filled, IconSquareNumber9, IconSquareNumber9Filled, IconSquareOff, IconSquarePercentage, IconSquarePlus, IconSquarePlus2, IconSquareRoot, IconSquareRoot2, IconSquareRotated, IconSquareRotatedAsterisk, IconSquareRotatedFilled, IconSquareRotatedForbid, IconSquareRotatedForbid2, IconSquareRotatedOff, IconSquareRounded, IconSquareRoundedArrowDown, IconSquareRoundedArrowDownFilled, IconSquareRoundedArrowLeft, IconSquareRoundedArrowLeftFilled, IconSquareRoundedArrowRight, IconSquareRoundedArrowRightFilled, IconSquareRoundedArrowUp, IconSquareRoundedArrowUpFilled, IconSquareRoundedCheck, IconSquareRoundedCheckFilled, IconSquareRoundedChevronDown, IconSquareRoundedChevronDownFilled, IconSquareRoundedChevronLeft, IconSquareRoundedChevronLeftFilled, IconSquareRoundedChevronRight, IconSquareRoundedChevronRightFilled, IconSquareRoundedChevronUp, IconSquareRoundedChevronUpFilled, IconSquareRoundedChevronsDown, IconSquareRoundedChevronsDownFilled, IconSquareRoundedChevronsLeft, IconSquareRoundedChevronsLeftFilled, IconSquareRoundedChevronsRight, IconSquareRoundedChevronsRightFilled, IconSquareRoundedChevronsUp, IconSquareRoundedChevronsUpFilled, IconSquareRoundedFilled, IconSquareRoundedLetterA, IconSquareRoundedLetterAFilled, IconSquareRoundedLetterB, IconSquareRoundedLetterBFilled, IconSquareRoundedLetterC, IconSquareRoundedLetterCFilled, IconSquareRoundedLetterD, IconSquareRoundedLetterDFilled, IconSquareRoundedLetterE, IconSquareRoundedLetterEFilled, IconSquareRoundedLetterF, IconSquareRoundedLetterFFilled, IconSquareRoundedLetterG, IconSquareRoundedLetterGFilled, IconSquareRoundedLetterH, IconSquareRoundedLetterHFilled, IconSquareRoundedLetterI, IconSquareRoundedLetterIFilled, IconSquareRoundedLetterJ, IconSquareRoundedLetterJFilled, IconSquareRoundedLetterK, IconSquareRoundedLetterKFilled, IconSquareRoundedLetterL, IconSquareRoundedLetterLFilled, IconSquareRoundedLetterM, IconSquareRoundedLetterMFilled, IconSquareRoundedLetterN, IconSquareRoundedLetterNFilled, IconSquareRoundedLetterO, IconSquareRoundedLetterOFilled, IconSquareRoundedLetterP, IconSquareRoundedLetterPFilled, IconSquareRoundedLetterQ, IconSquareRoundedLetterQFilled, IconSquareRoundedLetterR, IconSquareRoundedLetterRFilled, IconSquareRoundedLetterS, IconSquareRoundedLetterSFilled, IconSquareRoundedLetterT, IconSquareRoundedLetterTFilled, IconSquareRoundedLetterU, IconSquareRoundedLetterUFilled, IconSquareRoundedLetterV, IconSquareRoundedLetterVFilled, IconSquareRoundedLetterW, IconSquareRoundedLetterWFilled, IconSquareRoundedLetterX, IconSquareRoundedLetterXFilled, IconSquareRoundedLetterY, IconSquareRoundedLetterYFilled, IconSquareRoundedLetterZ, IconSquareRoundedLetterZFilled, IconSquareRoundedMinus, IconSquareRoundedMinus2, IconSquareRoundedMinusFilled, IconSquareRoundedNumber0, IconSquareRoundedNumber0Filled, IconSquareRoundedNumber1, IconSquareRoundedNumber1Filled, IconSquareRoundedNumber2, IconSquareRoundedNumber2Filled, IconSquareRoundedNumber3, IconSquareRoundedNumber3Filled, IconSquareRoundedNumber4, IconSquareRoundedNumber4Filled, IconSquareRoundedNumber5, IconSquareRoundedNumber5Filled, IconSquareRoundedNumber6, IconSquareRoundedNumber6Filled, IconSquareRoundedNumber7, IconSquareRoundedNumber7Filled, IconSquareRoundedNumber8, IconSquareRoundedNumber8Filled, IconSquareRoundedNumber9, IconSquareRoundedNumber9Filled, IconSquareRoundedPercentage, IconSquareRoundedPlus, IconSquareRoundedPlus2, IconSquareRoundedPlusFilled, IconSquareRoundedX, IconSquareRoundedXFilled, IconSquareToggle, IconSquareToggleHorizontal, IconSquareX, IconSquareXFilled, IconSquares, IconSquaresDiagonal, IconSquaresFilled, IconSquaresSelected, IconStack, IconStack2, IconStack2Filled, IconStack3, IconStack3Filled, IconStackBack, IconStackBackward, IconStackFilled, IconStackForward, IconStackFront, IconStackMiddle, IconStackPop, IconStackPush, IconStairs, IconStairsDown, IconStairsUp, IconStar, IconStarFilled, IconStarHalf, IconStarHalfFilled, IconStarOff, IconStars, IconStarsFilled, IconStarsOff, IconStatusChange, IconSteam, IconSteeringWheel, IconSteeringWheelFilled, IconSteeringWheelOff, IconStepInto, IconStepOut, IconStereoGlasses, IconStethoscope, IconStethoscopeOff, IconSticker, IconSticker2, IconStopwatch, IconStorm, IconStormOff, IconStretching, IconStretching2, IconStrikethrough, IconSubmarine, IconSubscript, IconSubtask, IconSubtitles, IconSubtitlesAi, IconSubtitlesEdit, IconSubtitlesOff, IconSum, IconSumOff, IconSun, IconSunElectricity, IconSunFilled, IconSunHigh, IconSunHighFilled, IconSunLow, IconSunLowFilled, IconSunMoon, IconSunOff, IconSunWind, IconSunglasses, IconSunglassesFilled, IconSunrise, IconSunriseFilled, IconSunset, IconSunset2, IconSunset2Filled, IconSunsetFilled, IconSuperscript, IconSvg, IconSwimming, IconSwipe, IconSwipeDown, IconSwipeDownFilled, IconSwipeLeft, IconSwipeLeftFilled, IconSwipeRight, IconSwipeRightFilled, IconSwipeUp, IconSwipeUpFilled, IconSwitch, IconSwitch2, IconSwitch3, IconSwitchHorizontal, IconSwitchVertical, IconSword, IconSwordOff, IconSwords, IconTable, IconTableAlias, IconTableColumn, IconTableDashed, IconTableDown, IconTableExport, IconTableFilled, IconTableHeart, IconTableImport, IconTableMinus, IconTableOff, IconTableOptions, IconTablePlus, IconTableRow, IconTableShare, IconTableShortcut, IconTableSpark, IconTag, IconTagFilled, IconTagMinus, IconTagOff, IconTagPlus, IconTagStarred, IconTags, IconTagsFilled, IconTagsOff, IconTallymark1, IconTallymark2, IconTallymark3, IconTallymark4, IconTallymarks, IconTank, IconTarget, IconTargetArrow, IconTargetOff, IconTax, IconTaxEuro, IconTaxPound, IconTeapot, IconTelescope, IconTelescopeOff, IconTemperature, IconTemperatureCelsius, IconTemperatureFahrenheit, IconTemperatureMinus, IconTemperatureMinusFilled, IconTemperatureOff, IconTemperaturePlus, IconTemperaturePlusFilled, IconTemperatureSnow, IconTemperatureSun, IconTemplate, IconTemplateFilled, IconTemplateOff, IconTent, IconTentOff, IconTerminal, IconTerminal2, IconTestPipe, IconTestPipe2, IconTestPipe2Filled, IconTestPipeOff, IconTex, IconTextCaption, IconTextColor, IconTextDecrease, IconTextDirectionLtr, IconTextDirectionRtl, IconTextGrammar, IconTextIncrease, IconTextOrientation, IconTextPlus, IconTextRecognition, IconTextResize, IconTextScan2, IconTextSize, IconTextSpellcheck, IconTextWrap, IconTextWrapColumn, IconTextWrapDisabled, IconTexture, IconTheater, IconThermometer, IconThumbDown, IconThumbDownFilled, IconThumbDownOff, IconThumbUp, IconThumbUpFilled, IconThumbUpOff, IconTicTac, IconTicket, IconTicketOff, IconTie, IconTilde, IconTiltShift, IconTiltShiftFilled, IconTiltShiftOff, IconTimeDuration0, IconTimeDuration10, IconTimeDuration15, IconTimeDuration30, IconTimeDuration45, IconTimeDuration5, IconTimeDuration60, IconTimeDuration90, IconTimeDurationOff, IconTimeline, IconTimelineEvent, IconTimelineEventExclamation, IconTimelineEventFilled, IconTimelineEventMinus, IconTimelineEventPlus, IconTimelineEventText, IconTimelineEventX, IconTimezone, IconTipJar, IconTipJarEuro, IconTipJarPound, IconTir, IconToggleLeft, IconToggleLeftFilled, IconToggleRight, IconToggleRightFilled, IconToiletPaper, IconToiletPaperOff, IconToml, IconTool, IconTools, IconToolsKitchen, IconToolsKitchen2, IconToolsKitchen2Off, IconToolsKitchen3, IconToolsKitchenOff, IconToolsOff, IconTooltip, IconTopologyBus, IconTopologyComplex, IconTopologyFull, IconTopologyFullHierarchy, IconTopologyRing, IconTopologyRing2, IconTopologyRing3, IconTopologyStar, IconTopologyStar2, IconTopologyStar3, IconTopologyStarRing, IconTopologyStarRing2, IconTopologyStarRing3, IconTorii, IconTornado, IconTournament, IconTower, IconTowerOff, IconTrack, IconTractor, IconTrademark, IconTrafficCone, IconTrafficConeOff, IconTrafficLights, IconTrafficLightsOff, IconTrain, IconTrainFilled, IconTransactionBitcoin, IconTransactionDollar, IconTransactionEuro, IconTransactionPound, IconTransactionRupee, IconTransactionYen, IconTransactionYuan, IconTransfer, IconTransferIn, IconTransferOut, IconTransferVertical, IconTransform, IconTransformFilled, IconTransformPoint, IconTransformPointBottomLeft, IconTransformPointBottomRight, IconTransformPointTopLeft, IconTransformPointTopRight, IconTransitionBottom, IconTransitionBottomFilled, IconTransitionLeft, IconTransitionLeftFilled, IconTransitionRight, IconTransitionRightFilled, IconTransitionTop, IconTransitionTopFilled, IconTrash, IconTrashFilled, IconTrashOff, IconTrashX, IconTrashXFilled, IconTreadmill, IconTree, IconTrees, IconTrekking, IconTrendingDown, IconTrendingDown2, IconTrendingDown3, IconTrendingUp, IconTrendingUp2, IconTrendingUp3, IconTriangle, IconTriangleFilled, IconTriangleInverted, IconTriangleInvertedFilled, IconTriangleMinus, IconTriangleMinus2, IconTriangleOff, IconTrianglePlus, IconTrianglePlus2, IconTriangleSquareCircle, IconTriangleSquareCircleFilled, IconTriangles, IconTrident, IconTrolley, IconTrolleyFilled, IconTrophy, IconTrophyFilled, IconTrophyOff, IconTrowel, IconTruck, IconTruckDelivery, IconTruckFilled, IconTruckLoading, IconTruckOff, IconTruckReturn, IconTxt, IconTypeface, IconTypography, IconTypographyOff, IconUTurnLeft, IconUTurnRight, IconUfo, IconUfoFilled, IconUfoOff, IconUhd, IconUmbrella, IconUmbrella2, IconUmbrellaClosed, IconUmbrellaClosed2, IconUmbrellaFilled, IconUmbrellaOff, IconUnderline, IconUniverse, IconUnlink, IconUpload, IconUrgent, IconUsb, IconUser, IconUserBitcoin, IconUserBolt, IconUserCancel, IconUserCheck, IconUserCircle, IconUserCode, IconUserCog, IconUserDollar, IconUserDown, IconUserEdit, IconUserExclamation, IconUserFilled, IconUserHeart, IconUserHexagon, IconUserMinus, IconUserOff, IconUserPause, IconUserPentagon, IconUserPin, IconUserPlus, IconUserQuestion, IconUserScan, IconUserScreen, IconUserSearch, IconUserShare, IconUserShield, IconUserSquare, IconUserSquareRounded, IconUserStar, IconUserUp, IconUserX, IconUsers, IconUsersGroup, IconUsersMinus, IconUsersPlus, IconUvIndex, IconUxCircle, IconVaccine, IconVaccineBottle, IconVaccineBottleOff, IconVaccineOff, IconVacuumCleaner, IconVariable, IconVariableMinus, IconVariableOff, IconVariablePlus, IconVector, IconVectorBezier, IconVectorBezier2, IconVectorBezierArc, IconVectorBezierCircle, IconVectorOff, IconVectorSpline, IconVectorTriangle, IconVectorTriangleOff, IconVenus, IconVersions, IconVersionsFilled, IconVersionsOff, IconVideo, IconVideoFilled, IconVideoMinus, IconVideoMinusFilled, IconVideoOff, IconVideoPlus, IconVideoPlusFilled, IconView360, IconView360Arrow, IconView360Number, IconView360Off, IconViewfinder, IconViewfinderOff, IconViewportNarrow, IconViewportShort, IconViewportTall, IconViewportWide, IconVinyl, IconVip, IconVipOff, IconVirus, IconVirusOff, IconVirusSearch, IconVocabulary, IconVocabularyOff, IconVolcano, IconVolume, IconVolume2, IconVolume3, IconVolume4, IconVolumeOff, IconVs, IconWalk, IconWall, IconWallOff, IconWallet, IconWalletOff, IconWallpaper, IconWallpaperOff, IconWand, IconWandOff, IconWash, IconWashDry, IconWashDry1, IconWashDry2, IconWashDry3, IconWashDryA, IconWashDryDip, IconWashDryF, IconWashDryFlat, IconWashDryHang, IconWashDryOff, IconWashDryP, IconWashDryShade, IconWashDryW, IconWashDryclean, IconWashDrycleanOff, IconWashEco, IconWashGentle, IconWashHand, IconWashMachine, IconWashOff, IconWashPress, IconWashTemperature1, IconWashTemperature2, IconWashTemperature3, IconWashTemperature4, IconWashTemperature5, IconWashTemperature6, IconWashTumbleDry, IconWashTumbleOff, IconWaterpolo, IconWaveSawTool, IconWaveSine, IconWaveSquare, IconWavesElectricity, IconWebhook, IconWebhookOff, IconWeight, IconWheat, IconWheatOff, IconWheel, IconWheelchair, IconWheelchairOff, IconWhirl, IconWhisk, IconWifi, IconWifi0, IconWifi1, IconWifi2, IconWifiOff, IconWind, IconWindElectricity, IconWindOff, IconWindmill, IconWindmillFilled, IconWindmillOff, IconWindow, IconWindowMaximize, IconWindowMinimize, IconWindowOff, IconWindsock, IconWindsockFilled, IconWiper, IconWiperWash, IconWoman, IconWomanFilled, IconWood, IconWorld, IconWorldBolt, IconWorldCancel, IconWorldCheck, IconWorldCode, IconWorldCog, IconWorldDollar, IconWorldDown, IconWorldDownload, IconWorldExclamation, IconWorldHeart, IconWorldLatitude, IconWorldLongitude, IconWorldMinus, IconWorldOff, IconWorldPause, IconWorldPin, IconWorldPlus, IconWorldQuestion, IconWorldSearch, IconWorldShare, IconWorldStar, IconWorldUp, IconWorldUpload, IconWorldWww, IconWorldX, IconWreckingBall, IconWriting, IconWritingFilled, IconWritingOff, IconWritingSign, IconWritingSignFilled, IconWritingSignOff, IconX, IconXPowerY, IconXboxA, IconXboxAFilled, IconXboxB, IconXboxBFilled, IconXboxX, IconXboxXFilled, IconXboxY, IconXboxYFilled, IconXd, IconXxx, IconYinYang, IconYinYangFilled, IconYoga, IconZeppelin, IconZeppelinFilled, IconZeppelinOff, IconZip, IconZodiacAquarius, IconZodiacAries, IconZodiacCancer, IconZodiacCapricorn, IconZodiacGemini, IconZodiacLeo, IconZodiacLibra, IconZodiacPisces, IconZodiacSagittarius, IconZodiacScorpio, IconZodiacTaurus, IconZodiacVirgo, IconZoom, IconZoomCancel, IconZoomCancelFilled, IconZoomCheck, IconZoomCheckFilled, IconZoomCode, IconZoomCodeFilled, IconZoomExclamation, IconZoomExclamationFilled, IconZoomFilled, IconZoomIn, IconZoomInArea, IconZoomInAreaFilled, IconZoomInFilled, IconZoomMoney, IconZoomMoneyFilled, IconZoomOut, IconZoomOutArea, IconZoomOutAreaFilled, IconZoomOutFilled, IconZoomPan, IconZoomPanFilled, IconZoomQuestion, IconZoomQuestionFilled, IconZoomReplace, IconZoomReset, IconZoomScan, IconZoomScanFilled, IconZzz, IconZzzOff, createReactComponent, index as icons, iconsList };
export type { Icon, IconNode, IconProps, TablerIcon };
